/* Generated by Cython 3.2.4 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "depends": [
            "/usr/include/libpq-fe.h",
            "/usr/include/pg_config.h",
            "/usr/include/stdio.h"
        ],
        "include_dirs": [
            "/usr/include"
        ],
        "libraries": [
            "pq"
        ],
        "library_dirs": [
            "/usr/lib"
        ],
        "name": "psycopg_c._psycopg",
        "sources": [
            "psycopg_c/_psycopg.pyx",
            "psycopg_c/types/numutils.c"
        ]
    },
    "module_name": "psycopg_c._psycopg"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
/* InitLimitedAPI */
#if defined(Py_LIMITED_API)
  #if !defined(CYTHON_LIMITED_API)
  #define CYTHON_LIMITED_API 1
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef _MSC_VER
  #pragma message ("Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.")
  #else
  #warning Limited API usage is enabled with 'CYTHON_LIMITED_API' but 'Py_LIMITED_API' does not define a Python target version. Consider setting 'Py_LIMITED_API' instead.
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x03080000
    #error Cython requires Python 3.8+.
#else
#define __PYX_ABI_VERSION "3_2_4"
#define CYTHON_HEX_VERSION 0x030204F0
#define CYTHON_FUTURE_DIVISION 1
/* CModulePreamble */
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 1
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 1
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PYPY_VERSION_NUM >= 0x07030C00)
  #endif
  #undef CYTHON_USE_AM_SEND
  #define CYTHON_USE_AM_SEND 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC (PYPY_VERSION_NUM >= 0x07031100)
  #endif
  #undef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 0
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_ASSUME_SAFE_SIZE
  #define CYTHON_ASSUME_SAFE_SIZE 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #undef CYTHON_USE_SYS_MONITORING
  #define CYTHON_USE_SYS_MONITORING 0
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND (__PYX_LIMITED_VERSION_HEX >= 0x030A0000)
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
  #ifndef CYTHON_USE_FREELISTS
  #define CYTHON_USE_FREELISTS 1
  #endif
  #undef CYTHON_IMMORTAL_CONSTANTS
  #define CYTHON_IMMORTAL_CONSTANTS 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #ifdef Py_GIL_DISABLED
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 1
  #else
    #define CYTHON_COMPILING_IN_CPYTHON_FREETHREADING 0
  #endif
  #if PY_VERSION_HEX < 0x030A0000
    #undef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #elif !defined(CYTHON_USE_TYPE_SLOTS)
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLIST_INTERNALS)
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 1
  #elif !defined(CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)
    #define CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_ASSUME_SAFE_SIZE
    #define CYTHON_ASSUME_SAFE_SIZE 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL 0
  #elif !defined(CYTHON_FAST_GIL)
    #define CYTHON_FAST_GIL (PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #ifndef CYTHON_USE_SYS_MONITORING
    #define CYTHON_USE_SYS_MONITORING (PY_VERSION_HEX >= 0x030d00B1)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #ifndef CYTHON_USE_AM_SEND
    #define CYTHON_USE_AM_SEND 1
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5 && !CYTHON_USE_MODULE_STATE)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
  #ifndef CYTHON_USE_FREELISTS
    #define CYTHON_USE_FREELISTS (!CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
  #if defined(CYTHON_IMMORTAL_CONSTANTS) && PY_VERSION_HEX < 0x030C0000
    #undef CYTHON_IMMORTAL_CONSTANTS
    #define CYTHON_IMMORTAL_CONSTANTS 0  // definitely won't work
  #elif !defined(CYTHON_IMMORTAL_CONSTANTS)
    #define CYTHON_IMMORTAL_CONSTANTS (PY_VERSION_HEX >= 0x030C0000 && !CYTHON_USE_MODULE_STATE && CYTHON_COMPILING_IN_CPYTHON_FREETHREADING)
  #endif
#endif
#ifndef CYTHON_COMPRESS_STRINGS
  #define CYTHON_COMPRESS_STRINGS 1
#endif
#ifndef CYTHON_FAST_PYCCALL
#define CYTHON_FAST_PYCCALL  CYTHON_FAST_PYCALL
#endif
#ifndef CYTHON_VECTORCALL
#if CYTHON_COMPILING_IN_LIMITED_API
#define CYTHON_VECTORCALL  (__PYX_LIMITED_VERSION_HEX >= 0x030C0000)
#else
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL)
#endif
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#include <stdint.h>
typedef uintptr_t  __pyx_uintptr_t;
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifndef Py_UNREACHABLE
  #define Py_UNREACHABLE()  assert(0); abort()
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

/* CInitCode */
#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* PythonCompatibility */
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#define __Pyx_BUILTIN_MODULE_NAME "builtins"
#define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    #ifndef CO_OPTIMIZED
    static int CO_OPTIMIZED;
    #endif
    #ifndef CO_NEWLOCALS
    static int CO_NEWLOCALS;
    #endif
    #ifndef CO_VARARGS
    static int CO_VARARGS;
    #endif
    #ifndef CO_VARKEYWORDS
    static int CO_VARKEYWORDS;
    #endif
    #ifndef CO_ASYNC_GENERATOR
    static int CO_ASYNC_GENERATOR;
    #endif
    #ifndef CO_GENERATOR
    static int CO_GENERATOR;
    #endif
    #ifndef CO_COROUTINE
    static int CO_COROUTINE;
    #endif
#else
    #ifndef CO_COROUTINE
      #define CO_COROUTINE 0x80
    #endif
    #ifndef CO_ASYNC_GENERATOR
      #define CO_ASYNC_GENERATOR 0x200
    #endif
#endif
static int __Pyx_init_co_variables(void);
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef Py_TPFLAGS_IMMUTABLETYPE
  #define Py_TPFLAGS_IMMUTABLETYPE (1UL << 8)
#endif
#ifndef Py_TPFLAGS_DISALLOW_INSTANTIATION
  #define Py_TPFLAGS_DISALLOW_INSTANTIATION (1UL << 7)
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#ifndef METH_FASTCALL
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #if PY_VERSION_HEX >= 0x030d00A4
  #  define __Pyx_PyCFunctionFast PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords PyCFunctionFastWithKeywords
  #else
  #  define __Pyx_PyCFunctionFast _PyCFunctionFast
  #  define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
  #endif
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_VERSION_HEX >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void (*cfunc)(void)) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if PY_VERSION_HEX < 0x03090000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000)
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) GraalPyFrame_SetLineNumber((frame), (lineno))
#elif CYTHON_COMPILING_IN_GRAAL
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) _PyFrame_SetLineNumber((frame), (lineno))
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#endif
#if CYTHON_USE_MODULE_STATE
static CYTHON_INLINE void *__Pyx__PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#define __Pyx_PyModule_GetState(o) (__pyx_mstatetype *)__Pyx__PyModule_GetState(o)
#else
#define __Pyx_PyModule_GetState(op) ((void)op,__pyx_mstate_global)
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE((PyObject *) obj), name, func_ctype)
#define __Pyx_PyObject_TryGetSlot(obj, name, func_ctype) __Pyx_PyType_TryGetSlot(Py_TYPE(obj), name, func_ctype)
#define __Pyx_PyObject_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#define __Pyx_PyObject_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSubSlot(Py_TYPE(obj), sub, name, func_ctype)
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype) __Pyx_PyType_GetSlot(type, name, func_ctype)
  #define __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype) (((type)->sub) ? ((type)->sub->name) : NULL)
  #define __Pyx_PyType_TryGetSubSlot(type, sub, name, func_ctype) __Pyx_PyType_GetSubSlot(type, sub, name, func_ctype)
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
  #define __Pyx_PyType_TryGetSlot(type, name, func_ctype)\
    ((__PYX_LIMITED_VERSION_HEX >= 0x030A0000 ||\
     (PyType_GetFlags(type) & Py_TPFLAGS_HEAPTYPE) || __Pyx_get_runtime_version() >= 0x030A0000) ?\
     __Pyx_PyType_GetSlot(type, name, func_ctype) : NULL)
  #define __Pyx_PyType_GetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_GetSlot(obj, name, func_ctype)
  #define __Pyx_PyType_TryGetSubSlot(obj, sub, name, func_ctype) __Pyx_PyType_TryGetSlot(obj, name, func_ctype)
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
#define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
#endif
#define __Pyx_PyObject_GetIterNextFunc(iterator)  __Pyx_PyObject_GetSlot(iterator, tp_iternext, iternextfunc)
#if CYTHON_USE_TYPE_SPECS
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#else
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains)
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && PyUnstable_Object_IsUniquelyReferenced(obj)) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#elif CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
enum __Pyx_ReferenceSharing {
  __Pyx_ReferenceSharing_DefinitelyUnique, // We created it so we know it's unshared - no need to check
  __Pyx_ReferenceSharing_OwnStrongReference,
  __Pyx_ReferenceSharing_FunctionArgument,
  __Pyx_ReferenceSharing_SharedReference, // Never trust it to be unshared because it's a global or similar
};
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && PY_VERSION_HEX >= 0x030E0000
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing)\
    (sharing == __Pyx_ReferenceSharing_DefinitelyUnique ? 1 :\
      (sharing == __Pyx_ReferenceSharing_FunctionArgument ? PyUnstable_Object_IsUniqueReferencedTemporary(o) :\
      (sharing == __Pyx_ReferenceSharing_OwnStrongReference ? PyUnstable_Object_IsUniquelyReferenced(o) : 0)))
#elif (CYTHON_COMPILING_IN_CPYTHON && !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING) || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)sharing), Py_REFCNT(o) == 1)
#else
#define __Pyx_IS_UNIQUELY_REFERENCED(o, sharing) (((void)o), ((void)sharing), 0)
#endif
#if CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyList_GetItemRef(o, i) (likely((i) >= 0) ? PySequence_GetItem(o, i) : (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
  #else
    #define __Pyx_PyList_GetItemRef(o, i) PySequence_ITEM(o, i)
  #endif
#elif CYTHON_COMPILING_IN_LIMITED_API || !CYTHON_ASSUME_SAFE_MACROS
  #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    #define __Pyx_PyList_GetItemRef(o, i) PyList_GetItemRef(o, i)
  #else
    #define __Pyx_PyList_GetItemRef(o, i) __Pyx_XNewRef(PyList_GetItem(o, i))
  #endif
#else
  #define __Pyx_PyList_GetItemRef(o, i) __Pyx_NewRef(PyList_GET_ITEM(o, i))
#endif
#if CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS && !CYTHON_COMPILING_IN_LIMITED_API && CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) (__Pyx_IS_UNIQUELY_REFERENCED(o, unsafe_shared) ?\
    __Pyx_NewRef(PyList_GET_ITEM(o, i)) : __Pyx_PyList_GetItemRef(o, i))
#else
  #define __Pyx_PyList_GetItemRefFast(o, i, unsafe_shared) __Pyx_PyList_GetItemRef(o, i)
#endif
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyDict_GetItemRef(dict, key, result) PyDict_GetItemRef(dict, key, result)
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyObject_GetItem(dict, key);
  if (*result == NULL) {
    if (PyErr_ExceptionMatches(PyExc_KeyError)) {
      PyErr_Clear();
      return 0;
    }
    return -1;
  }
  return 1;
}
#else
static CYTHON_INLINE int __Pyx_PyDict_GetItemRef(PyObject *dict, PyObject *key, PyObject **result) {
  *result = PyDict_GetItemWithError(dict, key);
  if (*result == NULL) {
    return PyErr_Occurred() ? -1 : 0;
  }
  Py_INCREF(*result);
  return 1;
}
#endif
#if defined(CYTHON_DEBUG_VISIT_CONST) && CYTHON_DEBUG_VISIT_CONST
  #define __Pyx_VISIT_CONST(obj)  Py_VISIT(obj)
#else
  #define __Pyx_VISIT_CONST(obj)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GET_ITEM(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GET_ITEM(o, i)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_ITEM(o, i) PyTuple_GetItem(o, i)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyList_GET_ITEM(o, i) PyList_GetItem(o, i)
#endif
#if CYTHON_ASSUME_SAFE_SIZE
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GET_LENGTH(o)
#else
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
  #define __Pyx_PyUnicode_GET_LENGTH(o) PyUnicode_GetLength(o)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_InternFromString)
  #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
#endif
#define __Pyx_PyLong_FromHash_t PyLong_FromSsize_t
#define __Pyx_PyLong_AsHash_t   __Pyx_PyIndex_AsSsize_t
#if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
    #define __Pyx_PySendResult PySendResult
#else
    typedef enum {
        PYGEN_RETURN = 0,
        PYGEN_ERROR = -1,
        PYGEN_NEXT = 1,
    } __Pyx_PySendResult;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030A00A3
  typedef __Pyx_PySendResult (*__Pyx_pyiter_sendfunc)(PyObject *iter, PyObject *value, PyObject **result);
#else
  #define __Pyx_pyiter_sendfunc sendfunc
#endif
#if !CYTHON_USE_AM_SEND
#define __PYX_HAS_PY_AM_SEND 0
#elif __PYX_LIMITED_VERSION_HEX >= 0x030A0000
#define __PYX_HAS_PY_AM_SEND 1
#else
#define __PYX_HAS_PY_AM_SEND 2  // our own backported implementation
#endif
#if __PYX_HAS_PY_AM_SEND < 2
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#else
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
        __Pyx_pyiter_sendfunc am_send;
    } __Pyx_PyAsyncMethodsStruct;
    #define __Pyx_SlotTpAsAsync(s) ((PyAsyncMethods*)(s))
#endif
#if CYTHON_USE_AM_SEND && PY_VERSION_HEX < 0x030A00F0
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (1UL << 21)
#else
    #define __Pyx_TPFLAGS_HAVE_AM_SEND (0)
#endif
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyInterpreterState_Get() PyInterpreterState_Get()
#else
#define __Pyx_PyInterpreterState_Get() PyThreadState_Get()->interp
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030A0000
#ifdef __cplusplus
extern "C"
#endif
PyAPI_FUNC(void *) PyMem_Calloc(size_t nelem, size_t elsize);
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_init_co_variable(PyObject *inspect, const char* name, int *write_to) {
    int value;
    PyObject *py_value = PyObject_GetAttrString(inspect, name);
    if (!py_value) return 0;
    value = (int) PyLong_AsLong(py_value);
    Py_DECREF(py_value);
    *write_to = value;
    return value != -1 || !PyErr_Occurred();
}
static int __Pyx_init_co_variables(void) {
    PyObject *inspect;
    int result;
    inspect = PyImport_ImportModule("inspect");
    result =
#if !defined(CO_OPTIMIZED)
        __Pyx_init_co_variable(inspect, "CO_OPTIMIZED", &CO_OPTIMIZED) &&
#endif
#if !defined(CO_NEWLOCALS)
        __Pyx_init_co_variable(inspect, "CO_NEWLOCALS", &CO_NEWLOCALS) &&
#endif
#if !defined(CO_VARARGS)
        __Pyx_init_co_variable(inspect, "CO_VARARGS", &CO_VARARGS) &&
#endif
#if !defined(CO_VARKEYWORDS)
        __Pyx_init_co_variable(inspect, "CO_VARKEYWORDS", &CO_VARKEYWORDS) &&
#endif
#if !defined(CO_ASYNC_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_ASYNC_GENERATOR", &CO_ASYNC_GENERATOR) &&
#endif
#if !defined(CO_GENERATOR)
        __Pyx_init_co_variable(inspect, "CO_GENERATOR", &CO_GENERATOR) &&
#endif
#if !defined(CO_COROUTINE)
        __Pyx_init_co_variable(inspect, "CO_COROUTINE", &CO_COROUTINE) &&
#endif
        1;
    Py_DECREF(inspect);
    return result ? 0 : -1;
}
#else
static int __Pyx_init_co_variables(void) {
    return 0;  // It's a limited API-only feature
}
#endif

/* MathInitCode */
#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #ifndef _USE_MATH_DEFINES
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#ifndef CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#define CYTHON_CLINE_IN_TRACEBACK_RUNTIME 0
#endif
#ifndef CYTHON_CLINE_IN_TRACEBACK
#define CYTHON_CLINE_IN_TRACEBACK CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#endif
#if CYTHON_CLINE_IN_TRACEBACK
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; __pyx_clineno = __LINE__; (void) __pyx_clineno; }
#else
#define __PYX_MARK_ERR_POS(f_index, lineno)  { __pyx_filename = __pyx_f[f_index]; (void) __pyx_filename; __pyx_lineno = lineno; (void) __pyx_lineno; (void) __pyx_clineno; }
#endif
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__psycopg_c___psycopg
#define __PYX_HAVE_API__psycopg_c___psycopg
/* Early includes */

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
    typedef signed pid_t;
#else
    #include <fcntl.h>
#endif
    
#include "stdio.h"
#include "pg_config.h"
#include "libpq-fe.h"

/* Hack to allow the use of old libpq versions */
#if PG_VERSION_NUM < 100000
#define PQencryptPasswordConn(conn, passwd, user, algorithm) NULL
#endif

#if PG_VERSION_NUM < 120000
#define PQhostaddr(conn) NULL
#endif

#if PG_VERSION_NUM < 140000
#define PGRES_PIPELINE_SYNC 10
#define PGRES_PIPELINE_ABORTED 11
typedef enum {
    PQ_PIPELINE_OFF,
    PQ_PIPELINE_ON,
    PQ_PIPELINE_ABORTED
} PGpipelineStatus;
#define PQpipelineStatus(conn) PQ_PIPELINE_OFF
#define PQenterPipelineMode(conn) 0
#define PQexitPipelineMode(conn) 1
#define PQpipelineSync(conn) 0
#define PQsendFlushRequest(conn) 0
#define PQsetTraceFlags(conn, stream) do {} while (0)
#endif

#if PG_VERSION_NUM < 160000
#define PQconnectionUsedGSSAPI(conn) 0
#endif

#if PG_VERSION_NUM < 170000
typedef struct pg_cancel_conn PGcancelConn;
#define PQchangePassword(conn, user, passwd) NULL
#define PQclosePrepared(conn, name) NULL
#define PQclosePortal(conn, name) NULL
#define PQsendClosePrepared(conn, name) 0
#define PQsendClosePortal(conn, name) 0
#define PQcancelCreate(conn) NULL
#define PQcancelStart(cancelConn) 0
#define PQcancelBlocking(cancelConn) 0
#define PQcancelPoll(cancelConn) CONNECTION_OK
#define PQcancelStatus(cancelConn) 0
#define PQcancelSocket(cancelConn) -1
#define PQcancelErrorMessage(cancelConn) NULL
#define PQcancelReset(cancelConn) 0
#define PQcancelFinish(cancelConn) 0
#define PQsetChunkedRowsMode(conn, chunkSize) 0
#endif

#if PG_VERSION_NUM < 180000
#define PQfullProtocolVersion(conn) 0
#endif


/* Include this early to avoid a warning about redefined ARRAYSIZE in winnt.h */
#ifdef MS_WINDOWS
#define WIN32_LEAN_AND_MEAN
#include <winsock2.h>
#endif

#ifndef ARRAYSIZE
#define ARRAYSIZE(a) ((sizeof(a) / sizeof(*(a))))
#endif
    
#include <string.h>
#include <stdio.h>
#include <stdint.h>


// "License": Public Domain
// I, Mathias Panzenböck, place this file hereby into the public domain.
// Use it at your own risk for whatever you like.
// In case there are jurisdictions that don't support putting things in the
// public domain you can also consider it to be "dual licensed" under the BSD,
// MIT and Apache licenses, if you want to.
// This code is trivial anyway. Consider it an example on how to get the endian
// conversion functions on different platforms.

#ifndef PORTABLE_ENDIAN_H__
#define PORTABLE_ENDIAN_H__

#if (defined(_WIN16) || defined(_WIN32) || defined(_WIN64)) && !defined(__WINDOWS__)

#   define __WINDOWS__

#endif

#if defined(__linux__) || defined(__CYGWIN__)

#   include <endian.h>

#elif defined(__APPLE__)

#   include <libkern/OSByteOrder.h>

#   define htobe16(x) OSSwapHostToBigInt16(x)
#   define htole16(x) OSSwapHostToLittleInt16(x)
#   define be16toh(x) OSSwapBigToHostInt16(x)
#   define le16toh(x) OSSwapLittleToHostInt16(x)

#   define htobe32(x) OSSwapHostToBigInt32(x)
#   define htole32(x) OSSwapHostToLittleInt32(x)
#   define be32toh(x) OSSwapBigToHostInt32(x)
#   define le32toh(x) OSSwapLittleToHostInt32(x)

#   define htobe64(x) OSSwapHostToBigInt64(x)
#   define htole64(x) OSSwapHostToLittleInt64(x)
#   define be64toh(x) OSSwapBigToHostInt64(x)
#   define le64toh(x) OSSwapLittleToHostInt64(x)

#   define __BYTE_ORDER    BYTE_ORDER
#   define __BIG_ENDIAN    BIG_ENDIAN
#   define __LITTLE_ENDIAN LITTLE_ENDIAN
#   define __PDP_ENDIAN    PDP_ENDIAN

#elif defined(__OpenBSD__) ||  defined(__NetBSD__) || defined(__FreeBSD__) \
    || defined(__DragonFly__)

#   include <sys/endian.h>

/* For functions still missing, try to substitute 'historic' OpenBSD names */
#ifndef be16toh
#   define be16toh(x) betoh16(x)
#endif
#ifndef le16toh
#   define le16toh(x) letoh16(x)
#endif
#ifndef be32toh
#   define be32toh(x) betoh32(x)
#endif
#ifndef le32toh
#   define le32toh(x) letoh32(x)
#endif
#ifndef be64toh
#   define be64toh(x) betoh64(x)
#endif
#ifndef le64toh
#   define le64toh(x) letoh64(x)
#endif

#elif defined(__WINDOWS__)

#   include <winsock2.h>
#       ifndef _MSC_VER
#       include <sys/param.h>
#       endif

#   if BYTE_ORDER == LITTLE_ENDIAN

#       define htobe16(x) htons(x)
#       define htole16(x) (x)
#       define be16toh(x) ntohs(x)
#       define le16toh(x) (x)

#       define htobe32(x) htonl(x)
#       define htole32(x) (x)
#       define be32toh(x) ntohl(x)
#       define le32toh(x) (x)

#       define htobe64(x) htonll(x)
#       define htole64(x) (x)
#       define be64toh(x) ntohll(x)
#       define le64toh(x) (x)

#   elif BYTE_ORDER == BIG_ENDIAN

        /* that would be xbox 360 */
#       define htobe16(x) (x)
#       define htole16(x) __builtin_bswap16(x)
#       define be16toh(x) (x)
#       define le16toh(x) __builtin_bswap16(x)

#       define htobe32(x) (x)
#       define htole32(x) __builtin_bswap32(x)
#       define be32toh(x) (x)
#       define le32toh(x) __builtin_bswap32(x)

#       define htobe64(x) (x)
#       define htole64(x) __builtin_bswap64(x)
#       define be64toh(x) (x)
#       define le64toh(x) __builtin_bswap64(x)

#   else

#       error byte order not supported

#   endif

#   define __BYTE_ORDER    BYTE_ORDER
#   define __BIG_ENDIAN    BIG_ENDIAN
#   define __LITTLE_ENDIAN LITTLE_ENDIAN
#   define __PDP_ENDIAN    PDP_ENDIAN

#elif defined(__sun)
#   include <endian.h>
#else

#   error platform not supported

#endif

#endif
    

/* handle chars to (un)escape in text copy representation */
/* '', '	', '
', '', '', '
', '\' */

/* Escaping chars */
static const char copy_escape_lut[] = {
  0,   0,   0,   0,   0,   0,   0,   0,  98, 116, 110, 118, 102, 114,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,  92,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
  0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,   0,
};

/* Conversion of escaped to unescaped chars */
static const char copy_unescape_lut[] = {
  0,   1,   2,   3,   4,   5,   6,   7,   8,   9,  10,  11,  12,  13,  14,  15,
 16,  17,  18,  19,  20,  21,  22,  23,  24,  25,  26,  27,  28,  29,  30,  31,
 32,  33,  34,  35,  36,  37,  38,  39,  40,  41,  42,  43,  44,  45,  46,  47,
 48,  49,  50,  51,  52,  53,  54,  55,  56,  57,  58,  59,  60,  61,  62,  63,
 64,  65,  66,  67,  68,  69,  70,  71,  72,  73,  74,  75,  76,  77,  78,  79,
 80,  81,  82,  83,  84,  85,  86,  87,  88,  89,  90,  91,  92,  93,  94,  95,
 96,  97,   8,  99, 100, 101,  12, 103, 104, 105, 106, 107, 108, 109,  10, 111,
112, 113,  13, 115,   9, 117,  11, 119, 120, 121, 122, 123, 124, 125, 126, 127,
128, 129, 130, 131, 132, 133, 134, 135, 136, 137, 138, 139, 140, 141, 142, 143,
144, 145, 146, 147, 148, 149, 150, 151, 152, 153, 154, 155, 156, 157, 158, 159,
160, 161, 162, 163, 164, 165, 166, 167, 168, 169, 170, 171, 172, 173, 174, 175,
176, 177, 178, 179, 180, 181, 182, 183, 184, 185, 186, 187, 188, 189, 190, 191,
192, 193, 194, 195, 196, 197, 198, 199, 200, 201, 202, 203, 204, 205, 206, 207,
208, 209, 210, 211, 212, 213, 214, 215, 216, 217, 218, 219, 220, 221, 222, 223,
224, 225, 226, 227, 228, 229, 230, 231, 232, 233, 234, 235, 236, 237, 238, 239,
240, 241, 242, 243, 244, 245, 246, 247, 248, 249, 250, 251, 252, 253, 254, 255,
};
    

    #if PY_MAJOR_VERSION <= 2
    #define PyDict_GetItemWithError _PyDict_GetItemWithError
    #endif

    #if __PYX_LIMITED_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int
    __Pyx_CAPI_PyDict_GetItemStringRef(PyObject *mp, const char *key, PyObject **result)
    {
        int res;
        PyObject *key_obj = PyUnicode_FromString(key);
        if (key_obj == NULL) {
            *result = NULL;
            return -1;
        }
        res = __Pyx_PyDict_GetItemRef(mp, key_obj, result);
        Py_DECREF(key_obj);
        return res;
    }
    #else
    #define __Pyx_CAPI_PyDict_GetItemStringRef PyDict_GetItemStringRef
    #endif
    #if PY_VERSION_HEX < 0x030d0000 || (CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030F0000)
    static CYTHON_INLINE int
    __Pyx_CAPI_PyDict_SetDefaultRef(PyObject *d, PyObject *key, PyObject *default_value,
                        PyObject **result)
    {
        PyObject *value;
        if (__Pyx_PyDict_GetItemRef(d, key, &value) < 0) {
            // get error
            if (result) {
                *result = NULL;
            }
            return -1;
        }
        if (value != NULL) {
            // present
            if (result) {
                *result = value;
            }
            else {
                Py_DECREF(value);
            }
            return 1;
        }

        // missing: set the item
        if (PyDict_SetItem(d, key, default_value) < 0) {
            // set error
            if (result) {
                *result = NULL;
            }
            return -1;
        }
        if (result) {
            Py_INCREF(default_value);
            *result = default_value;
        }
        return 0;
    }
    #else
    #define __Pyx_CAPI_PyDict_SetDefaultRef PyDict_SetDefaultRef
    #endif
    

    #if __PYX_LIMITED_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE PyObject *
    __Pyx_CAPI_PyList_GetItemRef(PyObject *list, Py_ssize_t index)
    {
        PyObject *item = PyList_GetItem(list, index);
        Py_XINCREF(item);
        return item;
    }
    #else
    #define __Pyx_CAPI_PyList_GetItemRef PyList_GetItemRef
    #endif

    #if CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int
    __Pyx_CAPI_PyList_Extend(PyObject *list, PyObject *iterable)
    {
        return PyList_SetSlice(list, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, iterable);
    }

    static CYTHON_INLINE int
    __Pyx_CAPI_PyList_Clear(PyObject *list)
    {
        return PyList_SetSlice(list, 0, PY_SSIZE_T_MAX, NULL);
    }
    #else
    #define __Pyx_CAPI_PyList_Extend PyList_Extend
    #define __Pyx_CAPI_PyList_Clear PyList_Clear
    #endif
    

#if defined(HAVE_POLL) && !defined(HAVE_BROKEN_POLL)

#if defined(HAVE_POLL_H)
#include <poll.h>
#elif defined(HAVE_SYS_POLL_H)
#include <sys/poll.h>
#endif

#else  /* no poll available */

#ifdef MS_WINDOWS
#include <winsock2.h>
#else
#include <sys/select.h>
#endif

#endif  /* HAVE_POLL */

#define SELECT_EV_READ 1
#define SELECT_EV_WRITE 2
#define CWAIT_SELECT_ERROR -1
#define CWAIT_SOCKET_ERROR -2

#define SEC_TO_MS 1000
#define SEC_TO_US (1000 * 1000)

/* Use select to wait for readiness on fileno.
 *
 * - Return SELECT_EV_* if the file is ready
 * - Return SELECT_EV_NONE on timeout
 * - Return CWAIT_SELECT_ERROR (and set an exception) on error.
 * - Return CWAIT_SOCKET_ERROR on poll success but fd error.
 *
 * The wisdom of this function comes from:
 *
 * - PostgreSQL libpq (see src/interfaces/libpq/fe-misc.c)
 * - Python select module (see Modules/selectmodule.c)
 */
static int
wait_c_impl(int fileno, int wait, float timeout)
{
    int select_rv;
    int rv = CWAIT_SELECT_ERROR;

#if defined(HAVE_POLL) && !defined(HAVE_BROKEN_POLL)

    struct pollfd input_fd;
    int timeout_ms;

    input_fd.fd = fileno;
    input_fd.events = POLLERR;
    input_fd.revents = 0;

    if (wait & SELECT_EV_READ) { input_fd.events |= POLLIN; }
    if (wait & SELECT_EV_WRITE) { input_fd.events |= POLLOUT; }

    if (timeout < 0.0) {
        timeout_ms = -1;
    } else {
        timeout_ms = (int)(timeout * SEC_TO_MS);
    }

retry_eintr:

    Py_BEGIN_ALLOW_THREADS
    errno = 0;
    select_rv = poll(&input_fd, 1, timeout_ms);
    Py_END_ALLOW_THREADS

    /* The grace of PEP 475 */
    if (errno == EINTR) {
        goto retry_eintr;
    }

    if (PyErr_CheckSignals()) { goto finally; }
    if (select_rv < 0) { goto error; }  /* poll error */

    rv = 0;  /* success, maybe with timeout */
    if (select_rv >= 0) {
        if (input_fd.revents & POLLIN) { rv |= SELECT_EV_READ; }
        if (input_fd.revents & POLLOUT) { rv |= SELECT_EV_WRITE; }
        if (!rv && (input_fd.revents & ~(POLLIN | POLLOUT))) {
            rv = CWAIT_SOCKET_ERROR;
        }
    }

#else

    fd_set ifds;
    fd_set ofds;
    fd_set efds;
    struct timeval tv, *tvptr;

#ifndef MS_WINDOWS
    if (fileno >= 1024) {
        PyErr_SetString(
            PyExc_ValueError,  /* same exception of Python's 'select.select()' */
            "connection file descriptor out of range for 'select()'");
        return CWAIT_SELECT_ERROR;
    }
#endif

    FD_ZERO(&ifds);
    FD_ZERO(&ofds);
    FD_ZERO(&efds);

    if (wait & SELECT_EV_READ) { FD_SET(fileno, &ifds); }
    if (wait & SELECT_EV_WRITE) { FD_SET(fileno, &ofds); }
    FD_SET(fileno, &efds);

    /* Compute appropriate timeout interval */
    if (timeout < 0.0) {
        tvptr = NULL;
    }
    else {
        tv.tv_sec = (int)timeout;
        tv.tv_usec = (int)((long)(timeout * SEC_TO_US) % SEC_TO_US);
        tvptr = &tv;
    }

retry_eintr:

    Py_BEGIN_ALLOW_THREADS
    errno = 0;
    select_rv = select(fileno + 1, &ifds, &ofds, &efds, tvptr);
    Py_END_ALLOW_THREADS

    /* The grace of PEP 475 */
    if (errno == EINTR) {
        goto retry_eintr;
    }

    if (PyErr_CheckSignals()) { goto finally; }
    if (select_rv < 0) { goto error; }  /* select error */

    rv = 0;
    if (select_rv > 0) {
        if (!FD_ISSET(fileno, &efds)) {
            if (FD_ISSET(fileno, &ifds)) { rv |= SELECT_EV_READ; }
            if (FD_ISSET(fileno, &ofds)) { rv |= SELECT_EV_WRITE; }
        }
        else {
            /* There is an error on the FD. Assume it means it is closed. We
             * want to raise a chained exception, which is tricky in C, so
             * return the special value CWAIT_SOCKET_ERROR to signal the Cython
             * wrapper to check the fd and raise the appropriate exception.
             */
            rv = CWAIT_SOCKET_ERROR;
        }
    }

#endif  /* HAVE_POLL */

    return rv;

error:

    rv = CWAIT_SELECT_ERROR;

#ifdef MS_WINDOWS
    if (select_rv == SOCKET_ERROR) {
        PyErr_SetExcFromWindowsErr(PyExc_OSError, WSAGetLastError());
    }
#else
    if (select_rv < 0) {
        PyErr_SetFromErrno(PyExc_OSError);
    }
#endif
    else {
        PyErr_SetString(PyExc_OSError, "unexpected error from select()");
    }

finally:

    return rv;

}
    

/* Defined in PostgreSQL in src/include/utils/array.h */
#define MAXDIM 6
    

    #if PY_MAJOR_VERSION >= 3
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj)
    #else
      #define __Pyx_PyFloat_FromString(obj)  PyFloat_FromString(obj, NULL)
    #endif
    
#include <stddef.h>

    #if PY_VERSION_HEX < 0x030d0000
    static CYTHON_INLINE int __Pyx_PyWeakref_GetRef(PyObject *ref, PyObject **pobj)
    {
        PyObject *obj = PyWeakref_GetObject(ref);
        if (obj == NULL) {
            // SystemError if ref is NULL
            *pobj = NULL;
            return -1;
        }
        if (obj == Py_None) {
            *pobj = NULL;
            return 0;
        }
        Py_INCREF(obj);
        *pobj = obj;
        return 1;
    }
    #else
    #define __Pyx_PyWeakref_GetRef PyWeakref_GetRef
    #endif
    
#include "pythread.h"

    #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM < 0x07030600) && !defined(PyContextVar_Get)
    #define PyContextVar_Get(var, d, v)         ((d) ?             ((void)(var), Py_INCREF(d), (v)[0] = (d), 0) :             ((v)[0] = NULL, 0)         )
    #endif
    

    #if CYTHON_COMPILING_IN_LIMITED_API
    #ifdef _MSC_VER
    #pragma message ("This module uses CPython specific internals of 'datetime.datetime', which are not available in the limited API.")
    #else
    #warning This module uses CPython specific internals of 'datetime.datetime', which are not available in the limited API.
    #endif
    #endif
    
#include "datetime.h"

    #define __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)         PyDateTimeAPI->DateTime_FromDateAndTimeAndFold(year, month, day, hour, minute, second,             microsecond, tz, fold, PyDateTimeAPI->DateTimeType)
    #define __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)         PyDateTimeAPI->Time_FromTimeAndFold(hour, minute, second, microsecond, tz, fold, PyDateTimeAPI->TimeType)

    #define __Pyx_TimeZone_UTC PyDateTime_TimeZone_UTC
    #define __Pyx_TimeZone_FromOffsetAndName(offset, name) PyTimeZone_FromOffsetAndName(offset, name)

    /* Backport for Python < 3.10 */
    #if PY_VERSION_HEX < 0x030a00a1
        #ifndef PyDateTime_TIME_GET_TZINFO
            #define PyDateTime_TIME_GET_TZINFO(o)                 ((((PyDateTime_Time*)o)->hastzinfo) ? ((PyDateTime_Time*)o)->tzinfo : Py_None)
        #endif
        #ifndef PyDateTime_DATE_GET_TZINFO
            #define PyDateTime_DATE_GET_TZINFO(o)                 ((((PyDateTime_DateTime*)o)->hastzinfo) ? ((PyDateTime_DateTime*)o)->tzinfo : Py_None)
        #endif
    #endif
    

/* Multipliers from fraction of seconds to microseconds */
static int _uspad[] = {0, 100000, 10000, 1000, 100, 10, 1};
    

int pg_lltoa(int64_t value, char *a);
#define MAXINT8LEN 20
    

/* Ratio between number of bits required to store a number and number of pg
 * decimal digits required (log(2) / log(10_000)).
 */
#define BIT_PER_PGDIGIT 0.07525749891599529

/* decimal digits per Postgres "digit" */
#define DEC_DIGITS 4

#define NUMERIC_POS 0x0000
#define NUMERIC_NEG 0x4000
#define NUMERIC_NAN 0xC000
#define NUMERIC_PINF 0xD000
#define NUMERIC_NINF 0xF000


/* Weights of py digits into a pg digit according to their positions. */
static const int pydigit_weights[] = {1000, 100, 10, 1};


static const int8_t hex_to_int_map[] = {
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 0-15
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 16-31
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 32-47
    0, 1, 2, 3, 4, 5, 6, 7, 8, 9, -1, -1, -1, -1, -1, -1,            // 48-63 ('0'-'9')
    -1, 10, 11, 12, 13, 14, 15, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 64-79 ('A'-'F')
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 80-95
    -1, 10, 11, 12, 13, 14, 15, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 96-111 ('a'-'f')
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 112-127
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 128-143
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 144-159
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 160-175
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 176-191
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 192-207
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 208-223
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1,  // 224-239
    -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1, -1   // 240-255
};

#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifdef CYTHON_FREETHREADING_COMPATIBLE
#if CYTHON_FREETHREADING_COMPATIBLE
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_USED
#endif
#else
#define __Pyx_FREETHREADING_COMPATIBLE Py_MOD_GIL_NOT_USED
#endif
#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AS_STRING(s)
#else
    #define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AsString(s))
    #define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AsString(s))
    #define __Pyx_PyByteArray_AsString(s) PyByteArray_AsString(s)
#endif
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
static CYTHON_INLINE PyObject *__Pyx_NewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_NewRef)
    return Py_NewRef(obj);
#else
    Py_INCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_XNewRef(PyObject *obj) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030a0000 || defined(Py_XNewRef)
    return Py_XNewRef(obj);
#else
    Py_XINCREF(obj);
    return obj;
#endif
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b);
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __Pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AS_DOUBLE(x)
#else
#define __Pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#define __Pyx_PyFloat_AS_DOUBLE(x) PyFloat_AsDouble(x)
#endif
#define __Pyx_PyFloat_AsFloat(x) ((float) __Pyx_PyFloat_AsDouble(x))
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#elif __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeASCII(c_str, size, NULL)
#else
  #define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
/* PretendToInitialize */
#ifdef __cplusplus
#if __cplusplus > 201103L
#include <type_traits>
#endif
template <typename T>
static void __Pyx_pretend_to_initialize(T* ptr) {
#if __cplusplus > 201103L
    if ((std::is_trivially_default_constructible<T>::value))
#endif
        *ptr = T();
    (void)ptr;
}
#else
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }
#endif


#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * const __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* #### Code section: filename_table ### */

static const char* const __pyx_f[] = {
  "psycopg_c/_psycopg.pyx",
  "psycopg_c/types/datetime.pyx",
  "psycopg_c/types/uuid.pyx",
  "cpython/contextvars.pxd",
  "datetime.pxd",
  "psycopg_c/_psycopg/adapt.pyx",
  "(tree fragment)",
  "psycopg_c/_psycopg/copy.pyx",
  "psycopg_c/_psycopg/generators.pyx",
  "psycopg_c/_psycopg/transform.pyx",
  "psycopg_c/_psycopg/waiting.pyx",
  "psycopg_c/types/array.pyx",
  "psycopg_c/types/numeric.pyx",
  "psycopg_c/types/bool.pyx",
  "psycopg_c/types/numpy.pyx",
  "psycopg_c/types/string.pyx",
  "psycopg_c/pq.pxd",
  "cpython/type.pxd",
  "cpython/bool.pxd",
  "cpython/complex.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* Atomics.proto (used by UnpackUnboundCMethod) */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __PYX_GET_CYTHON_COMPILING_IN_CPYTHON_FREETHREADING() CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_ptr_type atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) atomic_fetch_add_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) atomic_load(value)
    #define __pyx_atomic_store(value, new_value) atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) atomic_load_explicit(value, memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) atomic_load_explicit(value, memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_ptr_type std::atomic_uintptr_t
    #define __pyx_nonatomic_ptr_type uintptr_t
    #define __pyx_atomic_incr_relaxed(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_incr_acq_rel(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_decr_acq_rel(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #define __pyx_atomic_sub(value, arg) std::atomic_fetch_sub(value, arg)
    #define __pyx_atomic_int_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #define __pyx_atomic_load(value) std::atomic_load(value)
    #define __pyx_atomic_store(value, new_value) std::atomic_store(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) std::atomic_load_explicit(value, std::memory_order_relaxed)
    #define __pyx_atomic_pointer_load_acquire(value) std::atomic_load_explicit(value, std::memory_order_acquire)
    #define __pyx_atomic_pointer_exchange(value, new_value) std::atomic_exchange(value, (__pyx_nonatomic_ptr_type)new_value)
    #define __pyx_atomic_pointer_cmp_exchange(value, expected, desired) std::atomic_compare_exchange_strong(value, expected, desired)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_ptr_type void*
    #define __pyx_nonatomic_ptr_type void*
    #define __pyx_atomic_incr_relaxed(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) __sync_fetch_and_sub(value, 1)
    #define __pyx_atomic_sub(value, arg) __sync_fetch_and_sub(value, arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_store(value, new_value) __sync_lock_test_and_set(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_load_acquire(value) __sync_fetch_and_add(value, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) __sync_lock_test_and_set(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_nonatomic_ptr_type old = __sync_val_compare_and_swap(value, *expected, desired);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #define __pyx_atomic_ptr_type void*
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #define __pyx_nonatomic_ptr_type void*
    #pragma intrinsic (_InterlockedExchangeAdd, _InterlockedExchange, _InterlockedCompareExchange, _InterlockedCompareExchangePointer, _InterlockedExchangePointer)
    #define __pyx_atomic_incr_relaxed(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_incr_acq_rel(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_acq_rel(value) _InterlockedExchangeAdd(value, -1)
    #define __pyx_atomic_sub(value, arg) _InterlockedExchangeAdd(value, -arg)
    static CYTHON_INLINE int __pyx_atomic_int_cmp_exchange(__pyx_atomic_int_type* value, __pyx_nonatomic_int_type* expected, __pyx_nonatomic_int_type desired) {
        __pyx_nonatomic_int_type old = _InterlockedCompareExchange(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #define __pyx_atomic_load(value) _InterlockedExchangeAdd(value, 0)
    #define __pyx_atomic_store(value, new_value) _InterlockedExchange(value, new_value)
    #define __pyx_atomic_pointer_load_relaxed(value) *(void * volatile *)value
    #define __pyx_atomic_pointer_load_acquire(value) _InterlockedCompareExchangePointer(value, 0, 0)
    #define __pyx_atomic_pointer_exchange(value, new_value) _InterlockedExchangePointer(value, (__pyx_atomic_ptr_type)new_value)
    static CYTHON_INLINE int __pyx_atomic_pointer_cmp_exchange(__pyx_atomic_ptr_type* value, __pyx_nonatomic_ptr_type* expected, __pyx_nonatomic_ptr_type desired) {
        __pyx_atomic_ptr_type old = _InterlockedCompareExchangePointer(value, desired, *expected);
        int result = old == *expected;
        *expected = old;
        return result;
    }
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif

/* CriticalSectionsDefinition.proto (used by CriticalSections) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection void*
#define __Pyx_PyCriticalSection2 void*
#define __Pyx_PyCriticalSection_End(cs)
#define __Pyx_PyCriticalSection2_End(cs)
#else
#define __Pyx_PyCriticalSection PyCriticalSection
#define __Pyx_PyCriticalSection2 PyCriticalSection2
#define __Pyx_PyCriticalSection_End PyCriticalSection_End
#define __Pyx_PyCriticalSection2_End PyCriticalSection2_End
#endif

/* CriticalSections.proto (used by ParseKeywordsImpl) */
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyCriticalSection_Begin(cs, arg) (void)(cs)
#define __Pyx_PyCriticalSection2_Begin(cs, arg1, arg2) (void)(cs)
#else
#define __Pyx_PyCriticalSection_Begin PyCriticalSection_Begin
#define __Pyx_PyCriticalSection2_Begin PyCriticalSection2_Begin
#endif
#if PY_VERSION_HEX < 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_BEGIN_CRITICAL_SECTION(o) {
#define __Pyx_END_CRITICAL_SECTION() }
#else
#define __Pyx_BEGIN_CRITICAL_SECTION Py_BEGIN_CRITICAL_SECTION
#define __Pyx_END_CRITICAL_SECTION Py_END_CRITICAL_SECTION
#endif

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* IncludeStructmemberH.proto (used by FixUpExtensionType) */
#include <structmember.h>

/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* #### Code section: numeric_typedefs ### */
/* #### Code section: complex_type_declarations ### */
/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_9psycopg_c_2pq_PGconn;
struct __pyx_obj_9psycopg_c_2pq_PGresult;
struct __pyx_obj_9psycopg_c_2pq_PGcancelConn;
struct __pyx_obj_9psycopg_c_2pq_PGcancel;
struct __pyx_obj_9psycopg_c_2pq_Escaping;
struct __pyx_obj_9psycopg_c_2pq_PQBuffer;
struct __pyx_obj_9psycopg_c_2pq_ViewBuffer;
struct __pyx_obj_9psycopg_c_8_psycopg_CDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_CLoader;
struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Transformer;
struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper;
struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;
struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName;
struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar;
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName;
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown;
struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper;
struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader;
struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error;

/* "oids.pxd":9
 * # Use tools/update_oids.py to update this data.
 * 
 * cdef enum:             # <<<<<<<<<<<<<<
 *     INVALID_OID = 0
 * 
*/
enum  {
  __pyx_e_9psycopg_c_8_psycopg_4oids_INVALID_OID = 0,
  __pyx_e_9psycopg_c_8_psycopg_4oids_ACLITEM_OID = 0x409,
  __pyx_e_9psycopg_c_8_psycopg_4oids_BIT_OID = 0x618,
  __pyx_e_9psycopg_c_8_psycopg_4oids_BOOL_OID = 16,
  __pyx_e_9psycopg_c_8_psycopg_4oids_BOX_OID = 0x25B,
  __pyx_e_9psycopg_c_8_psycopg_4oids_BPCHAR_OID = 0x412,
  __pyx_e_9psycopg_c_8_psycopg_4oids_BYTEA_OID = 17,
  __pyx_e_9psycopg_c_8_psycopg_4oids_CHAR_OID = 18,
  __pyx_e_9psycopg_c_8_psycopg_4oids_CID_OID = 29,
  __pyx_e_9psycopg_c_8_psycopg_4oids_CIDR_OID = 0x28A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_CIRCLE_OID = 0x2CE,
  __pyx_e_9psycopg_c_8_psycopg_4oids_DATE_OID = 0x43A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_DATEMULTIRANGE_OID = 0x11B7,
  __pyx_e_9psycopg_c_8_psycopg_4oids_DATERANGE_OID = 0xF48,
  __pyx_e_9psycopg_c_8_psycopg_4oids_FLOAT4_OID = 0x2BC,
  __pyx_e_9psycopg_c_8_psycopg_4oids_FLOAT8_OID = 0x2BD,
  __pyx_e_9psycopg_c_8_psycopg_4oids_GTSVECTOR_OID = 0xE3A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INET_OID = 0x365,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT2_OID = 21,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT2VECTOR_OID = 22,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT4_OID = 23,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT4MULTIRANGE_OID = 0x1163,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT4RANGE_OID = 0xF40,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT8_OID = 20,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT8MULTIRANGE_OID = 0x11B8,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INT8RANGE_OID = 0xF56,
  __pyx_e_9psycopg_c_8_psycopg_4oids_INTERVAL_OID = 0x4A2,
  __pyx_e_9psycopg_c_8_psycopg_4oids_JSON_OID = 0x72,
  __pyx_e_9psycopg_c_8_psycopg_4oids_JSONB_OID = 0xEDA,
  __pyx_e_9psycopg_c_8_psycopg_4oids_JSONPATH_OID = 0xFE8,
  __pyx_e_9psycopg_c_8_psycopg_4oids_LINE_OID = 0x274,
  __pyx_e_9psycopg_c_8_psycopg_4oids_LSEG_OID = 0x259,
  __pyx_e_9psycopg_c_8_psycopg_4oids_MACADDR_OID = 0x33D,
  __pyx_e_9psycopg_c_8_psycopg_4oids_MACADDR8_OID = 0x306,
  __pyx_e_9psycopg_c_8_psycopg_4oids_MONEY_OID = 0x316,
  __pyx_e_9psycopg_c_8_psycopg_4oids_NAME_OID = 19,
  __pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID = 0x6A4,
  __pyx_e_9psycopg_c_8_psycopg_4oids_NUMMULTIRANGE_OID = 0x11B4,
  __pyx_e_9psycopg_c_8_psycopg_4oids_NUMRANGE_OID = 0xF42,
  __pyx_e_9psycopg_c_8_psycopg_4oids_OID_OID = 26,
  __pyx_e_9psycopg_c_8_psycopg_4oids_OIDVECTOR_OID = 30,
  __pyx_e_9psycopg_c_8_psycopg_4oids_PATH_OID = 0x25A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_PG_LSN_OID = 0xC94,
  __pyx_e_9psycopg_c_8_psycopg_4oids_POINT_OID = 0x258,
  __pyx_e_9psycopg_c_8_psycopg_4oids_POLYGON_OID = 0x25C,
  __pyx_e_9psycopg_c_8_psycopg_4oids_RECORD_OID = 0x8C9,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REFCURSOR_OID = 0x6FE,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGCLASS_OID = 0x89D,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGCOLLATION_OID = 0x105F,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGCONFIG_OID = 0xE96,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGDICTIONARY_OID = 0xEB9,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGNAMESPACE_OID = 0xFF9,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGOPER_OID = 0x89B,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGOPERATOR_OID = 0x89C,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGPROC_OID = 24,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGPROCEDURE_OID = 0x89A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGROLE_OID = 0x1000,
  __pyx_e_9psycopg_c_8_psycopg_4oids_REGTYPE_OID = 0x89E,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TEXT_OID = 25,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TID_OID = 27,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TIME_OID = 0x43B,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TIMESTAMP_OID = 0x45A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TIMESTAMPTZ_OID = 0x4A0,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TIMETZ_OID = 0x4F2,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TSMULTIRANGE_OID = 0x11B5,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TSQUERY_OID = 0xE1F,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TSRANGE_OID = 0xF44,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TSTZMULTIRANGE_OID = 0x11B6,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TSTZRANGE_OID = 0xF46,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TSVECTOR_OID = 0xE1E,
  __pyx_e_9psycopg_c_8_psycopg_4oids_TXID_SNAPSHOT_OID = 0xB9A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_UUID_OID = 0xB86,
  __pyx_e_9psycopg_c_8_psycopg_4oids_VARBIT_OID = 0x61A,
  __pyx_e_9psycopg_c_8_psycopg_4oids_VARCHAR_OID = 0x413,
  __pyx_e_9psycopg_c_8_psycopg_4oids_XID_OID = 28,
  __pyx_e_9psycopg_c_8_psycopg_4oids_XID8_OID = 0x13CD,
  __pyx_e_9psycopg_c_8_psycopg_4oids_XML_OID = 0x8E
};

/* "pq.pxd":16
 * from psycopg_c.pq cimport libpq
 * 
 * ctypedef char *(*conn_bytes_f) (const libpq.PGconn *) noexcept nogil             # <<<<<<<<<<<<<<
 * ctypedef int (*conn_int_f) (const libpq.PGconn *) noexcept nogil
 * ctypedef void *(*conn_f_with_param) (const libpq.PGconn *, const char *) noexcept nogil
*/
typedef char *(*__pyx_t_9psycopg_c_2pq_conn_bytes_f)(PGconn const *);

/* "pq.pxd":17
 * 
 * ctypedef char *(*conn_bytes_f) (const libpq.PGconn *) noexcept nogil
 * ctypedef int (*conn_int_f) (const libpq.PGconn *) noexcept nogil             # <<<<<<<<<<<<<<
 * ctypedef void *(*conn_f_with_param) (const libpq.PGconn *, const char *) noexcept nogil
 * ctypedef int (*conn_int_f_with_param) (
*/
typedef int (*__pyx_t_9psycopg_c_2pq_conn_int_f)(PGconn const *);

/* "pq.pxd":18
 * ctypedef char *(*conn_bytes_f) (const libpq.PGconn *) noexcept nogil
 * ctypedef int (*conn_int_f) (const libpq.PGconn *) noexcept nogil
 * ctypedef void *(*conn_f_with_param) (const libpq.PGconn *, const char *) noexcept nogil             # <<<<<<<<<<<<<<
 * ctypedef int (*conn_int_f_with_param) (
 *     const libpq.PGconn *, const char *
*/
typedef void *(*__pyx_t_9psycopg_c_2pq_conn_f_with_param)(PGconn const *, char const *);

/* "pq.pxd":19
 * ctypedef int (*conn_int_f) (const libpq.PGconn *) noexcept nogil
 * ctypedef void *(*conn_f_with_param) (const libpq.PGconn *, const char *) noexcept nogil
 * ctypedef int (*conn_int_f_with_param) (             # <<<<<<<<<<<<<<
 *     const libpq.PGconn *, const char *
 * ) noexcept nogil
*/
typedef int (*__pyx_t_9psycopg_c_2pq_conn_int_f_with_param)(PGconn const *, char const *);
struct __pyx_opt_args_7cpython_11contextvars_get_value;
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default;

/* "cpython/contextvars.pxd":116
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
*/
struct __pyx_opt_args_7cpython_11contextvars_get_value {
  int __pyx_n;
  PyObject *default_value;
};

/* "cpython/contextvars.pxd":134
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
*/
struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default {
  int __pyx_n;
  PyObject *default_value;
};
struct __pyx_opt_args_7cpython_8datetime_time_new;
struct __pyx_opt_args_7cpython_8datetime_datetime_new;
struct __pyx_opt_args_7cpython_8datetime_timezone_new;
struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp;

/* "datetime.pxd":265
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
*/
struct __pyx_opt_args_7cpython_8datetime_time_new {
  int __pyx_n;
  int fold;
};

/* "datetime.pxd":270
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
*/
struct __pyx_opt_args_7cpython_8datetime_datetime_new {
  int __pyx_n;
  int fold;
};

/* "datetime.pxd":279
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
*/
struct __pyx_opt_args_7cpython_8datetime_timezone_new {
  int __pyx_n;
  PyObject *name;
};

/* "datetime.pxd":283
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
*/
struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp {
  int __pyx_n;
  PyObject *tz;
};
struct __pyx_t_9psycopg_c_8_psycopg_PGresAttValue;
typedef struct __pyx_t_9psycopg_c_8_psycopg_PGresAttValue __pyx_t_9psycopg_c_8_psycopg_PGresAttValue;
struct __pyx_t_9psycopg_c_8_psycopg_pg_result_int;
typedef struct __pyx_t_9psycopg_c_8_psycopg_pg_result_int __pyx_t_9psycopg_c_8_psycopg_pg_result_int;
struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult;
struct __pyx_opt_args_9psycopg_c_8_psycopg__timezone_from_seconds;
struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error;

/* "psycopg_c/types/datetime.pyx":35
 * cdt.import_datetime()
 * 
 * cdef enum:             # <<<<<<<<<<<<<<
 *     ORDER_YMD = 0
 *     ORDER_DMY = 1
*/
enum  {
  __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD = 0,
  __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY = 1,
  __pyx_e_9psycopg_c_8_psycopg_ORDER_MDY = 2,
  __pyx_e_9psycopg_c_8_psycopg_ORDER_PGDM = 3,
  __pyx_e_9psycopg_c_8_psycopg_ORDER_PGMD = 4
};

/* "psycopg_c/types/datetime.pyx":42
 *     ORDER_PGMD = 4
 * 
 * cdef enum:             # <<<<<<<<<<<<<<
 *     INTERVALSTYLE_OTHERS = 0
 *     INTERVALSTYLE_SQL_STANDARD = 1
*/
enum  {
  __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_OTHERS = 0,
  __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_SQL_STANDARD = 1,
  __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_POSTGRES = 2
};

/* "psycopg_c/types/datetime.pyx":47
 *     INTERVALSTYLE_POSTGRES = 2
 * 
 * cdef enum:             # <<<<<<<<<<<<<<
 *     PG_DATE_EPOCH_DAYS = 730120  # date(2000, 1, 1).toordinal()
 *     PY_DATE_MIN_DAYS = 1  # date.min.toordinal()
*/
enum  {
  __pyx_e_9psycopg_c_8_psycopg_PG_DATE_EPOCH_DAYS = 0xB2408,
  __pyx_e_9psycopg_c_8_psycopg_PY_DATE_MIN_DAYS = 1
};

/* "psycopg_c/_psycopg/transform.pyx":33
 * # 10% of the innermost loop, so I'm willing to ask for forgiveness later...
 * 
 * ctypedef struct PGresAttValue:             # <<<<<<<<<<<<<<
 *     int len
 *     char *value
*/
struct __pyx_t_9psycopg_c_8_psycopg_PGresAttValue {
  int len;
  char *value;
};

/* "psycopg_c/_psycopg/transform.pyx":37
 *     char *value
 * 
 * ctypedef struct pg_result_int:             # <<<<<<<<<<<<<<
 *     # NOTE: it would be advised that we don't know this structure's content
 *     int ntups
*/
struct __pyx_t_9psycopg_c_8_psycopg_pg_result_int {
  int ntups;
  int numAttributes;
  PGresAttDesc *attDescs;
  __pyx_t_9psycopg_c_8_psycopg_PGresAttValue **tuples;
};

/* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/
struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult {
  int __pyx_n;
  PyObject *set_loaders;
  PyObject *format;
};

/* "psycopg_c/types/datetime.pyx":1099
 * 
 * 
 * cdef object _timezone_from_seconds(int sec, __cache={}):  # no-cython-lint             # <<<<<<<<<<<<<<
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
*/
struct __pyx_opt_args_9psycopg_c_8_psycopg__timezone_from_seconds {
  int __pyx_n;
  PyObject *__pyx___cache;
};

/* "psycopg_c/types/datetime.pyx":1111
 * 
 * 
 * cdef object _get_timestamp_load_error(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, const char *data, ex: Exception | None = None
 * ):
*/
struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error {
  int __pyx_n;
  PyObject *ex;
};

/* "pq.pxd":24
 * 
 * 
 * cdef class PGconn:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGconn* _pgconn_ptr
 *     cdef object __weakref__
*/
struct __pyx_obj_9psycopg_c_2pq_PGconn {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn *__pyx_vtab;
  PGconn *_pgconn_ptr;
  PyObject *__weakref__;
  PyObject *notice_handler;
  PyObject *notify_handler;
  pid_t _procpid;
};


/* "pq.pxd":38
 * 
 * 
 * cdef class PGresult:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGresult* _pgresult_ptr
 * 
*/
struct __pyx_obj_9psycopg_c_2pq_PGresult {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_PGresult *__pyx_vtab;
  PGresult *_pgresult_ptr;
};


/* "pq.pxd":45
 * 
 * 
 * cdef class PGcancelConn:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancelConn* pgcancelconn_ptr
 * 
*/
struct __pyx_obj_9psycopg_c_2pq_PGcancelConn {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancelConn *__pyx_vtab;
  PGcancelConn *pgcancelconn_ptr;
};


/* "pq.pxd":52
 * 
 * 
 * cdef class PGcancel:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancel* pgcancel_ptr
 * 
*/
struct __pyx_obj_9psycopg_c_2pq_PGcancel {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancel *__pyx_vtab;
  PGcancel *pgcancel_ptr;
};


/* "pq.pxd":59
 * 
 * 
 * cdef class Escaping:             # <<<<<<<<<<<<<<
 *     cdef PGconn conn
 * 
*/
struct __pyx_obj_9psycopg_c_2pq_Escaping {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping *__pyx_vtab;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *conn;
};


/* "pq.pxd":69
 * 
 * 
 * cdef class PQBuffer:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *buf
 *     cdef Py_ssize_t len
*/
struct __pyx_obj_9psycopg_c_2pq_PQBuffer {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_PQBuffer *__pyx_vtab;
  unsigned char *buf;
  Py_ssize_t len;
};


/* "pq.pxd":77
 * 
 * 
 * cdef class ViewBuffer:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *buf
 *     cdef Py_ssize_t len
*/
struct __pyx_obj_9psycopg_c_2pq_ViewBuffer {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_2pq_ViewBuffer *__pyx_vtab;
  unsigned char *buf;
  Py_ssize_t len;
  PyObject *obj;
};


/* "psycopg_c/_psycopg/adapt.pyx":26
 * 
 * 
 * @cython.freelist(8)             # <<<<<<<<<<<<<<
 * cdef class CDumper:
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_CDumper {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *__pyx_vtab;
  PyObject *cls;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *_pgconn;
};


/* "psycopg_c/_psycopg/adapt.pyx":144
 * 
 * 
 * @cython.freelist(8)             # <<<<<<<<<<<<<<
 * cdef class CLoader:
 *     cdef public libpq.Oid oid
*/
struct __pyx_obj_9psycopg_c_8_psycopg_CLoader {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *__pyx_vtab;
  Oid oid;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *_pgconn;
};


/* "psycopg_c/_psycopg/adapt.pyx":164
 * 
 * 
 * cdef class _CRecursiveLoader(CLoader):             # <<<<<<<<<<<<<<
 * 
 *     cdef Transformer _tx
*/
struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *_tx;
};


/* "psycopg_c/_psycopg/transform.pyx":46
 * 
 * 
 * @cython.freelist(16)             # <<<<<<<<<<<<<<
 * cdef class RowLoader:
 *     cdef CLoader cloader
*/
struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *cloader;
  PyObject *pyloader;
  PyObject *loadfunc;
};


/* "psycopg_c/_psycopg/transform.pyx":53
 * 
 * 
 * @cython.freelist(16)             # <<<<<<<<<<<<<<
 * cdef class RowDumper:
 *     cdef CDumper cdumper
*/
struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *cdumper;
  PyObject *pydumper;
  PyObject *dumpfunc;
  PyObject *oid;
  PyObject *format;
};


/* "psycopg_c/_psycopg/transform.pyx":62
 * 
 * 
 * cdef class Transformer:             # <<<<<<<<<<<<<<
 *     """
 *     An object that can adapt efficiently between Python and PostgreSQL.
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Transformer {
  PyObject_HEAD
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *__pyx_vtab;
  PyObject *connection;
  PyObject *adapters;
  PyObject *types;
  PyObject *formats;
  PyObject *_encoding;
  int _none_oid;
  PyObject *_auto_dumpers;
  PyObject *_text_dumpers;
  PyObject *_binary_dumpers;
  PyObject *_text_loaders;
  PyObject *_binary_loaders;
  PyObject *_oid_text_dumpers;
  PyObject *_oid_binary_dumpers;
  struct __pyx_obj_9psycopg_c_2pq_PGresult *_pgresult;
  int _nfields;
  int _ntuples;
  PyObject *_row_dumpers;
  PyObject *_row_loaders;
  PyObject *_oid_types;
};


/* "psycopg_c/types/array.pyx":31
 * 
 * 
 * cdef class ArrayLoader(_CRecursiveLoader):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader __pyx_base;
  PyObject *row_loader;
  char cdelim;
  char *scratch;
  size_t sclen;
};


/* "psycopg_c/types/array.pyx":60
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ArrayBinaryLoader(_CRecursiveLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader __pyx_base;
  PyObject *row_loader;
};


/* "psycopg_c/types/datetime.pyx":68
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":88
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":104
 * 
 * 
 * cdef class _BaseTimeDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_key(self, obj, format):
*/
struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":126
 * 
 * 
 * cdef class _BaseTimeTextDumper(_BaseTimeDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":142
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeDumper(_BaseTimeTextDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":154
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeTzDumper(_BaseTimeTextDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":164
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeBinaryDumper(_BaseTimeDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":188
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeTzBinaryDumper(_BaseTimeDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":212
 * 
 * 
 * cdef class _BaseDatetimeDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_key(self, obj, format):
*/
struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":226
 * 
 * 
 * cdef class _BaseDatetimeTextDumper(_BaseDatetimeDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":244
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeDumper(_BaseDatetimeTextDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":256
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeNoTzDumper(_BaseDatetimeTextDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":262
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeBinaryDumper(_BaseDatetimeDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":287
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeNoTzBinaryDumper(_BaseDatetimeDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":306
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimedeltaDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
  int _style;
};


/* "psycopg_c/types/datetime.pyx":343
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimedeltaBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":368
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  int _order;
};


/* "psycopg_c/types/datetime.pyx":422
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":442
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":472
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":501
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimetzLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":538
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimetzBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":573
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestampLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  int _order;
};


/* "psycopg_c/types/datetime.pyx":677
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestampBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":714
 * 
 * 
 * cdef class _BaseTimestamptzLoader(CLoader):             # <<<<<<<<<<<<<<
 *     cdef object _time_zone
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  PyObject *_time_zone;
};


/* "psycopg_c/types/datetime.pyx":721
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestamptzLoader(_BaseTimestamptzLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader __pyx_base;
  int _order;
};


/* "psycopg_c/types/datetime.pyx":806
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestamptzBinaryLoader(_BaseTimestamptzLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader __pyx_base;
};


/* "psycopg_c/types/datetime.pyx":868
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntervalLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  int _style;
};


/* "psycopg_c/types/datetime.pyx":979
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntervalBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":57
 * 
 * 
 * cdef class _IntDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":79
 * 
 * 
 * cdef class _IntOrSubclassDumper(_IntDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":97
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int2Dumper(_IntOrSubclassDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":103
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int4Dumper(_IntOrSubclassDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":109
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int8Dumper(_IntOrSubclassDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":115
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntNumericDumper(_IntOrSubclassDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":121
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int2BinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":131
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int4BinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":141
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int8BinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":176
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntNumericBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":186
 * 
 * 
 * cdef class IntDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":240
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntBinaryDumper(IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":251
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":271
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int2BinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":282
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int4BinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":293
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int8BinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":304
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class OidBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":315
 * 
 * 
 * cdef class _FloatDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":344
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FloatDumper(_FloatDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":350
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float4Dumper(_FloatDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":356
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FloatBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":373
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float4BinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":390
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FloatLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":402
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float4BinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":416
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float8BinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":430
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DecimalDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":454
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":475
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":529
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DecimalBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":539
 * 
 * 
 * cdef class _MixedNumericDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     oid = oids.NUMERIC_OID
*/
struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":554
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericDumper(_MixedNumericDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper __pyx_base;
};


/* "psycopg_c/types/numeric.pyx":572
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericBinaryDumper(_MixedNumericDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper __pyx_base;
};


/* "psycopg_c/types/bool.pyx":10
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/bool.pyx":40
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/bool.pyx":62
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/bool.pyx":72
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":10
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt16Dumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":16
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt32Dumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":22
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt64Dumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":28
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPNumericDumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":34
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt16BinaryDumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":44
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt32BinaryDumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":54
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt64BinaryDumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/numpy.pyx":64
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPNumericBinaryDumper(_IntDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":24
 * 
 * 
 * cdef class _BaseStrDumper(CDumper):             # <<<<<<<<<<<<<<
 *     cdef int is_utf8
 *     cdef char *encoding
*/
struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
  int is_utf8;
  char *encoding;
  PyObject *_bytes_encoding;
};


/* "psycopg_c/types/string.pyx":68
 * 
 * 
 * cdef class _StrBinaryDumper(_BaseStrDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_BINARY
*/
struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":73
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrBinaryDumper(_StrBinaryDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":79
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrBinaryDumperVarchar(_StrBinaryDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":85
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrBinaryDumperName(_StrBinaryDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":91
 * 
 * 
 * cdef class _StrDumper(_BaseStrDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":107
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumper(_StrDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":113
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumperVarchar(_StrDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":119
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumperName(_StrDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":125
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumperUnknown(_StrDumper):
 *     pass
*/
struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":130
 * 
 * 
 * cdef class _TextLoader(CLoader):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  int is_utf8;
  char *encoding;
  PyObject *_bytes_encoding;
};


/* "psycopg_c/types/string.pyx":167
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TextLoader(_TextLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader __pyx_base;
};


/* "psycopg_c/types/string.pyx":173
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TextBinaryLoader(_TextLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader __pyx_base;
};


/* "psycopg_c/types/string.pyx":179
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BytesDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
  int _qplen;
};


/* "psycopg_c/types/string.pyx":271
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BytesBinaryDumper(CDumper):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper __pyx_base;
};


/* "psycopg_c/types/string.pyx":287
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ByteaLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/string.pyx":306
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ByteaBinaryLoader(CLoader):
 * 
*/
struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
};


/* "psycopg_c/types/uuid.pyx":29
 * 
 * 
 * cdef class _UUIDLoader(CLoader):             # <<<<<<<<<<<<<<
 * 
 *     cdef object _object_new
*/
struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader __pyx_base;
  PyObject *_object_new;
  PyObject *_uuid_type;
  PyObject *_wuuid_type;
  PyObject *_safeuuid_unknown;
};


/* "psycopg_c/types/uuid.pyx":57
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class UUIDLoader(_UUIDLoader):
 *     format = PQ_TEXT
*/
struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader __pyx_base;
};


/* "psycopg_c/types/uuid.pyx":85
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class UUIDBinaryLoader(_UUIDLoader):
 *     format = PQ_BINARY
*/
struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader {
  struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader __pyx_base;
};


/* "psycopg_c/_psycopg/generators.pyx":32
 * 
 * 
 * def connect(conninfo: str, *, timeout: float = 0.0) -> PQGenConn[abc.PGconn]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to create a database connection without blocking.
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_conn;
  int __pyx_v_conn_status;
  PyObject *__pyx_v_conninfo;
  double __pyx_v_deadline;
  PyObject *__pyx_v_encoding;
  PGconn *__pyx_v_pgconn_ptr;
  int __pyx_v_poll_status;
  PyObject *__pyx_v_ready;
  double __pyx_v_timeout;
  PyObject *__pyx_v_wait;
};


/* "psycopg_c/_psycopg/generators.pyx":89
 * 
 * 
 * def cancel(pq.PGcancelConn cancel_conn, *, timeout: float = 0.0) -> PQGenConn[None]:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancelConn *pgcancelconn_ptr = cancel_conn.pgcancelconn_ptr
 *     cdef int status
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_2pq_PGcancelConn *__pyx_v_cancel_conn;
  double __pyx_v_deadline;
  PGcancelConn *__pyx_v_pgcancelconn_ptr;
  int __pyx_v_status;
  double __pyx_v_timeout;
};


/* "psycopg_c/_psycopg/generators.pyx":116
 * 
 * 
 * def execute(pq.PGconn pgconn) -> PQGen[list[abc.PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator sending a query and returning results without blocking.
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn;
  PyObject *__pyx_v_rv;
};


/* "psycopg_c/_psycopg/generators.pyx":132
 * 
 * 
 * def send(pq.PGconn pgconn) -> PQGen[None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to send a query to the server without blocking.
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send {
  PyObject_HEAD
  int __pyx_v_cires;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn;
  PGconn *__pyx_v_pgconn_ptr;
  int __pyx_v_ready;
};


/* "psycopg_c/_psycopg/generators.pyx":166
 * 
 * 
 * def fetch_many(pq.PGconn pgconn) -> PQGen[list[PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving results from the database without blocking.
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many {
  PyObject_HEAD
  PyObject *__pyx_v_genexpr;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn;
  PGresult *__pyx_v_pgres;
  struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_result;
  PyObject *__pyx_v_results;
  int __pyx_v_status;
  PyObject *__pyx_t_0;
  PyObject *__pyx_t_1;
  PyObject *__pyx_t_2;
};


/* "psycopg_c/_psycopg/generators.pyx":189
 *             # timeout. Check if we had received an error before, and raise it
 *             # as exception, because it should contain more details. See #988.
 *             if any(result.status == libpq.PGRES_FATAL_ERROR for res in results):             # <<<<<<<<<<<<<<
 *                 break
 *             else:
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *__pyx_outer_scope;
  PyObject *__pyx_genexpr_arg_0;
  PyObject *__pyx_v_res;
};


/* "psycopg_c/_psycopg/generators.pyx":218
 * 
 * 
 * def fetch(pq.PGconn pgconn) -> PQGen[PGresult | None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving a single result from the database without blocking.
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch {
  PyObject_HEAD
  int __pyx_v_cires;
  int __pyx_v_ibres;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn;
  PGconn *__pyx_v_pgconn_ptr;
  PGresult *__pyx_v_pgres;
  PyObject *__pyx_v_ready;
};


/* "psycopg_c/_psycopg/generators.pyx":265
 * 
 * 
 * def pipeline_communicate(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, commands: deque[PipelineCommand]
 * ) -> PQGen[list[list[PGresult]]]:
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate {
  PyObject_HEAD
  int __pyx_v_cires;
  PyObject *__pyx_v_commands;
  int __pyx_v_cready;
  int __pyx_v_ibres;
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn;
  PGconn *__pyx_v_pgconn_ptr;
  PGresult *__pyx_v_pgres;
  struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_r;
  PyObject *__pyx_v_ready;
  PyObject *__pyx_v_res;
  PyObject *__pyx_v_results;
  int __pyx_v_status;
};


/* "psycopg_c/types/datetime.pyx":1111
 * 
 * 
 * cdef object _get_timestamp_load_error(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, const char *data, ex: Exception | None = None
 * ):
*/
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error {
  PyObject_HEAD
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn;
};



/* "pq.pxd":24
 * 
 * 
 * cdef class PGconn:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGconn* _pgconn_ptr
 *     cdef object __weakref__
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn {
  struct __pyx_obj_9psycopg_c_2pq_PGconn *(*_from_ptr)(PGconn *);
  int (*flush)(struct __pyx_obj_9psycopg_c_2pq_PGconn *, int __pyx_skip_dispatch);
  PyObject *(*notifies)(struct __pyx_obj_9psycopg_c_2pq_PGconn *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn *__pyx_vtabptr_9psycopg_c_2pq_PGconn;


/* "pq.pxd":38
 * 
 * 
 * cdef class PGresult:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGresult* _pgresult_ptr
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_PGresult {
  struct __pyx_obj_9psycopg_c_2pq_PGresult *(*_from_ptr)(PGresult *);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_PGresult *__pyx_vtabptr_9psycopg_c_2pq_PGresult;


/* "pq.pxd":45
 * 
 * 
 * cdef class PGcancelConn:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancelConn* pgcancelconn_ptr
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancelConn {
  struct __pyx_obj_9psycopg_c_2pq_PGcancelConn *(*_from_ptr)(PGcancelConn *);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancelConn *__pyx_vtabptr_9psycopg_c_2pq_PGcancelConn;


/* "pq.pxd":52
 * 
 * 
 * cdef class PGcancel:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancel* pgcancel_ptr
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancel {
  struct __pyx_obj_9psycopg_c_2pq_PGcancel *(*_from_ptr)(PGcancel *);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancel *__pyx_vtabptr_9psycopg_c_2pq_PGcancel;


/* "pq.pxd":59
 * 
 * 
 * cdef class Escaping:             # <<<<<<<<<<<<<<
 *     cdef PGconn conn
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping {
  PyObject *(*escape_literal)(struct __pyx_obj_9psycopg_c_2pq_Escaping *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*escape_identifier)(struct __pyx_obj_9psycopg_c_2pq_Escaping *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*escape_string)(struct __pyx_obj_9psycopg_c_2pq_Escaping *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*escape_bytea)(struct __pyx_obj_9psycopg_c_2pq_Escaping *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*unescape_bytea)(struct __pyx_obj_9psycopg_c_2pq_Escaping *, unsigned char const *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping *__pyx_vtabptr_9psycopg_c_2pq_Escaping;


/* "pq.pxd":69
 * 
 * 
 * cdef class PQBuffer:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *buf
 *     cdef Py_ssize_t len
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_PQBuffer {
  struct __pyx_obj_9psycopg_c_2pq_PQBuffer *(*_from_buffer)(unsigned char *, Py_ssize_t);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_PQBuffer *__pyx_vtabptr_9psycopg_c_2pq_PQBuffer;


/* "pq.pxd":77
 * 
 * 
 * cdef class ViewBuffer:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *buf
 *     cdef Py_ssize_t len
*/

struct __pyx_vtabstruct_9psycopg_c_2pq_ViewBuffer {
  struct __pyx_obj_9psycopg_c_2pq_ViewBuffer *(*_from_buffer)(PyObject *, unsigned char *, Py_ssize_t);
};
static struct __pyx_vtabstruct_9psycopg_c_2pq_ViewBuffer *__pyx_vtabptr_9psycopg_c_2pq_ViewBuffer;


/* "psycopg_c/_psycopg/adapt.pyx":26
 * 
 * 
 * @cython.freelist(8)             # <<<<<<<<<<<<<<
 * cdef class CDumper:
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper {
  Py_ssize_t (*cdump)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t);
  PyObject *(*get_key)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*upgrade)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  char *(*ensure_size)(PyObject *, Py_ssize_t, Py_ssize_t);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;


/* "psycopg_c/_psycopg/adapt.pyx":144
 * 
 * 
 * @cython.freelist(8)             # <<<<<<<<<<<<<<
 * cdef class CLoader:
 *     cdef public libpq.Oid oid
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader {
  PyObject *(*cload)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;


/* "psycopg_c/_psycopg/adapt.pyx":164
 * 
 * 
 * cdef class _CRecursiveLoader(CLoader):             # <<<<<<<<<<<<<<
 * 
 *     cdef Transformer _tx
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__CRecursiveLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_vtabptr_9psycopg_c_8_psycopg__CRecursiveLoader;


/* "psycopg_c/_psycopg/transform.pyx":62
 * 
 * 
 * cdef class Transformer:             # <<<<<<<<<<<<<<
 *     """
 *     An object that can adapt efficiently between Python and PostgreSQL.
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer {
  PyObject *(*set_pgresult)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, struct __pyx_obj_9psycopg_c_2pq_PGresult *, int __pyx_skip_dispatch, struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult *__pyx_optional_args);
  PyObject *(*as_literal)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*get_row_dumper)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *);
  PyObject *(*get_dumper_by_oid)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *);
  PyObject *(*dump_sequence)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*load_sequence)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*_c_get_loader)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *__pyx_vtabptr_9psycopg_c_8_psycopg_Transformer;


/* "psycopg_c/types/array.pyx":31
 * 
 * 
 * cdef class ArrayLoader(_CRecursiveLoader):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ArrayLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__CRecursiveLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ArrayLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_ArrayLoader;


/* "psycopg_c/types/array.pyx":60
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ArrayBinaryLoader(_CRecursiveLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ArrayBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__CRecursiveLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_ArrayBinaryLoader;


/* "psycopg_c/types/datetime.pyx":68
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DateDumper;


/* "psycopg_c/types/datetime.pyx":88
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryDumper;


/* "psycopg_c/types/datetime.pyx":104
 * 
 * 
 * cdef class _BaseTimeDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_key(self, obj, format):
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
  PyObject *(*_get_offset)(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *, PyObject *);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper;


/* "psycopg_c/types/datetime.pyx":126
 * 
 * 
 * cdef class _BaseTimeTextDumper(_BaseTimeDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeTextDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeTextDumper;


/* "psycopg_c/types/datetime.pyx":142
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeDumper(_BaseTimeTextDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeTextDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_TimeDumper;


/* "psycopg_c/types/datetime.pyx":154
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeTzDumper(_BaseTimeTextDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeTextDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzDumper;


/* "psycopg_c/types/datetime.pyx":164
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeBinaryDumper(_BaseTimeDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryDumper;


/* "psycopg_c/types/datetime.pyx":188
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeTzBinaryDumper(_BaseTimeDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzBinaryDumper;


/* "psycopg_c/types/datetime.pyx":212
 * 
 * 
 * cdef class _BaseDatetimeDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_key(self, obj, format):
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper;


/* "psycopg_c/types/datetime.pyx":226
 * 
 * 
 * cdef class _BaseDatetimeTextDumper(_BaseDatetimeDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeTextDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;


/* "psycopg_c/types/datetime.pyx":244
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeDumper(_BaseDatetimeTextDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeTextDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeDumper;


/* "psycopg_c/types/datetime.pyx":256
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeNoTzDumper(_BaseDatetimeTextDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeNoTzDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeTextDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeNoTzDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzDumper;


/* "psycopg_c/types/datetime.pyx":262
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeBinaryDumper(_BaseDatetimeDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeBinaryDumper;


/* "psycopg_c/types/datetime.pyx":287
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DatetimeNoTzBinaryDumper(_BaseDatetimeDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;


/* "psycopg_c/types/datetime.pyx":306
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimedeltaDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimedeltaDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaDumper;


/* "psycopg_c/types/datetime.pyx":343
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimedeltaBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimedeltaBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;


/* "psycopg_c/types/datetime.pyx":368
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
  PyObject *(*_error_date)(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *, char const *, PyObject *);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_DateLoader;
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10DateLoader__error_date(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *, char const *, PyObject *);


/* "psycopg_c/types/datetime.pyx":422
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DateBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryLoader;


/* "psycopg_c/types/datetime.pyx":442
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimeLoader;


/* "psycopg_c/types/datetime.pyx":472
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimeBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryLoader;


/* "psycopg_c/types/datetime.pyx":501
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimetzLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimetzLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimetzLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimetzLoader;


/* "psycopg_c/types/datetime.pyx":538
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimetzBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimetzBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimetzBinaryLoader;


/* "psycopg_c/types/datetime.pyx":573
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestampLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestampLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
  PyObject *(*_cload_pg)(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *, char const *, char const *);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestampLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimestampLoader;
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader__cload_pg(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *, char const *, char const *);


/* "psycopg_c/types/datetime.pyx":677
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestampBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestampBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimestampBinaryLoader;


/* "psycopg_c/types/datetime.pyx":714
 * 
 * 
 * cdef class _BaseTimestamptzLoader(CLoader):             # <<<<<<<<<<<<<<
 *     cdef object _time_zone
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimestamptzLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimestamptzLoader;


/* "psycopg_c/types/datetime.pyx":721
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestamptzLoader(_BaseTimestamptzLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestamptzLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimestamptzLoader __pyx_base;
  PyObject *(*_cload_notimpl)(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *, char const *, size_t);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzLoader;
static PyObject *__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader__cload_notimpl(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *, char const *, size_t);


/* "psycopg_c/types/datetime.pyx":806
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TimestamptzBinaryLoader(_BaseTimestamptzLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestamptzBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimestamptzLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;


/* "psycopg_c/types/datetime.pyx":868
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntervalLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntervalLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
  PyObject *(*_cload_notimpl)(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *, char const *, size_t);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntervalLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_IntervalLoader;
static PyObject *__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader__cload_notimpl(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *, char const *, size_t);


/* "psycopg_c/types/datetime.pyx":979
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntervalBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntervalBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_IntervalBinaryLoader;


/* "psycopg_c/types/numeric.pyx":57
 * 
 * 
 * cdef class _IntDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;


/* "psycopg_c/types/numeric.pyx":79
 * 
 * 
 * cdef class _IntOrSubclassDumper(_IntDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper;


/* "psycopg_c/types/numeric.pyx":97
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int2Dumper(_IntOrSubclassDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Int2Dumper;


/* "psycopg_c/types/numeric.pyx":103
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int4Dumper(_IntOrSubclassDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Int4Dumper;


/* "psycopg_c/types/numeric.pyx":109
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int8Dumper(_IntOrSubclassDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Int8Dumper;


/* "psycopg_c/types/numeric.pyx":115
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntNumericDumper(_IntOrSubclassDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntNumericDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntNumericDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericDumper;


/* "psycopg_c/types/numeric.pyx":121
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int2BinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryDumper;


/* "psycopg_c/types/numeric.pyx":131
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int4BinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryDumper;


/* "psycopg_c/types/numeric.pyx":141
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int8BinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryDumper;


/* "psycopg_c/types/numeric.pyx":176
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntNumericBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntNumericBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericBinaryDumper;


/* "psycopg_c/types/numeric.pyx":186
 * 
 * 
 * cdef class IntDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_IntDumper;


/* "psycopg_c/types/numeric.pyx":240
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntBinaryDumper(IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_IntBinaryDumper;


/* "psycopg_c/types/numeric.pyx":251
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class IntLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_IntLoader;


/* "psycopg_c/types/numeric.pyx":271
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int2BinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2BinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryLoader;


/* "psycopg_c/types/numeric.pyx":282
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int4BinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4BinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryLoader;


/* "psycopg_c/types/numeric.pyx":293
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Int8BinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8BinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryLoader;


/* "psycopg_c/types/numeric.pyx":304
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class OidBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_OidBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_OidBinaryLoader;


/* "psycopg_c/types/numeric.pyx":315
 * 
 * 
 * cdef class _FloatDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__FloatDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__FloatDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__FloatDumper;


/* "psycopg_c/types/numeric.pyx":344
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FloatDumper(_FloatDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__FloatDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_FloatDumper;


/* "psycopg_c/types/numeric.pyx":350
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float4Dumper(_FloatDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__FloatDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Float4Dumper;


/* "psycopg_c/types/numeric.pyx":356
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FloatBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_FloatBinaryDumper;


/* "psycopg_c/types/numeric.pyx":373
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float4BinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryDumper;


/* "psycopg_c/types/numeric.pyx":390
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class FloatLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_FloatLoader;


/* "psycopg_c/types/numeric.pyx":402
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float4BinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4BinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryLoader;


/* "psycopg_c/types/numeric.pyx":416
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class Float8BinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float8BinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_Float8BinaryLoader;


/* "psycopg_c/types/numeric.pyx":430
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DecimalDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DecimalDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DecimalDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DecimalDumper;


/* "psycopg_c/types/numeric.pyx":454
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_NumericLoader;


/* "psycopg_c/types/numeric.pyx":475
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryLoader;


/* "psycopg_c/types/numeric.pyx":529
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class DecimalBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DecimalBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_DecimalBinaryDumper;


/* "psycopg_c/types/numeric.pyx":539
 * 
 * 
 * cdef class _MixedNumericDumper(CDumper):             # <<<<<<<<<<<<<<
 * 
 *     oid = oids.NUMERIC_OID
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__MixedNumericDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__MixedNumericDumper;


/* "psycopg_c/types/numeric.pyx":554
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericDumper(_MixedNumericDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__MixedNumericDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NumericDumper;


/* "psycopg_c/types/numeric.pyx":572
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NumericBinaryDumper(_MixedNumericDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__MixedNumericDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryDumper;


/* "psycopg_c/types/bool.pyx":10
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_BoolDumper;


/* "psycopg_c/types/bool.pyx":40
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryDumper;


/* "psycopg_c/types/bool.pyx":62
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_BoolLoader;


/* "psycopg_c/types/bool.pyx":72
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BoolBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryLoader;


/* "psycopg_c/types/numpy.pyx":10
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt16Dumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt16Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt16Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16Dumper;


/* "psycopg_c/types/numpy.pyx":16
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt32Dumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt32Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt32Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32Dumper;


/* "psycopg_c/types/numpy.pyx":22
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt64Dumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt64Dumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt64Dumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64Dumper;


/* "psycopg_c/types/numpy.pyx":28
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPNumericDumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPNumericDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPNumericDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericDumper;


/* "psycopg_c/types/numpy.pyx":34
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt16BinaryDumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt16BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16BinaryDumper;


/* "psycopg_c/types/numpy.pyx":44
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt32BinaryDumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt32BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32BinaryDumper;


/* "psycopg_c/types/numpy.pyx":54
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPInt64BinaryDumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt64BinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64BinaryDumper;


/* "psycopg_c/types/numpy.pyx":64
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class NPNumericBinaryDumper(_IntDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPNumericBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericBinaryDumper;


/* "psycopg_c/types/string.pyx":24
 * 
 * 
 * cdef class _BaseStrDumper(CDumper):             # <<<<<<<<<<<<<<
 *     cdef int is_utf8
 *     cdef char *encoding
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseStrDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseStrDumper;


/* "psycopg_c/types/string.pyx":68
 * 
 * 
 * cdef class _StrBinaryDumper(_BaseStrDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_BINARY
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseStrDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper;


/* "psycopg_c/types/string.pyx":73
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrBinaryDumper(_StrBinaryDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumper;


/* "psycopg_c/types/string.pyx":79
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrBinaryDumperVarchar(_StrBinaryDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumperVarchar {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *__pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;


/* "psycopg_c/types/string.pyx":85
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrBinaryDumperName(_StrBinaryDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumperName {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumperName *__pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperName;


/* "psycopg_c/types/string.pyx":91
 * 
 * 
 * cdef class _StrDumper(_BaseStrDumper):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseStrDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper *__pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper;


/* "psycopg_c/types/string.pyx":107
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumper(_StrDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumper;


/* "psycopg_c/types/string.pyx":113
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumperVarchar(_StrDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperVarchar {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperVarchar *__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperVarchar;


/* "psycopg_c/types/string.pyx":119
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumperName(_StrDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperName {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperName *__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperName;


/* "psycopg_c/types/string.pyx":125
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class StrDumperUnknown(_StrDumper):
 *     pass
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperUnknown {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperUnknown *__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperUnknown;


/* "psycopg_c/types/string.pyx":130
 * 
 * 
 * cdef class _TextLoader(CLoader):             # <<<<<<<<<<<<<<
 * 
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__TextLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__TextLoader *__pyx_vtabptr_9psycopg_c_8_psycopg__TextLoader;


/* "psycopg_c/types/string.pyx":167
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TextLoader(_TextLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TextLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__TextLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TextLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TextLoader;


/* "psycopg_c/types/string.pyx":173
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class TextBinaryLoader(_TextLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TextBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__TextLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TextBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_TextBinaryLoader;


/* "psycopg_c/types/string.pyx":179
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BytesDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BytesDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BytesDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_BytesDumper;


/* "psycopg_c/types/string.pyx":271
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class BytesBinaryDumper(CDumper):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BytesBinaryDumper {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_vtabptr_9psycopg_c_8_psycopg_BytesBinaryDumper;


/* "psycopg_c/types/string.pyx":287
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ByteaLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ByteaLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ByteaLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_ByteaLoader;


/* "psycopg_c/types/string.pyx":306
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class ByteaBinaryLoader(CLoader):
 * 
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ByteaBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_ByteaBinaryLoader;


/* "psycopg_c/types/uuid.pyx":29
 * 
 * 
 * cdef class _UUIDLoader(CLoader):             # <<<<<<<<<<<<<<
 * 
 *     cdef object _object_new
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg__UUIDLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_base;
  PyObject *(*_return_uuid)(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *, uint64_t, uint64_t);
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__UUIDLoader *__pyx_vtabptr_9psycopg_c_8_psycopg__UUIDLoader;


/* "psycopg_c/types/uuid.pyx":57
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class UUIDLoader(_UUIDLoader):
 *     format = PQ_TEXT
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__UUIDLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_UUIDLoader;


/* "psycopg_c/types/uuid.pyx":85
 * 
 * 
 * @cython.final             # <<<<<<<<<<<<<<
 * cdef class UUIDBinaryLoader(_UUIDLoader):
 *     format = PQ_BINARY
*/

struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDBinaryLoader {
  struct __pyx_vtabstruct_9psycopg_c_8_psycopg__UUIDLoader __pyx_base;
};
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_vtabptr_9psycopg_c_8_psycopg_UUIDBinaryLoader;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto (used by PyErrFetchRestore) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto (used by GetBuiltinName) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* TupleAndListFromArray.proto (used by fastcall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
#endif
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto (used by BytesEquals) */
#include <string.h>

/* BytesEquals.proto (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_PySequence_ITEM(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_NewRef(__Pyx_PyTuple_GET_ITEM(args, i))
#else
    #define __Pyx_ArgRef_VARARGS(args, i) __Pyx_XNewRef(PyTuple_GetItem(args, i))
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_ArgRef_FASTCALL(args, i) __Pyx_NewRef(args[i])
    #define __Pyx_NumKwargs_FASTCALL(kwds) __Pyx_PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
#else
    #define __Pyx_ArgRef_FASTCALL __Pyx_ArgRef_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
#endif
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#if CYTHON_METH_FASTCALL || (CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(args + start, stop - start)
#else
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* py_dict_items.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d);

/* CallCFunction.proto (used by CallUnboundCMethod0) */
#define __Pyx_CallCFunction(cfunc, self, args)\
    ((PyCFunction)(void(*)(void))(cfunc)->func)(self, args)
#define __Pyx_CallCFunctionWithKeywords(cfunc, self, args, kwargs)\
    ((PyCFunctionWithKeywords)(void(*)(void))(cfunc)->func)(self, args, kwargs)
#define __Pyx_CallCFunctionFast(cfunc, self, args, nargs)\
    ((__Pyx_PyCFunctionFast)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs)
#define __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, nargs, kwnames)\
    ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))(PyCFunction)(cfunc)->func)(self, args, nargs, kwnames)

/* PyObjectCall.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto (used by PyObjectCallOneArg) */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs);

/* PyObjectCallOneArg.proto (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* UnpackUnboundCMethod.proto (used by CallUnboundCMethod0) */
typedef struct {
    PyObject *type;
    PyObject **method_name;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && CYTHON_ATOMICS
    __pyx_atomic_int_type initialized;
#endif
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
static CYTHON_INLINE int __Pyx_CachedCFunction_GetAndSetInitializing(__Pyx_CachedCFunction *cfunc) {
#if !CYTHON_ATOMICS
    return 1;
#else
    __pyx_nonatomic_int_type expected = 0;
    if (__pyx_atomic_int_cmp_exchange(&cfunc->initialized, &expected, 1)) {
        return 0;
    }
    return expected;
#endif
}
static CYTHON_INLINE void __Pyx_CachedCFunction_SetFinishedInitializing(__Pyx_CachedCFunction *cfunc) {
#if CYTHON_ATOMICS
    __pyx_atomic_store(&cfunc->initialized, 2);
#endif
}
#else
#define __Pyx_CachedCFunction_GetAndSetInitializing(cfunc) 2
#define __Pyx_CachedCFunction_SetFinishedInitializing(cfunc)
#endif

/* CallUnboundCMethod0.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* py_dict_values.proto (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* OwnedDictNext.proto (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue);
#else
CYTHON_INLINE
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue);
#endif

/* RaiseDoubleKeywords.proto (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywordsImpl.export */
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name
);
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* CallUnboundCMethod2.proto */
CYTHON_UNUSED
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ParseKeywords.proto */
static CYTHON_INLINE int __Pyx_ParseKeywords(
    PyObject *kwds, PyObject *const *kwvalues, PyObject ** const argnames[],
    PyObject *kwds2, PyObject *values[],
    Py_ssize_t num_pos_args, Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs
);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* PyNotImplementedError_Check.proto */
#define __Pyx_PyExc_NotImplementedError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_NotImplementedError)

/* RaiseException.export */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* PyObjectFastCallMethod.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_PyObject_FastCallMethod(name, args, nargsf) PyObject_VectorcallMethod(name, args, nargsf, NULL)
#else
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf);
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __Pyx_XNewRef(__pyx_dict_cached_value);\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyTypeError_Check.proto */
#define __Pyx_PyExc_TypeError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_TypeError)

/* pyint_simplify.proto */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none);

/* ArgTypeTestFunc.export */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_mstate_global->__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* BuildPyUnicode.proto (used by COrdinalToPyUnicode) */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, const char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* COrdinalToPyUnicode.proto (used by CIntToPyUnicode) */
static CYTHON_INLINE int __Pyx_CheckUnicodeValue(int value);
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromOrdinal_Padded(int value, Py_ssize_t width, char padding_char);

/* GCCDiagnostics.proto (used by CIntToPyUnicode) */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* IncludeStdlibH.proto (used by CIntToPyUnicode) */
#include <stdlib.h>

/* CIntToPyUnicode.proto */
#define __Pyx_PyUnicode_From_Py_ssize_t(value, width, padding_char, format_char) (\
    ((format_char) == ('c')) ?\
        __Pyx_uchar___Pyx_PyUnicode_From_Py_ssize_t(value, width, padding_char) :\
        __Pyx____Pyx_PyUnicode_From_Py_ssize_t(value, width, padding_char, format_char)\
    )
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char);
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.export */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* GetTopmostException.proto (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SetStringIndexingError.proto (used by SetItemIntByteArray) */
static void __Pyx_SetStringIndexingError(const char* message, int has_gil);

/* SetItemIntByteArray.proto */
#define __Pyx_SetItemInt_ByteArray(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_ByteArray_Fast(o, (Py_ssize_t)i, v, wraparound, boundscheck, has_gil, unsafe_shared) :\
    (__Pyx_SetStringIndexingError("bytearray index out of range", has_gil), -1))
static CYTHON_INLINE int __Pyx_SetItemInt_ByteArray_Fast(PyObject* string, Py_ssize_t i, unsigned char v,
                                                         int wraparound, int boundscheck, int has_gil, int unsafe_shared);

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

/* PyObjectVectorCallKwBuilder.proto */
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#if CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_Vectorcall_CallFromBuilder PyObject_Vectorcall
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder _PyObject_Vectorcall
#endif
#define __Pyx_MakeVectorcallBuilderKwds(n) PyTuple_New(n)
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n);
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n);
#else
#define __Pyx_Object_Vectorcall_CallFromBuilder __Pyx_PyObject_FastCallDict
#define __Pyx_MakeVectorcallBuilderKwds(n) __Pyx_PyDict_NewPresized(n)
#define __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n) PyDict_SetItem(builder, key, value)
#define __Pyx_VectorcallBuilder_AddArgStr(key, value, builder, args, n) PyDict_SetItemString(builder, key, value)
#endif

/* CIntToPyUnicode.proto */
#define __Pyx_PyUnicode_From_int(value, width, padding_char, format_char) (\
    ((format_char) == ('c')) ?\
        __Pyx_uchar___Pyx_PyUnicode_From_int(value, width, padding_char) :\
        __Pyx____Pyx_PyUnicode_From_int(value, width, padding_char, format_char)\
    )
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char);
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* PyObjectDelAttr.proto (used by PyObjectSetAttrStr) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
#define __Pyx_PyObject_DelAttr(o, n) PyObject_SetAttr(o, n, NULL)
#else
#define __Pyx_PyObject_DelAttr(o, n) PyObject_DelAttr(o, n)
#endif

/* PyObjectSetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o, n, NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value);
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   __Pyx_PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

/* pep479.proto */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen);

/* dict_setdefault.proto (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value);

/* LimitedApiGetTypeDict.proto (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp);
#endif

/* SetItemOnTypeDict.proto (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v);
#define __Pyx_SetItemOnTypeDict(tp, k, v) __Pyx__SetItemOnTypeDict((PyTypeObject*)tp, k, v)

/* FixUpExtensionType.proto (used by FetchCommonType) */
static CYTHON_INLINE int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);

/* AddModuleRef.proto (used by FetchSharedCythonModule) */
#if ((CYTHON_COMPILING_IN_CPYTHON_FREETHREADING ) ||\
     __PYX_LIMITED_VERSION_HEX < 0x030d0000)
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name);
#else
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#endif

/* FetchSharedCythonModule.proto (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto (used by CommonTypesMetaclass) */
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases);

/* CommonTypesMetaclass.proto (used by CoroutineBase) */
static int __pyx_CommonTypesMetaclass_init(PyObject *module);
#define __Pyx_CommonTypesMetaclass_USED

/* CallTypeTraverse.proto (used by CoroutineBase) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#define __Pyx_call_type_traverse(o, always_call, visit, arg) 0
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg);
#endif

/* IterNextPlain.proto (used by CoroutineBase) */
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator);
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void);
#endif

/* PyObjectCall2Args.proto (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);
#endif

/* PyObjectCallMethod1.proto (used by CoroutineBase) */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* PyObjectCallNoArg.proto (used by CoroutineBase) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* ReturnWithStopIteration.proto (used by CoroutineBase) */
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext);

/* CoroutineBase.proto (used by Generator) */
struct __pyx_CoroutineObject;
typedef PyObject *(*__pyx_coroutine_body_t)(struct __pyx_CoroutineObject *, PyThreadState *, PyObject *);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_ExcInfoStruct  _PyErr_StackItem
#else
typedef struct {
    PyObject *exc_type;
    PyObject *exc_value;
    PyObject *exc_traceback;
} __Pyx_ExcInfoStruct;
#endif
typedef struct __pyx_CoroutineObject {
    PyObject_HEAD
    __pyx_coroutine_body_t body;
    PyObject *closure;
    __Pyx_ExcInfoStruct gi_exc_state;
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *gi_weakreflist;
#endif
    PyObject *classobj;
    PyObject *yieldfrom;
    __Pyx_pyiter_sendfunc yieldfrom_am_send;
    PyObject *gi_name;
    PyObject *gi_qualname;
    PyObject *gi_modulename;
    PyObject *gi_code;
    PyObject *gi_frame;
#if CYTHON_USE_SYS_MONITORING && (CYTHON_PROFILE || CYTHON_TRACE)
    PyMonitoringState __pyx_pymonitoring_state[__Pyx_MonitoringEventTypes_CyGen_count];
    uint64_t __pyx_pymonitoring_version;
#endif
    int resume_label;
    char is_running;
} __pyx_CoroutineObject;
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
    PyTypeObject *type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
    PyObject *name, PyObject *qualname, PyObject *module_name);
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name);
static CYTHON_INLINE void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *self);
static int __Pyx_Coroutine_clear(PyObject *self);
static __Pyx_PySendResult __Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval);
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value);
static __Pyx_PySendResult __Pyx_Coroutine_Close(PyObject *self, PyObject **retval);
static PyObject *__Pyx_Coroutine_Throw(PyObject *gen, PyObject *args);
#if CYTHON_USE_EXC_INFO_STACK
#define __Pyx_Coroutine_SwapException(self)
#define __Pyx_Coroutine_ResetAndClearException(self)  __Pyx_Coroutine_ExceptionClear(&(self)->gi_exc_state)
#else
#define __Pyx_Coroutine_SwapException(self) {\
    __Pyx_ExceptionSwap(&(self)->gi_exc_state.exc_type, &(self)->gi_exc_state.exc_value, &(self)->gi_exc_state.exc_traceback);\
    __Pyx_Coroutine_ResetFrameBackpointer(&(self)->gi_exc_state);\
    }
#define __Pyx_Coroutine_ResetAndClearException(self) {\
    __Pyx_ExceptionReset((self)->gi_exc_state.exc_type, (self)->gi_exc_state.exc_value, (self)->gi_exc_state.exc_traceback);\
    (self)->gi_exc_state.exc_type = (self)->gi_exc_state.exc_value = (self)->gi_exc_state.exc_traceback = NULL;\
    }
#endif
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__pyx_tstate, pvalue)
#else
#define __Pyx_PyGen_FetchStopIterationValue(pvalue)\
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, pvalue)
#endif
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *tstate, PyObject **pvalue);
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state);
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen);
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen);
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen);
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure);
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send);
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg);

/* Generator.proto (used by GeneratorYieldFrom) */
#define __Pyx_Generator_USED
#define __Pyx_Generator_CheckExact(obj) __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_GeneratorType)
#define __Pyx_Generator_New(body, code, closure, name, qualname, module_name)\
    __Pyx__Coroutine_New(__pyx_mstate_global->__pyx_GeneratorType, body, code, closure, name, qualname, module_name)
static PyObject *__Pyx_Generator_Next(PyObject *self);
static int __pyx_Generator_init(PyObject *module);
static CYTHON_INLINE PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self);

/* GeneratorYieldFrom.proto */
static CYTHON_INLINE __Pyx_PySendResult __Pyx_Generator_Yield_From(__pyx_CoroutineObject *gen, PyObject *source, PyObject **retval);

/* RaiseUnboundLocalError.proto */
static void __Pyx_RaiseUnboundLocalError(const char *varname);

/* RaiseClosureNameError.proto */
static void __Pyx_RaiseClosureNameError(const char *varname);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2) {
    return PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2);
}
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)
#ifdef PyExceptionInstance_Check
  #define __Pyx_PyBaseException_Check(obj) PyExceptionInstance_Check(obj)
#else
  #define __Pyx_PyBaseException_Check(obj) __Pyx_TypeCheck(obj, PyExc_BaseException)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* HasAttr.proto (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ImportImpl.export */
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level);

/* Import.proto */
static CYTHON_INLINE PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck, unsafe_shared) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck, has_gil, unsafe_shared)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck, unsafe_shared) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck, int unsafe_shared);

/* PyLongCompare.proto */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace);

/* PyValueError_Check.proto */
#define __Pyx_PyExc_ValueError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_ValueError)

/* PyObject_Format1.proto */
#define __Pyx_PyObject_Format1(obj) PyObject_Format((obj), NULL)

/* pybytes_as_double.proto (used by pyobject_as_double) */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj);
static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length);
static CYTHON_INLINE double __Pyx_PyBytes_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    as_c_string = PyBytes_AS_STRING(obj);
    size = PyBytes_GET_SIZE(obj);
#else
    if (PyBytes_AsStringAndSize(obj, &as_c_string, &size) < 0) {
        return (double)-1;
    }
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}
static CYTHON_INLINE double __Pyx_PyByteArray_AsDouble(PyObject *obj) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    as_c_string = PyByteArray_AS_STRING(obj);
    size = PyByteArray_GET_SIZE(obj);
#else
    as_c_string = PyByteArray_AsString(obj);
    if (as_c_string == NULL) {
        return (double)-1;
    }
    size = PyByteArray_Size(obj);
#endif
    return __Pyx__PyBytes_AsDouble(obj, as_c_string, size);
}

/* pyunicode_as_double.proto (used by pyobject_as_double) */
#if !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
static const char* __Pyx__PyUnicode_AsDouble_Copy(const void* data, const int kind, char* buffer, Py_ssize_t start, Py_ssize_t end) {
    int last_was_punctuation;
    Py_ssize_t i;
    last_was_punctuation = 1;
    for (i=start; i <= end; i++) {
        Py_UCS4 chr = PyUnicode_READ(kind, data, i);
        int is_punctuation = (chr == '_') | (chr == '.');
        *buffer = (char)chr;
        buffer += (chr != '_');
        if (unlikely(chr > 127)) goto parse_failure;
        if (unlikely(last_was_punctuation & is_punctuation)) goto parse_failure;
        last_was_punctuation = is_punctuation;
    }
    if (unlikely(last_was_punctuation)) goto parse_failure;
    *buffer = '\0';
    return buffer;
parse_failure:
    return NULL;
}
static double __Pyx__PyUnicode_AsDouble_inf_nan(const void* data, int kind, Py_ssize_t start, Py_ssize_t length) {
    int matches = 1;
    Py_UCS4 chr;
    Py_UCS4 sign = PyUnicode_READ(kind, data, start);
    int is_signed = (sign == '-') | (sign == '+');
    start += is_signed;
    length -= is_signed;
    switch (PyUnicode_READ(kind, data, start)) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'a') | (chr == 'A');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'n') | (chr == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+1);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+2);
            matches &= (chr == 'f') | (chr == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            chr = PyUnicode_READ(kind, data, start+3);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+4);
            matches &= (chr == 'n') | (chr == 'N');
            chr = PyUnicode_READ(kind, data, start+5);
            matches &= (chr == 'i') | (chr == 'I');
            chr = PyUnicode_READ(kind, data, start+6);
            matches &= (chr == 't') | (chr == 'T');
            chr = PyUnicode_READ(kind, data, start+7);
            matches &= (chr == 'y') | (chr == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static double __Pyx_PyUnicode_AsDouble_WithSpaces(PyObject *obj) {
    double value;
    const char *last;
    char *end;
    Py_ssize_t start, length = PyUnicode_GET_LENGTH(obj);
    const int kind = PyUnicode_KIND(obj);
    const void* data = PyUnicode_DATA(obj);
    start = 0;
    while (Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, start)))
        start++;
    while (start < length - 1 && Py_UNICODE_ISSPACE(PyUnicode_READ(kind, data, length - 1)))
        length--;
    length -= start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyUnicode_AsDouble_inf_nan(data, kind, start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    if (length < 40) {
        char number[40];
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((length + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyUnicode_AsDouble_Copy(data, kind, number, start, start + length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}
#endif
static CYTHON_INLINE double __Pyx_PyUnicode_AsDouble(PyObject *obj) {
#if !CYTHON_COMPILING_IN_PYPY && CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(__Pyx_PyUnicode_READY(obj) == -1))
        return (double)-1;
    if (likely(PyUnicode_IS_ASCII(obj))) {
        const char *s;
        Py_ssize_t length;
        s = PyUnicode_AsUTF8AndSize(obj, &length);
        return __Pyx__PyBytes_AsDouble(obj, s, length);
    }
    return __Pyx_PyUnicode_AsDouble_WithSpaces(obj);
#else
    return __Pyx_SlowPyString_AsDouble(obj);
#endif
}

/* pyobject_as_double.proto */
static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyLong_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?  __Pyx_PyFloat_AS_DOUBLE(obj) :\
 likely(PyLong_CheckExact(obj)) ?\
 PyLong_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

/* FloatExceptionCheck.proto */
#define __PYX_CHECK_FLOAT_EXCEPTION(value, error_value)\
    ((error_value) == (error_value) ?\
     (value) == (error_value) :\
     (value) != (value))

/* IterNext.proto */
#define __Pyx_PyIter_Next(obj) __Pyx_PyIter_Next2(obj, NULL)
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject *, PyObject *);

/* PyAssertionError_Check.proto */
#define __Pyx_PyExc_AssertionError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_AssertionError)

/* PyStopIteration_Check.proto */
#define __Pyx_PyExc_StopIteration_Check(obj)  __Pyx_TypeCheck(obj, PyExc_StopIteration)

/* PyObjectCallMethod0.proto (used by pop) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* pop.proto */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L);
#define __Pyx_PyObject_Pop(L) (likely(PyList_CheckExact(L)) ?\
    __Pyx_PyList_Pop(L) : __Pyx__PyObject_Pop(L))
#else
#define __Pyx_PyList_Pop(L)  __Pyx__PyObject_Pop(L)
#define __Pyx_PyObject_Pop(L)  __Pyx__PyObject_Pop(L)
#endif

/* PyObjectFormatAndDecref.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f);
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f);

/* PyObject_Unicode.proto */
#define __Pyx_PyObject_Unicode(obj)\
    (likely(PyUnicode_CheckExact(obj)) ? __Pyx_NewRef(obj) : PyObject_Str(obj))

/* decode_c_string_utf16.proto (used by decode_c_string) */
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 0;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16LE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = -1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_DecodeUTF16BE(const char *s, Py_ssize_t size, const char *errors) {
    int byteorder = 1;
    return PyUnicode_DecodeUTF16(s, size, errors, &byteorder);
}

/* decode_c_string.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* decode_c_bytes.proto (used by decode_bytes) */
static CYTHON_INLINE PyObject* __Pyx_decode_c_bytes(
         const char* cstring, Py_ssize_t length, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors));

/* decode_bytes.proto */
static CYTHON_INLINE PyObject* __Pyx_decode_bytes(
         PyObject* string, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    char* as_c_string;
    Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    as_c_string = PyBytes_AS_STRING(string);
    size = PyBytes_GET_SIZE(string);
#else
    if (PyBytes_AsStringAndSize(string, &as_c_string, &size) < 0) {
        return NULL;
    }
#endif
    return __Pyx_decode_c_bytes(
        as_c_string, size,
        start, stop, encoding, errors, decode_func);
}

/* PyUnicodeContains.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_ContainsTF(PyObject* substring, PyObject* text, int eq) {
    int result = PyUnicode_Contains(text, substring);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* PyUnicode_Unicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* PyKeyError_Check.proto */
#define __Pyx_PyExc_KeyError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_KeyError)

/* ModInt[int64_t].proto */
static CYTHON_INLINE int64_t __Pyx_mod_int64_t(int64_t, int64_t, int b_is_constant);

/* PyOverflowError_Check.proto */
#define __Pyx_PyExc_OverflowError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_OverflowError)

/* PyObjectVectorCallMethodKwBuilder.proto */
#if CYTHON_VECTORCALL && PY_VERSION_HEX >= 0x03090000
#define __Pyx_Object_VectorcallMethod_CallFromBuilder PyObject_VectorcallMethod
#else
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#endif

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_MultiplyCObj(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* DivInt[int64_t].proto */
static CYTHON_INLINE int64_t __Pyx_div_int64_t(int64_t, int64_t, int b_is_constant);

/* ModInt[long].proto */
static CYTHON_INLINE long __Pyx_mod_long(long, long, int b_is_constant);

/* bytes_tailmatch.proto */
static int __Pyx_PyBytes_SingleTailmatch(PyObject* self, PyObject* arg,
                                         Py_ssize_t start, Py_ssize_t end, int direction);
static int __Pyx_PyBytes_Tailmatch(PyObject* self, PyObject* substr,
                                   Py_ssize_t start, Py_ssize_t end, int direction);

/* PyMethodNew.proto (used by CythonFunctionShared) */
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ);

/* PyVectorcallFastCallDict.proto (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto (used by CythonFunction) */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API && CYTHON_METH_FASTCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_dict;
#endif
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    PyObject *defaults;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_mstate_global->__pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_mstate_global->__pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_mstate_global->__pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void));
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func,
                                                         PyTypeObject *defaults_type);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* unicode_tailmatch.proto */
static int __Pyx_PyUnicode_Tailmatch(
    PyObject* s, PyObject* substr, Py_ssize_t start, Py_ssize_t end, int direction);

/* PyOSError_Check.proto */
#define __Pyx_PyExc_OSError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_OSError)

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* UnicodeConcatInPlace.proto */
# if CYTHON_COMPILING_IN_CPYTHON
    #if CYTHON_REFNANNY
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared, __pyx_refnanny)
    #else
        #define __Pyx_PyUnicode_ConcatInPlace(left, right, unsafe_shared) __Pyx_PyUnicode_ConcatInPlaceImpl(&left, right, unsafe_shared)
    #endif
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_OwnStrongReference)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_DefinitelyUnique)
    #define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right) __Pyx_PyUnicode_ConcatInPlace(left, right, __Pyx_ReferenceSharing_SharedReference)
    static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    );
#else
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace __Pyx_PyUnicode_Concat
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace __Pyx_PyUnicode_Concat
#endif
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_DefinitelyUniqueInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_FunctionArgumentInPlace(left, right))
#define __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlaceSafe(left, right)\
    ((unlikely((left) == Py_None) || unlikely((right) == Py_None)) ?\
    PyNumber_InPlaceAdd(left, right) : __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_SharedReferenceInPlace(left, right))

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_MultiplyObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceMultiply(op1, op2) : PyNumber_Multiply(op1, op2))
#endif

/* DictGetItem.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* CIntToPyUnicode.proto */
#define __Pyx_PyUnicode_From_uint16_t(value, width, padding_char, format_char) (\
    ((format_char) == ('c')) ?\
        __Pyx_uchar___Pyx_PyUnicode_From_uint16_t(value, width, padding_char) :\
        __Pyx____Pyx_PyUnicode_From_uint16_t(value, width, padding_char, format_char)\
    )
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_uint16_t(uint16_t value, Py_ssize_t width, char padding_char);
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_uint16_t(uint16_t value, Py_ssize_t width, char padding_char, char format_char);

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_RemainderObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceRemainder(op1, op2) : PyNumber_Remainder(op1, op2))
#endif

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_FloorDivideObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceFloorDivide(op1, op2) : PyNumber_FloorDivide(op1, op2))
#endif

/* RejectKeywords.export */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds);

/* PyMemoryError_Check.proto */
#define __Pyx_PyExc_MemoryError_Check(obj)  __Pyx_TypeCheck(obj, PyExc_MemoryError)

/* CheckTypeForFreelists.proto */
#if CYTHON_USE_FREELISTS
#if CYTHON_USE_TYPE_SPECS
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t) == (expected_tp)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  Py_TPFLAGS_IS_ABSTRACT
#else
#define __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, expected_tp, expected_size) ((int) ((t)->tp_basicsize == (expected_size)))
#define __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS  (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)
#endif
#define __PYX_CHECK_TYPE_FOR_FREELISTS(t, expected_tp, expected_size)\
    (__PYX_CHECK_FINAL_TYPE_FOR_FREELISTS((t), (expected_tp), (expected_size)) &\
     (int) (!__Pyx_PyType_HasFeature((t), __PYX_CHECK_TYPE_FOR_FREELIST_FLAGS)))
#endif

/* AllocateExtensionType.proto */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final);

/* ValidateBasesTuple.proto (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
static int __Pyx_MergeVtables(PyTypeObject *type);

/* DelItemOnTypeDict.proto (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k);
#define __Pyx_DelItemOnTypeDict(tp, k) __Pyx__DelItemOnTypeDict((PyTypeObject*)tp, k)

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_2_4
#define __PYX_HAVE_RT_ImportType_proto_3_2_4
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_2_4(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_2_4 {
   __Pyx_ImportType_CheckSize_Error_3_2_4 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_2_4 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_2_4 = 2
};
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size);
#endif

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* ClassMethod.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include "descrobject.h"
#endif
CYTHON_UNUSED static PyObject* __Pyx_Method_ClassMethod(PyObject *method);

/* GetNameInClass.proto */
#define __Pyx_GetNameInClass(var, nmspace, name)  (var) = __Pyx__GetNameInClass(nmspace, name)
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name);

/* PyLongBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* PyRange_Check.proto */
#if CYTHON_COMPILING_IN_PYPY && !defined(PyRange_Check)
  #define PyRange_Check(obj)  __Pyx_TypeCheck((obj), &PyRange_Type)
#endif

/* CLineInTraceback.proto (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#else
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#endif

/* CodeObjectCache.proto (used by AddTraceback) */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject __Pyx_CachedCodeObjectType;
#else
typedef PyCodeObject __Pyx_CachedCodeObjectType;
#endif
typedef struct {
    __Pyx_CachedCodeObjectType* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_int_type accessor_count;
  #endif
};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CheckUnpickleChecksum.proto */
static CYTHON_INLINE int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From___pyx_anon_enum(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE Oid __Pyx_PyLong_As_Oid(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_Oid(Oid value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_ExecStatusType(ExecStatusType value);

/* CIntFromPy.proto */
static CYTHON_INLINE char __Pyx_PyLong_As_char(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE int32_t __Pyx_PyLong_As_int32_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int64_t(int64_t value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_char(char value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint16_t(uint16_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE uint16_t __Pyx_PyLong_As_uint16_t(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE size_t __Pyx_PyLong_As_size_t(PyObject *);

/* UpdateUnpickledDict.proto */
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
#define __Pyx_PyType_GetFullyQualifiedName PyType_GetFullyQualifiedName
#else
static __Pyx_TypeName __Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp);
#endif
#else  // !LIMITED_API
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetFullyQualifiedName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* GetRuntimeVersion.proto */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
static unsigned long __Pyx_cached_runtime_version = 0;
static void __Pyx_init_runtime_version(void);
#else
#define __Pyx_init_runtime_version()
#endif
static unsigned long __Pyx_get_runtime_version(void);

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* DecompressString.proto */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo);

/* MultiPhaseInitModuleState.proto */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
static PyObject *__Pyx_State_FindModule(void*);
static int __Pyx_State_AddModule(PyObject* module, void*);
static int __Pyx_State_RemoveModule(void*);
#elif CYTHON_USE_MODULE_STATE
#define __Pyx_State_FindModule PyState_FindModule
#define __Pyx_State_AddModule PyState_AddModule
#define __Pyx_State_RemoveModule PyState_RemoveModule
#endif

/* #### Code section: module_declarations ### */
/* CythonABIVersion.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
    #if CYTHON_METH_FASTCALL
        #define __PYX_FASTCALL_ABI_SUFFIX  "_fastcall"
    #else
        #define __PYX_FASTCALL_ABI_SUFFIX
    #endif
    #define __PYX_LIMITED_ABI_SUFFIX "limited" __PYX_FASTCALL_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#else
    #define __PYX_LIMITED_ABI_SUFFIX
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    #define __PYX_AM_SEND_ABI_SUFFIX
#elif __PYX_HAS_PY_AM_SEND == 2
    #define __PYX_AM_SEND_ABI_SUFFIX "amsendbackport"
#else
    #define __PYX_AM_SEND_ABI_SUFFIX "noamsend"
#endif
#ifndef __PYX_MONITORING_ABI_SUFFIX
    #define __PYX_MONITORING_ABI_SUFFIX
#endif
#if CYTHON_USE_TP_FINALIZE
    #define __PYX_TP_FINALIZE_ABI_SUFFIX
#else
    #define __PYX_TP_FINALIZE_ABI_SUFFIX "nofinalize"
#endif
#if CYTHON_USE_FREELISTS || !defined(__Pyx_AsyncGen_USED)
    #define __PYX_FREELISTS_ABI_SUFFIX
#else
    #define __PYX_FREELISTS_ABI_SUFFIX "nofreelists"
#endif
#define CYTHON_ABI  __PYX_ABI_VERSION __PYX_LIMITED_ABI_SUFFIX __PYX_MONITORING_ABI_SUFFIX __PYX_TP_FINALIZE_ABI_SUFFIX __PYX_FREELISTS_ABI_SUFFIX __PYX_AM_SEND_ABI_SUFFIX
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self); /* proto*/
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self); /* proto*/
#endif
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_4year_year(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_5month_month(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_3day_day(PyDateTime_Date *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4hour_hour(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6minute_minute(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6second_second(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_11microsecond_microsecond(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_4time_6tzinfo_tzinfo(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4fold_fold(PyDateTime_Time *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4year_year(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_5month_month(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_3day_day(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4hour_hour(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6minute_minute(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6second_second(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4fold_fold(PyDateTime_DateTime *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_3day_day(PyDateTime_Delta *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_6second_second(PyDateTime_Delta *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_11microsecond_microsecond(PyDateTime_Delta *__pyx_v_self); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_7CDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_rv, CYTHON_UNUSED Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_7CDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_7CDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static char *__pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(PyObject *__pyx_v_ba, Py_ssize_t __pyx_v_offset, Py_ssize_t __pyx_v_size); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_7CLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, CYTHON_UNUSED char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_set_pgresult(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_result, int __pyx_skip_dispatch, struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult *__pyx_optional_args); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_as_literal(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_get_row_dumper(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_fmt); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_get_dumper_by_oid(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_oid, PyObject *__pyx_v_fmt); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_dump_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_params, PyObject *__pyx_v_formats, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_load_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_record, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer__c_get_loader(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_oid, PyObject *__pyx_v_fmt); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11ArrayLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_17ArrayBinaryLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10DateDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16DateBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_upgrade(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper__get_offset(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10TimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_12TimeTzDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_upgrade(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_15TimedeltaDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10DateLoader__error_date(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, char const *__pyx_v_data, PyObject *__pyx_v_msg); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10DateLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16DateBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10TimeLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_12TimetzLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_18TimetzBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader__cload_pg(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, char const *__pyx_v_data, char const *__pyx_v_end); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_21TimestampBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader__cload_notimpl(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader__cload_notimpl(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_20IntervalBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10_IntDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16Int2BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16Int4BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16Int8BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_9IntDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_rv, CYTHON_UNUSED Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_9IntDumper_get_key(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_9IntDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_9IntLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16Int2BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16Int4BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16Int8BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15OidBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_12_FloatDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_17FloatBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_18Float4BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11FloatLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_18Float4BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_18Float8BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_13DecimalDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_13NumericLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_19NumericBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19DecimalBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_13NumericDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NumericBinaryDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10BoolDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16BoolBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10BoolLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16BoolBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_14_BaseStrDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10_StrDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11_TextLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_11BytesDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_17BytesBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11ByteaLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_17ByteaBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11_UUIDLoader__return_uuid(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self, uint64_t __pyx_v_low, uint64_t __pyx_v_high); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10UUIDLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16UUIDBinaryLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length); /* proto*/

/* Module declarations from "psycopg_c._psycopg.oids" */

/* Module declarations from "psycopg_c" */

/* Module declarations from "psycopg_c.pq.libpq" */

/* Module declarations from "psycopg_c.pq" */
static int (*__pyx_f_9psycopg_c_2pq__buffer_as_string_and_size)(PyObject *, char **, Py_ssize_t *); /*proto*/

/* Module declarations from "cython" */

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython.version" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "cpython.exc" */

/* Module declarations from "cpython.module" */

/* Module declarations from "cpython.mem" */

/* Module declarations from "cpython.tuple" */

/* Module declarations from "cpython.list" */

/* Module declarations from "cpython.sequence" */

/* Module declarations from "cpython.mapping" */

/* Module declarations from "cpython.iterator" */

/* Module declarations from "cpython.number" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.bool" */

/* Module declarations from "cpython.long" */

/* Module declarations from "cpython.float" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.complex" */

/* Module declarations from "libc.stddef" */

/* Module declarations from "cpython.unicode" */

/* Module declarations from "cpython.pyport" */

/* Module declarations from "cpython.dict" */

/* Module declarations from "cpython.instance" */

/* Module declarations from "cpython.function" */

/* Module declarations from "cpython.method" */

/* Module declarations from "cpython.weakref" */

/* Module declarations from "cpython.getargs" */

/* Module declarations from "cpython.pythread" */

/* Module declarations from "cpython.pystate" */

/* Module declarations from "cpython.set" */

/* Module declarations from "cpython.buffer" */

/* Module declarations from "cpython.bytes" */

/* Module declarations from "cpython.pycapsule" */

/* Module declarations from "cpython.contextvars" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.bytearray" */

/* Module declarations from "libc.stdint" */

/* Module declarations from "cpython.memoryview" */

/* Module declarations from "psycopg_c._psycopg.endian" */

/* Module declarations from "datetime" */

/* Module declarations from "cpython.datetime" */
static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void); /*proto*/
static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_new(int, int, int); /*proto*/
static CYTHON_INLINE PyDateTime_Time *__pyx_f_7cpython_8datetime_time_new(int, int, int, int, PyObject *, struct __pyx_opt_args_7cpython_8datetime_time_new *__pyx_optional_args); /*proto*/
static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_new(int, int, int, int, int, int, int, PyObject *, struct __pyx_opt_args_7cpython_8datetime_datetime_new *__pyx_optional_args); /*proto*/
static CYTHON_INLINE PyDateTime_Delta *__pyx_f_7cpython_8datetime_timedelta_new(int, int, int); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *); /*proto*/

/* Module declarations from "psycopg_c._psycopg" */
static int32_t __pyx_v_9psycopg_c_8_psycopg__binary_null;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_WAIT_W = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_WAIT_R = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_WAIT_RW = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_PY_READY_NONE = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_PY_READY_R = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_PY_READY_W = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_PY_READY_RW = 0;
static int __pyx_v_9psycopg_c_8_psycopg_READY_NONE;
static int __pyx_v_9psycopg_c_8_psycopg_READY_R;
static int __pyx_v_9psycopg_c_8_psycopg_READY_W;
static int __pyx_v_9psycopg_c_8_psycopg_READY_RW;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_date_toordinal = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_date_fromordinal = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_datetime_astimezone = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_time_utcoffset = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_timedelta_total_seconds = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_timezone_utc = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg__month_abbr = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg__timezones = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg__special_float = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg__special_decimal = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg__decimal_special = 0;
static PyObject *__pyx_v_9psycopg_c_8_psycopg__contexts = 0;
static PyObject *__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i;
static PyObject *__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n;
static PyObject *__pyx_f_9psycopg_c_8_psycopg__format_row_binary(PyObject *, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *); /*proto*/
static int __pyx_f_9psycopg_c_8_psycopg__append_binary_none(PyObject *, Py_ssize_t *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__format_row_text(PyObject *, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *); /*proto*/
static int __pyx_f_9psycopg_c_8_psycopg__append_text_none(PyObject *, Py_ssize_t *, int); /*proto*/
static int __pyx_f_9psycopg_c_8_psycopg__consume_notifies(struct __pyx_obj_9psycopg_c_2pq_PGconn *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__as_row_dumper(PyObject *); /*proto*/
static struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_f_9psycopg_c_8_psycopg__tx_from_context(PyObject *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__array_load_text(char const *, size_t, PyObject *, char, char **, size_t *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__parse_token(char const **, char const *, char, char **, size_t *, struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, PyObject *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__array_load_binary(char const *, size_t, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject **); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__array_load_binary_rec(Py_ssize_t, Py_ssize_t *, char const **, PyObject *); /*proto*/
static char const *__pyx_f_9psycopg_c_8_psycopg__parse_date_values(char const *, char const *, int64_t *, int); /*proto*/
static char const *__pyx_f_9psycopg_c_8_psycopg__parse_micros(char const *, int *); /*proto*/
static int __pyx_f_9psycopg_c_8_psycopg__parse_timezone_to_seconds(char const **, char const *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__timezone_from_seconds(int, struct __pyx_opt_args_9psycopg_c_8_psycopg__timezone_from_seconds *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(struct __pyx_obj_9psycopg_c_2pq_PGconn *, char const *, struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg__timezone_from_connection(struct __pyx_obj_9psycopg_c_2pq_PGconn *); /*proto*/
static char const *__pyx_f_9psycopg_c_8_psycopg__get_datestyle(struct __pyx_obj_9psycopg_c_2pq_PGconn *); /*proto*/
static char const *__pyx_f_9psycopg_c_8_psycopg__get_intervalstyle(struct __pyx_obj_9psycopg_c_2pq_PGconn *); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_text(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_numeric_binary(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_text(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_or_sub_to_text(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int2_binary(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int4_binary(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int8_binary(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_numeric_binary(PyObject *, PyObject *, Py_ssize_t); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowLoader__set_state(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *, PyObject *); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowDumper__set_state(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "psycopg_c._psycopg"
extern int __pyx_module_is_main_psycopg_c___psycopg;
int __pyx_module_is_main_psycopg_c___psycopg = 0;

/* Implementation of "psycopg_c._psycopg" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_object;
/* #### Code section: string_decls ### */
static const char __pyx_k_N[] = "\t\\N";
static const char __pyx_k_N_2[] = "\\N";
static const char __pyx_k_NaN[] = "NaN";
static const char __pyx_k_ISO_DMY[] = "ISO, DMY";
static const char __pyx_k_replace[] = "replace";
static const char __pyx_k_TimeZone[] = "TimeZone";
static const char __pyx_k_postgres[] = "postgres";
static const char __pyx_k_DateStyle[] = "DateStyle";
static const char __pyx_k_IntervalStyle[] = "IntervalStyle";
static const char __pyx_k_client_encoding[] = "client_encoding";
static const char __pyx_k_cloader_loadfunc_pyloader[] = "cloader, loadfunc, pyloader";
static const char __pyx_k_standard_conforming_strings[] = "standard_conforming_strings";
static const char __pyx_k_psycopg_c__psycopg_optimization[] = "\npsycopg_c._psycopg optimization module.\n\nThe module contains optimized C code used in preference to Python code\nif a compiler is available.\n";
static const char __pyx_k_cdumper_dumpfunc_format_oid_pydu[] = "cdumper, dumpfunc, format, oid, pydumper";
/* #### Code section: decls ### */
static int __pyx_pf_9psycopg_c_8_psycopg_7CDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_2dump(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_4quote(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_6get_key(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_8upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_3cls___get__(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_10__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_12__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_7CLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, Oid __pyx_v_oid, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_2load(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, PyObject *__pyx_v_data); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_3oid___get__(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_7CLoader_3oid_2__set__(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_format_row_binary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_row, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject *__pyx_v_out); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_2format_row_text(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_row, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject *__pyx_v_out); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_4parse_row_binary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_6parse_row_text(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_8connect(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_conninfo, double __pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11cancel(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGcancelConn *__pyx_v_cancel_conn, double __pyx_v_timeout); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14execute(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17send(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10fetch_many_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20fetch_many(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23fetch(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_26pipeline_communicate(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn, PyObject *__pyx_v_commands); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowLoader___reduce_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowLoader_2__setstate_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowDumper___reduce_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowDumper_2__setstate_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_11Transformer___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_2from_context(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8encoding___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8pgresult___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_4set_pgresult(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_result, PyObject *__pyx_v_set_loaders, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_6set_dumper_types(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_types, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8set_loader_types(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_types, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_10as_literal(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_12get_dumper(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_14dump_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_params, PyObject *__pyx_v_formats); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_16load_rows(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, int __pyx_v_row0, int __pyx_v_row1, PyObject *__pyx_v_make_row); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_18load_row(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, int __pyx_v_row, PyObject *__pyx_v_make_row); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_20load_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_record); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_22get_loader(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_oid, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_10connection___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8adapters___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_5types___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_7formats___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_24__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_26__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_29wait_c(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_gen, int __pyx_v_fileno, PyObject *__pyx_v_interval); /* proto */
static void __pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader___dealloc__(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ArrayBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ArrayBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_2upgrade(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseTimeTextDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimeTzDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimeTzDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimeTzBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_2upgrade(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18DatetimeNoTzDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_10DateLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimetzLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimetzLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimetzBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimetzBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimestampBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimestampBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20IntervalBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20IntervalBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_25_get_timestamp_load_error_is_overflow(PyObject *__pyx_self, PyObject *__pyx_v_s); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_quote(struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper___cinit__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int2Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int2Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int4Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int4Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int8Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int8Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16IntNumericDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16IntNumericDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22IntNumericBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_2upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15IntBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15IntBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15OidBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15OidBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_quote(struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12Float4Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12Float4Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17FloatBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17FloatBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float8BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float8BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_quote(struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19DecimalBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19DecimalBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper___cinit__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_quote(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self, int __pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt16Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt16Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt32Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt32Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt64Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt64Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15NPNumericDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15NPNumericDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt16BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt32BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt64BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21NPNumericBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16_StrBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16_StrBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15StrBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15StrBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19StrBinaryDumperName___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19StrBinaryDumperName_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_StrDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_StrDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9StrDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9StrDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperVarchar___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperVarchar_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13StrDumperName___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13StrDumperName_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperUnknown___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperUnknown_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_11_TextLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_TextLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_TextLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TextLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TextLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TextBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TextBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_11BytesDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_2quote(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17BytesBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17BytesBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ByteaLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ByteaLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ByteaBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ByteaBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10UUIDLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10UUIDLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16UUIDBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16UUIDBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_31__pyx_unpickle_RowLoader(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_9psycopg_c_8_psycopg_33__pyx_unpickle_RowDumper(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_CDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_CLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__CRecursiveLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_RowLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_RowDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Transformer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ArrayLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ArrayBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeTextDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeTzDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeTzBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeTextDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimetzLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimetzBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestampLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestampBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimestamptzLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntervalLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntervalBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int2Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int4Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int8Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntNumericDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntNumericBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_OidBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__FloatDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_FloatDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float4Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_FloatBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_FloatLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float8BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DecimalDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DecimalBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__MixedNumericDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt16Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt32Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt64Dumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPNumericDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt16BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt32BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt64BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPNumericBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseStrDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperVarchar(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperName(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__StrDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperVarchar(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperName(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperUnknown(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__TextLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TextLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TextBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BytesDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BytesBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ByteaLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ByteaBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__UUIDLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_UUIDLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_UUIDBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct__connect(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_3_send(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
/* SmallCodeConfig */
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_PGconn;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_PGresult;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_PGcancelConn;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_PGcancel;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_Escaping;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_PQBuffer;
  PyTypeObject *__pyx_ptype_9psycopg_c_2pq_ViewBuffer;
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  PyTypeObject *__pyx_ptype_7cpython_4bool_bool;
  PyTypeObject *__pyx_ptype_7cpython_7complex_complex;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_date;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_time;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_datetime;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_timedelta;
  PyTypeObject *__pyx_ptype_7cpython_8datetime_tzinfo;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_CDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_CLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_RowLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_RowDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Transformer;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_ArrayLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DateDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimeDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimeTzDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DatetimeDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DateLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimeLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimetzLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimestampLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntervalLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__IntDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int2Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int4Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int8Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntNumericDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_IntLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__FloatDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_FloatDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Float4Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_FloatLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DecimalDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NumericLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NumericDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_BoolDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_BoolLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPNumericDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__BaseStrDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__StrDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrDumperName;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__TextLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TextLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_BytesDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_ByteaLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg__UUIDLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_UUIDLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate;
  PyObject *__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_RowLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_RowDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Transformer;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DateDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DateLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_IntLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__StrDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__TextLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TextLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate;
  PyTypeObject *__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_items;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_pop;
  __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values;
  __Pyx_CachedCFunction __pyx_umethod_PyList_Type_pop;
  PyObject *__pyx_k__8;
  PyObject *__pyx_tuple[4];
  PyObject *__pyx_codeobj_tab[249];
  PyObject *__pyx_string_tab[832];
  PyObject *__pyx_number_tab[11];
/* #### Code section: module_state_contents ### */
/* CommonTypesMetaclass.module_state_decls */
PyTypeObject *__pyx_CommonTypesMetaclassType;

/* IterNextPlain.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
PyObject *__Pyx_GetBuiltinNext_LimitedAPI_cache;
#endif

/* Generator.module_state_decls */
PyTypeObject *__pyx_GeneratorType;

/* CachedMethodType.module_state_decls */
#if CYTHON_COMPILING_IN_LIMITED_API
PyObject *__Pyx_CachedMethodType;
#endif

/* CythonFunctionShared.module_state_decls */
PyTypeObject *__pyx_CyFunctionType;


#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_freelist_9psycopg_c_8_psycopg_CDumper[8];
int __pyx_freecount_9psycopg_c_8_psycopg_CDumper;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_freelist_9psycopg_c_8_psycopg_CLoader[8];
int __pyx_freecount_9psycopg_c_8_psycopg_CLoader;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_freelist_9psycopg_c_8_psycopg_RowLoader[16];
int __pyx_freecount_9psycopg_c_8_psycopg_RowLoader;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_freelist_9psycopg_c_8_psycopg_RowDumper[16];
int __pyx_freecount_9psycopg_c_8_psycopg_RowDumper;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct__connect[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct__connect;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_3_send[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_3_send;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate;
#endif

#if CYTHON_USE_FREELISTS
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error[8];
int __pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error;
#endif
/* CodeObjectCache.module_state_decls */
struct __Pyx_CodeObjectCache __pyx_code_cache;

/* #### Code section: module_state_end ### */
} __pyx_mstatetype;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate_global (__Pyx_PyModule_GetState(__Pyx_State_FindModule(&__pyx_moduledef)))

#define __pyx_m (__Pyx_State_FindModule(&__pyx_moduledef))
#else
static __pyx_mstatetype __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstatetype * const __pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: constant_name_defines ### */
#define __pyx_kp_u_AdaptContext_None __pyx_string_tab[0]
#define __pyx_kp_u_Buffer_None __pyx_string_tab[1]
#define __pyx_kp_u_COPY_cannot_be_used_in_pipeline __pyx_string_tab[2]
#define __pyx_kp_u_Dumper __pyx_string_tab[3]
#define __pyx_kp_u_Infinity_2 __pyx_string_tab[4]
#define __pyx_kp_u_Invalid_UUID_data __pyx_string_tab[5]
#define __pyx_kp_u_Invalid_UUID_string __pyx_string_tab[6]
#define __pyx_kp_u_Loader __pyx_string_tab[7]
#define __pyx_kp_u_None __pyx_string_tab[8]
#define __pyx_kp_u_Note_that_Cython_is_deliberately __pyx_string_tab[9]
#define __pyx_kp_u_PQGenConn_None __pyx_string_tab[10]
#define __pyx_kp_u_PQGenConn_abc_PGconn __pyx_string_tab[11]
#define __pyx_kp_u_PQGen_None __pyx_string_tab[12]
#define __pyx_kp_u_PQGen_PGresult_None __pyx_string_tab[13]
#define __pyx_kp_u_PQGen_RV __pyx_string_tab[14]
#define __pyx_kp_u_PQGen_list_PGresult __pyx_string_tab[15]
#define __pyx_kp_u_PQGen_list_abc_PGresult __pyx_string_tab[16]
#define __pyx_kp_u_PQGen_list_list_PGresult __pyx_string_tab[17]
#define __pyx_kp_u_PostgreSQL_text_fields_cannot_co __pyx_string_tab[18]
#define __pyx_kp_u_Sequence_Any __pyx_string_tab[19]
#define __pyx_kp_u_Sequence_Buffer_None __pyx_string_tab[20]
#define __pyx_kp_u_Sequence_int __pyx_string_tab[21]
#define __pyx_kp_u__11 __pyx_string_tab[22]
#define __pyx_kp_u__3 __pyx_string_tab[23]
#define __pyx_kp_u__4 __pyx_string_tab[24]
#define __pyx_kp_u__6 __pyx_string_tab[25]
#define __pyx_kp_u__7 __pyx_string_tab[26]
#define __pyx_kp_u_add_note __pyx_string_tab[27]
#define __pyx_kp_u_bad_copy_data_field_delimiter_no __pyx_string_tab[28]
#define __pyx_kp_u_bad_copy_data_got_a_tab_at_the_e __pyx_string_tab[29]
#define __pyx_kp_u_bad_copy_data_length_exceeding_d __pyx_string_tab[30]
#define __pyx_kp_u_bad_copy_format_got_a_newline_be __pyx_string_tab[31]
#define __pyx_kp_u_bad_ndigits_in_numeric_binary_re __pyx_string_tab[32]
#define __pyx_kp_u_bad_value_for_numeric_sign_0x __pyx_string_tab[33]
#define __pyx_kp_u_bytes __pyx_string_tab[34]
#define __pyx_kp_u_can_t_parse_date __pyx_string_tab[35]
#define __pyx_kp_u_can_t_parse_interval __pyx_string_tab[36]
#define __pyx_kp_u_can_t_parse_interval_2 __pyx_string_tab[37]
#define __pyx_kp_u_can_t_parse_interval_with_Interv __pyx_string_tab[38]
#define __pyx_kp_u_can_t_parse_time __pyx_string_tab[39]
#define __pyx_kp_u_can_t_parse_timestamp __pyx_string_tab[40]
#define __pyx_kp_u_can_t_parse_timestamptz_with_Dat __pyx_string_tab[41]
#define __pyx_kp_u_can_t_parse_timetz __pyx_string_tab[42]
#define __pyx_kp_u_cancellation_failed __pyx_string_tab[43]
#define __pyx_kp_u_cancellation_timeout_expired __pyx_string_tab[44]
#define __pyx_kp_u_cannot_calculate_the_offset_of_t __pyx_string_tab[45]
#define __pyx_kp_u_cannot_dump __pyx_string_tab[46]
#define __pyx_kp_u_cannot_load_sequence_of __pyx_string_tab[47]
#define __pyx_kp_u_class __pyx_string_tab[48]
#define __pyx_kp_u_connection_failed __pyx_string_tab[49]
#define __pyx_kp_u_connection_is_bad __pyx_string_tab[50]
#define __pyx_kp_u_connection_polled_s __pyx_string_tab[51]
#define __pyx_kp_u_connection_socket_closed __pyx_string_tab[52]
#define __pyx_kp_u_connection_started_s __pyx_string_tab[53]
#define __pyx_kp_u_connection_timeout_expired __pyx_string_tab[54]
#define __pyx_kp_u_consuming_input_failed __pyx_string_tab[55]
#define __pyx_kp_u_couldn_t_allocate_for_escape_byt __pyx_string_tab[56]
#define __pyx_kp_u_couldn_t_allocate_for_unescape_b __pyx_string_tab[57]
#define __pyx_kp_u_d_day_d_second_d_microsecond __pyx_string_tab[58]
#define __pyx_kp_u_date_too_large_after_year_10K __pyx_string_tab[59]
#define __pyx_kp_u_date_too_large_after_year_10K_2 __pyx_string_tab[60]
#define __pyx_kp_u_date_too_small_before_year_1 __pyx_string_tab[61]
#define __pyx_kp_u_date_too_small_before_year_1_2 __pyx_string_tab[62]
#define __pyx_kp_u_deque_PipelineCommand __pyx_string_tab[63]
#define __pyx_kp_u_disable __pyx_string_tab[64]
#define __pyx_kp_u_enable __pyx_string_tab[65]
#define __pyx_kp_u_error_handling_PostgreSQL_timezo __pyx_string_tab[66]
#define __pyx_kp_u_exceeding_the_maximum_allowed __pyx_string_tab[67]
#define __pyx_kp_u_expected __pyx_string_tab[68]
#define __pyx_kp_u_format_should_be_a_psycopg_adapt __pyx_string_tab[69]
#define __pyx_kp_u_format_should_be_a_psycopg_pq_Fo __pyx_string_tab[70]
#define __pyx_kp_u_gc __pyx_string_tab[71]
#define __pyx_kp_u_indefinite_wait_not_supported_an __pyx_string_tab[72]
#define __pyx_kp_u_infinity_2 __pyx_string_tab[73]
#define __pyx_kp_u_integer_expected_got __pyx_string_tab[74]
#define __pyx_kp_u_is_a_dispatcher_to_other_dumper __pyx_string_tab[75]
#define __pyx_kp_u_isenabled __pyx_string_tab[76]
#define __pyx_kp_u_items __pyx_string_tab[77]
#define __pyx_kp_u_list_Row __pyx_string_tab[78]
#define __pyx_kp_u_loaders_registered __pyx_string_tab[79]
#define __pyx_kp_u_malformed_array_empty_data __pyx_string_tab[80]
#define __pyx_kp_u_malformed_array_hit_the_end_of_t __pyx_string_tab[81]
#define __pyx_kp_u_malformed_array_missing_initial __pyx_string_tab[82]
#define __pyx_kp_u_malformed_array_no_after_dimensi __pyx_string_tab[83]
#define __pyx_kp_u_malformed_array_unexpected __pyx_string_tab[84]
#define __pyx_kp_u_no_default___reduce___due_to_non __pyx_string_tab[85]
#define __pyx_kp_u_psycopg_c__psycopg_adapt_pyx __pyx_string_tab[86]
#define __pyx_kp_u_psycopg_c__psycopg_copy_pyx __pyx_string_tab[87]
#define __pyx_kp_u_psycopg_c__psycopg_generators_py __pyx_string_tab[88]
#define __pyx_kp_u_psycopg_c__psycopg_transform_pyx __pyx_string_tab[89]
#define __pyx_kp_u_psycopg_c__psycopg_waiting_pyx __pyx_string_tab[90]
#define __pyx_kp_u_psycopg_c_types_bool_pyx __pyx_string_tab[91]
#define __pyx_kp_u_psycopg_c_types_datetime_pyx __pyx_string_tab[92]
#define __pyx_kp_u_psycopg_c_types_numeric_pyx __pyx_string_tab[93]
#define __pyx_kp_u_psycopg_c_types_string_pyx __pyx_string_tab[94]
#define __pyx_kp_u_result_not_set __pyx_string_tab[95]
#define __pyx_kp_u_row_must_be_included_between_0_a __pyx_string_tab[96]
#define __pyx_kp_u_rows_must_be_included_between_0 __pyx_string_tab[97]
#define __pyx_kp_u_string_too_big_for_an_int __pyx_string_tab[98]
#define __pyx_kp_u_time_not_supported_by_Python_hou __pyx_string_tab[99]
#define __pyx_kp_u_timestamp_too_large_after_year_1 __pyx_string_tab[100]
#define __pyx_kp_u_timestamp_too_large_after_year_1_2 __pyx_string_tab[101]
#define __pyx_kp_u_timestamp_too_small_before_year __pyx_string_tab[102]
#define __pyx_kp_u_timestamp_too_small_before_year_2 __pyx_string_tab[103]
#define __pyx_kp_u_tree_fragment __pyx_string_tab[104]
#define __pyx_kp_u_tuple_Any __pyx_string_tab[105]
#define __pyx_kp_u_unexpected_DateStyle __pyx_string_tab[106]
#define __pyx_kp_u_unexpected_decimal_exponent __pyx_string_tab[107]
#define __pyx_kp_u_unexpected_length __pyx_string_tab[108]
#define __pyx_kp_u_unexpected_number_of_dimensions __pyx_string_tab[109]
#define __pyx_kp_u_unexpected_poll_status __pyx_string_tab[110]
#define __pyx_kp_u_unexpected_ready_value __pyx_string_tab[111]
#define __pyx_kp_u_unknown __pyx_string_tab[112]
#define __pyx_kp_u_unknown_PostgreSQL_timezone_r_wi __pyx_string_tab[113]
#define __pyx_kp_u_unknown_oid_loader_not_found __pyx_string_tab[114]
#define __pyx_kp_u_utf_8 __pyx_string_tab[115]
#define __pyx_kp_u_values_in_row_got __pyx_string_tab[116]
#define __pyx_kp_u_without_a_date __pyx_string_tab[117]
#define __pyx_n_u_AUTO __pyx_string_tab[118]
#define __pyx_n_u_Any __pyx_string_tab[119]
#define __pyx_n_u_ArrayBinaryLoader __pyx_string_tab[120]
#define __pyx_n_u_ArrayBinaryLoader___reduce_cytho __pyx_string_tab[121]
#define __pyx_n_u_ArrayBinaryLoader___setstate_cyt __pyx_string_tab[122]
#define __pyx_n_u_ArrayLoader __pyx_string_tab[123]
#define __pyx_n_u_ArrayLoader___reduce_cython __pyx_string_tab[124]
#define __pyx_n_u_ArrayLoader___setstate_cython __pyx_string_tab[125]
#define __pyx_n_u_BC __pyx_string_tab[126]
#define __pyx_n_u_BINARY __pyx_string_tab[127]
#define __pyx_n_u_BaseDatetimeDumper __pyx_string_tab[128]
#define __pyx_n_u_BaseDatetimeDumper___reduce_cyt __pyx_string_tab[129]
#define __pyx_n_u_BaseDatetimeDumper___setstate_c __pyx_string_tab[130]
#define __pyx_n_u_BaseDatetimeDumper_get_key __pyx_string_tab[131]
#define __pyx_n_u_BaseDatetimeDumper_upgrade __pyx_string_tab[132]
#define __pyx_n_u_BaseDatetimeTextDumper __pyx_string_tab[133]
#define __pyx_n_u_BaseDatetimeTextDumper___reduce __pyx_string_tab[134]
#define __pyx_n_u_BaseDatetimeTextDumper___setsta __pyx_string_tab[135]
#define __pyx_n_u_BaseStrDumper __pyx_string_tab[136]
#define __pyx_n_u_BaseStrDumper___reduce_cython __pyx_string_tab[137]
#define __pyx_n_u_BaseStrDumper___setstate_cython __pyx_string_tab[138]
#define __pyx_n_u_BaseTimeDumper __pyx_string_tab[139]
#define __pyx_n_u_BaseTimeDumper___reduce_cython __pyx_string_tab[140]
#define __pyx_n_u_BaseTimeDumper___setstate_cytho __pyx_string_tab[141]
#define __pyx_n_u_BaseTimeDumper_get_key __pyx_string_tab[142]
#define __pyx_n_u_BaseTimeDumper_upgrade __pyx_string_tab[143]
#define __pyx_n_u_BaseTimeTextDumper __pyx_string_tab[144]
#define __pyx_n_u_BaseTimeTextDumper___reduce_cyt __pyx_string_tab[145]
#define __pyx_n_u_BaseTimeTextDumper___setstate_c __pyx_string_tab[146]
#define __pyx_n_u_BaseTimestamptzLoader __pyx_string_tab[147]
#define __pyx_n_u_BaseTimestamptzLoader___reduce __pyx_string_tab[148]
#define __pyx_n_u_BaseTimestamptzLoader___setstat __pyx_string_tab[149]
#define __pyx_n_u_BoolBinaryDumper __pyx_string_tab[150]
#define __pyx_n_u_BoolBinaryDumper___reduce_cython __pyx_string_tab[151]
#define __pyx_n_u_BoolBinaryDumper___setstate_cyth __pyx_string_tab[152]
#define __pyx_n_u_BoolBinaryLoader __pyx_string_tab[153]
#define __pyx_n_u_BoolBinaryLoader___reduce_cython __pyx_string_tab[154]
#define __pyx_n_u_BoolBinaryLoader___setstate_cyth __pyx_string_tab[155]
#define __pyx_n_u_BoolDumper __pyx_string_tab[156]
#define __pyx_n_u_BoolDumper___reduce_cython __pyx_string_tab[157]
#define __pyx_n_u_BoolDumper___setstate_cython __pyx_string_tab[158]
#define __pyx_n_u_BoolDumper_quote __pyx_string_tab[159]
#define __pyx_n_u_BoolLoader __pyx_string_tab[160]
#define __pyx_n_u_BoolLoader___reduce_cython __pyx_string_tab[161]
#define __pyx_n_u_BoolLoader___setstate_cython __pyx_string_tab[162]
#define __pyx_n_u_Buffer __pyx_string_tab[163]
#define __pyx_n_u_ByteaBinaryLoader __pyx_string_tab[164]
#define __pyx_n_u_ByteaBinaryLoader___reduce_cytho __pyx_string_tab[165]
#define __pyx_n_u_ByteaBinaryLoader___setstate_cyt __pyx_string_tab[166]
#define __pyx_n_u_ByteaLoader __pyx_string_tab[167]
#define __pyx_n_u_ByteaLoader___reduce_cython __pyx_string_tab[168]
#define __pyx_n_u_ByteaLoader___setstate_cython __pyx_string_tab[169]
#define __pyx_n_u_BytesBinaryDumper __pyx_string_tab[170]
#define __pyx_n_u_BytesBinaryDumper___reduce_cytho __pyx_string_tab[171]
#define __pyx_n_u_BytesBinaryDumper___setstate_cyt __pyx_string_tab[172]
#define __pyx_n_u_BytesDumper __pyx_string_tab[173]
#define __pyx_n_u_BytesDumper___reduce_cython __pyx_string_tab[174]
#define __pyx_n_u_BytesDumper___setstate_cython __pyx_string_tab[175]
#define __pyx_n_u_BytesDumper_quote __pyx_string_tab[176]
#define __pyx_n_u_CDumper __pyx_string_tab[177]
#define __pyx_n_u_CDumper___reduce_cython __pyx_string_tab[178]
#define __pyx_n_u_CDumper___setstate_cython __pyx_string_tab[179]
#define __pyx_n_u_CDumper_dump __pyx_string_tab[180]
#define __pyx_n_u_CDumper_get_key __pyx_string_tab[181]
#define __pyx_n_u_CDumper_quote __pyx_string_tab[182]
#define __pyx_n_u_CDumper_upgrade __pyx_string_tab[183]
#define __pyx_n_u_CLoader __pyx_string_tab[184]
#define __pyx_n_u_CLoader___reduce_cython __pyx_string_tab[185]
#define __pyx_n_u_CLoader___setstate_cython __pyx_string_tab[186]
#define __pyx_n_u_CLoader_load __pyx_string_tab[187]
#define __pyx_n_u_CRecursiveLoader __pyx_string_tab[188]
#define __pyx_n_u_CRecursiveLoader___reduce_cytho __pyx_string_tab[189]
#define __pyx_n_u_CRecursiveLoader___setstate_cyt __pyx_string_tab[190]
#define __pyx_n_u_CancellationTimeout __pyx_string_tab[191]
#define __pyx_n_u_ConnectionTimeout __pyx_string_tab[192]
#define __pyx_n_u_Context __pyx_string_tab[193]
#define __pyx_n_u_DataError __pyx_string_tab[194]
#define __pyx_n_u_DatabaseError __pyx_string_tab[195]
#define __pyx_n_u_DateBinaryDumper __pyx_string_tab[196]
#define __pyx_n_u_DateBinaryDumper___reduce_cython __pyx_string_tab[197]
#define __pyx_n_u_DateBinaryDumper___setstate_cyth __pyx_string_tab[198]
#define __pyx_n_u_DateBinaryLoader __pyx_string_tab[199]
#define __pyx_n_u_DateBinaryLoader___reduce_cython __pyx_string_tab[200]
#define __pyx_n_u_DateBinaryLoader___setstate_cyth __pyx_string_tab[201]
#define __pyx_n_u_DateDumper __pyx_string_tab[202]
#define __pyx_n_u_DateDumper___reduce_cython __pyx_string_tab[203]
#define __pyx_n_u_DateDumper___setstate_cython __pyx_string_tab[204]
#define __pyx_n_u_DateLoader __pyx_string_tab[205]
#define __pyx_n_u_DateLoader___reduce_cython __pyx_string_tab[206]
#define __pyx_n_u_DateLoader___setstate_cython __pyx_string_tab[207]
#define __pyx_n_u_DatetimeBinaryDumper __pyx_string_tab[208]
#define __pyx_n_u_DatetimeBinaryDumper___reduce_cy __pyx_string_tab[209]
#define __pyx_n_u_DatetimeBinaryDumper___setstate __pyx_string_tab[210]
#define __pyx_n_u_DatetimeBinaryDumper_upgrade __pyx_string_tab[211]
#define __pyx_n_u_DatetimeDumper __pyx_string_tab[212]
#define __pyx_n_u_DatetimeDumper___reduce_cython __pyx_string_tab[213]
#define __pyx_n_u_DatetimeDumper___setstate_cython __pyx_string_tab[214]
#define __pyx_n_u_DatetimeDumper_upgrade __pyx_string_tab[215]
#define __pyx_n_u_DatetimeNoTzBinaryDumper __pyx_string_tab[216]
#define __pyx_n_u_DatetimeNoTzBinaryDumper___reduc __pyx_string_tab[217]
#define __pyx_n_u_DatetimeNoTzBinaryDumper___setst __pyx_string_tab[218]
#define __pyx_n_u_DatetimeNoTzDumper __pyx_string_tab[219]
#define __pyx_n_u_DatetimeNoTzDumper___reduce_cyth __pyx_string_tab[220]
#define __pyx_n_u_DatetimeNoTzDumper___setstate_cy __pyx_string_tab[221]
#define __pyx_n_u_Decimal __pyx_string_tab[222]
#define __pyx_n_u_DecimalBinaryDumper __pyx_string_tab[223]
#define __pyx_n_u_DecimalBinaryDumper___reduce_cyt __pyx_string_tab[224]
#define __pyx_n_u_DecimalBinaryDumper___setstate_c __pyx_string_tab[225]
#define __pyx_n_u_DecimalDumper __pyx_string_tab[226]
#define __pyx_n_u_DecimalDumper___reduce_cython __pyx_string_tab[227]
#define __pyx_n_u_DecimalDumper___setstate_cython __pyx_string_tab[228]
#define __pyx_n_u_DecimalDumper_quote __pyx_string_tab[229]
#define __pyx_n_u_DefaultContext __pyx_string_tab[230]
#define __pyx_n_u_Float4BinaryDumper __pyx_string_tab[231]
#define __pyx_n_u_Float4BinaryDumper___reduce_cyth __pyx_string_tab[232]
#define __pyx_n_u_Float4BinaryDumper___setstate_cy __pyx_string_tab[233]
#define __pyx_n_u_Float4BinaryLoader __pyx_string_tab[234]
#define __pyx_n_u_Float4BinaryLoader___reduce_cyth __pyx_string_tab[235]
#define __pyx_n_u_Float4BinaryLoader___setstate_cy __pyx_string_tab[236]
#define __pyx_n_u_Float4Dumper __pyx_string_tab[237]
#define __pyx_n_u_Float4Dumper___reduce_cython __pyx_string_tab[238]
#define __pyx_n_u_Float4Dumper___setstate_cython __pyx_string_tab[239]
#define __pyx_n_u_Float8BinaryLoader __pyx_string_tab[240]
#define __pyx_n_u_Float8BinaryLoader___reduce_cyth __pyx_string_tab[241]
#define __pyx_n_u_Float8BinaryLoader___setstate_cy __pyx_string_tab[242]
#define __pyx_n_u_FloatBinaryDumper __pyx_string_tab[243]
#define __pyx_n_u_FloatBinaryDumper___reduce_cytho __pyx_string_tab[244]
#define __pyx_n_u_FloatBinaryDumper___setstate_cyt __pyx_string_tab[245]
#define __pyx_n_u_FloatDumper __pyx_string_tab[246]
#define __pyx_n_u_FloatDumper_2 __pyx_string_tab[247]
#define __pyx_n_u_FloatDumper___reduce_cython __pyx_string_tab[248]
#define __pyx_n_u_FloatDumper___reduce_cython_2 __pyx_string_tab[249]
#define __pyx_n_u_FloatDumper___setstate_cython __pyx_string_tab[250]
#define __pyx_n_u_FloatDumper___setstate_cython_2 __pyx_string_tab[251]
#define __pyx_n_u_FloatDumper_quote __pyx_string_tab[252]
#define __pyx_n_u_FloatLoader __pyx_string_tab[253]
#define __pyx_n_u_FloatLoader___reduce_cython __pyx_string_tab[254]
#define __pyx_n_u_FloatLoader___setstate_cython __pyx_string_tab[255]
#define __pyx_n_u_Format __pyx_string_tab[256]
#define __pyx_n_u_Infinity __pyx_string_tab[257]
#define __pyx_n_u_Int2 __pyx_string_tab[258]
#define __pyx_n_u_Int2BinaryDumper __pyx_string_tab[259]
#define __pyx_n_u_Int2BinaryDumper___reduce_cython __pyx_string_tab[260]
#define __pyx_n_u_Int2BinaryDumper___setstate_cyth __pyx_string_tab[261]
#define __pyx_n_u_Int2BinaryLoader __pyx_string_tab[262]
#define __pyx_n_u_Int2BinaryLoader___reduce_cython __pyx_string_tab[263]
#define __pyx_n_u_Int2BinaryLoader___setstate_cyth __pyx_string_tab[264]
#define __pyx_n_u_Int2Dumper __pyx_string_tab[265]
#define __pyx_n_u_Int2Dumper___reduce_cython __pyx_string_tab[266]
#define __pyx_n_u_Int2Dumper___setstate_cython __pyx_string_tab[267]
#define __pyx_n_u_Int4 __pyx_string_tab[268]
#define __pyx_n_u_Int4BinaryDumper __pyx_string_tab[269]
#define __pyx_n_u_Int4BinaryDumper___reduce_cython __pyx_string_tab[270]
#define __pyx_n_u_Int4BinaryDumper___setstate_cyth __pyx_string_tab[271]
#define __pyx_n_u_Int4BinaryLoader __pyx_string_tab[272]
#define __pyx_n_u_Int4BinaryLoader___reduce_cython __pyx_string_tab[273]
#define __pyx_n_u_Int4BinaryLoader___setstate_cyth __pyx_string_tab[274]
#define __pyx_n_u_Int4Dumper __pyx_string_tab[275]
#define __pyx_n_u_Int4Dumper___reduce_cython __pyx_string_tab[276]
#define __pyx_n_u_Int4Dumper___setstate_cython __pyx_string_tab[277]
#define __pyx_n_u_Int8 __pyx_string_tab[278]
#define __pyx_n_u_Int8BinaryDumper __pyx_string_tab[279]
#define __pyx_n_u_Int8BinaryDumper___reduce_cython __pyx_string_tab[280]
#define __pyx_n_u_Int8BinaryDumper___setstate_cyth __pyx_string_tab[281]
#define __pyx_n_u_Int8BinaryLoader __pyx_string_tab[282]
#define __pyx_n_u_Int8BinaryLoader___reduce_cython __pyx_string_tab[283]
#define __pyx_n_u_Int8BinaryLoader___setstate_cyth __pyx_string_tab[284]
#define __pyx_n_u_Int8Dumper __pyx_string_tab[285]
#define __pyx_n_u_Int8Dumper___reduce_cython __pyx_string_tab[286]
#define __pyx_n_u_Int8Dumper___setstate_cython __pyx_string_tab[287]
#define __pyx_n_u_IntBinaryDumper __pyx_string_tab[288]
#define __pyx_n_u_IntBinaryDumper___reduce_cython __pyx_string_tab[289]
#define __pyx_n_u_IntBinaryDumper___setstate_cytho __pyx_string_tab[290]
#define __pyx_n_u_IntDumper __pyx_string_tab[291]
#define __pyx_n_u_IntDumper_2 __pyx_string_tab[292]
#define __pyx_n_u_IntDumper___reduce_cython __pyx_string_tab[293]
#define __pyx_n_u_IntDumper___reduce_cython_2 __pyx_string_tab[294]
#define __pyx_n_u_IntDumper___setstate_cython __pyx_string_tab[295]
#define __pyx_n_u_IntDumper___setstate_cython_2 __pyx_string_tab[296]
#define __pyx_n_u_IntDumper_get_key __pyx_string_tab[297]
#define __pyx_n_u_IntDumper_quote __pyx_string_tab[298]
#define __pyx_n_u_IntDumper_upgrade __pyx_string_tab[299]
#define __pyx_n_u_IntLoader __pyx_string_tab[300]
#define __pyx_n_u_IntLoader___reduce_cython __pyx_string_tab[301]
#define __pyx_n_u_IntLoader___setstate_cython __pyx_string_tab[302]
#define __pyx_n_u_IntNumeric __pyx_string_tab[303]
#define __pyx_n_u_IntNumericBinaryDumper __pyx_string_tab[304]
#define __pyx_n_u_IntNumericBinaryDumper___reduce __pyx_string_tab[305]
#define __pyx_n_u_IntNumericBinaryDumper___setstat __pyx_string_tab[306]
#define __pyx_n_u_IntNumericDumper __pyx_string_tab[307]
#define __pyx_n_u_IntNumericDumper___reduce_cython __pyx_string_tab[308]
#define __pyx_n_u_IntNumericDumper___setstate_cyth __pyx_string_tab[309]
#define __pyx_n_u_IntOrSubclassDumper __pyx_string_tab[310]
#define __pyx_n_u_IntOrSubclassDumper___reduce_cy __pyx_string_tab[311]
#define __pyx_n_u_IntOrSubclassDumper___setstate __pyx_string_tab[312]
#define __pyx_n_u_InterfaceError __pyx_string_tab[313]
#define __pyx_n_u_InternalError __pyx_string_tab[314]
#define __pyx_n_u_IntervalBinaryLoader __pyx_string_tab[315]
#define __pyx_n_u_IntervalBinaryLoader___reduce_cy __pyx_string_tab[316]
#define __pyx_n_u_IntervalBinaryLoader___setstate __pyx_string_tab[317]
#define __pyx_n_u_IntervalLoader __pyx_string_tab[318]
#define __pyx_n_u_IntervalLoader___reduce_cython __pyx_string_tab[319]
#define __pyx_n_u_IntervalLoader___setstate_cython __pyx_string_tab[320]
#define __pyx_n_u_MixedNumericDumper __pyx_string_tab[321]
#define __pyx_n_u_MixedNumericDumper___reduce_cyt __pyx_string_tab[322]
#define __pyx_n_u_MixedNumericDumper___setstate_c __pyx_string_tab[323]
#define __pyx_n_u_NONE __pyx_string_tab[324]
#define __pyx_n_u_NPInt16BinaryDumper __pyx_string_tab[325]
#define __pyx_n_u_NPInt16BinaryDumper___reduce_cyt __pyx_string_tab[326]
#define __pyx_n_u_NPInt16BinaryDumper___setstate_c __pyx_string_tab[327]
#define __pyx_n_u_NPInt16Dumper __pyx_string_tab[328]
#define __pyx_n_u_NPInt16Dumper___reduce_cython __pyx_string_tab[329]
#define __pyx_n_u_NPInt16Dumper___setstate_cython __pyx_string_tab[330]
#define __pyx_n_u_NPInt32BinaryDumper __pyx_string_tab[331]
#define __pyx_n_u_NPInt32BinaryDumper___reduce_cyt __pyx_string_tab[332]
#define __pyx_n_u_NPInt32BinaryDumper___setstate_c __pyx_string_tab[333]
#define __pyx_n_u_NPInt32Dumper __pyx_string_tab[334]
#define __pyx_n_u_NPInt32Dumper___reduce_cython __pyx_string_tab[335]
#define __pyx_n_u_NPInt32Dumper___setstate_cython __pyx_string_tab[336]
#define __pyx_n_u_NPInt64BinaryDumper __pyx_string_tab[337]
#define __pyx_n_u_NPInt64BinaryDumper___reduce_cyt __pyx_string_tab[338]
#define __pyx_n_u_NPInt64BinaryDumper___setstate_c __pyx_string_tab[339]
#define __pyx_n_u_NPInt64Dumper __pyx_string_tab[340]
#define __pyx_n_u_NPInt64Dumper___reduce_cython __pyx_string_tab[341]
#define __pyx_n_u_NPInt64Dumper___setstate_cython __pyx_string_tab[342]
#define __pyx_n_u_NPNumericBinaryDumper __pyx_string_tab[343]
#define __pyx_n_u_NPNumericBinaryDumper___reduce_c __pyx_string_tab[344]
#define __pyx_n_u_NPNumericBinaryDumper___setstate __pyx_string_tab[345]
#define __pyx_n_u_NPNumericDumper __pyx_string_tab[346]
#define __pyx_n_u_NPNumericDumper___reduce_cython __pyx_string_tab[347]
#define __pyx_n_u_NPNumericDumper___setstate_cytho __pyx_string_tab[348]
#define __pyx_n_u_NaN __pyx_string_tab[349]
#define __pyx_n_u_None __pyx_string_tab[350]
#define __pyx_n_u_NoneType __pyx_string_tab[351]
#define __pyx_n_u_NotSupportedError __pyx_string_tab[352]
#define __pyx_n_u_NumericBinaryDumper __pyx_string_tab[353]
#define __pyx_n_u_NumericBinaryDumper___reduce_cyt __pyx_string_tab[354]
#define __pyx_n_u_NumericBinaryDumper___setstate_c __pyx_string_tab[355]
#define __pyx_n_u_NumericBinaryLoader __pyx_string_tab[356]
#define __pyx_n_u_NumericBinaryLoader___reduce_cyt __pyx_string_tab[357]
#define __pyx_n_u_NumericBinaryLoader___setstate_c __pyx_string_tab[358]
#define __pyx_n_u_NumericDumper __pyx_string_tab[359]
#define __pyx_n_u_NumericDumper___reduce_cython __pyx_string_tab[360]
#define __pyx_n_u_NumericDumper___setstate_cython __pyx_string_tab[361]
#define __pyx_n_u_NumericLoader __pyx_string_tab[362]
#define __pyx_n_u_NumericLoader___reduce_cython __pyx_string_tab[363]
#define __pyx_n_u_NumericLoader___setstate_cython __pyx_string_tab[364]
#define __pyx_n_u_OidBinaryLoader __pyx_string_tab[365]
#define __pyx_n_u_OidBinaryLoader___reduce_cython __pyx_string_tab[366]
#define __pyx_n_u_OidBinaryLoader___setstate_cytho __pyx_string_tab[367]
#define __pyx_n_u_OperationalError __pyx_string_tab[368]
#define __pyx_n_u_PG_AUTO __pyx_string_tab[369]
#define __pyx_n_u_PG_BINARY __pyx_string_tab[370]
#define __pyx_n_u_PG_TEXT __pyx_string_tab[371]
#define __pyx_n_u_PQGen __pyx_string_tab[372]
#define __pyx_n_u_PQ_BINARY __pyx_string_tab[373]
#define __pyx_n_u_PQ_TEXT __pyx_string_tab[374]
#define __pyx_n_u_PipelineCommand __pyx_string_tab[375]
#define __pyx_n_u_PqFormat __pyx_string_tab[376]
#define __pyx_n_u_ProgrammingError __pyx_string_tab[377]
#define __pyx_n_u_PyFormat __pyx_string_tab[378]
#define __pyx_n_u_Pyx_PyDict_NextRef __pyx_string_tab[379]
#define __pyx_n_u_R __pyx_string_tab[380]
#define __pyx_n_u_RV __pyx_string_tab[381]
#define __pyx_n_u_RW __pyx_string_tab[382]
#define __pyx_n_u_Ready __pyx_string_tab[383]
#define __pyx_n_u_Row __pyx_string_tab[384]
#define __pyx_n_u_RowDumper __pyx_string_tab[385]
#define __pyx_n_u_RowDumper___reduce_cython __pyx_string_tab[386]
#define __pyx_n_u_RowDumper___setstate_cython __pyx_string_tab[387]
#define __pyx_n_u_RowLoader __pyx_string_tab[388]
#define __pyx_n_u_RowLoader___reduce_cython __pyx_string_tab[389]
#define __pyx_n_u_RowLoader___setstate_cython __pyx_string_tab[390]
#define __pyx_n_u_SafeUUID_unknown __pyx_string_tab[391]
#define __pyx_n_u_Sequence __pyx_string_tab[392]
#define __pyx_n_u_StrBinaryDumper __pyx_string_tab[393]
#define __pyx_n_u_StrBinaryDumperName __pyx_string_tab[394]
#define __pyx_n_u_StrBinaryDumperName___reduce_cyt __pyx_string_tab[395]
#define __pyx_n_u_StrBinaryDumperName___setstate_c __pyx_string_tab[396]
#define __pyx_n_u_StrBinaryDumperVarchar __pyx_string_tab[397]
#define __pyx_n_u_StrBinaryDumperVarchar___reduce __pyx_string_tab[398]
#define __pyx_n_u_StrBinaryDumperVarchar___setstat __pyx_string_tab[399]
#define __pyx_n_u_StrBinaryDumper_2 __pyx_string_tab[400]
#define __pyx_n_u_StrBinaryDumper___reduce_cython __pyx_string_tab[401]
#define __pyx_n_u_StrBinaryDumper___reduce_cython_2 __pyx_string_tab[402]
#define __pyx_n_u_StrBinaryDumper___setstate_cyth __pyx_string_tab[403]
#define __pyx_n_u_StrBinaryDumper___setstate_cytho __pyx_string_tab[404]
#define __pyx_n_u_StrDumper __pyx_string_tab[405]
#define __pyx_n_u_StrDumperName __pyx_string_tab[406]
#define __pyx_n_u_StrDumperName___reduce_cython __pyx_string_tab[407]
#define __pyx_n_u_StrDumperName___setstate_cython __pyx_string_tab[408]
#define __pyx_n_u_StrDumperUnknown __pyx_string_tab[409]
#define __pyx_n_u_StrDumperUnknown___reduce_cython __pyx_string_tab[410]
#define __pyx_n_u_StrDumperUnknown___setstate_cyth __pyx_string_tab[411]
#define __pyx_n_u_StrDumperVarchar __pyx_string_tab[412]
#define __pyx_n_u_StrDumperVarchar___reduce_cython __pyx_string_tab[413]
#define __pyx_n_u_StrDumperVarchar___setstate_cyth __pyx_string_tab[414]
#define __pyx_n_u_StrDumper_2 __pyx_string_tab[415]
#define __pyx_n_u_StrDumper___reduce_cython __pyx_string_tab[416]
#define __pyx_n_u_StrDumper___reduce_cython_2 __pyx_string_tab[417]
#define __pyx_n_u_StrDumper___setstate_cython __pyx_string_tab[418]
#define __pyx_n_u_StrDumper___setstate_cython_2 __pyx_string_tab[419]
#define __pyx_n_u_TEXT __pyx_string_tab[420]
#define __pyx_n_u_TextBinaryLoader __pyx_string_tab[421]
#define __pyx_n_u_TextBinaryLoader___reduce_cython __pyx_string_tab[422]
#define __pyx_n_u_TextBinaryLoader___setstate_cyth __pyx_string_tab[423]
#define __pyx_n_u_TextLoader __pyx_string_tab[424]
#define __pyx_n_u_TextLoader_2 __pyx_string_tab[425]
#define __pyx_n_u_TextLoader___reduce_cython __pyx_string_tab[426]
#define __pyx_n_u_TextLoader___reduce_cython_2 __pyx_string_tab[427]
#define __pyx_n_u_TextLoader___setstate_cython __pyx_string_tab[428]
#define __pyx_n_u_TextLoader___setstate_cython_2 __pyx_string_tab[429]
#define __pyx_n_u_TimeBinaryDumper __pyx_string_tab[430]
#define __pyx_n_u_TimeBinaryDumper___reduce_cython __pyx_string_tab[431]
#define __pyx_n_u_TimeBinaryDumper___setstate_cyth __pyx_string_tab[432]
#define __pyx_n_u_TimeBinaryDumper_upgrade __pyx_string_tab[433]
#define __pyx_n_u_TimeBinaryLoader __pyx_string_tab[434]
#define __pyx_n_u_TimeBinaryLoader___reduce_cython __pyx_string_tab[435]
#define __pyx_n_u_TimeBinaryLoader___setstate_cyth __pyx_string_tab[436]
#define __pyx_n_u_TimeDumper __pyx_string_tab[437]
#define __pyx_n_u_TimeDumper___reduce_cython __pyx_string_tab[438]
#define __pyx_n_u_TimeDumper___setstate_cython __pyx_string_tab[439]
#define __pyx_n_u_TimeDumper_upgrade __pyx_string_tab[440]
#define __pyx_n_u_TimeLoader __pyx_string_tab[441]
#define __pyx_n_u_TimeLoader___reduce_cython __pyx_string_tab[442]
#define __pyx_n_u_TimeLoader___setstate_cython __pyx_string_tab[443]
#define __pyx_n_u_TimeTzBinaryDumper __pyx_string_tab[444]
#define __pyx_n_u_TimeTzBinaryDumper___reduce_cyth __pyx_string_tab[445]
#define __pyx_n_u_TimeTzBinaryDumper___setstate_cy __pyx_string_tab[446]
#define __pyx_n_u_TimeTzDumper __pyx_string_tab[447]
#define __pyx_n_u_TimeTzDumper___reduce_cython __pyx_string_tab[448]
#define __pyx_n_u_TimeTzDumper___setstate_cython __pyx_string_tab[449]
#define __pyx_n_u_TimedeltaBinaryDumper __pyx_string_tab[450]
#define __pyx_n_u_TimedeltaBinaryDumper___reduce_c __pyx_string_tab[451]
#define __pyx_n_u_TimedeltaBinaryDumper___setstate __pyx_string_tab[452]
#define __pyx_n_u_TimedeltaDumper __pyx_string_tab[453]
#define __pyx_n_u_TimedeltaDumper___reduce_cython __pyx_string_tab[454]
#define __pyx_n_u_TimedeltaDumper___setstate_cytho __pyx_string_tab[455]
#define __pyx_n_u_TimestampBinaryLoader __pyx_string_tab[456]
#define __pyx_n_u_TimestampBinaryLoader___reduce_c __pyx_string_tab[457]
#define __pyx_n_u_TimestampBinaryLoader___setstate __pyx_string_tab[458]
#define __pyx_n_u_TimestampLoader __pyx_string_tab[459]
#define __pyx_n_u_TimestampLoader___reduce_cython __pyx_string_tab[460]
#define __pyx_n_u_TimestampLoader___setstate_cytho __pyx_string_tab[461]
#define __pyx_n_u_TimestamptzBinaryLoader __pyx_string_tab[462]
#define __pyx_n_u_TimestamptzBinaryLoader___reduce __pyx_string_tab[463]
#define __pyx_n_u_TimestamptzBinaryLoader___setsta __pyx_string_tab[464]
#define __pyx_n_u_TimestamptzLoader __pyx_string_tab[465]
#define __pyx_n_u_TimestamptzLoader___reduce_cytho __pyx_string_tab[466]
#define __pyx_n_u_TimestamptzLoader___setstate_cyt __pyx_string_tab[467]
#define __pyx_n_u_TimetzBinaryLoader __pyx_string_tab[468]
#define __pyx_n_u_TimetzBinaryLoader___reduce_cyth __pyx_string_tab[469]
#define __pyx_n_u_TimetzBinaryLoader___setstate_cy __pyx_string_tab[470]
#define __pyx_n_u_TimetzLoader __pyx_string_tab[471]
#define __pyx_n_u_TimetzLoader___reduce_cython __pyx_string_tab[472]
#define __pyx_n_u_TimetzLoader___setstate_cython __pyx_string_tab[473]
#define __pyx_n_u_Transformer __pyx_string_tab[474]
#define __pyx_n_u_Transformer___reduce_cython __pyx_string_tab[475]
#define __pyx_n_u_Transformer___setstate_cython __pyx_string_tab[476]
#define __pyx_n_u_Transformer_as_literal __pyx_string_tab[477]
#define __pyx_n_u_Transformer_dump_sequence __pyx_string_tab[478]
#define __pyx_n_u_Transformer_from_context __pyx_string_tab[479]
#define __pyx_n_u_Transformer_get_dumper __pyx_string_tab[480]
#define __pyx_n_u_Transformer_get_loader __pyx_string_tab[481]
#define __pyx_n_u_Transformer_load_row __pyx_string_tab[482]
#define __pyx_n_u_Transformer_load_rows __pyx_string_tab[483]
#define __pyx_n_u_Transformer_load_sequence __pyx_string_tab[484]
#define __pyx_n_u_Transformer_set_dumper_types __pyx_string_tab[485]
#define __pyx_n_u_Transformer_set_loader_types __pyx_string_tab[486]
#define __pyx_n_u_Transformer_set_pgresult __pyx_string_tab[487]
#define __pyx_n_u_TypeVar __pyx_string_tab[488]
#define __pyx_n_u_UTC __pyx_string_tab[489]
#define __pyx_n_u_UUID __pyx_string_tab[490]
#define __pyx_n_u_UUIDBinaryLoader __pyx_string_tab[491]
#define __pyx_n_u_UUIDBinaryLoader___reduce_cython __pyx_string_tab[492]
#define __pyx_n_u_UUIDBinaryLoader___setstate_cyth __pyx_string_tab[493]
#define __pyx_n_u_UUIDLoader __pyx_string_tab[494]
#define __pyx_n_u_UUIDLoader_2 __pyx_string_tab[495]
#define __pyx_n_u_UUIDLoader___reduce_cython __pyx_string_tab[496]
#define __pyx_n_u_UUIDLoader___reduce_cython_2 __pyx_string_tab[497]
#define __pyx_n_u_UUIDLoader___setstate_cython __pyx_string_tab[498]
#define __pyx_n_u_UUIDLoader___setstate_cython_2 __pyx_string_tab[499]
#define __pyx_n_u_W __pyx_string_tab[500]
#define __pyx_n_u_Wait __pyx_string_tab[501]
#define __pyx_n_u_WritableUUID __pyx_string_tab[502]
#define __pyx_n_u_X __pyx_string_tab[503]
#define __pyx_n_u_ZoneInfo __pyx_string_tab[504]
#define __pyx_n_u_abc __pyx_string_tab[505]
#define __pyx_n_u_adapters __pyx_string_tab[506]
#define __pyx_n_u_array_oid __pyx_string_tab[507]
#define __pyx_n_u_as_literal __pyx_string_tab[508]
#define __pyx_n_u_as_tuple __pyx_string_tab[509]
#define __pyx_n_u_astimezone __pyx_string_tab[510]
#define __pyx_n_u_asyncio_coroutines __pyx_string_tab[511]
#define __pyx_n_u_attval __pyx_string_tab[512]
#define __pyx_n_u_b __pyx_string_tab[513]
#define __pyx_n_u_base_oid __pyx_string_tab[514]
#define __pyx_n_u_belength __pyx_string_tab[515]
#define __pyx_n_u_benfields __pyx_string_tab[516]
#define __pyx_n_u_bit_length __pyx_string_tab[517]
#define __pyx_n_u_bool __pyx_string_tab[518]
#define __pyx_n_u_bufend __pyx_string_tab[519]
#define __pyx_n_u_bufsize __pyx_string_tab[520]
#define __pyx_n_u_bytearray __pyx_string_tab[521]
#define __pyx_n_u_cancel __pyx_string_tab[522]
#define __pyx_n_u_cancel_conn __pyx_string_tab[523]
#define __pyx_n_u_cinterval __pyx_string_tab[524]
#define __pyx_n_u_cires __pyx_string_tab[525]
#define __pyx_n_u_class_2 __pyx_string_tab[526]
#define __pyx_n_u_class_getitem __pyx_string_tab[527]
#define __pyx_n_u_cline_in_traceback __pyx_string_tab[528]
#define __pyx_n_u_close __pyx_string_tab[529]
#define __pyx_n_u_cls __pyx_string_tab[530]
#define __pyx_n_u_col __pyx_string_tab[531]
#define __pyx_n_u_collections __pyx_string_tab[532]
#define __pyx_n_u_commands __pyx_string_tab[533]
#define __pyx_n_u_conn __pyx_string_tab[534]
#define __pyx_n_u_conn_encoding __pyx_string_tab[535]
#define __pyx_n_u_conn_status __pyx_string_tab[536]
#define __pyx_n_u_connect __pyx_string_tab[537]
#define __pyx_n_u_connect_start __pyx_string_tab[538]
#define __pyx_n_u_connection __pyx_string_tab[539]
#define __pyx_n_u_conninfo __pyx_string_tab[540]
#define __pyx_n_u_conninfo_encoding __pyx_string_tab[541]
#define __pyx_n_u_context __pyx_string_tab[542]
#define __pyx_n_u_cready __pyx_string_tab[543]
#define __pyx_n_u_data __pyx_string_tab[544]
#define __pyx_n_u_date __pyx_string_tab[545]
#define __pyx_n_u_datetime __pyx_string_tab[546]
#define __pyx_n_u_days __pyx_string_tab[547]
#define __pyx_n_u_deadline __pyx_string_tab[548]
#define __pyx_n_u_debug __pyx_string_tab[549]
#define __pyx_n_u_decimal __pyx_string_tab[550]
#define __pyx_n_u_delimiter __pyx_string_tab[551]
#define __pyx_n_u_deque __pyx_string_tab[552]
#define __pyx_n_u_dict __pyx_string_tab[553]
#define __pyx_n_u_dict_2 __pyx_string_tab[554]
#define __pyx_n_u_ds __pyx_string_tab[555]
#define __pyx_n_u_dump __pyx_string_tab[556]
#define __pyx_n_u_dump_sequence __pyx_string_tab[557]
#define __pyx_n_u_dumper_ptr __pyx_string_tab[558]
#define __pyx_n_u_dumpers __pyx_string_tab[559]
#define __pyx_n_u_e __pyx_string_tab[560]
#define __pyx_n_u_encode __pyx_string_tab[561]
#define __pyx_n_u_encoding __pyx_string_tab[562]
#define __pyx_n_u_enumerate __pyx_string_tab[563]
#define __pyx_n_u_errors __pyx_string_tab[564]
#define __pyx_n_u_esc __pyx_string_tab[565]
#define __pyx_n_u_escaped __pyx_string_tab[566]
#define __pyx_n_u_ex __pyx_string_tab[567]
#define __pyx_n_u_execute __pyx_string_tab[568]
#define __pyx_n_u_fend __pyx_string_tab[569]
#define __pyx_n_u_fetch __pyx_string_tab[570]
#define __pyx_n_u_fetch_many __pyx_string_tab[571]
#define __pyx_n_u_fetch_many_locals_genexpr __pyx_string_tab[572]
#define __pyx_n_u_field __pyx_string_tab[573]
#define __pyx_n_u_fileno __pyx_string_tab[574]
#define __pyx_n_u_finish_pgconn __pyx_string_tab[575]
#define __pyx_n_u_float __pyx_string_tab[576]
#define __pyx_n_u_format __pyx_string_tab[577]
#define __pyx_n_u_format_row_binary __pyx_string_tab[578]
#define __pyx_n_u_format_row_text __pyx_string_tab[579]
#define __pyx_n_u_formats __pyx_string_tab[580]
#define __pyx_n_u_from_context __pyx_string_tab[581]
#define __pyx_n_u_fromordinal __pyx_string_tab[582]
#define __pyx_n_u_fstart __pyx_string_tab[583]
#define __pyx_n_u_fstat __pyx_string_tab[584]
#define __pyx_n_u_func __pyx_string_tab[585]
#define __pyx_n_u_gen __pyx_string_tab[586]
#define __pyx_n_u_genexpr __pyx_string_tab[587]
#define __pyx_n_u_get __pyx_string_tab[588]
#define __pyx_n_u_getLogger __pyx_string_tab[589]
#define __pyx_n_u_get_dumper __pyx_string_tab[590]
#define __pyx_n_u_get_dumper_by_oid __pyx_string_tab[591]
#define __pyx_n_u_get_error_message __pyx_string_tab[592]
#define __pyx_n_u_get_key __pyx_string_tab[593]
#define __pyx_n_u_get_loader __pyx_string_tab[594]
#define __pyx_n_u_get_timestamp_load_error_locals __pyx_string_tab[595]
#define __pyx_n_u_getstate __pyx_string_tab[596]
#define __pyx_n_u_i __pyx_string_tab[597]
#define __pyx_n_u_i_2 __pyx_string_tab[598]
#define __pyx_n_u_ibres __pyx_string_tab[599]
#define __pyx_n_u_infinity __pyx_string_tab[600]
#define __pyx_n_u_int __pyx_string_tab[601]
#define __pyx_n_u_int2_dumper __pyx_string_tab[602]
#define __pyx_n_u_int4_dumper __pyx_string_tab[603]
#define __pyx_n_u_int8_dumper __pyx_string_tab[604]
#define __pyx_n_u_int_classes __pyx_string_tab[605]
#define __pyx_n_u_int_numeric_dumper __pyx_string_tab[606]
#define __pyx_n_u_integer __pyx_string_tab[607]
#define __pyx_n_u_interval __pyx_string_tab[608]
#define __pyx_n_u_ires __pyx_string_tab[609]
#define __pyx_n_u_is_coroutine __pyx_string_tab[610]
#define __pyx_n_u_is_overflow __pyx_string_tab[611]
#define __pyx_n_u_is_safe __pyx_string_tab[612]
#define __pyx_n_u_items_2 __pyx_string_tab[613]
#define __pyx_n_u_length __pyx_string_tab[614]
#define __pyx_n_u_load __pyx_string_tab[615]
#define __pyx_n_u_load_row __pyx_string_tab[616]
#define __pyx_n_u_load_rows __pyx_string_tab[617]
#define __pyx_n_u_load_sequence __pyx_string_tab[618]
#define __pyx_n_u_loader __pyx_string_tab[619]
#define __pyx_n_u_loaders __pyx_string_tab[620]
#define __pyx_n_u_logger __pyx_string_tab[621]
#define __pyx_n_u_logging __pyx_string_tab[622]
#define __pyx_n_u_main __pyx_string_tab[623]
#define __pyx_n_u_make_row __pyx_string_tab[624]
#define __pyx_n_u_max __pyx_string_tab[625]
#define __pyx_n_u_microseconds __pyx_string_tab[626]
#define __pyx_n_u_min __pyx_string_tab[627]
#define __pyx_n_u_module __pyx_string_tab[628]
#define __pyx_n_u_modules __pyx_string_tab[629]
#define __pyx_n_u_monotonic __pyx_string_tab[630]
#define __pyx_n_u_name __pyx_string_tab[631]
#define __pyx_n_u_name_2 __pyx_string_tab[632]
#define __pyx_n_u_new __pyx_string_tab[633]
#define __pyx_n_u_next __pyx_string_tab[634]
#define __pyx_n_u_nfields __pyx_string_tab[635]
#define __pyx_n_u_nonblocking __pyx_string_tab[636]
#define __pyx_n_u_ntypes __pyx_string_tab[637]
#define __pyx_n_u_num_bs __pyx_string_tab[638]
#define __pyx_n_u_numpy __pyx_string_tab[639]
#define __pyx_n_u_obj __pyx_string_tab[640]
#define __pyx_n_u_object __pyx_string_tab[641]
#define __pyx_n_u_oid __pyx_string_tab[642]
#define __pyx_n_u_os __pyx_string_tab[643]
#define __pyx_n_u_out __pyx_string_tab[644]
#define __pyx_n_u_params __pyx_string_tab[645]
#define __pyx_n_u_parse_row_binary __pyx_string_tab[646]
#define __pyx_n_u_parse_row_text __pyx_string_tab[647]
#define __pyx_n_u_pg2pyenc __pyx_string_tab[648]
#define __pyx_n_u_pgcancelconn_ptr __pyx_string_tab[649]
#define __pyx_n_u_pgconn __pyx_string_tab[650]
#define __pyx_n_u_pgconn_ptr __pyx_string_tab[651]
#define __pyx_n_u_pgres __pyx_string_tab[652]
#define __pyx_n_u_pipeline_communicate __pyx_string_tab[653]
#define __pyx_n_u_poll_status __pyx_string_tab[654]
#define __pyx_n_u_pop __pyx_string_tab[655]
#define __pyx_n_u_popleft __pyx_string_tab[656]
#define __pyx_n_u_postgres __pyx_string_tab[657]
#define __pyx_n_u_pq_Format __pyx_string_tab[658]
#define __pyx_n_u_prec __pyx_string_tab[659]
#define __pyx_n_u_psycopg __pyx_string_tab[660]
#define __pyx_n_u_psycopg__encodings __pyx_string_tab[661]
#define __pyx_n_u_psycopg__enums __pyx_string_tab[662]
#define __pyx_n_u_psycopg__wrappers __pyx_string_tab[663]
#define __pyx_n_u_psycopg_abc __pyx_string_tab[664]
#define __pyx_n_u_psycopg_c __pyx_string_tab[665]
#define __pyx_n_u_psycopg_c__psycopg __pyx_string_tab[666]
#define __pyx_n_u_psycopg_pq __pyx_string_tab[667]
#define __pyx_n_u_psycopg_rows __pyx_string_tab[668]
#define __pyx_n_u_ptr __pyx_string_tab[669]
#define __pyx_n_u_ptr_out __pyx_string_tab[670]
#define __pyx_n_u_py_Format __pyx_string_tab[671]
#define __pyx_n_u_pyready __pyx_string_tab[672]
#define __pyx_n_u_pyval __pyx_string_tab[673]
#define __pyx_n_u_pyx_checksum __pyx_string_tab[674]
#define __pyx_n_u_pyx_result __pyx_string_tab[675]
#define __pyx_n_u_pyx_state __pyx_string_tab[676]
#define __pyx_n_u_pyx_type __pyx_string_tab[677]
#define __pyx_n_u_pyx_unpickle_RowDumper __pyx_string_tab[678]
#define __pyx_n_u_pyx_unpickle_RowLoader __pyx_string_tab[679]
#define __pyx_n_u_pyx_vtable __pyx_string_tab[680]
#define __pyx_n_u_qualname __pyx_string_tab[681]
#define __pyx_n_u_quote __pyx_string_tab[682]
#define __pyx_n_u_r __pyx_string_tab[683]
#define __pyx_n_u_ready __pyx_string_tab[684]
#define __pyx_n_u_record __pyx_string_tab[685]
#define __pyx_n_u_records __pyx_string_tab[686]
#define __pyx_n_u_reduce __pyx_string_tab[687]
#define __pyx_n_u_reduce_cython __pyx_string_tab[688]
#define __pyx_n_u_reduce_ex __pyx_string_tab[689]
#define __pyx_n_u_regtype __pyx_string_tab[690]
#define __pyx_n_u_replace __pyx_string_tab[691]
#define __pyx_n_u_res __pyx_string_tab[692]
#define __pyx_n_u_result __pyx_string_tab[693]
#define __pyx_n_u_results __pyx_string_tab[694]
#define __pyx_n_u_return __pyx_string_tab[695]
#define __pyx_n_u_row __pyx_string_tab[696]
#define __pyx_n_u_row0 __pyx_string_tab[697]
#define __pyx_n_u_row1 __pyx_string_tab[698]
#define __pyx_n_u_row_dumper __pyx_string_tab[699]
#define __pyx_n_u_row_loader __pyx_string_tab[700]
#define __pyx_n_u_row_loaders __pyx_string_tab[701]
#define __pyx_n_u_rowend __pyx_string_tab[702]
#define __pyx_n_u_rv __pyx_string_tab[703]
#define __pyx_n_u_s __pyx_string_tab[704]
#define __pyx_n_u_scaleb __pyx_string_tab[705]
#define __pyx_n_u_scs __pyx_string_tab[706]
#define __pyx_n_u_seconds __pyx_string_tab[707]
#define __pyx_n_u_self __pyx_string_tab[708]
#define __pyx_n_u_send __pyx_string_tab[709]
#define __pyx_n_u_set_dumper_types __pyx_string_tab[710]
#define __pyx_n_u_set_loader_types __pyx_string_tab[711]
#define __pyx_n_u_set_loaders __pyx_string_tab[712]
#define __pyx_n_u_set_name __pyx_string_tab[713]
#define __pyx_n_u_set_pgresult __pyx_string_tab[714]
#define __pyx_n_u_setdefault __pyx_string_tab[715]
#define __pyx_n_u_setstate __pyx_string_tab[716]
#define __pyx_n_u_setstate_cython __pyx_string_tab[717]
#define __pyx_n_u_shift __pyx_string_tab[718]
#define __pyx_n_u_size __pyx_string_tab[719]
#define __pyx_n_u_split __pyx_string_tab[720]
#define __pyx_n_u_src __pyx_string_tab[721]
#define __pyx_n_u_state __pyx_string_tab[722]
#define __pyx_n_u_status __pyx_string_tab[723]
#define __pyx_n_u_str __pyx_string_tab[724]
#define __pyx_n_u_sys __pyx_string_tab[725]
#define __pyx_n_u_test __pyx_string_tab[726]
#define __pyx_n_u_tgt __pyx_string_tab[727]
#define __pyx_n_u_throw __pyx_string_tab[728]
#define __pyx_n_u_time __pyx_string_tab[729]
#define __pyx_n_u_timedelta __pyx_string_tab[730]
#define __pyx_n_u_timeout __pyx_string_tab[731]
#define __pyx_n_u_timezone __pyx_string_tab[732]
#define __pyx_n_u_toordinal __pyx_string_tab[733]
#define __pyx_n_u_total_seconds __pyx_string_tab[734]
#define __pyx_n_u_tx __pyx_string_tab[735]
#define __pyx_n_u_types __pyx_string_tab[736]
#define __pyx_n_u_types_fast __pyx_string_tab[737]
#define __pyx_n_u_typing __pyx_string_tab[738]
#define __pyx_n_u_tzinfo __pyx_string_tab[739]
#define __pyx_n_u_update __pyx_string_tab[740]
#define __pyx_n_u_upgrade __pyx_string_tab[741]
#define __pyx_n_u_use_setstate __pyx_string_tab[742]
#define __pyx_n_u_utc __pyx_string_tab[743]
#define __pyx_n_u_utcoffset __pyx_string_tab[744]
#define __pyx_n_u_uuid __pyx_string_tab[745]
#define __pyx_n_u_value __pyx_string_tab[746]
#define __pyx_n_u_values __pyx_string_tab[747]
#define __pyx_n_u_wait __pyx_string_tab[748]
#define __pyx_n_u_wait_c __pyx_string_tab[749]
#define __pyx_n_u_warning __pyx_string_tab[750]
#define __pyx_n_u_zoneinfo __pyx_string_tab[751]
#define __pyx_kp_b_ __pyx_string_tab[752]
#define __pyx_kp_b_000 __pyx_string_tab[753]
#define __pyx_kp_b_Infinity_2 __pyx_string_tab[754]
#define __pyx_kp_b_Infinity_float8 __pyx_string_tab[755]
#define __pyx_kp_b_Infinity_float8_2 __pyx_string_tab[756]
#define __pyx_kp_b_Infinity_numeric __pyx_string_tab[757]
#define __pyx_kp_b_Infinity_numeric_2 __pyx_string_tab[758]
#define __pyx_kp_b_Jan_Feb_Mar_Apr_May_Jun_Jul_Aug __pyx_string_tab[759]
#define __pyx_kp_b_NaN_float8 __pyx_string_tab[760]
#define __pyx_kp_b_NaN_numeric __pyx_string_tab[761]
#define __pyx_kp_b__10 __pyx_string_tab[762]
#define __pyx_kp_b__2 __pyx_string_tab[763]
#define __pyx_kp_b__4 __pyx_string_tab[764]
#define __pyx_kp_b__5 __pyx_string_tab[765]
#define __pyx_kp_b__6 __pyx_string_tab[766]
#define __pyx_kp_b__9 __pyx_string_tab[767]
#define __pyx_kp_b_inf_2 __pyx_string_tab[768]
#define __pyx_kp_b_int_PyObject_char_Py_ssize_t__bu __pyx_string_tab[769]
#define __pyx_kp_b_iso88591_1_6_q_t6_q __pyx_string_tab[770]
#define __pyx_kp_b_iso88591_1_q_A_V1E_Q_4q_q __pyx_string_tab[771]
#define __pyx_kp_b_iso88591_4A_4_Q_1_4r_F_a_5Qd_4z_31_AT_d __pyx_string_tab[772]
#define __pyx_kp_b_iso88591_4_Q_1_5_XT_4r_HD_6at1_4z_31_j_b __pyx_string_tab[773]
#define __pyx_kp_b_iso88591_4s_1_A_1_iq __pyx_string_tab[774]
#define __pyx_kp_b_iso88591_94DA __pyx_string_tab[775]
#define __pyx_kp_b_iso88591_9_Jaq_E_aq_q_1E_Q_Qha_1IS_A __pyx_string_tab[776]
#define __pyx_kp_b_iso88591_A __pyx_string_tab[777]
#define __pyx_kp_b_iso88591_AQ_AQ_E_aq_q_q_E_Q_Qha_1IS_A_IU __pyx_string_tab[778]
#define __pyx_kp_b_iso88591_A_3a_1_1D __pyx_string_tab[779]
#define __pyx_kp_b_iso88591_A_3a_1_Qd __pyx_string_tab[780]
#define __pyx_kp_b_iso88591_A_3a_4q_D __pyx_string_tab[781]
#define __pyx_kp_b_iso88591_A_4q_1_1A_4r_AQ_3aq_b_Rq_3aq_b_b __pyx_string_tab[782]
#define __pyx_kp_b_iso88591_A_4q_4s_T_q_T_at1_auA_Rr_V1E_Q __pyx_string_tab[783]
#define __pyx_kp_b_iso88591_A_4s_1_Qd __pyx_string_tab[784]
#define __pyx_kp_b_iso88591_A_4s_1_q_A __pyx_string_tab[785]
#define __pyx_kp_b_iso88591_A_4s_4q_D __pyx_string_tab[786]
#define __pyx_kp_b_iso88591_A_5_1_1_S_q_z_G1_q_q_z_G1_q_q __pyx_string_tab[787]
#define __pyx_kp_b_iso88591_A_5_1_4_1A_S_q_z_G1_t_t_z_G1_t_t __pyx_string_tab[788]
#define __pyx_kp_b_iso88591_A_A_O1_Q_1_1_a_1_U_1_0_a_6_L_iwa __pyx_string_tab[789]
#define __pyx_kp_b_iso88591_A_D_q_K_7_k_A_k_A_V6_fA_4t4wj_Ct __pyx_string_tab[790]
#define __pyx_kp_b_iso88591_A_E_4y_q_4q_3oQa_4q_ha_c_q_5_aq __pyx_string_tab[791]
#define __pyx_kp_b_iso88591_A_M_7_Q_D_A_q_A_4z_Zq_Zq_4q_4t1 __pyx_string_tab[792]
#define __pyx_kp_b_iso88591_A_Qd_q_1_A_4s_81_y_Cwe2Q __pyx_string_tab[793]
#define __pyx_kp_b_iso88591_A_Qd_q_1_a_4s_81_y_Cwe2Q __pyx_string_tab[794]
#define __pyx_kp_b_iso88591_A_e1A_9AU_1_4q_4y_q_t4q_Q_a_4t3 __pyx_string_tab[795]
#define __pyx_kp_b_iso88591_A_q __pyx_string_tab[796]
#define __pyx_kp_b_iso88591_A_q_2 __pyx_string_tab[797]
#define __pyx_kp_b_iso88591_A_t1 __pyx_string_tab[798]
#define __pyx_kp_b_iso88591_D_q_a __pyx_string_tab[799]
#define __pyx_kp_b_iso88591_Q __pyx_string_tab[800]
#define __pyx_kp_b_iso88591_Q_81_1_k_d_1_A_1_1Cq_A_G5_1M_uC __pyx_string_tab[801]
#define __pyx_kp_b_iso88591_Q_a __pyx_string_tab[802]
#define __pyx_kp_b_iso88591_Q_avYaxq_r_Jaq_uAQ_q_d_3c_t4q_3 __pyx_string_tab[803]
#define __pyx_kp_b_iso88591_T_4_a_G1F_a_vWE_Q_q_t9G5_4z_SPT __pyx_string_tab[804]
#define __pyx_kp_b_iso88591_T_4_it6_Q_G1F_a_vWE_Q_q_t9G5_4z __pyx_string_tab[805]
#define __pyx_kp_b_iso88591__12 __pyx_string_tab[806]
#define __pyx_kp_b_iso88591__13 __pyx_string_tab[807]
#define __pyx_kp_b_iso88591__14 __pyx_string_tab[808]
#define __pyx_kp_b_iso88591_a __pyx_string_tab[809]
#define __pyx_kp_b_iso88591_a_q_5_A_5_a __pyx_string_tab[810]
#define __pyx_kp_b_iso88591_hi_7q __pyx_string_tab[811]
#define __pyx_kp_b_iso88591_m_D_a_a __pyx_string_tab[812]
#define __pyx_kp_b_iso88591_nA_q_d_5_a __pyx_string_tab[813]
#define __pyx_kp_b_iso88591_q __pyx_string_tab[814]
#define __pyx_kp_b_iso88591_q_0_kQR_9HAQ_7_1L_a_1 __pyx_string_tab[815]
#define __pyx_kp_b_iso88591_q_a __pyx_string_tab[816]
#define __pyx_kp_b_iso88591_q_avYauAQ_Rq_1KuG1_XQa_7_Jaq_uA __pyx_string_tab[817]
#define __pyx_kp_b_iso88591_y_1_j_uAQ_z_1_A_3a_t1A_Kq_a_vS __pyx_string_tab[818]
#define __pyx_kp_b_s_s __pyx_string_tab[819]
#define __pyx_kp_b_utf_8 __pyx_string_tab[820]
#define __pyx_n_b_Infinity __pyx_string_tab[821]
#define __pyx_n_b_NaN __pyx_string_tab[822]
#define __pyx_n_b_P __pyx_string_tab[823]
#define __pyx_n_b_SQL_ASCII __pyx_string_tab[824]
#define __pyx_n_b_UTC __pyx_string_tab[825]
#define __pyx_n_b_UTF8 __pyx_string_tab[826]
#define __pyx_n_b_ascii __pyx_string_tab[827]
#define __pyx_n_b_false __pyx_string_tab[828]
#define __pyx_n_b_inf __pyx_string_tab[829]
#define __pyx_n_b_nan __pyx_string_tab[830]
#define __pyx_n_b_true __pyx_string_tab[831]
#define __pyx_float_0_0 __pyx_number_tab[0]
#define __pyx_int_0 __pyx_number_tab[1]
#define __pyx_int_1 __pyx_number_tab[2]
#define __pyx_int_39 __pyx_number_tab[3]
#define __pyx_int_64 __pyx_number_tab[4]
#define __pyx_int_2000 __pyx_number_tab[5]
#define __pyx_int_8192 __pyx_number_tab[6]
#define __pyx_int_10000 __pyx_number_tab[7]
#define __pyx_int_1000000 __pyx_number_tab[8]
#define __pyx_int_93828620 __pyx_number_tab[9]
#define __pyx_int_172291013 __pyx_number_tab[10]
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_clear(PyObject *m) {
  __pyx_mstatetype *clear_module_state = __Pyx_PyModule_GetState(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __Pyx_State_RemoveModule(NULL);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_PGconn);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_PGresult);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_PGcancelConn);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_PGcancel);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_Escaping);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_PQBuffer);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_2pq_ViewBuffer);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_date);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_time);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_datetime);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_timedelta);
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_8datetime_tzinfo);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_CDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_CDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_CLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_CLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_RowLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_RowDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Transformer);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Transformer);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_ArrayLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DateDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeTzDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DateLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimetzLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestampLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntervalLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__IntDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int2Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int4Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int8Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntNumericDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_IntLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__FloatDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_FloatDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Float4Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_FloatLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DecimalDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPNumericDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseStrDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__StrDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumperName);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__TextLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TextLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_BytesDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_ByteaLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg__UUIDLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_UUIDLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate);
  Py_CLEAR(clear_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error);
  Py_CLEAR(clear_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error);
  Py_CLEAR(clear_module_state->__pyx_k__8);
  for (int i=0; i<4; ++i) { Py_CLEAR(clear_module_state->__pyx_tuple[i]); }
  for (int i=0; i<249; ++i) { Py_CLEAR(clear_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<832; ++i) { Py_CLEAR(clear_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<11; ++i) { Py_CLEAR(clear_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_clear_contents ### */
/* CommonTypesMetaclass.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CommonTypesMetaclassType);

/* Generator.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_GeneratorType);

/* CythonFunctionShared.module_state_clear */
Py_CLEAR(clear_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_clear_end ### */
return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstatetype *traverse_module_state = __Pyx_PyModule_GetState(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_tuple);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_bytes);
  __Pyx_VISIT_CONST(traverse_module_state->__pyx_empty_unicode);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_PGconn);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_PGresult);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_PGcancelConn);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_PGcancel);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_Escaping);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_PQBuffer);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_2pq_ViewBuffer);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4bool_bool);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_7complex_complex);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_date);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_time);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_datetime);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_timedelta);
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_8datetime_tzinfo);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_CDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_CDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_CLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_CLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_RowLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_RowDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Transformer);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Transformer);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_ArrayLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DateDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeTzDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DateLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimetzLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestampLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntervalLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__IntDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int2Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int4Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int8Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntNumericDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_IntLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__FloatDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_FloatDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Float4Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_FloatLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DecimalDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPNumericDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__BaseStrDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__StrDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumperName);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__TextLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TextLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_BytesDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_ByteaLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg__UUIDLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_UUIDLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate);
  Py_VISIT(traverse_module_state->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error);
  Py_VISIT(traverse_module_state->__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error);
  Py_VISIT(traverse_module_state->__pyx_k__8);
  for (int i=0; i<4; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_tuple[i]); }
  for (int i=0; i<249; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_codeobj_tab[i]); }
  for (int i=0; i<832; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_string_tab[i]); }
  for (int i=0; i<11; ++i) { __Pyx_VISIT_CONST(traverse_module_state->__pyx_number_tab[i]); }
/* #### Code section: module_state_traverse_contents ### */
/* CommonTypesMetaclass.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CommonTypesMetaclassType);

/* Generator.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_GeneratorType);

/* CythonFunctionShared.module_state_traverse */
Py_VISIT(traverse_module_state->__pyx_CyFunctionType);

/* #### Code section: module_state_traverse_end ### */
return 0;
}
#endif
/* #### Code section: module_code ### */

/* "cpython/complex.pxd":20
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4real_real(PyComplexObject *__pyx_v_self) {
  double __pyx_r;

  /* "cpython/complex.pxd":23
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
 *             return self.cval.real             # <<<<<<<<<<<<<<
 * 
 *         # unavailable in limited API
*/
  __pyx_r = __pyx_v_self->cval.real;
  goto __pyx_L0;

  /* "cpython/complex.pxd":20
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double real(self) noexcept:
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/complex.pxd":26
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE double __pyx_f_7cpython_7complex_7complex_4imag_imag(PyComplexObject *__pyx_v_self) {
  double __pyx_r;

  /* "cpython/complex.pxd":29
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
 *             return self.cval.imag             # <<<<<<<<<<<<<<
 * 
 *     # PyTypeObject PyComplex_Type
*/
  __pyx_r = __pyx_v_self->cval.imag;
  goto __pyx_L0;

  /* "cpython/complex.pxd":26
 * 
 *         # unavailable in limited API
 *         @property             # <<<<<<<<<<<<<<
 *         @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 *         cdef inline double imag(self) noexcept:
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/contextvars.pxd":115
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value *__pyx_optional_args) {

  /* "cpython/contextvars.pxd":116
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the default value of the context variable,
*/
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value;
  PyObject *__pyx_v_pyvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }

  /* "cpython/contextvars.pxd":121
 *     or None if no such value or default was found.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:
*/
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":122
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)             # <<<<<<<<<<<<<<
 *     if value is NULL:
 *         # context variable does not have a default
*/
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, NULL, (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(3, 122, __pyx_L1_error)

  /* "cpython/contextvars.pxd":123
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
*/
  __pyx_t_2 = (__pyx_v_value == NULL);
  if (__pyx_t_2) {

    /* "cpython/contextvars.pxd":125
 *     if value is NULL:
 *         # context variable does not have a default
 *         pyvalue = default_value             # <<<<<<<<<<<<<<
 *     else:
 *         # value or default value of context variable
*/
    __Pyx_INCREF(__pyx_v_default_value);
    __pyx_v_pyvalue = __pyx_v_default_value;

    /* "cpython/contextvars.pxd":123
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, NULL, &value)
 *     if value is NULL:             # <<<<<<<<<<<<<<
 *         # context variable does not have a default
 *         pyvalue = default_value
*/
    goto __pyx_L3;
  }

  /* "cpython/contextvars.pxd":128
 *     else:
 *         # value or default value of context variable
 *         pyvalue = <object>value             # <<<<<<<<<<<<<<
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
*/
  /*else*/ {
    __pyx_t_3 = ((PyObject *)__pyx_v_value);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_pyvalue = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "cpython/contextvars.pxd":129
 *         # value or default value of context variable
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
 * 
*/
    Py_XDECREF(__pyx_v_value);
  }
  __pyx_L3:;

  /* "cpython/contextvars.pxd":130
 *         pyvalue = <object>value
 *         Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyvalue);
  __pyx_r = __pyx_v_pyvalue;
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":115
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.contextvars.get_value", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "cpython/contextvars.pxd":133
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value_no_default(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

#if !CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE PyObject *__pyx_f_7cpython_11contextvars_get_value_no_default(PyObject *__pyx_v_var, struct __pyx_opt_args_7cpython_11contextvars_get_value_no_default *__pyx_optional_args) {

  /* "cpython/contextvars.pxd":134
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")
 * cdef inline object get_value_no_default(var, default_value=None):             # <<<<<<<<<<<<<<
 *     """Return a new reference to the value of the context variable,
 *     or the provided default value if no such value was found.
*/
  PyObject *__pyx_v_default_value = ((PyObject *)Py_None);
  PyObject *__pyx_v_value;
  PyObject *__pyx_v_pyvalue = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_value_no_default", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_default_value = __pyx_optional_args->default_value;
    }
  }

  /* "cpython/contextvars.pxd":140
 *     Ignores the default value of the context variable, if any.
 *     """
 *     cdef PyObject *value = NULL             # <<<<<<<<<<<<<<
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
*/
  __pyx_v_value = NULL;

  /* "cpython/contextvars.pxd":141
 *     """
 *     cdef PyObject *value = NULL
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)             # <<<<<<<<<<<<<<
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
*/
  __pyx_t_1 = PyContextVar_Get(__pyx_v_var, ((PyObject *)__pyx_v_default_value), (&__pyx_v_value)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(3, 141, __pyx_L1_error)

  /* "cpython/contextvars.pxd":143
 *     PyContextVar_Get(var, <PyObject*>default_value, &value)
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value             # <<<<<<<<<<<<<<
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_value);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_pyvalue = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "cpython/contextvars.pxd":144
 *     # value of context variable or 'default_value'
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'             # <<<<<<<<<<<<<<
 *     return pyvalue
*/
  Py_XDECREF(__pyx_v_value);

  /* "cpython/contextvars.pxd":145
 *     pyvalue = <object>value
 *     Py_XDECREF(value)  # PyContextVar_Get() returned an owned reference as 'PyObject*'
 *     return pyvalue             # <<<<<<<<<<<<<<
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_pyvalue);
  __pyx_r = __pyx_v_pyvalue;
  goto __pyx_L0;

  /* "cpython/contextvars.pxd":133
 * 
 * 
 * @_cython.c_compile_guard("!CYTHON_COMPILING_IN_LIMITED_API")             # <<<<<<<<<<<<<<
 * cdef inline object get_value_no_default(var, default_value=None):
 *     """Return a new reference to the value of the context variable,
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.contextvars.get_value_no_default", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_pyvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
#endif /*!(#if !CYTHON_COMPILING_IN_LIMITED_API)*/

/* "datetime.pxd":44
 * 
 *     ctypedef extern class datetime.date[object PyDateTime_Date]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int year(self) noexcept:
 *             return PyDateTime_GET_YEAR(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_4year_year(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":46
 *         @property
 *         cdef inline int year(self) noexcept:
 *             return PyDateTime_GET_YEAR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_GET_YEAR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":44
 * 
 *     ctypedef extern class datetime.date[object PyDateTime_Date]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int year(self) noexcept:
 *             return PyDateTime_GET_YEAR(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":48
 *             return PyDateTime_GET_YEAR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int month(self) noexcept:
 *             return PyDateTime_GET_MONTH(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_5month_month(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":50
 *         @property
 *         cdef inline int month(self) noexcept:
 *             return PyDateTime_GET_MONTH(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_GET_MONTH(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":48
 *             return PyDateTime_GET_YEAR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int month(self) noexcept:
 *             return PyDateTime_GET_MONTH(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":52
 *             return PyDateTime_GET_MONTH(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_GET_DAY(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4date_3day_day(PyDateTime_Date *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":54
 *         @property
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_GET_DAY(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
*/
  __pyx_r = PyDateTime_GET_DAY(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":52
 *             return PyDateTime_GET_MONTH(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_GET_DAY(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":57
 * 
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int hour(self) noexcept:
 *             return PyDateTime_TIME_GET_HOUR(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4hour_hour(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":59
 *         @property
 *         cdef inline int hour(self) noexcept:
 *             return PyDateTime_TIME_GET_HOUR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_TIME_GET_HOUR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":57
 * 
 *     ctypedef extern class datetime.time[object PyDateTime_Time]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int hour(self) noexcept:
 *             return PyDateTime_TIME_GET_HOUR(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":61
 *             return PyDateTime_TIME_GET_HOUR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int minute(self) noexcept:
 *             return PyDateTime_TIME_GET_MINUTE(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6minute_minute(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":63
 *         @property
 *         cdef inline int minute(self) noexcept:
 *             return PyDateTime_TIME_GET_MINUTE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_TIME_GET_MINUTE(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":61
 *             return PyDateTime_TIME_GET_HOUR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int minute(self) noexcept:
 *             return PyDateTime_TIME_GET_MINUTE(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":65
 *             return PyDateTime_TIME_GET_MINUTE(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_TIME_GET_SECOND(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_6second_second(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":67
 *         @property
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_TIME_GET_SECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_TIME_GET_SECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":65
 *             return PyDateTime_TIME_GET_MINUTE(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_TIME_GET_SECOND(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":69
 *             return PyDateTime_TIME_GET_SECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_11microsecond_microsecond(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":71
 *         @property
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_TIME_GET_MICROSECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":69
 *             return PyDateTime_TIME_GET_SECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":73
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
*/

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_4time_6tzinfo_tzinfo(PyDateTime_Time *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("tzinfo", 0);

  /* "datetime.pxd":75
 *         @property
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_TIME_GET_TZINFO(((PyObject *)__pyx_v_self));
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":73
 *             return PyDateTime_TIME_GET_MICROSECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":77
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int fold(self) noexcept:
 *             # For Python < 3.6 this returns 0 no matter what
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_4time_4fold_fold(PyDateTime_Time *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":80
 *         cdef inline int fold(self) noexcept:
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_TIME_GET_FOLD(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
*/
  __pyx_r = PyDateTime_TIME_GET_FOLD(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":77
 *             return <object>PyDateTime_TIME_GET_TZINFO(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int fold(self) noexcept:
 *             # For Python < 3.6 this returns 0 no matter what
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":83
 * 
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int year(self) noexcept:
 *             return PyDateTime_GET_YEAR(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4year_year(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":85
 *         @property
 *         cdef inline int year(self) noexcept:
 *             return PyDateTime_GET_YEAR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_GET_YEAR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":83
 * 
 *     ctypedef extern class datetime.datetime[object PyDateTime_DateTime]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int year(self) noexcept:
 *             return PyDateTime_GET_YEAR(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":87
 *             return PyDateTime_GET_YEAR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int month(self) noexcept:
 *             return PyDateTime_GET_MONTH(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_5month_month(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":89
 *         @property
 *         cdef inline int month(self) noexcept:
 *             return PyDateTime_GET_MONTH(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_GET_MONTH(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":87
 *             return PyDateTime_GET_YEAR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int month(self) noexcept:
 *             return PyDateTime_GET_MONTH(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":91
 *             return PyDateTime_GET_MONTH(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_GET_DAY(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_3day_day(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":93
 *         @property
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_GET_DAY(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_GET_DAY(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":91
 *             return PyDateTime_GET_MONTH(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_GET_DAY(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":95
 *             return PyDateTime_GET_DAY(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int hour(self) noexcept:
 *             return PyDateTime_DATE_GET_HOUR(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4hour_hour(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":97
 *         @property
 *         cdef inline int hour(self) noexcept:
 *             return PyDateTime_DATE_GET_HOUR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_DATE_GET_HOUR(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":95
 *             return PyDateTime_GET_DAY(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int hour(self) noexcept:
 *             return PyDateTime_DATE_GET_HOUR(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":99
 *             return PyDateTime_DATE_GET_HOUR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int minute(self) noexcept:
 *             return PyDateTime_DATE_GET_MINUTE(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6minute_minute(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":101
 *         @property
 *         cdef inline int minute(self) noexcept:
 *             return PyDateTime_DATE_GET_MINUTE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_DATE_GET_MINUTE(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":99
 *             return PyDateTime_DATE_GET_HOUR(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int minute(self) noexcept:
 *             return PyDateTime_DATE_GET_MINUTE(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":103
 *             return PyDateTime_DATE_GET_MINUTE(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_DATE_GET_SECOND(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_6second_second(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":105
 *         @property
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_DATE_GET_SECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_DATE_GET_SECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":103
 *             return PyDateTime_DATE_GET_MINUTE(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_DATE_GET_SECOND(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":107
 *             return PyDateTime_DATE_GET_SECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_11microsecond_microsecond(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":109
 *         @property
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_DATE_GET_MICROSECOND(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":107
 *             return PyDateTime_DATE_GET_SECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":111
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
*/

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_8datetime_6tzinfo_tzinfo(PyDateTime_DateTime *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("tzinfo", 0);

  /* "datetime.pxd":113
 *         @property
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_DATE_GET_TZINFO(((PyObject *)__pyx_v_self));
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":111
 *             return PyDateTime_DATE_GET_MICROSECOND(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline object tzinfo(self):
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":115
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int fold(self) noexcept:
 *             # For Python < 3.6 this returns 0 no matter what
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_8datetime_4fold_fold(PyDateTime_DateTime *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":118
 *         cdef inline int fold(self) noexcept:
 *             # For Python < 3.6 this returns 0 no matter what
 *             return PyDateTime_DATE_GET_FOLD(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
*/
  __pyx_r = PyDateTime_DATE_GET_FOLD(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":115
 *             return <object>PyDateTime_DATE_GET_TZINFO(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int fold(self) noexcept:
 *             # For Python < 3.6 this returns 0 no matter what
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":121
 * 
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_DELTA_GET_DAYS(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_3day_day(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":123
 *         @property
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_DELTA_GET_DAYS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_DELTA_GET_DAYS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":121
 * 
 *     ctypedef extern class datetime.timedelta[object PyDateTime_Delta]:
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int day(self) noexcept:
 *             return PyDateTime_DELTA_GET_DAYS(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":125
 *             return PyDateTime_DELTA_GET_DAYS(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_DELTA_GET_SECONDS(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_6second_second(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":127
 *         @property
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_DELTA_GET_SECONDS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
*/
  __pyx_r = PyDateTime_DELTA_GET_SECONDS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":125
 *             return PyDateTime_DELTA_GET_DAYS(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int second(self) noexcept:
 *             return PyDateTime_DELTA_GET_SECONDS(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":129
 *             return PyDateTime_DELTA_GET_SECONDS(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_9timedelta_11microsecond_microsecond(PyDateTime_Delta *__pyx_v_self) {
  int __pyx_r;

  /* "datetime.pxd":131
 *         @property
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef extern class datetime.tzinfo[object PyDateTime_TZInfo]:
*/
  __pyx_r = PyDateTime_DELTA_GET_MICROSECONDS(((PyObject *)__pyx_v_self));
  goto __pyx_L0;

  /* "datetime.pxd":129
 *             return PyDateTime_DELTA_GET_SECONDS(self)
 * 
 *         @property             # <<<<<<<<<<<<<<
 *         cdef inline int microsecond(self) noexcept:
 *             return PyDateTime_DELTA_GET_MICROSECONDS(self)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":255
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime() noexcept:             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
*/

static CYTHON_INLINE void __pyx_f_7cpython_8datetime_import_datetime(void) {

  /* "datetime.pxd":256
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime() noexcept:
 *     PyDateTime_IMPORT             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DateTime CAPI factory function.
*/
  (void)(PyDateTime_IMPORT);

  /* "datetime.pxd":255
 * # Datetime C API initialization function.
 * # You have to call it before any usage of DateTime CAPI functions.
 * cdef inline void import_datetime() noexcept:             # <<<<<<<<<<<<<<
 *     PyDateTime_IMPORT
 * 
*/

  /* function exit code */
}

/* "datetime.pxd":260
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
*/

static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day) {
  PyDateTime_Date *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_new", 0);

  /* "datetime.pxd":261
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)             # <<<<<<<<<<<<<<
 * 
 * # Create time object using DateTime CAPI factory function
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyDateTimeAPI->Date_FromDate(__pyx_v_year, __pyx_v_month, __pyx_v_day, PyDateTimeAPI->DateType)); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 261, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_Date *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":260
 * # Create date object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline date date_new(int year, int month, int day):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromDate(year, month, day, PyDateTimeAPI.DateType)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.date_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":265
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
*/

static CYTHON_INLINE PyDateTime_Time *__pyx_f_7cpython_8datetime_time_new(int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz, struct __pyx_opt_args_7cpython_8datetime_time_new *__pyx_optional_args) {
  int __pyx_v_fold = ((int)0);
  PyDateTime_Time *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("time_new", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_fold = __pyx_optional_args->fold;
    }
  }

  /* "datetime.pxd":266
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DateTime CAPI factory function.
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)__Pyx_DateTime_TimeWithFold(__pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, __pyx_v_fold)); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_7cpython_8datetime_time))))) __PYX_ERR(4, 266, __pyx_L1_error)
  __pyx_r = ((PyDateTime_Time *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":265
 * # Create time object using DateTime CAPI factory function
 * # Note, there are no range checks for any of the arguments.
 * cdef inline time time_new(int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_TimeWithFold(hour, minute, second, microsecond, tz, fold)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.time_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":270
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
*/

static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_new(int __pyx_v_year, int __pyx_v_month, int __pyx_v_day, int __pyx_v_hour, int __pyx_v_minute, int __pyx_v_second, int __pyx_v_microsecond, PyObject *__pyx_v_tz, struct __pyx_opt_args_7cpython_8datetime_datetime_new *__pyx_optional_args) {
  int __pyx_v_fold = ((int)0);
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_new", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_fold = __pyx_optional_args->fold;
    }
  }

  /* "datetime.pxd":271
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)__Pyx_DateTime_DateTimeWithFold(__pyx_v_year, __pyx_v_month, __pyx_v_day, __pyx_v_hour, __pyx_v_minute, __pyx_v_second, __pyx_v_microsecond, __pyx_v_tz, __pyx_v_fold)); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":270
 * # Create datetime object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline datetime datetime_new(int year, int month, int day, int hour, int minute, int second, int microsecond, object tz, int fold=0):             # <<<<<<<<<<<<<<
 *     return __Pyx_DateTime_DateTimeWithFold(year, month, day, hour, minute, second, microsecond, tz, fold)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.datetime_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":275
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
*/

static CYTHON_INLINE PyDateTime_Delta *__pyx_f_7cpython_8datetime_timedelta_new(int __pyx_v_days, int __pyx_v_seconds, int __pyx_v_useconds) {
  PyDateTime_Delta *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timedelta_new", 0);

  /* "datetime.pxd":276
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)             # <<<<<<<<<<<<<<
 * 
 * # Create timedelta object using DateTime CAPI factory function.
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = ((PyObject *)PyDateTimeAPI->Delta_FromDelta(__pyx_v_days, __pyx_v_seconds, __pyx_v_useconds, 1, PyDateTimeAPI->DeltaType)); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = ((PyDateTime_Delta *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":275
 * # Create timedelta object using DateTime CAPI factory function.
 * # Note, there are no range checks for any of the arguments.
 * cdef inline timedelta timedelta_new(int days, int seconds, int useconds):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Delta_FromDelta(days, seconds, useconds, 1, PyDateTimeAPI.DeltaType)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cpython.datetime.timedelta_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":279
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_timezone_new(PyObject *__pyx_v_offset, struct __pyx_opt_args_7cpython_8datetime_timezone_new *__pyx_optional_args) {
  PyObject *__pyx_v_name = ((PyObject *)Py_None);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("timezone_new", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_name = __pyx_optional_args->name;
    }
  }

  /* "datetime.pxd":280
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)             # <<<<<<<<<<<<<<
 * 
 * # Create datetime object using DB API constructor.
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = (__pyx_v_name != Py_None);
  if (__pyx_t_2) {
    __pyx_t_1 = ((PyObject *)__pyx_v_name);
  } else {
    __pyx_t_1 = NULL;
  }
  __pyx_t_3 = __Pyx_TimeZone_FromOffsetAndName(__pyx_v_offset, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":279
 * 
 * # Create timedelta object using DateTime CAPI factory function.
 * cdef inline object timezone_new(object offset, object name=None):             # <<<<<<<<<<<<<<
 *     return __Pyx_TimeZone_FromOffsetAndName(offset, <PyObject*>name if name is not None else NULL)
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.datetime.timezone_new", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":283
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
*/

static CYTHON_INLINE PyDateTime_DateTime *__pyx_f_7cpython_8datetime_datetime_from_timestamp(PyObject *__pyx_v_timestamp, struct __pyx_opt_args_7cpython_8datetime_datetime_from_timestamp *__pyx_optional_args) {
  PyObject *__pyx_v_tz = ((PyObject *)Py_None);
  PyDateTime_DateTime *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("datetime_from_timestamp", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_tz = __pyx_optional_args->tz;
    }
  }

  /* "datetime.pxd":284
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(             # <<<<<<<<<<<<<<
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 * 
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);

  /* "datetime.pxd":285
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)             # <<<<<<<<<<<<<<
 * 
 * # Create date object using DB API constructor.
*/
  __pyx_t_2 = (__pyx_v_tz != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timestamp) != (0)) __PYX_ERR(4, 285, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_tz);
    __Pyx_GIVEREF(__pyx_v_tz);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_tz) != (0)) __PYX_ERR(4, 285, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 285, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_timestamp);
    __Pyx_GIVEREF(__pyx_v_timestamp);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_timestamp) != (0)) __PYX_ERR(4, 285, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }

  /* "datetime.pxd":284
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):
 *     return PyDateTimeAPI.DateTime_FromTimestamp(             # <<<<<<<<<<<<<<
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
 * 
*/
  __pyx_t_3 = ((PyObject *)PyDateTimeAPI->DateTime_FromTimestamp(((PyObject *)PyDateTimeAPI->DateTimeType), __pyx_t_1, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(4, 284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyDateTime_DateTime *)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":283
 * 
 * # Create datetime object using DB API constructor.
 * cdef inline datetime datetime_from_timestamp(timestamp, tz=None):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.DateTime_FromTimestamp(
 *         <PyObject*>PyDateTimeAPI.DateTimeType, (timestamp, tz) if tz is not None else (timestamp,), NULL)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("cpython.datetime.datetime_from_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":288
 * 
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))
 * 
*/

static CYTHON_INLINE PyDateTime_Date *__pyx_f_7cpython_8datetime_date_from_timestamp(PyObject *__pyx_v_timestamp) {
  PyDateTime_Date *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("date_from_timestamp", 0);

  /* "datetime.pxd":289
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))             # <<<<<<<<<<<<<<
 * 
 * # More recognizable getters for date/time/datetime/timedelta.
*/
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_timestamp);
  __Pyx_GIVEREF(__pyx_v_timestamp);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_timestamp) != (0)) __PYX_ERR(4, 289, __pyx_L1_error);
  __pyx_t_2 = ((PyObject *)PyDateTimeAPI->Date_FromTimestamp(((PyObject *)PyDateTimeAPI->DateType), __pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(4, 289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = ((PyDateTime_Date *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "datetime.pxd":288
 * 
 * # Create date object using DB API constructor.
 * cdef inline date date_from_timestamp(timestamp):             # <<<<<<<<<<<<<<
 *     return PyDateTimeAPI.Date_FromTimestamp(<PyObject*>PyDateTimeAPI.DateType, (timestamp,))
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cpython.datetime.date_from_timestamp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":297
 * 
 * # Get UTC singleton
 * cdef inline object get_utc():             # <<<<<<<<<<<<<<
 *     return <object>__Pyx_TimeZone_UTC
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_get_utc(void) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_utc", 0);

  /* "datetime.pxd":298
 * # Get UTC singleton
 * cdef inline object get_utc():
 *     return <object>__Pyx_TimeZone_UTC             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of time
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__Pyx_TimeZone_UTC));
  __pyx_r = ((PyObject *)__Pyx_TimeZone_UTC);
  goto __pyx_L0;

  /* "datetime.pxd":297
 * 
 * # Get UTC singleton
 * cdef inline object get_utc():             # <<<<<<<<<<<<<<
 *     return <object>__Pyx_TimeZone_UTC
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":301
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_time_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("time_tzinfo", 0);

  /* "datetime.pxd":302
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)             # <<<<<<<<<<<<<<
 * 
 * # Get tzinfo of datetime
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_TIME_GET_TZINFO(__pyx_v_o);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":301
 * 
 * # Get tzinfo of time
 * cdef inline object time_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_TIME_GET_TZINFO(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":305
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)
 * 
*/

static CYTHON_INLINE PyObject *__pyx_f_7cpython_8datetime_datetime_tzinfo(PyObject *__pyx_v_o) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  __Pyx_RefNannySetupContext("datetime_tzinfo", 0);

  /* "datetime.pxd":306
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of date
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyDateTime_DATE_GET_TZINFO(__pyx_v_o);
  __Pyx_INCREF(((PyObject *)__pyx_t_1));
  __pyx_r = ((PyObject *)__pyx_t_1);
  goto __pyx_L0;

  /* "datetime.pxd":305
 * 
 * # Get tzinfo of datetime
 * cdef inline object datetime_tzinfo(object o):             # <<<<<<<<<<<<<<
 *     return <object>PyDateTime_DATE_GET_TZINFO(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "datetime.pxd":309
 * 
 * # Get year of date
 * cdef inline int date_year(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_year(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":310
 * # Get year of date
 * cdef inline int date_year(object o) noexcept:
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of date
*/
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":309
 * 
 * # Get year of date
 * cdef inline int date_year(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":313
 * 
 * # Get month of date
 * cdef inline int date_month(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_month(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":314
 * # Get month of date
 * cdef inline int date_month(object o) noexcept:
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of date
*/
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":313
 * 
 * # Get month of date
 * cdef inline int date_month(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":317
 * 
 * # Get day of date
 * cdef inline int date_day(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_date_day(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":318
 * # Get day of date
 * cdef inline int date_day(object o) noexcept:
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get year of datetime
*/
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":317
 * 
 * # Get day of date
 * cdef inline int date_day(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":321
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_year(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":322
 * # Get year of datetime
 * cdef inline int datetime_year(object o) noexcept:
 *     return PyDateTime_GET_YEAR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get month of datetime
*/
  __pyx_r = PyDateTime_GET_YEAR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":321
 * 
 * # Get year of datetime
 * cdef inline int datetime_year(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_YEAR(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":325
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_month(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":326
 * # Get month of datetime
 * cdef inline int datetime_month(object o) noexcept:
 *     return PyDateTime_GET_MONTH(o)             # <<<<<<<<<<<<<<
 * 
 * # Get day of datetime
*/
  __pyx_r = PyDateTime_GET_MONTH(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":325
 * 
 * # Get month of datetime
 * cdef inline int datetime_month(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_MONTH(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":329
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_day(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":330
 * # Get day of datetime
 * cdef inline int datetime_day(object o) noexcept:
 *     return PyDateTime_GET_DAY(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of time
*/
  __pyx_r = PyDateTime_GET_DAY(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":329
 * 
 * # Get day of datetime
 * cdef inline int datetime_day(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_GET_DAY(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":333
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_hour(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":334
 * # Get hour of time
 * cdef inline int time_hour(object o) noexcept:
 *     return PyDateTime_TIME_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of time
*/
  __pyx_r = PyDateTime_TIME_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":333
 * 
 * # Get hour of time
 * cdef inline int time_hour(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_HOUR(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":337
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_minute(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":338
 * # Get minute of time
 * cdef inline int time_minute(object o) noexcept:
 *     return PyDateTime_TIME_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of time
*/
  __pyx_r = PyDateTime_TIME_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":337
 * 
 * # Get minute of time
 * cdef inline int time_minute(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MINUTE(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":341
 * 
 * # Get second of time
 * cdef inline int time_second(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_second(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":342
 * # Get second of time
 * cdef inline int time_second(object o) noexcept:
 *     return PyDateTime_TIME_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of time
*/
  __pyx_r = PyDateTime_TIME_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":341
 * 
 * # Get second of time
 * cdef inline int time_second(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_SECOND(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":345
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":346
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o) noexcept:
 *     return PyDateTime_TIME_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get fold of time
*/
  __pyx_r = PyDateTime_TIME_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":345
 * 
 * # Get microsecond of time
 * cdef inline int time_microsecond(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_TIME_GET_MICROSECOND(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":349
 * 
 * # Get fold of time
 * cdef inline int time_fold(object o) noexcept:             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_time_fold(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":351
 * cdef inline int time_fold(object o) noexcept:
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)             # <<<<<<<<<<<<<<
 * 
 * # Get hour of datetime
*/
  __pyx_r = PyDateTime_TIME_GET_FOLD(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":349
 * 
 * # Get fold of time
 * cdef inline int time_fold(object o) noexcept:             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_TIME_GET_FOLD(o)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":354
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_hour(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":355
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o) noexcept:
 *     return PyDateTime_DATE_GET_HOUR(o)             # <<<<<<<<<<<<<<
 * 
 * # Get minute of datetime
*/
  __pyx_r = PyDateTime_DATE_GET_HOUR(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":354
 * 
 * # Get hour of datetime
 * cdef inline int datetime_hour(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_HOUR(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":358
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_minute(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":359
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o) noexcept:
 *     return PyDateTime_DATE_GET_MINUTE(o)             # <<<<<<<<<<<<<<
 * 
 * # Get second of datetime
*/
  __pyx_r = PyDateTime_DATE_GET_MINUTE(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":358
 * 
 * # Get minute of datetime
 * cdef inline int datetime_minute(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MINUTE(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":362
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_second(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":363
 * # Get second of datetime
 * cdef inline int datetime_second(object o) noexcept:
 *     return PyDateTime_DATE_GET_SECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microsecond of datetime
*/
  __pyx_r = PyDateTime_DATE_GET_SECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":362
 * 
 * # Get second of datetime
 * cdef inline int datetime_second(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_SECOND(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":366
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_microsecond(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":367
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o) noexcept:
 *     return PyDateTime_DATE_GET_MICROSECOND(o)             # <<<<<<<<<<<<<<
 * 
 * # Get fold of datetime
*/
  __pyx_r = PyDateTime_DATE_GET_MICROSECOND(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":366
 * 
 * # Get microsecond of datetime
 * cdef inline int datetime_microsecond(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DATE_GET_MICROSECOND(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":370
 * 
 * # Get fold of datetime
 * cdef inline int datetime_fold(object o) noexcept:             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_datetime_fold(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":372
 * cdef inline int datetime_fold(object o) noexcept:
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)             # <<<<<<<<<<<<<<
 * 
 * # Get days of timedelta
*/
  __pyx_r = PyDateTime_DATE_GET_FOLD(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":370
 * 
 * # Get fold of datetime
 * cdef inline int datetime_fold(object o) noexcept:             # <<<<<<<<<<<<<<
 *     # For Python < 3.6 this returns 0 no matter what
 *     return PyDateTime_DATE_GET_FOLD(o)
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":375
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DELTA_GET_DAYS(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_days(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":376
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o) noexcept:
 *     return PyDateTime_DELTA_GET_DAYS(o)             # <<<<<<<<<<<<<<
 * 
 * # Get seconds of timedelta
*/
  __pyx_r = PyDateTime_DELTA_GET_DAYS(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":375
 * 
 * # Get days of timedelta
 * cdef inline int timedelta_days(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DELTA_GET_DAYS(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":379
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DELTA_GET_SECONDS(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_seconds(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":380
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o) noexcept:
 *     return PyDateTime_DELTA_GET_SECONDS(o)             # <<<<<<<<<<<<<<
 * 
 * # Get microseconds of timedelta
*/
  __pyx_r = PyDateTime_DELTA_GET_SECONDS(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":379
 * 
 * # Get seconds of timedelta
 * cdef inline int timedelta_seconds(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DELTA_GET_SECONDS(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":383
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DELTA_GET_MICROSECONDS(o)
 * 
*/

static CYTHON_INLINE int __pyx_f_7cpython_8datetime_timedelta_microseconds(PyObject *__pyx_v_o) {
  int __pyx_r;

  /* "datetime.pxd":384
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o) noexcept:
 *     return PyDateTime_DELTA_GET_MICROSECONDS(o)             # <<<<<<<<<<<<<<
 * 
 * cdef inline double total_seconds(timedelta obj) noexcept:
*/
  __pyx_r = PyDateTime_DELTA_GET_MICROSECONDS(__pyx_v_o);
  goto __pyx_L0;

  /* "datetime.pxd":383
 * 
 * # Get microseconds of timedelta
 * cdef inline int timedelta_microseconds(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return PyDateTime_DELTA_GET_MICROSECONDS(o)
 * 
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "datetime.pxd":386
 *     return PyDateTime_DELTA_GET_MICROSECONDS(o)
 * 
 * cdef inline double total_seconds(timedelta obj) noexcept:             # <<<<<<<<<<<<<<
 *     # Mirrors the "timedelta.total_seconds()" method.
 *     # Note that this implementation is not guaranteed to give *exactly* the same
*/

static CYTHON_INLINE double __pyx_f_7cpython_8datetime_total_seconds(PyDateTime_Delta *__pyx_v_obj) {
  double __pyx_v_days;
  double __pyx_v_seconds;
  double __pyx_v_micros;
  double __pyx_r;

  /* "datetime.pxd":392
 *     cdef:
 *         double days, seconds, micros
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)             # <<<<<<<<<<<<<<
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
*/
  __pyx_v_days = ((double)PyDateTime_DELTA_GET_DAYS(((PyObject *)__pyx_v_obj)));

  /* "datetime.pxd":393
 *         double days, seconds, micros
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)             # <<<<<<<<<<<<<<
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 *     return days * 24 * 3600 + seconds + micros / 1_000_000
*/
  __pyx_v_seconds = ((double)PyDateTime_DELTA_GET_SECONDS(((PyObject *)__pyx_v_obj)));

  /* "datetime.pxd":394
 *     days = <double>PyDateTime_DELTA_GET_DAYS(obj)
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)             # <<<<<<<<<<<<<<
 *     return days * 24 * 3600 + seconds + micros / 1_000_000
*/
  __pyx_v_micros = ((double)PyDateTime_DELTA_GET_MICROSECONDS(((PyObject *)__pyx_v_obj)));

  /* "datetime.pxd":395
 *     seconds = <double>PyDateTime_DELTA_GET_SECONDS(obj)
 *     micros = <double>PyDateTime_DELTA_GET_MICROSECONDS(obj)
 *     return days * 24 * 3600 + seconds + micros / 1_000_000             # <<<<<<<<<<<<<<
*/
  __pyx_r = ((((__pyx_v_days * 24.0) * 3600.0) + __pyx_v_seconds) + (__pyx_v_micros / 1000000.0));
  goto __pyx_L0;

  /* "datetime.pxd":386
 *     return PyDateTime_DELTA_GET_MICROSECONDS(o)
 * 
 * cdef inline double total_seconds(timedelta obj) noexcept:             # <<<<<<<<<<<<<<
 *     # Mirrors the "timedelta.total_seconds()" method.
 *     # Note that this implementation is not guaranteed to give *exactly* the same
*/

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":34
 *     oid = oids.INVALID_OID
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self.cls = cls
 *         conn = context.connection if context is not None else None
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_7CDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_7CDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_cls = 0;
  PyObject *__pyx_v_context = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_context,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(5, 34, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 34, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 34, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(5, 34, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(5, 34, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 34, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 34, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_cls = values[0];
    __pyx_v_context = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(5, 34, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), __pyx_v_cls, __pyx_v_context);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_7CDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_cls, PyObject *__pyx_v_context) {
  PyObject *__pyx_v_conn = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":35
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
 *         self.cls = cls             # <<<<<<<<<<<<<<
 *         conn = context.connection if context is not None else None
 *         self._pgconn = conn.pgconn if conn is not None else None
*/
  __Pyx_INCREF(__pyx_v_cls);
  __Pyx_GIVEREF(__pyx_v_cls);
  __Pyx_GOTREF(__pyx_v_self->cls);
  __Pyx_DECREF(__pyx_v_self->cls);
  __pyx_v_self->cls = __pyx_v_cls;

  /* "psycopg_c/_psycopg/adapt.pyx":36
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
 *         self.cls = cls
 *         conn = context.connection if context is not None else None             # <<<<<<<<<<<<<<
 *         self._pgconn = conn.pgconn if conn is not None else None
 * 
*/
  __pyx_t_2 = (__pyx_v_context != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_mstate_global->__pyx_n_u_connection); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 36, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  __pyx_v_conn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":37
 *         self.cls = cls
 *         conn = context.connection if context is not None else None
 *         self._pgconn = conn.pgconn if conn is not None else None             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_2 = (__pyx_v_conn != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_conn, __pyx_mstate_global->__pyx_n_u_pgconn); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn))))) __PYX_ERR(5, 37, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn))))) __PYX_ERR(5, 37, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_pgconn);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_pgconn);
  __pyx_v_self->_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":34
 *     oid = oids.INVALID_OID
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self.cls = cls
 *         conn = context.connection if context is not None else None
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_conn);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":39
 *         self._pgconn = conn.pgconn if conn is not None else None
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         """Store the Postgres representation *obj* into *rv* at *offset*
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_7CDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_rv, CYTHON_UNUSED Py_ssize_t __pyx_v_offset) {
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cdump", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":55
 *         might probably come handy.
 *         """
 *         raise NotImplementedError()             # <<<<<<<<<<<<<<
 * 
 *     def dump(self, obj) -> Buffer | None:
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_NotImplementedError)), __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 55, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(5, 55, __pyx_L1_error)

  /* "psycopg_c/_psycopg/adapt.pyx":39
 *         self._pgconn = conn.pgconn if conn is not None else None
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         """Store the Postgres representation *obj* into *rv* at *offset*
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1L;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":57
 *         raise NotImplementedError()
 * 
 *     def dump(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         """Return the Postgres representation of *obj* as Python array of bytes"""
 *         cdef rv = PyByteArray_FromStringAndSize("", 0)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_3dump(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_7CDumper_2dump, "Return the Postgres representation of *obj* as Python array of bytes");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CDumper_3dump = {"dump", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_3dump, METH_O, __pyx_doc_9psycopg_c_8_psycopg_7CDumper_2dump};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_3dump(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_2dump(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_2dump(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_v_rv = 0;
  Py_ssize_t __pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":59
 *     def dump(self, obj) -> Buffer | None:
 *         """Return the Postgres representation of *obj* as Python array of bytes"""
 *         cdef rv = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t length = self.cdump(obj, rv, 0)
 *         PyByteArray_Resize(rv, length)
*/
  __pyx_t_1 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rv = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":60
 *         """Return the Postgres representation of *obj* as Python array of bytes"""
 *         cdef rv = PyByteArray_FromStringAndSize("", 0)
 *         cdef Py_ssize_t length = self.cdump(obj, rv, 0)             # <<<<<<<<<<<<<<
 *         PyByteArray_Resize(rv, length)
 *         return rv
*/
  __pyx_t_1 = __pyx_v_rv;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyByteArray_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytearray", __pyx_t_1))) __PYX_ERR(5, 60, __pyx_L1_error)
  __pyx_t_2 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self->__pyx_vtab)->cdump(__pyx_v_self, __pyx_v_obj, ((PyObject*)__pyx_t_1), 0); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(5, 60, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_length = __pyx_t_2;

  /* "psycopg_c/_psycopg/adapt.pyx":61
 *         cdef rv = PyByteArray_FromStringAndSize("", 0)
 *         cdef Py_ssize_t length = self.cdump(obj, rv, 0)
 *         PyByteArray_Resize(rv, length)             # <<<<<<<<<<<<<<
 *         return rv
 * 
*/
  __pyx_t_3 = PyByteArray_Resize(__pyx_v_rv, __pyx_v_length); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(5, 61, __pyx_L1_error)

  /* "psycopg_c/_psycopg/adapt.pyx":62
 *         cdef Py_ssize_t length = self.cdump(obj, rv, 0)
 *         PyByteArray_Resize(rv, length)
 *         return rv             # <<<<<<<<<<<<<<
 * 
 *     def quote(self, obj) -> Buffer:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rv);
  __pyx_r = __pyx_v_rv;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/adapt.pyx":57
 *         raise NotImplementedError()
 * 
 *     def dump(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         """Return the Postgres representation of *obj* as Python array of bytes"""
 *         cdef rv = PyByteArray_FromStringAndSize("", 0)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.dump", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_rv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":64
 *         return rv
 * 
 *     def quote(self, obj) -> Buffer:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef char *ptr_out
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_5quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CDumper_5quote = {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_5quote, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_5quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("quote (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_4quote(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_4quote(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
  char *__pyx_v_ptr;
  char *__pyx_v_ptr_out;
  Py_ssize_t __pyx_v_length;
  PyObject *__pyx_v_value = NULL;
  struct __pyx_obj_9psycopg_c_2pq_Escaping *__pyx_v_esc = NULL;
  PyObject *__pyx_v_rv = NULL;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("quote", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":69
 *         cdef Py_ssize_t length
 * 
 *         value = self.dump(obj)             # <<<<<<<<<<<<<<
 * 
 *         if self._pgconn is not None:
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_obj};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_dump, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_value = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":71
 *         value = self.dump(obj)
 * 
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             esc = Escaping(self._pgconn)
 *             # escaping and quoting
*/
  __pyx_t_4 = (((PyObject *)__pyx_v_self->_pgconn) != Py_None);
  if (__pyx_t_4) {

    /* "psycopg_c/_psycopg/adapt.pyx":72
 * 
 *         if self._pgconn is not None:
 *             esc = Escaping(self._pgconn)             # <<<<<<<<<<<<<<
 *             # escaping and quoting
 *             return esc.escape_literal(value)
*/
    __pyx_t_2 = NULL;
    __pyx_t_3 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_v_self->_pgconn)};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_Escaping, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 72, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_1);
    }
    __pyx_v_esc = ((struct __pyx_obj_9psycopg_c_2pq_Escaping *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/adapt.pyx":74
 *             esc = Escaping(self._pgconn)
 *             # escaping and quoting
 *             return esc.escape_literal(value)             # <<<<<<<<<<<<<<
 * 
 *         # This path is taken when quote is asked without a connection,
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping *)__pyx_v_esc->__pyx_vtab)->escape_literal(__pyx_v_esc, __pyx_v_value, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 74, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/adapt.pyx":71
 *         value = self.dump(obj)
 * 
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             esc = Escaping(self._pgconn)
 *             # escaping and quoting
*/
  }

  /* "psycopg_c/_psycopg/adapt.pyx":81
 *         # someone generating a SQL file to consume elsewhere.
 * 
 *         rv = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 * 
 *         # No quoting, only quote escaping, random bs escaping. See further.
*/
  __pyx_t_1 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rv = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":84
 * 
 *         # No quoting, only quote escaping, random bs escaping. See further.
 *         esc = Escaping()             # <<<<<<<<<<<<<<
 *         out = esc.escape_string(value)
 * 
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_Escaping, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 84, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_esc = ((struct __pyx_obj_9psycopg_c_2pq_Escaping *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":85
 *         # No quoting, only quote escaping, random bs escaping. See further.
 *         esc = Escaping()
 *         out = esc.escape_string(value)             # <<<<<<<<<<<<<<
 * 
 *         _buffer_as_string_and_size(out, &ptr, &length)
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping *)__pyx_v_esc->__pyx_vtab)->escape_string(__pyx_v_esc, __pyx_v_value, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":87
 *         out = esc.escape_string(value)
 * 
 *         _buffer_as_string_and_size(out, &ptr, &length)             # <<<<<<<<<<<<<<
 * 
 *         if not memchr(ptr, b'\\', length):
*/
  __pyx_t_5 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_out, (&__pyx_v_ptr), (&__pyx_v_length)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(5, 87, __pyx_L1_error)

  /* "psycopg_c/_psycopg/adapt.pyx":89
 *         _buffer_as_string_and_size(out, &ptr, &length)
 * 
 *         if not memchr(ptr, b'\\', length):             # <<<<<<<<<<<<<<
 *             # If the string has no backslash, the result is correct and we
 *             # don't need to bother with standard_conforming_strings.
*/
  __pyx_t_4 = (!(memchr(__pyx_v_ptr, '\\', __pyx_v_length) != 0));
  if (__pyx_t_4) {

    /* "psycopg_c/_psycopg/adapt.pyx":92
 *             # If the string has no backslash, the result is correct and we
 *             # don't need to bother with standard_conforming_strings.
 *             PyByteArray_Resize(rv, length + 2)  # Must include the quotes             # <<<<<<<<<<<<<<
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             ptr_out[0] = b"'"
*/
    __pyx_t_5 = PyByteArray_Resize(__pyx_v_rv, (__pyx_v_length + 2)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(5, 92, __pyx_L1_error)

    /* "psycopg_c/_psycopg/adapt.pyx":93
 *             # don't need to bother with standard_conforming_strings.
 *             PyByteArray_Resize(rv, length + 2)  # Must include the quotes
 *             ptr_out = PyByteArray_AS_STRING(rv)             # <<<<<<<<<<<<<<
 *             ptr_out[0] = b"'"
 *             memcpy(ptr_out + 1, ptr, length)
*/
    __pyx_v_ptr_out = PyByteArray_AS_STRING(__pyx_v_rv);

    /* "psycopg_c/_psycopg/adapt.pyx":94
 *             PyByteArray_Resize(rv, length + 2)  # Must include the quotes
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             ptr_out[0] = b"'"             # <<<<<<<<<<<<<<
 *             memcpy(ptr_out + 1, ptr, length)
 *             ptr_out[length + 1] = b"'"
*/
    (__pyx_v_ptr_out[0]) = '\'';

    /* "psycopg_c/_psycopg/adapt.pyx":95
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             ptr_out[0] = b"'"
 *             memcpy(ptr_out + 1, ptr, length)             # <<<<<<<<<<<<<<
 *             ptr_out[length + 1] = b"'"
 *             return rv
*/
    (void)(memcpy((__pyx_v_ptr_out + 1), __pyx_v_ptr, __pyx_v_length));

    /* "psycopg_c/_psycopg/adapt.pyx":96
 *             ptr_out[0] = b"'"
 *             memcpy(ptr_out + 1, ptr, length)
 *             ptr_out[length + 1] = b"'"             # <<<<<<<<<<<<<<
 *             return rv
 * 
*/
    (__pyx_v_ptr_out[(__pyx_v_length + 1)]) = '\'';

    /* "psycopg_c/_psycopg/adapt.pyx":97
 *             memcpy(ptr_out + 1, ptr, length)
 *             ptr_out[length + 1] = b"'"
 *             return rv             # <<<<<<<<<<<<<<
 * 
 *         # The libpq has a crazy behaviour: PQescapeString uses the last
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_rv);
    __pyx_r = __pyx_v_rv;
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/adapt.pyx":89
 *         _buffer_as_string_and_size(out, &ptr, &length)
 * 
 *         if not memchr(ptr, b'\\', length):             # <<<<<<<<<<<<<<
 *             # If the string has no backslash, the result is correct and we
 *             # don't need to bother with standard_conforming_strings.
*/
  }

  /* "psycopg_c/_psycopg/adapt.pyx":108
 *         # Check what the libpq does, and if it doesn't escape the backslash
 *         # let's do it on our own. Never mind the race condition.
 *         PyByteArray_Resize(rv, length + 4)  # Must include " E'...'" quotes             # <<<<<<<<<<<<<<
 *         ptr_out = PyByteArray_AS_STRING(rv)
 *         ptr_out[0] = b" "
*/
  __pyx_t_5 = PyByteArray_Resize(__pyx_v_rv, (__pyx_v_length + 4)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(5, 108, __pyx_L1_error)

  /* "psycopg_c/_psycopg/adapt.pyx":109
 *         # let's do it on our own. Never mind the race condition.
 *         PyByteArray_Resize(rv, length + 4)  # Must include " E'...'" quotes
 *         ptr_out = PyByteArray_AS_STRING(rv)             # <<<<<<<<<<<<<<
 *         ptr_out[0] = b" "
 *         ptr_out[1] = b"E"
*/
  __pyx_v_ptr_out = PyByteArray_AS_STRING(__pyx_v_rv);

  /* "psycopg_c/_psycopg/adapt.pyx":110
 *         PyByteArray_Resize(rv, length + 4)  # Must include " E'...'" quotes
 *         ptr_out = PyByteArray_AS_STRING(rv)
 *         ptr_out[0] = b" "             # <<<<<<<<<<<<<<
 *         ptr_out[1] = b"E"
 *         ptr_out[2] = b"'"
*/
  (__pyx_v_ptr_out[0]) = ' ';

  /* "psycopg_c/_psycopg/adapt.pyx":111
 *         ptr_out = PyByteArray_AS_STRING(rv)
 *         ptr_out[0] = b" "
 *         ptr_out[1] = b"E"             # <<<<<<<<<<<<<<
 *         ptr_out[2] = b"'"
 *         memcpy(ptr_out + 3, ptr, length)
*/
  (__pyx_v_ptr_out[1]) = 'E';

  /* "psycopg_c/_psycopg/adapt.pyx":112
 *         ptr_out[0] = b" "
 *         ptr_out[1] = b"E"
 *         ptr_out[2] = b"'"             # <<<<<<<<<<<<<<
 *         memcpy(ptr_out + 3, ptr, length)
 *         ptr_out[length + 3] = b"'"
*/
  (__pyx_v_ptr_out[2]) = '\'';

  /* "psycopg_c/_psycopg/adapt.pyx":113
 *         ptr_out[1] = b"E"
 *         ptr_out[2] = b"'"
 *         memcpy(ptr_out + 3, ptr, length)             # <<<<<<<<<<<<<<
 *         ptr_out[length + 3] = b"'"
 * 
*/
  (void)(memcpy((__pyx_v_ptr_out + 3), __pyx_v_ptr, __pyx_v_length));

  /* "psycopg_c/_psycopg/adapt.pyx":114
 *         ptr_out[2] = b"'"
 *         memcpy(ptr_out + 3, ptr, length)
 *         ptr_out[length + 3] = b"'"             # <<<<<<<<<<<<<<
 * 
 *         if esc.escape_string(b"\\") == b"\\":
*/
  (__pyx_v_ptr_out[(__pyx_v_length + 3)]) = '\'';

  /* "psycopg_c/_psycopg/adapt.pyx":116
 *         ptr_out[length + 3] = b"'"
 * 
 *         if esc.escape_string(b"\\") == b"\\":             # <<<<<<<<<<<<<<
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
 *         return rv
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping *)__pyx_v_esc->__pyx_vtab)->escape_string(__pyx_v_esc, __pyx_mstate_global->__pyx_kp_b_, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = (__Pyx_PyBytes_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_b_, Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "psycopg_c/_psycopg/adapt.pyx":117
 * 
 *         if esc.escape_string(b"\\") == b"\\":
 *             rv = bytes(rv).replace(b"\\", b"\\\\")             # <<<<<<<<<<<<<<
 *         return rv
 * 
*/
    __pyx_t_2 = NULL;
    __pyx_t_3 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_rv};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 117, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[0], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 117, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF_SET(__pyx_v_rv, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/adapt.pyx":116
 *         ptr_out[length + 3] = b"'"
 * 
 *         if esc.escape_string(b"\\") == b"\\":             # <<<<<<<<<<<<<<
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
 *         return rv
*/
  }

  /* "psycopg_c/_psycopg/adapt.pyx":118
 *         if esc.escape_string(b"\\") == b"\\":
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
 *         return rv             # <<<<<<<<<<<<<<
 * 
 *     cpdef object get_key(self, object obj, object format):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rv);
  __pyx_r = __pyx_v_rv;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/adapt.pyx":64
 *         return rv
 * 
 *     def quote(self, obj) -> Buffer:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef char *ptr_out
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_value);
  __Pyx_XDECREF((PyObject *)__pyx_v_esc);
  __Pyx_XDECREF(__pyx_v_rv);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":120
 *         return rv
 * 
 *     cpdef object get_key(self, object obj, object format):             # <<<<<<<<<<<<<<
 *         return self.cls
 * 
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_7get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_7CDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_key", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 120, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_7CDumper_7get_key)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 120, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "psycopg_c/_psycopg/adapt.pyx":121
 * 
 *     cpdef object get_key(self, object obj, object format):
 *         return self.cls             # <<<<<<<<<<<<<<
 * 
 *     cpdef object upgrade(self, object obj, object format):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->cls);
  __pyx_r = __pyx_v_self->cls;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/adapt.pyx":120
 *         return rv
 * 
 *     cpdef object get_key(self, object obj, object format):             # <<<<<<<<<<<<<<
 *         return self.cls
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_7get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CDumper_7get_key = {"get_key", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_7get_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_7get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_key (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(5, 120, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 120, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 120, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_key", 0) < (0)) __PYX_ERR(5, 120, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, i); __PYX_ERR(5, 120, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 120, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 120, __pyx_L3_error)
    }
    __pyx_v_obj = values[0];
    __pyx_v_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 120, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_6get_key(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_6get_key(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_key", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_get_key(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":123
 *         return self.cls
 * 
 *     cpdef object upgrade(self, object obj, object format):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_9upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_7CDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("upgrade", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_upgrade); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 123, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_7CDumper_9upgrade)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 123, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "psycopg_c/_psycopg/adapt.pyx":124
 * 
 *     cpdef object upgrade(self, object obj, object format):
 *         return self             # <<<<<<<<<<<<<<
 * 
 *     @staticmethod
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/adapt.pyx":123
 *         return self.cls
 * 
 *     cpdef object upgrade(self, object obj, object format):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_9upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CDumper_9upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_9upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_9upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(5, 123, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 123, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 123, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(5, 123, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(5, 123, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 123, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 123, __pyx_L3_error)
    }
    __pyx_v_obj = values[0];
    __pyx_v_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 123, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_8upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_8upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("upgrade", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":126
 *         return self
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef char *ensure_size(
 *         bytearray ba, Py_ssize_t offset, Py_ssize_t size
*/

static char *__pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(PyObject *__pyx_v_ba, Py_ssize_t __pyx_v_offset, Py_ssize_t __pyx_v_size) {
  Py_ssize_t __pyx_v_curr_size;
  Py_ssize_t __pyx_v_new_size;
  char *__pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":136
 *         you want to write *size* bytes.
 *         """
 *         cdef Py_ssize_t curr_size = PyByteArray_GET_SIZE(ba)             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t new_size = offset + size
 *         if curr_size < new_size:
*/
  __pyx_v_curr_size = PyByteArray_GET_SIZE(__pyx_v_ba);

  /* "psycopg_c/_psycopg/adapt.pyx":137
 *         """
 *         cdef Py_ssize_t curr_size = PyByteArray_GET_SIZE(ba)
 *         cdef Py_ssize_t new_size = offset + size             # <<<<<<<<<<<<<<
 *         if curr_size < new_size:
 *             PyByteArray_Resize(ba, new_size)
*/
  __pyx_v_new_size = (__pyx_v_offset + __pyx_v_size);

  /* "psycopg_c/_psycopg/adapt.pyx":138
 *         cdef Py_ssize_t curr_size = PyByteArray_GET_SIZE(ba)
 *         cdef Py_ssize_t new_size = offset + size
 *         if curr_size < new_size:             # <<<<<<<<<<<<<<
 *             PyByteArray_Resize(ba, new_size)
 * 
*/
  __pyx_t_1 = (__pyx_v_curr_size < __pyx_v_new_size);
  if (__pyx_t_1) {

    /* "psycopg_c/_psycopg/adapt.pyx":139
 *         cdef Py_ssize_t new_size = offset + size
 *         if curr_size < new_size:
 *             PyByteArray_Resize(ba, new_size)             # <<<<<<<<<<<<<<
 * 
 *         return PyByteArray_AS_STRING(ba) + offset
*/
    __pyx_t_2 = PyByteArray_Resize(__pyx_v_ba, __pyx_v_new_size); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(5, 139, __pyx_L1_error)

    /* "psycopg_c/_psycopg/adapt.pyx":138
 *         cdef Py_ssize_t curr_size = PyByteArray_GET_SIZE(ba)
 *         cdef Py_ssize_t new_size = offset + size
 *         if curr_size < new_size:             # <<<<<<<<<<<<<<
 *             PyByteArray_Resize(ba, new_size)
 * 
*/
  }

  /* "psycopg_c/_psycopg/adapt.pyx":141
 *             PyByteArray_Resize(ba, new_size)
 * 
 *         return PyByteArray_AS_STRING(ba) + offset             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = (PyByteArray_AS_STRING(__pyx_v_ba) + __pyx_v_offset);
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/adapt.pyx":126
 *         return self
 * 
 *     @staticmethod             # <<<<<<<<<<<<<<
 *     cdef char *ensure_size(
 *         bytearray ba, Py_ssize_t offset, Py_ssize_t size
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.ensure_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":29
 * cdef class CDumper:
 * 
 *     cdef readonly object cls             # <<<<<<<<<<<<<<
 *     cdef pq.PGconn _pgconn
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_3cls_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_3cls_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_3cls___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_3cls___get__(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->cls);
  __pyx_r = __pyx_v_self->cls;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_11__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CDumper_11__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_11__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_11__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_10__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_10__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_13__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CDumper_13__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_13__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CDumper_13__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CDumper_12__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CDumper_12__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.CDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":149
 *     cdef pq.PGconn _pgconn
 * 
 *     def __cinit__(self, libpq.Oid oid, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self.oid = oid
 *         conn = context.connection if context is not None else None
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_7CLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_7CLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  Oid __pyx_v_oid;
  PyObject *__pyx_v_context = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(5, 149, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 149, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 149, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(5, 149, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(5, 149, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 149, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 149, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_oid = __Pyx_PyLong_As_Oid(values[0]); if (unlikely((__pyx_v_oid == ((Oid)-1)) && PyErr_Occurred())) __PYX_ERR(5, 149, __pyx_L3_error)
    __pyx_v_context = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(5, 149, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_7CLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, Oid __pyx_v_oid, PyObject *__pyx_v_context) {
  PyObject *__pyx_v_conn = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":150
 * 
 *     def __cinit__(self, libpq.Oid oid, context: AdaptContext | None = None):
 *         self.oid = oid             # <<<<<<<<<<<<<<
 *         conn = context.connection if context is not None else None
 *         self._pgconn = conn.pgconn if conn is not None else None
*/
  __pyx_v_self->oid = __pyx_v_oid;

  /* "psycopg_c/_psycopg/adapt.pyx":151
 *     def __cinit__(self, libpq.Oid oid, context: AdaptContext | None = None):
 *         self.oid = oid
 *         conn = context.connection if context is not None else None             # <<<<<<<<<<<<<<
 *         self._pgconn = conn.pgconn if conn is not None else None
 * 
*/
  __pyx_t_2 = (__pyx_v_context != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_mstate_global->__pyx_n_u_connection); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  __pyx_v_conn = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":152
 *         self.oid = oid
 *         conn = context.connection if context is not None else None
 *         self._pgconn = conn.pgconn if conn is not None else None             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __pyx_t_2 = (__pyx_v_conn != Py_None);
  if (__pyx_t_2) {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_conn, __pyx_mstate_global->__pyx_n_u_pgconn); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 152, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn))))) __PYX_ERR(5, 152, __pyx_L1_error)
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  } else {
    __Pyx_INCREF(Py_None);
    __pyx_t_1 = Py_None;
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn))))) __PYX_ERR(5, 152, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_pgconn);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_pgconn);
  __pyx_v_self->_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":149
 *     cdef pq.PGconn _pgconn
 * 
 *     def __cinit__(self, libpq.Oid oid, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self.oid = oid
 *         conn = context.connection if context is not None else None
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_conn);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":154
 *         self._pgconn = conn.pgconn if conn is not None else None
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError()
 * 
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_7CLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, CYTHON_UNUSED char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cload", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":155
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         raise NotImplementedError()             # <<<<<<<<<<<<<<
 * 
 *     def load(self, object data) -> Any:
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_NotImplementedError)), __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(5, 155, __pyx_L1_error)

  /* "psycopg_c/_psycopg/adapt.pyx":154
 *         self._pgconn = conn.pgconn if conn is not None else None
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":157
 *         raise NotImplementedError()
 * 
 *     def load(self, object data) -> Any:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef Py_ssize_t length
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_3load(PyObject *__pyx_v_self, PyObject *__pyx_v_data); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CLoader_3load = {"load", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CLoader_3load, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_3load(PyObject *__pyx_v_self, PyObject *__pyx_v_data) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CLoader_2load(((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self), ((PyObject *)__pyx_v_data));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_2load(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, PyObject *__pyx_v_data) {
  char *__pyx_v_ptr;
  Py_ssize_t __pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":160
 *         cdef char *ptr
 *         cdef Py_ssize_t length
 *         _buffer_as_string_and_size(data, &ptr, &length)             # <<<<<<<<<<<<<<
 *         return self.cload(ptr, length)
 * 
*/
  __pyx_t_1 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_data, (&__pyx_v_ptr), (&__pyx_v_length)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(5, 160, __pyx_L1_error)

  /* "psycopg_c/_psycopg/adapt.pyx":161
 *         cdef Py_ssize_t length
 *         _buffer_as_string_and_size(data, &ptr, &length)
 *         return self.cload(ptr, length)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self->__pyx_vtab)->cload(__pyx_v_self, __pyx_v_ptr, __pyx_v_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/adapt.pyx":157
 *         raise NotImplementedError()
 * 
 *     def load(self, object data) -> Any:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef Py_ssize_t length
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":146
 * @cython.freelist(8)
 * cdef class CLoader:
 *     cdef public libpq.Oid oid             # <<<<<<<<<<<<<<
 *     cdef pq.PGconn _pgconn
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_3oid_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_3oid_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CLoader_3oid___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_3oid___get__(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyLong_From_Oid(__pyx_v_self->oid); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.oid.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_7CLoader_3oid_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_7CLoader_3oid_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CLoader_3oid_2__set__(((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_7CLoader_3oid_2__set__(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  Oid __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __pyx_t_1 = __Pyx_PyLong_As_Oid(__pyx_v_value); if (unlikely((__pyx_t_1 == ((Oid)-1)) && PyErr_Occurred())) __PYX_ERR(5, 146, __pyx_L1_error)
  __pyx_v_self->oid = __pyx_t_1;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.oid.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CLoader_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CLoader_5__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CLoader_4__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7CLoader_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CLoader_7__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7CLoader_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_7CLoader_6__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_7CLoader_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.CLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/adapt.pyx":168
 *     cdef Transformer _tx
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self._tx = Transformer.from_context(context)
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
  PyObject *__pyx_v_context = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(5, 168, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 168, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 168, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(5, 168, __pyx_L3_error)
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(5, 168, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(5, 168, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(5, 168, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(5, 168, __pyx_L3_error)
    __pyx_v_oid = ((PyObject*)values[0]);
    __pyx_v_context = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(5, 168, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg._CRecursiveLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(5, 168, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, PyObject *__pyx_v_context) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":169
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 *         self._tx = Transformer.from_context(context)             # <<<<<<<<<<<<<<
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_context};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_from_context, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 169, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer))))) __PYX_ERR(5, 169, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_tx);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_tx);
  __pyx_v_self->_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":168
 *     cdef Transformer _tx
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self._tx = Transformer.from_context(context)
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg._CRecursiveLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17_CRecursiveLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg._CRecursiveLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17_CRecursiveLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17_CRecursiveLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg._CRecursiveLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":25
 * 
 * 
 * cdef object _format_row_binary(object row, Transformer tx, bytearray out):             # <<<<<<<<<<<<<<
 *     """Convert a row of adapted data to the data to send for binary copy"""
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__format_row_binary(PyObject *__pyx_v_row, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject *__pyx_v_out) {
  PyObject *__pyx_v_row_fast = 0;
  Py_ssize_t __pyx_v_rowlen;
  uint16_t __pyx_v_berowlen;
  Py_ssize_t __pyx_v_pos;
  char *__pyx_v_target;
  Py_ssize_t __pyx_v_size;
  uint32_t __pyx_v_besize;
  char *__pyx_v_buf;
  int __pyx_v_i;
  PyObject *__pyx_v_fmt;
  PyObject *__pyx_v_row_dumper;
  PyObject *__pyx_v_dumpers = NULL;
  PyObject *__pyx_v_item;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  char *__pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10[4];
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_format_row_binary", 0);

  /* "psycopg_c/_psycopg/copy.pyx":27
 * cdef object _format_row_binary(object row, Transformer tx, bytearray out):
 *     """Convert a row of adapted data to the data to send for binary copy"""
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)
 *     cdef uint16_t berowlen = endian.htobe16(<int16_t>rowlen)
*/
  __pyx_t_1 = PySequence_Fast(__pyx_v_row, ((char *)"'row' is not a valid sequence")); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_row_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":28
 *     """Convert a row of adapted data to the data to send for binary copy"""
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)             # <<<<<<<<<<<<<<
 *     cdef uint16_t berowlen = endian.htobe16(<int16_t>rowlen)
 * 
*/
  __pyx_v_rowlen = PySequence_Fast_GET_SIZE(__pyx_v_row_fast);

  /* "psycopg_c/_psycopg/copy.pyx":29
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)
 *     cdef uint16_t berowlen = endian.htobe16(<int16_t>rowlen)             # <<<<<<<<<<<<<<
 * 
 *     # offset in 'out' where to write
*/
  __pyx_v_berowlen = htobe16(((int16_t)__pyx_v_rowlen));

  /* "psycopg_c/_psycopg/copy.pyx":32
 * 
 *     # offset in 'out' where to write
 *     cdef Py_ssize_t pos = PyByteArray_GET_SIZE(out)             # <<<<<<<<<<<<<<
 * 
 *     cdef char *target = CDumper.ensure_size(out, pos, sizeof(berowlen))
*/
  __pyx_v_pos = PyByteArray_GET_SIZE(__pyx_v_out);

  /* "psycopg_c/_psycopg/copy.pyx":34
 *     cdef Py_ssize_t pos = PyByteArray_GET_SIZE(out)
 * 
 *     cdef char *target = CDumper.ensure_size(out, pos, sizeof(berowlen))             # <<<<<<<<<<<<<<
 * 
 *     # Write the number of fields as network-order 16 bits
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, __pyx_v_pos, (sizeof(__pyx_v_berowlen))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(7, 34, __pyx_L1_error)
  __pyx_v_target = __pyx_t_2;

  /* "psycopg_c/_psycopg/copy.pyx":37
 * 
 *     # Write the number of fields as network-order 16 bits
 *     memcpy(target, <void *>&berowlen, sizeof(berowlen))             # <<<<<<<<<<<<<<
 *     pos += sizeof(berowlen)
 * 
*/
  (void)(memcpy(__pyx_v_target, ((void *)(&__pyx_v_berowlen)), (sizeof(__pyx_v_berowlen))));

  /* "psycopg_c/_psycopg/copy.pyx":38
 *     # Write the number of fields as network-order 16 bits
 *     memcpy(target, <void *>&berowlen, sizeof(berowlen))
 *     pos += sizeof(berowlen)             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t size
*/
  __pyx_v_pos = (__pyx_v_pos + (sizeof(__pyx_v_berowlen)));

  /* "psycopg_c/_psycopg/copy.pyx":44
 *     cdef char *buf
 *     cdef int i
 *     cdef PyObject *fmt = <PyObject *>PG_BINARY             # <<<<<<<<<<<<<<
 *     cdef PyObject *row_dumper
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_PG_BINARY); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fmt = ((PyObject *)__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":47
 *     cdef PyObject *row_dumper
 * 
 *     if not tx._row_dumpers:             # <<<<<<<<<<<<<<
 *         tx._row_dumpers = PyList_New(rowlen)
 * 
*/
  if (__pyx_v_tx->_row_dumpers == Py_None) __pyx_t_3 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_tx->_row_dumpers);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(7, 47, __pyx_L1_error)
    __pyx_t_3 = (__pyx_temp != 0);
  }

  __pyx_t_4 = (!__pyx_t_3);
  if (__pyx_t_4) {

    /* "psycopg_c/_psycopg/copy.pyx":48
 * 
 *     if not tx._row_dumpers:
 *         tx._row_dumpers = PyList_New(rowlen)             # <<<<<<<<<<<<<<
 * 
 *     dumpers = tx._row_dumpers
*/
    __pyx_t_1 = PyList_New(__pyx_v_rowlen); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 48, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_tx->_row_dumpers);
    __Pyx_DECREF(__pyx_v_tx->_row_dumpers);
    __pyx_v_tx->_row_dumpers = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/copy.pyx":47
 *     cdef PyObject *row_dumper
 * 
 *     if not tx._row_dumpers:             # <<<<<<<<<<<<<<
 *         tx._row_dumpers = PyList_New(rowlen)
 * 
*/
  }

  /* "psycopg_c/_psycopg/copy.pyx":50
 *         tx._row_dumpers = PyList_New(rowlen)
 * 
 *     dumpers = tx._row_dumpers             # <<<<<<<<<<<<<<
 *     if PyList_GET_SIZE(dumpers) != rowlen:
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")
*/
  __pyx_t_1 = __pyx_v_tx->_row_dumpers;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_dumpers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":51
 * 
 *     dumpers = tx._row_dumpers
 *     if PyList_GET_SIZE(dumpers) != rowlen:             # <<<<<<<<<<<<<<
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")
 * 
*/
  __pyx_t_4 = (PyList_GET_SIZE(__pyx_v_dumpers) != __pyx_v_rowlen);
  if (unlikely(__pyx_t_4)) {

    /* "psycopg_c/_psycopg/copy.pyx":52
 *     dumpers = tx._row_dumpers
 *     if PyList_GET_SIZE(dumpers) != rowlen:
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *item
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(7, 52, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_PyList_GET_SIZE(__pyx_v_dumpers); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(7, 52, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_t_8, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_rowlen, 0, ' ', 'd'); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10[0] = __pyx_mstate_global->__pyx_kp_u_expected;
    __pyx_t_10[1] = __pyx_t_6;
    __pyx_t_10[2] = __pyx_mstate_global->__pyx_kp_u_values_in_row_got;
    __pyx_t_10[3] = __pyx_t_9;
    __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_10, 4, 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 20 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9), 127);
    if (unlikely(!__pyx_t_11)) __PYX_ERR(7, 52, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_12 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_11};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 52, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(7, 52, __pyx_L1_error)

    /* "psycopg_c/_psycopg/copy.pyx":51
 * 
 *     dumpers = tx._row_dumpers
 *     if PyList_GET_SIZE(dumpers) != rowlen:             # <<<<<<<<<<<<<<
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")
 * 
*/
  }

  /* "psycopg_c/_psycopg/copy.pyx":55
 * 
 *     cdef PyObject *item
 *     for i in range(rowlen):             # <<<<<<<<<<<<<<
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item is <PyObject *>None:
*/
  __pyx_t_8 = __pyx_v_rowlen;
  __pyx_t_13 = __pyx_t_8;
  for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
    __pyx_v_i = __pyx_t_14;

    /* "psycopg_c/_psycopg/copy.pyx":56
 *     cdef PyObject *item
 *     for i in range(rowlen):
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)             # <<<<<<<<<<<<<<
 *         if item is <PyObject *>None:
 *             _append_binary_none(out, &pos)
*/
    __pyx_v_item = PySequence_Fast_GET_ITEM(__pyx_v_row_fast, __pyx_v_i);

    /* "psycopg_c/_psycopg/copy.pyx":57
 *     for i in range(rowlen):
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item is <PyObject *>None:             # <<<<<<<<<<<<<<
 *             _append_binary_none(out, &pos)
 *             continue
*/
    __pyx_t_4 = (__pyx_v_item == ((PyObject *)Py_None));
    if (__pyx_t_4) {

      /* "psycopg_c/_psycopg/copy.pyx":58
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item is <PyObject *>None:
 *             _append_binary_none(out, &pos)             # <<<<<<<<<<<<<<
 *             continue
 * 
*/
      __pyx_t_15 = __pyx_f_9psycopg_c_8_psycopg__append_binary_none(__pyx_v_out, (&__pyx_v_pos)); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(7, 58, __pyx_L1_error)

      /* "psycopg_c/_psycopg/copy.pyx":59
 *         if item is <PyObject *>None:
 *             _append_binary_none(out, &pos)
 *             continue             # <<<<<<<<<<<<<<
 * 
 *         row_dumper = PyList_GET_ITEM(dumpers, i)
*/
      goto __pyx_L5_continue;

      /* "psycopg_c/_psycopg/copy.pyx":57
 *     for i in range(rowlen):
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item is <PyObject *>None:             # <<<<<<<<<<<<<<
 *             _append_binary_none(out, &pos)
 *             continue
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":61
 *             continue
 * 
 *         row_dumper = PyList_GET_ITEM(dumpers, i)             # <<<<<<<<<<<<<<
 *         if not row_dumper:
 *             row_dumper = tx.get_row_dumper(item, fmt)
*/
    __pyx_v_row_dumper = PyList_GET_ITEM(__pyx_v_dumpers, __pyx_v_i);

    /* "psycopg_c/_psycopg/copy.pyx":62
 * 
 *         row_dumper = PyList_GET_ITEM(dumpers, i)
 *         if not row_dumper:             # <<<<<<<<<<<<<<
 *             row_dumper = tx.get_row_dumper(item, fmt)
 *             Py_INCREF(<object>row_dumper)
*/
    __pyx_t_4 = (!(__pyx_v_row_dumper != 0));
    if (__pyx_t_4) {

      /* "psycopg_c/_psycopg/copy.pyx":63
 *         row_dumper = PyList_GET_ITEM(dumpers, i)
 *         if not row_dumper:
 *             row_dumper = tx.get_row_dumper(item, fmt)             # <<<<<<<<<<<<<<
 *             Py_INCREF(<object>row_dumper)
 *             PyList_SET_ITEM(dumpers, i, <object>row_dumper)
*/
      __pyx_t_16 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_tx->__pyx_vtab)->get_row_dumper(__pyx_v_tx, __pyx_v_item, __pyx_v_fmt); if (unlikely(__pyx_t_16 == ((void *)NULL))) __PYX_ERR(7, 63, __pyx_L1_error)
      __pyx_v_row_dumper = __pyx_t_16;

      /* "psycopg_c/_psycopg/copy.pyx":64
 *         if not row_dumper:
 *             row_dumper = tx.get_row_dumper(item, fmt)
 *             Py_INCREF(<object>row_dumper)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(dumpers, i, <object>row_dumper)
 * 
*/
      Py_INCREF(((PyObject *)__pyx_v_row_dumper));

      /* "psycopg_c/_psycopg/copy.pyx":65
 *             row_dumper = tx.get_row_dumper(item, fmt)
 *             Py_INCREF(<object>row_dumper)
 *             PyList_SET_ITEM(dumpers, i, <object>row_dumper)             # <<<<<<<<<<<<<<
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:
*/
      PyList_SET_ITEM(__pyx_v_dumpers, __pyx_v_i, ((PyObject *)__pyx_v_row_dumper));

      /* "psycopg_c/_psycopg/copy.pyx":62
 * 
 *         row_dumper = PyList_GET_ITEM(dumpers, i)
 *         if not row_dumper:             # <<<<<<<<<<<<<<
 *             row_dumper = tx.get_row_dumper(item, fmt)
 *             Py_INCREF(<object>row_dumper)
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":67
 *             PyList_SET_ITEM(dumpers, i, <object>row_dumper)
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:             # <<<<<<<<<<<<<<
 *             # A cdumper can resize if necessary and copy in place
 *             size = (<RowDumper>row_dumper).cdumper.cdump(
*/
    __pyx_t_4 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper) != Py_None);
    if (__pyx_t_4) {

      /* "psycopg_c/_psycopg/copy.pyx":69
 *         if (<RowDumper>row_dumper).cdumper is not None:
 *             # A cdumper can resize if necessary and copy in place
 *             size = (<RowDumper>row_dumper).cdumper.cdump(             # <<<<<<<<<<<<<<
 *                 <object>item, out, pos + sizeof(besize))
 *             # Also add the size of the item, before the item
*/
      __pyx_t_17 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper->__pyx_vtab)->cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper, ((PyObject *)__pyx_v_item), __pyx_v_out, (__pyx_v_pos + (sizeof(__pyx_v_besize)))); if (unlikely(__pyx_t_17 == ((Py_ssize_t)-1L))) __PYX_ERR(7, 69, __pyx_L1_error)
      __pyx_v_size = __pyx_t_17;

      /* "psycopg_c/_psycopg/copy.pyx":72
 *                 <object>item, out, pos + sizeof(besize))
 *             # Also add the size of the item, before the item
 *             besize = endian.htobe32(<int32_t>size)             # <<<<<<<<<<<<<<
 *             target = PyByteArray_AS_STRING(out)  # might have been moved by cdump
 *             memcpy(target + pos, <void *>&besize, sizeof(besize))
*/
      __pyx_v_besize = htobe32(((int32_t)__pyx_v_size));

      /* "psycopg_c/_psycopg/copy.pyx":73
 *             # Also add the size of the item, before the item
 *             besize = endian.htobe32(<int32_t>size)
 *             target = PyByteArray_AS_STRING(out)  # might have been moved by cdump             # <<<<<<<<<<<<<<
 *             memcpy(target + pos, <void *>&besize, sizeof(besize))
 *         else:
*/
      __pyx_v_target = PyByteArray_AS_STRING(__pyx_v_out);

      /* "psycopg_c/_psycopg/copy.pyx":74
 *             besize = endian.htobe32(<int32_t>size)
 *             target = PyByteArray_AS_STRING(out)  # might have been moved by cdump
 *             memcpy(target + pos, <void *>&besize, sizeof(besize))             # <<<<<<<<<<<<<<
 *         else:
 *             # A Python dumper, gotta call it and extract its juices
*/
      (void)(memcpy((__pyx_v_target + __pyx_v_pos), ((void *)(&__pyx_v_besize)), (sizeof(__pyx_v_besize))));

      /* "psycopg_c/_psycopg/copy.pyx":67
 *             PyList_SET_ITEM(dumpers, i, <object>row_dumper)
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:             # <<<<<<<<<<<<<<
 *             # A cdumper can resize if necessary and copy in place
 *             size = (<RowDumper>row_dumper).cdumper.cdump(
*/
      goto __pyx_L9;
    }

    /* "psycopg_c/_psycopg/copy.pyx":77
 *         else:
 *             # A Python dumper, gotta call it and extract its juices
 *             b = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:
*/
    /*else*/ {

      /* "psycopg_c/_psycopg/copy.pyx":78
 *             # A Python dumper, gotta call it and extract its juices
 *             b = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)             # <<<<<<<<<<<<<<
 *             if b is None:
 *                 _append_binary_none(out, &pos)
*/
      __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->dumpfunc;
      __Pyx_INCREF(__pyx_t_1);

      /* "psycopg_c/_psycopg/copy.pyx":77
 *         else:
 *             # A Python dumper, gotta call it and extract its juices
 *             b = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:
*/
      __pyx_t_7 = PyObject_CallFunctionObjArgs(__pyx_t_1, __pyx_v_item, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 77, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_b, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":79
 *             b = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:             # <<<<<<<<<<<<<<
 *                 _append_binary_none(out, &pos)
 *                 continue
*/
      __pyx_t_4 = (__pyx_v_b == Py_None);
      if (__pyx_t_4) {

        /* "psycopg_c/_psycopg/copy.pyx":80
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:
 *                 _append_binary_none(out, &pos)             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
*/
        __pyx_t_15 = __pyx_f_9psycopg_c_8_psycopg__append_binary_none(__pyx_v_out, (&__pyx_v_pos)); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(7, 80, __pyx_L1_error)

        /* "psycopg_c/_psycopg/copy.pyx":81
 *             if b is None:
 *                 _append_binary_none(out, &pos)
 *                 continue             # <<<<<<<<<<<<<<
 *             else:
 *                 _buffer_as_string_and_size(b, &buf, &size)
*/
        goto __pyx_L5_continue;

        /* "psycopg_c/_psycopg/copy.pyx":79
 *             b = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:             # <<<<<<<<<<<<<<
 *                 _append_binary_none(out, &pos)
 *                 continue
*/
      }

      /* "psycopg_c/_psycopg/copy.pyx":83
 *                 continue
 *             else:
 *                 _buffer_as_string_and_size(b, &buf, &size)             # <<<<<<<<<<<<<<
 *                 target = CDumper.ensure_size(out, pos, size + sizeof(besize))
 *                 besize = endian.htobe32(<int32_t>size)
*/
      /*else*/ {
        __pyx_t_15 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_b, (&__pyx_v_buf), (&__pyx_v_size)); if (unlikely(__pyx_t_15 == ((int)-1))) __PYX_ERR(7, 83, __pyx_L1_error)

        /* "psycopg_c/_psycopg/copy.pyx":84
 *             else:
 *                 _buffer_as_string_and_size(b, &buf, &size)
 *                 target = CDumper.ensure_size(out, pos, size + sizeof(besize))             # <<<<<<<<<<<<<<
 *                 besize = endian.htobe32(<int32_t>size)
 *                 memcpy(target, <void *>&besize, sizeof(besize))
*/
        __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, __pyx_v_pos, (__pyx_v_size + (sizeof(__pyx_v_besize)))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(7, 84, __pyx_L1_error)
        __pyx_v_target = __pyx_t_2;

        /* "psycopg_c/_psycopg/copy.pyx":85
 *                 _buffer_as_string_and_size(b, &buf, &size)
 *                 target = CDumper.ensure_size(out, pos, size + sizeof(besize))
 *                 besize = endian.htobe32(<int32_t>size)             # <<<<<<<<<<<<<<
 *                 memcpy(target, <void *>&besize, sizeof(besize))
 *                 memcpy(target + sizeof(besize), buf, size)
*/
        __pyx_v_besize = htobe32(((int32_t)__pyx_v_size));

        /* "psycopg_c/_psycopg/copy.pyx":86
 *                 target = CDumper.ensure_size(out, pos, size + sizeof(besize))
 *                 besize = endian.htobe32(<int32_t>size)
 *                 memcpy(target, <void *>&besize, sizeof(besize))             # <<<<<<<<<<<<<<
 *                 memcpy(target + sizeof(besize), buf, size)
 * 
*/
        (void)(memcpy(__pyx_v_target, ((void *)(&__pyx_v_besize)), (sizeof(__pyx_v_besize))));

        /* "psycopg_c/_psycopg/copy.pyx":87
 *                 besize = endian.htobe32(<int32_t>size)
 *                 memcpy(target, <void *>&besize, sizeof(besize))
 *                 memcpy(target + sizeof(besize), buf, size)             # <<<<<<<<<<<<<<
 * 
 *         pos += size + sizeof(besize)
*/
        (void)(memcpy((__pyx_v_target + (sizeof(__pyx_v_besize))), __pyx_v_buf, __pyx_v_size));
      }
    }
    __pyx_L9:;

    /* "psycopg_c/_psycopg/copy.pyx":89
 *                 memcpy(target + sizeof(besize), buf, size)
 * 
 *         pos += size + sizeof(besize)             # <<<<<<<<<<<<<<
 * 
 *     # Resize to the final size
*/
    __pyx_v_pos = (__pyx_v_pos + (__pyx_v_size + (sizeof(__pyx_v_besize))));
    __pyx_L5_continue:;
  }

  /* "psycopg_c/_psycopg/copy.pyx":92
 * 
 *     # Resize to the final size
 *     PyByteArray_Resize(out, pos)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_14 = PyByteArray_Resize(__pyx_v_out, __pyx_v_pos); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(7, 92, __pyx_L1_error)

  /* "psycopg_c/_psycopg/copy.pyx":25
 * 
 * 
 * cdef object _format_row_binary(object row, Transformer tx, bytearray out):             # <<<<<<<<<<<<<<
 *     """Convert a row of adapted data to the data to send for binary copy"""
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("psycopg_c._psycopg._format_row_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_row_fast);
  __Pyx_XDECREF(__pyx_v_dumpers);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":95
 * 
 * 
 * def format_row_binary(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_1format_row_binary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_1format_row_binary = {"format_row_binary", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_1format_row_binary, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_1format_row_binary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_row = 0;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx = 0;
  PyObject *__pyx_v_out = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("format_row_binary (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_row,&__pyx_mstate_global->__pyx_n_u_tx,&__pyx_mstate_global->__pyx_n_u_out,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(7, 95, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(7, 95, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 95, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 95, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "format_row_binary", 0) < (0)) __PYX_ERR(7, 95, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("format_row_binary", 1, 3, 3, i); __PYX_ERR(7, 95, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 95, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 95, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(7, 95, __pyx_L3_error)
    }
    __pyx_v_row = values[0];
    __pyx_v_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)values[1]);
    __pyx_v_out = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("format_row_binary", 1, 3, 3, __pyx_nargs); __PYX_ERR(7, 95, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.format_row_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tx), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, 0, "tx", 0))) __PYX_ERR(7, 95, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_out), (&PyByteArray_Type), 0, "out", 2))) __PYX_ERR(7, 95, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_format_row_binary(__pyx_self, __pyx_v_row, __pyx_v_tx, __pyx_v_out);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_format_row_binary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_row, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject *__pyx_v_out) {
  Py_ssize_t __pyx_v_size;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("format_row_binary", 0);

  /* "psycopg_c/_psycopg/copy.pyx":96
 * 
 * def format_row_binary(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)             # <<<<<<<<<<<<<<
 * 
 *     try:
*/
  __pyx_v_size = PyByteArray_GET_SIZE(__pyx_v_out);

  /* "psycopg_c/_psycopg/copy.pyx":98
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         _format_row_binary(row, tx, out)
 *     except Exception as e:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "psycopg_c/_psycopg/copy.pyx":99
 * 
 *     try:
 *         _format_row_binary(row, tx, out)             # <<<<<<<<<<<<<<
 *     except Exception as e:
 *         # Restore the input bytearray to the size it was before entering here
*/
      __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__format_row_binary(__pyx_v_row, __pyx_v_tx, __pyx_v_out); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 99, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":98
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         _format_row_binary(row, tx, out)
 *     except Exception as e:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "psycopg_c/_psycopg/copy.pyx":100
 *     try:
 *         _format_row_binary(row, tx, out)
 *     except Exception as e:             # <<<<<<<<<<<<<<
 *         # Restore the input bytearray to the size it was before entering here
 *         # to avoid potentially passing junk to copy.
*/
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("psycopg_c._psycopg.format_row_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(7, 100, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_e = __pyx_t_6;
      /*try:*/ {

        /* "psycopg_c/_psycopg/copy.pyx":103
 *         # Restore the input bytearray to the size it was before entering here
 *         # to avoid potentially passing junk to copy.
 *         PyByteArray_Resize(out, size)             # <<<<<<<<<<<<<<
 *         raise e
 * 
*/
        __pyx_t_5 = PyByteArray_Resize(__pyx_v_out, __pyx_v_size); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(7, 103, __pyx_L14_error)

        /* "psycopg_c/_psycopg/copy.pyx":104
 *         # to avoid potentially passing junk to copy.
 *         PyByteArray_Resize(out, size)
 *         raise e             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(7, 104, __pyx_L14_error)
      }

      /* "psycopg_c/_psycopg/copy.pyx":100
 *     try:
 *         _format_row_binary(row, tx, out)
 *     except Exception as e:             # <<<<<<<<<<<<<<
 *         # Restore the input bytearray to the size it was before entering here
 *         # to avoid potentially passing junk to copy.
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          if ( unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __pyx_t_5 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
          __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "psycopg_c/_psycopg/copy.pyx":98
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         _format_row_binary(row, tx, out)
 *     except Exception as e:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "psycopg_c/_psycopg/copy.pyx":95
 * 
 * 
 * def format_row_binary(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("psycopg_c._psycopg.format_row_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":107
 * 
 * 
 * cdef int _append_binary_none(bytearray out, Py_ssize_t *pos) except -1:             # <<<<<<<<<<<<<<
 *     cdef char *target
 *     target = CDumper.ensure_size(out, pos[0], sizeof(_binary_null))
*/

static int __pyx_f_9psycopg_c_8_psycopg__append_binary_none(PyObject *__pyx_v_out, Py_ssize_t *__pyx_v_pos) {
  char *__pyx_v_target;
  int __pyx_r;
  char *__pyx_t_1;
  long __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "psycopg_c/_psycopg/copy.pyx":109
 * cdef int _append_binary_none(bytearray out, Py_ssize_t *pos) except -1:
 *     cdef char *target
 *     target = CDumper.ensure_size(out, pos[0], sizeof(_binary_null))             # <<<<<<<<<<<<<<
 *     memcpy(target, <void *>&_binary_null, sizeof(_binary_null))
 *     pos[0] += sizeof(_binary_null)
*/
  __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, (__pyx_v_pos[0]), (sizeof(__pyx_v_9psycopg_c_8_psycopg__binary_null))); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(7, 109, __pyx_L1_error)
  __pyx_v_target = __pyx_t_1;

  /* "psycopg_c/_psycopg/copy.pyx":110
 *     cdef char *target
 *     target = CDumper.ensure_size(out, pos[0], sizeof(_binary_null))
 *     memcpy(target, <void *>&_binary_null, sizeof(_binary_null))             # <<<<<<<<<<<<<<
 *     pos[0] += sizeof(_binary_null)
 *     return 0
*/
  (void)(memcpy(__pyx_v_target, ((void *)(&__pyx_v_9psycopg_c_8_psycopg__binary_null)), (sizeof(__pyx_v_9psycopg_c_8_psycopg__binary_null))));

  /* "psycopg_c/_psycopg/copy.pyx":111
 *     target = CDumper.ensure_size(out, pos[0], sizeof(_binary_null))
 *     memcpy(target, <void *>&_binary_null, sizeof(_binary_null))
 *     pos[0] += sizeof(_binary_null)             # <<<<<<<<<<<<<<
 *     return 0
 * 
*/
  __pyx_t_2 = 0;
  (__pyx_v_pos[__pyx_t_2]) = ((__pyx_v_pos[__pyx_t_2]) + (sizeof(__pyx_v_9psycopg_c_8_psycopg__binary_null)));

  /* "psycopg_c/_psycopg/copy.pyx":112
 *     memcpy(target, <void *>&_binary_null, sizeof(_binary_null))
 *     pos[0] += sizeof(_binary_null)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/copy.pyx":107
 * 
 * 
 * cdef int _append_binary_none(bytearray out, Py_ssize_t *pos) except -1:             # <<<<<<<<<<<<<<
 *     cdef char *target
 *     target = CDumper.ensure_size(out, pos[0], sizeof(_binary_null))
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg._append_binary_none", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":115
 * 
 * 
 * cdef object _format_row_text(object row, Transformer tx, bytearray out):             # <<<<<<<<<<<<<<
 *     # offset in 'out' where to write
 *     cdef Py_ssize_t pos = PyByteArray_GET_SIZE(out)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__format_row_text(PyObject *__pyx_v_row, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject *__pyx_v_out) {
  Py_ssize_t __pyx_v_pos;
  PyObject *__pyx_v_row_fast = 0;
  Py_ssize_t __pyx_v_rowlen;
  Py_ssize_t __pyx_v_size;
  Py_ssize_t __pyx_v_tmpsize;
  char *__pyx_v_buf;
  int __pyx_v_i;
  int __pyx_v_j;
  unsigned char *__pyx_v_target;
  int __pyx_v_nesc;
  int __pyx_v_with_tab;
  PyObject *__pyx_v_fmt;
  PyObject *__pyx_v_row_dumper;
  PyObject *__pyx_v_dumpers = NULL;
  PyObject *__pyx_v_item;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10[4];
  PyObject *__pyx_t_11 = NULL;
  size_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  PyObject *__pyx_t_15;
  Py_ssize_t __pyx_t_16;
  char *__pyx_t_17;
  Py_ssize_t __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_format_row_text", 0);

  /* "psycopg_c/_psycopg/copy.pyx":117
 * cdef object _format_row_text(object row, Transformer tx, bytearray out):
 *     # offset in 'out' where to write
 *     cdef Py_ssize_t pos = PyByteArray_GET_SIZE(out)             # <<<<<<<<<<<<<<
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")
 * 
*/
  __pyx_v_pos = PyByteArray_GET_SIZE(__pyx_v_out);

  /* "psycopg_c/_psycopg/copy.pyx":118
 *     # offset in 'out' where to write
 *     cdef Py_ssize_t pos = PyByteArray_GET_SIZE(out)
 *     cdef row_fast = PySequence_Fast(row, "'row' is not a valid sequence")             # <<<<<<<<<<<<<<
 * 
 *     # exit early, if the row is empty
*/
  __pyx_t_1 = PySequence_Fast(__pyx_v_row, ((char *)"'row' is not a valid sequence")); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_row_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":121
 * 
 *     # exit early, if the row is empty
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)             # <<<<<<<<<<<<<<
 *     if rowlen == 0:
 *         PyByteArray_Resize(out, pos + 1)
*/
  __pyx_v_rowlen = PySequence_Fast_GET_SIZE(__pyx_v_row_fast);

  /* "psycopg_c/_psycopg/copy.pyx":122
 *     # exit early, if the row is empty
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)
 *     if rowlen == 0:             # <<<<<<<<<<<<<<
 *         PyByteArray_Resize(out, pos + 1)
 *         out[pos] = b"\n"
*/
  __pyx_t_2 = (__pyx_v_rowlen == 0);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/copy.pyx":123
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)
 *     if rowlen == 0:
 *         PyByteArray_Resize(out, pos + 1)             # <<<<<<<<<<<<<<
 *         out[pos] = b"\n"
 *         return
*/
    __pyx_t_3 = PyByteArray_Resize(__pyx_v_out, (__pyx_v_pos + 1)); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(7, 123, __pyx_L1_error)

    /* "psycopg_c/_psycopg/copy.pyx":124
 *     if rowlen == 0:
 *         PyByteArray_Resize(out, pos + 1)
 *         out[pos] = b"\n"             # <<<<<<<<<<<<<<
 *         return
 * 
*/
    if (unlikely((__Pyx_SetItemInt_ByteArray(__pyx_v_out, __pyx_v_pos, '\n', Py_ssize_t, 1, PyLong_FromSsize_t, 0, 1, 1, 1, __Pyx_ReferenceSharing_FunctionArgument) < 0))) __PYX_ERR(7, 124, __pyx_L1_error)

    /* "psycopg_c/_psycopg/copy.pyx":125
 *         PyByteArray_Resize(out, pos + 1)
 *         out[pos] = b"\n"
 *         return             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t size, tmpsize
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/copy.pyx":122
 *     # exit early, if the row is empty
 *     cdef Py_ssize_t rowlen = PySequence_Fast_GET_SIZE(row_fast)
 *     if rowlen == 0:             # <<<<<<<<<<<<<<
 *         PyByteArray_Resize(out, pos + 1)
 *         out[pos] = b"\n"
*/
  }

  /* "psycopg_c/_psycopg/copy.pyx":133
 *     cdef int nesc
 *     cdef int with_tab
 *     cdef PyObject *fmt = <PyObject *>PG_TEXT             # <<<<<<<<<<<<<<
 *     cdef PyObject *row_dumper
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_PG_TEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 133, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_fmt = ((PyObject *)__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":136
 *     cdef PyObject *row_dumper
 * 
 *     dumpers = tx._row_dumpers             # <<<<<<<<<<<<<<
 *     if dumpers and PyList_GET_SIZE(dumpers) != rowlen:
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")
*/
  __pyx_t_1 = __pyx_v_tx->_row_dumpers;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_dumpers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":137
 * 
 *     dumpers = tx._row_dumpers
 *     if dumpers and PyList_GET_SIZE(dumpers) != rowlen:             # <<<<<<<<<<<<<<
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")
 * 
*/
  if (__pyx_v_dumpers == Py_None) __pyx_t_4 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dumpers);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(7, 137, __pyx_L1_error)
    __pyx_t_4 = (__pyx_temp != 0);
  }

  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_4 = (PyList_GET_SIZE(__pyx_v_dumpers) != __pyx_v_rowlen);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "psycopg_c/_psycopg/copy.pyx":138
 *     dumpers = tx._row_dumpers
 *     if dumpers and PyList_GET_SIZE(dumpers) != rowlen:
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *item
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v_dumpers == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(7, 138, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_PyList_GET_SIZE(__pyx_v_dumpers); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(7, 138, __pyx_L1_error)
    __pyx_t_6 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_t_8, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_9 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_rowlen, 0, ' ', 'd'); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10[0] = __pyx_mstate_global->__pyx_kp_u_expected;
    __pyx_t_10[1] = __pyx_t_6;
    __pyx_t_10[2] = __pyx_mstate_global->__pyx_kp_u_values_in_row_got;
    __pyx_t_10[3] = __pyx_t_9;
    __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_10, 4, 9 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 20 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9), 127);
    if (unlikely(!__pyx_t_11)) __PYX_ERR(7, 138, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_12 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_12 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_11};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_12, (2-__pyx_t_12) | (__pyx_t_12*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 138, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(7, 138, __pyx_L1_error)

    /* "psycopg_c/_psycopg/copy.pyx":137
 * 
 *     dumpers = tx._row_dumpers
 *     if dumpers and PyList_GET_SIZE(dumpers) != rowlen:             # <<<<<<<<<<<<<<
 *         raise e.DataError(f"expected {len(dumpers)} values in row, got {rowlen}")
 * 
*/
  }

  /* "psycopg_c/_psycopg/copy.pyx":141
 * 
 *     cdef PyObject *item
 *     for i in range(rowlen):             # <<<<<<<<<<<<<<
 *         # Include the tab before the data, so it gets included in the resizes
 *         with_tab = i > 0
*/
  __pyx_t_8 = __pyx_v_rowlen;
  __pyx_t_13 = __pyx_t_8;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_13; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "psycopg_c/_psycopg/copy.pyx":143
 *     for i in range(rowlen):
 *         # Include the tab before the data, so it gets included in the resizes
 *         with_tab = i > 0             # <<<<<<<<<<<<<<
 * 
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
*/
    __pyx_v_with_tab = (__pyx_v_i > 0);

    /* "psycopg_c/_psycopg/copy.pyx":145
 *         with_tab = i > 0
 * 
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)             # <<<<<<<<<<<<<<
 *         if item == <PyObject *>None:
 *             _append_text_none(out, &pos, with_tab)
*/
    __pyx_v_item = PySequence_Fast_GET_ITEM(__pyx_v_row_fast, __pyx_v_i);

    /* "psycopg_c/_psycopg/copy.pyx":146
 * 
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item == <PyObject *>None:             # <<<<<<<<<<<<<<
 *             _append_text_none(out, &pos, with_tab)
 *             continue
*/
    __pyx_t_2 = (__pyx_v_item == ((PyObject *)Py_None));
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/copy.pyx":147
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item == <PyObject *>None:
 *             _append_text_none(out, &pos, with_tab)             # <<<<<<<<<<<<<<
 *             continue
 * 
*/
      __pyx_t_14 = __pyx_f_9psycopg_c_8_psycopg__append_text_none(__pyx_v_out, (&__pyx_v_pos), __pyx_v_with_tab); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(7, 147, __pyx_L1_error)

      /* "psycopg_c/_psycopg/copy.pyx":148
 *         if item == <PyObject *>None:
 *             _append_text_none(out, &pos, with_tab)
 *             continue             # <<<<<<<<<<<<<<
 * 
 *         if dumpers:
*/
      goto __pyx_L7_continue;

      /* "psycopg_c/_psycopg/copy.pyx":146
 * 
 *         item = PySequence_Fast_GET_ITEM(row_fast, i)
 *         if item == <PyObject *>None:             # <<<<<<<<<<<<<<
 *             _append_text_none(out, &pos, with_tab)
 *             continue
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":150
 *             continue
 * 
 *         if dumpers:             # <<<<<<<<<<<<<<
 *             # pinned dumpers from set_types are authoritative
 *             row_dumper = PyList_GET_ITEM(dumpers, i)
*/
    if (__pyx_v_dumpers == Py_None) __pyx_t_2 = 0;
    else
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dumpers);
      if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(7, 150, __pyx_L1_error)
      __pyx_t_2 = (__pyx_temp != 0);
    }

    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/copy.pyx":152
 *         if dumpers:
 *             # pinned dumpers from set_types are authoritative
 *             row_dumper = PyList_GET_ITEM(dumpers, i)             # <<<<<<<<<<<<<<
 *         else:
 *             # no pinned dumpers, thus free value dumping
*/
      __pyx_v_row_dumper = PyList_GET_ITEM(__pyx_v_dumpers, __pyx_v_i);

      /* "psycopg_c/_psycopg/copy.pyx":150
 *             continue
 * 
 *         if dumpers:             # <<<<<<<<<<<<<<
 *             # pinned dumpers from set_types are authoritative
 *             row_dumper = PyList_GET_ITEM(dumpers, i)
*/
      goto __pyx_L10;
    }

    /* "psycopg_c/_psycopg/copy.pyx":155
 *         else:
 *             # no pinned dumpers, thus free value dumping
 *             row_dumper = tx.get_row_dumper(item, fmt)             # <<<<<<<<<<<<<<
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:
*/
    /*else*/ {
      __pyx_t_15 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_tx->__pyx_vtab)->get_row_dumper(__pyx_v_tx, __pyx_v_item, __pyx_v_fmt); if (unlikely(__pyx_t_15 == ((void *)NULL))) __PYX_ERR(7, 155, __pyx_L1_error)
      __pyx_v_row_dumper = __pyx_t_15;
    }
    __pyx_L10:;

    /* "psycopg_c/_psycopg/copy.pyx":157
 *             row_dumper = tx.get_row_dumper(item, fmt)
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:             # <<<<<<<<<<<<<<
 *             # A cdumper can resize if necessary and copy in place
 *             size = (<RowDumper>row_dumper).cdumper.cdump(
*/
    __pyx_t_2 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper) != Py_None);
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/copy.pyx":159
 *         if (<RowDumper>row_dumper).cdumper is not None:
 *             # A cdumper can resize if necessary and copy in place
 *             size = (<RowDumper>row_dumper).cdumper.cdump(             # <<<<<<<<<<<<<<
 *                 <object>item, out, pos + with_tab)
 *             target = <unsigned char *>PyByteArray_AS_STRING(out) + pos
*/
      __pyx_t_16 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper->__pyx_vtab)->cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper, ((PyObject *)__pyx_v_item), __pyx_v_out, (__pyx_v_pos + __pyx_v_with_tab)); if (unlikely(__pyx_t_16 == ((Py_ssize_t)-1L))) __PYX_ERR(7, 159, __pyx_L1_error)
      __pyx_v_size = __pyx_t_16;

      /* "psycopg_c/_psycopg/copy.pyx":161
 *             size = (<RowDumper>row_dumper).cdumper.cdump(
 *                 <object>item, out, pos + with_tab)
 *             target = <unsigned char *>PyByteArray_AS_STRING(out) + pos             # <<<<<<<<<<<<<<
 *         else:
 *             # A Python dumper, gotta call it and extract its juices
*/
      __pyx_v_target = (((unsigned char *)PyByteArray_AS_STRING(__pyx_v_out)) + __pyx_v_pos);

      /* "psycopg_c/_psycopg/copy.pyx":157
 *             row_dumper = tx.get_row_dumper(item, fmt)
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:             # <<<<<<<<<<<<<<
 *             # A cdumper can resize if necessary and copy in place
 *             size = (<RowDumper>row_dumper).cdumper.cdump(
*/
      goto __pyx_L11;
    }

    /* "psycopg_c/_psycopg/copy.pyx":164
 *         else:
 *             # A Python dumper, gotta call it and extract its juices
 *             b = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:
*/
    /*else*/ {

      /* "psycopg_c/_psycopg/copy.pyx":165
 *             # A Python dumper, gotta call it and extract its juices
 *             b = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)             # <<<<<<<<<<<<<<
 *             if b is None:
 *                 _append_text_none(out, &pos, with_tab)
*/
      __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->dumpfunc;
      __Pyx_INCREF(__pyx_t_1);

      /* "psycopg_c/_psycopg/copy.pyx":164
 *         else:
 *             # A Python dumper, gotta call it and extract its juices
 *             b = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:
*/
      __pyx_t_7 = PyObject_CallFunctionObjArgs(__pyx_t_1, __pyx_v_item, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 164, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF_SET(__pyx_v_b, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":166
 *             b = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:             # <<<<<<<<<<<<<<
 *                 _append_text_none(out, &pos, with_tab)
 *                 continue
*/
      __pyx_t_2 = (__pyx_v_b == Py_None);
      if (__pyx_t_2) {

        /* "psycopg_c/_psycopg/copy.pyx":167
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:
 *                 _append_text_none(out, &pos, with_tab)             # <<<<<<<<<<<<<<
 *                 continue
 *             else:
*/
        __pyx_t_14 = __pyx_f_9psycopg_c_8_psycopg__append_text_none(__pyx_v_out, (&__pyx_v_pos), __pyx_v_with_tab); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(7, 167, __pyx_L1_error)

        /* "psycopg_c/_psycopg/copy.pyx":168
 *             if b is None:
 *                 _append_text_none(out, &pos, with_tab)
 *                 continue             # <<<<<<<<<<<<<<
 *             else:
 *                 _buffer_as_string_and_size(b, &buf, &size)
*/
        goto __pyx_L7_continue;

        /* "psycopg_c/_psycopg/copy.pyx":166
 *             b = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>row_dumper).dumpfunc, item, NULL)
 *             if b is None:             # <<<<<<<<<<<<<<
 *                 _append_text_none(out, &pos, with_tab)
 *                 continue
*/
      }

      /* "psycopg_c/_psycopg/copy.pyx":170
 *                 continue
 *             else:
 *                 _buffer_as_string_and_size(b, &buf, &size)             # <<<<<<<<<<<<<<
 *                 target = <unsigned char *>CDumper.ensure_size(out, pos, size + with_tab)
 *                 memcpy(target + with_tab, buf, size)
*/
      /*else*/ {
        __pyx_t_14 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_b, (&__pyx_v_buf), (&__pyx_v_size)); if (unlikely(__pyx_t_14 == ((int)-1))) __PYX_ERR(7, 170, __pyx_L1_error)

        /* "psycopg_c/_psycopg/copy.pyx":171
 *             else:
 *                 _buffer_as_string_and_size(b, &buf, &size)
 *                 target = <unsigned char *>CDumper.ensure_size(out, pos, size + with_tab)             # <<<<<<<<<<<<<<
 *                 memcpy(target + with_tab, buf, size)
 * 
*/
        __pyx_t_17 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, __pyx_v_pos, (__pyx_v_size + __pyx_v_with_tab)); if (unlikely(__pyx_t_17 == ((void *)NULL))) __PYX_ERR(7, 171, __pyx_L1_error)
        __pyx_v_target = ((unsigned char *)__pyx_t_17);

        /* "psycopg_c/_psycopg/copy.pyx":172
 *                 _buffer_as_string_and_size(b, &buf, &size)
 *                 target = <unsigned char *>CDumper.ensure_size(out, pos, size + with_tab)
 *                 memcpy(target + with_tab, buf, size)             # <<<<<<<<<<<<<<
 * 
 *         # Prepend a tab to the data just written
*/
        (void)(memcpy((__pyx_v_target + __pyx_v_with_tab), __pyx_v_buf, __pyx_v_size));
      }
    }
    __pyx_L11:;

    /* "psycopg_c/_psycopg/copy.pyx":175
 * 
 *         # Prepend a tab to the data just written
 *         if with_tab:             # <<<<<<<<<<<<<<
 *             target[0] = b"\t"
 *             target += 1
*/
    __pyx_t_2 = (__pyx_v_with_tab != 0);
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/copy.pyx":176
 *         # Prepend a tab to the data just written
 *         if with_tab:
 *             target[0] = b"\t"             # <<<<<<<<<<<<<<
 *             target += 1
 *             pos += 1
*/
      (__pyx_v_target[0]) = '\t';

      /* "psycopg_c/_psycopg/copy.pyx":177
 *         if with_tab:
 *             target[0] = b"\t"
 *             target += 1             # <<<<<<<<<<<<<<
 *             pos += 1
 * 
*/
      __pyx_v_target = (__pyx_v_target + 1);

      /* "psycopg_c/_psycopg/copy.pyx":178
 *             target[0] = b"\t"
 *             target += 1
 *             pos += 1             # <<<<<<<<<<<<<<
 * 
 *         # Now from pos to pos + size there is a textual representation: it may
*/
      __pyx_v_pos = (__pyx_v_pos + 1);

      /* "psycopg_c/_psycopg/copy.pyx":175
 * 
 *         # Prepend a tab to the data just written
 *         if with_tab:             # <<<<<<<<<<<<<<
 *             target[0] = b"\t"
 *             target += 1
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":182
 *         # Now from pos to pos + size there is a textual representation: it may
 *         # contain chars to escape. Scan to find how many such chars there are.
 *         nesc = 0             # <<<<<<<<<<<<<<
 *         for j in range(size):
 *             if copy_escape_lut[target[j]]:
*/
    __pyx_v_nesc = 0;

    /* "psycopg_c/_psycopg/copy.pyx":183
 *         # contain chars to escape. Scan to find how many such chars there are.
 *         nesc = 0
 *         for j in range(size):             # <<<<<<<<<<<<<<
 *             if copy_escape_lut[target[j]]:
 *                 nesc += 1
*/
    __pyx_t_16 = __pyx_v_size;
    __pyx_t_18 = __pyx_t_16;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_18; __pyx_t_14+=1) {
      __pyx_v_j = __pyx_t_14;

      /* "psycopg_c/_psycopg/copy.pyx":184
 *         nesc = 0
 *         for j in range(size):
 *             if copy_escape_lut[target[j]]:             # <<<<<<<<<<<<<<
 *                 nesc += 1
 * 
*/
      __pyx_t_2 = ((copy_escape_lut[(__pyx_v_target[__pyx_v_j])]) != 0);
      if (__pyx_t_2) {

        /* "psycopg_c/_psycopg/copy.pyx":185
 *         for j in range(size):
 *             if copy_escape_lut[target[j]]:
 *                 nesc += 1             # <<<<<<<<<<<<<<
 * 
 *         # If there is any char to escape, walk backwards pushing the chars
*/
        __pyx_v_nesc = (__pyx_v_nesc + 1);

        /* "psycopg_c/_psycopg/copy.pyx":184
 *         nesc = 0
 *         for j in range(size):
 *             if copy_escape_lut[target[j]]:             # <<<<<<<<<<<<<<
 *                 nesc += 1
 * 
*/
      }
    }

    /* "psycopg_c/_psycopg/copy.pyx":189
 *         # If there is any char to escape, walk backwards pushing the chars
 *         # forward and interspersing backslashes.
 *         if nesc > 0:             # <<<<<<<<<<<<<<
 *             tmpsize = size + nesc
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)
*/
    __pyx_t_2 = (__pyx_v_nesc > 0);
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/copy.pyx":190
 *         # forward and interspersing backslashes.
 *         if nesc > 0:
 *             tmpsize = size + nesc             # <<<<<<<<<<<<<<
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)
 *             for j in range(<int>size - 1, -1, -1):
*/
      __pyx_v_tmpsize = (__pyx_v_size + __pyx_v_nesc);

      /* "psycopg_c/_psycopg/copy.pyx":191
 *         if nesc > 0:
 *             tmpsize = size + nesc
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)             # <<<<<<<<<<<<<<
 *             for j in range(<int>size - 1, -1, -1):
 *                 if copy_escape_lut[target[j]]:
*/
      __pyx_t_17 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, __pyx_v_pos, __pyx_v_tmpsize); if (unlikely(__pyx_t_17 == ((void *)NULL))) __PYX_ERR(7, 191, __pyx_L1_error)
      __pyx_v_target = ((unsigned char *)__pyx_t_17);

      /* "psycopg_c/_psycopg/copy.pyx":192
 *             tmpsize = size + nesc
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)
 *             for j in range(<int>size - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if copy_escape_lut[target[j]]:
 *                     target[j + nesc] = copy_escape_lut[target[j]]
*/
      for (__pyx_t_14 = (((int)__pyx_v_size) - 1); __pyx_t_14 > -1; __pyx_t_14-=1) {
        __pyx_v_j = __pyx_t_14;

        /* "psycopg_c/_psycopg/copy.pyx":193
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)
 *             for j in range(<int>size - 1, -1, -1):
 *                 if copy_escape_lut[target[j]]:             # <<<<<<<<<<<<<<
 *                     target[j + nesc] = copy_escape_lut[target[j]]
 *                     nesc -= 1
*/
        __pyx_t_2 = ((copy_escape_lut[(__pyx_v_target[__pyx_v_j])]) != 0);
        if (__pyx_t_2) {

          /* "psycopg_c/_psycopg/copy.pyx":194
 *             for j in range(<int>size - 1, -1, -1):
 *                 if copy_escape_lut[target[j]]:
 *                     target[j + nesc] = copy_escape_lut[target[j]]             # <<<<<<<<<<<<<<
 *                     nesc -= 1
 *                     target[j + nesc] = b"\\"
*/
          (__pyx_v_target[(__pyx_v_j + __pyx_v_nesc)]) = (copy_escape_lut[(__pyx_v_target[__pyx_v_j])]);

          /* "psycopg_c/_psycopg/copy.pyx":195
 *                 if copy_escape_lut[target[j]]:
 *                     target[j + nesc] = copy_escape_lut[target[j]]
 *                     nesc -= 1             # <<<<<<<<<<<<<<
 *                     target[j + nesc] = b"\\"
 *                     if nesc <= 0:
*/
          __pyx_v_nesc = (__pyx_v_nesc - 1);

          /* "psycopg_c/_psycopg/copy.pyx":196
 *                     target[j + nesc] = copy_escape_lut[target[j]]
 *                     nesc -= 1
 *                     target[j + nesc] = b"\\"             # <<<<<<<<<<<<<<
 *                     if nesc <= 0:
 *                         break
*/
          (__pyx_v_target[(__pyx_v_j + __pyx_v_nesc)]) = '\\';

          /* "psycopg_c/_psycopg/copy.pyx":197
 *                     nesc -= 1
 *                     target[j + nesc] = b"\\"
 *                     if nesc <= 0:             # <<<<<<<<<<<<<<
 *                         break
 *                 else:
*/
          __pyx_t_2 = (__pyx_v_nesc <= 0);
          if (__pyx_t_2) {

            /* "psycopg_c/_psycopg/copy.pyx":198
 *                     target[j + nesc] = b"\\"
 *                     if nesc <= 0:
 *                         break             # <<<<<<<<<<<<<<
 *                 else:
 *                     target[j + nesc] = target[j]
*/
            goto __pyx_L19_break;

            /* "psycopg_c/_psycopg/copy.pyx":197
 *                     nesc -= 1
 *                     target[j + nesc] = b"\\"
 *                     if nesc <= 0:             # <<<<<<<<<<<<<<
 *                         break
 *                 else:
*/
          }

          /* "psycopg_c/_psycopg/copy.pyx":193
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)
 *             for j in range(<int>size - 1, -1, -1):
 *                 if copy_escape_lut[target[j]]:             # <<<<<<<<<<<<<<
 *                     target[j + nesc] = copy_escape_lut[target[j]]
 *                     nesc -= 1
*/
          goto __pyx_L20;
        }

        /* "psycopg_c/_psycopg/copy.pyx":200
 *                         break
 *                 else:
 *                     target[j + nesc] = target[j]             # <<<<<<<<<<<<<<
 *             pos += tmpsize
 *         else:
*/
        /*else*/ {
          (__pyx_v_target[(__pyx_v_j + __pyx_v_nesc)]) = (__pyx_v_target[__pyx_v_j]);
        }
        __pyx_L20:;
      }
      __pyx_L19_break:;

      /* "psycopg_c/_psycopg/copy.pyx":201
 *                 else:
 *                     target[j + nesc] = target[j]
 *             pos += tmpsize             # <<<<<<<<<<<<<<
 *         else:
 *             pos += size
*/
      __pyx_v_pos = (__pyx_v_pos + __pyx_v_tmpsize);

      /* "psycopg_c/_psycopg/copy.pyx":189
 *         # If there is any char to escape, walk backwards pushing the chars
 *         # forward and interspersing backslashes.
 *         if nesc > 0:             # <<<<<<<<<<<<<<
 *             tmpsize = size + nesc
 *             target = <unsigned char *>CDumper.ensure_size(out, pos, tmpsize)
*/
      goto __pyx_L17;
    }

    /* "psycopg_c/_psycopg/copy.pyx":203
 *             pos += tmpsize
 *         else:
 *             pos += size             # <<<<<<<<<<<<<<
 * 
 *     # Resize to the final size, add the newline
*/
    /*else*/ {
      __pyx_v_pos = (__pyx_v_pos + __pyx_v_size);
    }
    __pyx_L17:;
    __pyx_L7_continue:;
  }

  /* "psycopg_c/_psycopg/copy.pyx":206
 * 
 *     # Resize to the final size, add the newline
 *     PyByteArray_Resize(out, pos + 1)             # <<<<<<<<<<<<<<
 *     out[pos] = b"\n"
 * 
*/
  __pyx_t_3 = PyByteArray_Resize(__pyx_v_out, (__pyx_v_pos + 1)); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(7, 206, __pyx_L1_error)

  /* "psycopg_c/_psycopg/copy.pyx":207
 *     # Resize to the final size, add the newline
 *     PyByteArray_Resize(out, pos + 1)
 *     out[pos] = b"\n"             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (unlikely((__Pyx_SetItemInt_ByteArray(__pyx_v_out, __pyx_v_pos, '\n', Py_ssize_t, 1, PyLong_FromSsize_t, 0, 1, 1, 1, __Pyx_ReferenceSharing_FunctionArgument) < 0))) __PYX_ERR(7, 207, __pyx_L1_error)

  /* "psycopg_c/_psycopg/copy.pyx":115
 * 
 * 
 * cdef object _format_row_text(object row, Transformer tx, bytearray out):             # <<<<<<<<<<<<<<
 *     # offset in 'out' where to write
 *     cdef Py_ssize_t pos = PyByteArray_GET_SIZE(out)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("psycopg_c._psycopg._format_row_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_row_fast);
  __Pyx_XDECREF(__pyx_v_dumpers);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":210
 * 
 * 
 * def format_row_text(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_3format_row_text(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_3format_row_text = {"format_row_text", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_3format_row_text, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_3format_row_text(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_row = 0;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx = 0;
  PyObject *__pyx_v_out = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("format_row_text (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_row,&__pyx_mstate_global->__pyx_n_u_tx,&__pyx_mstate_global->__pyx_n_u_out,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(7, 210, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(7, 210, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 210, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 210, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "format_row_text", 0) < (0)) __PYX_ERR(7, 210, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("format_row_text", 1, 3, 3, i); __PYX_ERR(7, 210, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 210, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 210, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(7, 210, __pyx_L3_error)
    }
    __pyx_v_row = values[0];
    __pyx_v_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)values[1]);
    __pyx_v_out = ((PyObject*)values[2]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("format_row_text", 1, 3, 3, __pyx_nargs); __PYX_ERR(7, 210, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.format_row_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tx), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, 0, "tx", 0))) __PYX_ERR(7, 210, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_out), (&PyByteArray_Type), 0, "out", 2))) __PYX_ERR(7, 210, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_2format_row_text(__pyx_self, __pyx_v_row, __pyx_v_tx, __pyx_v_out);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_2format_row_text(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_row, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject *__pyx_v_out) {
  Py_ssize_t __pyx_v_size;
  PyObject *__pyx_v_e = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  char const *__pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("format_row_text", 0);

  /* "psycopg_c/_psycopg/copy.pyx":211
 * 
 * def format_row_text(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)             # <<<<<<<<<<<<<<
 * 
 *     try:
*/
  __pyx_v_size = PyByteArray_GET_SIZE(__pyx_v_out);

  /* "psycopg_c/_psycopg/copy.pyx":213
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         _format_row_text(row, tx, out)
 *     except Exception as e:
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "psycopg_c/_psycopg/copy.pyx":214
 * 
 *     try:
 *         _format_row_text(row, tx, out)             # <<<<<<<<<<<<<<
 *     except Exception as e:
 *         # Restore the input bytearray to the size it was before entering here
*/
      __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__format_row_text(__pyx_v_row, __pyx_v_tx, __pyx_v_out); if (unlikely(!__pyx_t_4)) __PYX_ERR(7, 214, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":213
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         _format_row_text(row, tx, out)
 *     except Exception as e:
*/
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "psycopg_c/_psycopg/copy.pyx":215
 *     try:
 *         _format_row_text(row, tx, out)
 *     except Exception as e:             # <<<<<<<<<<<<<<
 *         # Restore the input bytearray to the size it was before entering here
 *         # to avoid potentially passing junk to copy.
*/
    __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
    if (__pyx_t_5) {
      __Pyx_AddTraceback("psycopg_c._psycopg.format_row_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(7, 215, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __pyx_v_e = __pyx_t_6;
      /*try:*/ {

        /* "psycopg_c/_psycopg/copy.pyx":218
 *         # Restore the input bytearray to the size it was before entering here
 *         # to avoid potentially passing junk to copy.
 *         PyByteArray_Resize(out, size)             # <<<<<<<<<<<<<<
 *         raise e
 * 
*/
        __pyx_t_5 = PyByteArray_Resize(__pyx_v_out, __pyx_v_size); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(7, 218, __pyx_L14_error)

        /* "psycopg_c/_psycopg/copy.pyx":219
 *         # to avoid potentially passing junk to copy.
 *         PyByteArray_Resize(out, size)
 *         raise e             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __Pyx_Raise(__pyx_v_e, 0, 0, 0);
        __PYX_ERR(7, 219, __pyx_L14_error)
      }

      /* "psycopg_c/_psycopg/copy.pyx":215
 *     try:
 *         _format_row_text(row, tx, out)
 *     except Exception as e:             # <<<<<<<<<<<<<<
 *         # Restore the input bytearray to the size it was before entering here
 *         # to avoid potentially passing junk to copy.
*/
      /*finally:*/ {
        __pyx_L14_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
          if ( unlikely(__Pyx_GetException(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12) < 0)) __Pyx_ErrFetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_13);
          __Pyx_XGOTREF(__pyx_t_14);
          __Pyx_XGOTREF(__pyx_t_15);
          __pyx_t_5 = __pyx_lineno; __pyx_t_8 = __pyx_clineno; __pyx_t_9 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_e); __pyx_v_e = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_13);
          __Pyx_XGIVEREF(__pyx_t_14);
          __Pyx_XGIVEREF(__pyx_t_15);
          __Pyx_ExceptionReset(__pyx_t_13, __pyx_t_14, __pyx_t_15);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_ErrRestore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
          __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0; __pyx_t_13 = 0; __pyx_t_14 = 0; __pyx_t_15 = 0;
          __pyx_lineno = __pyx_t_5; __pyx_clineno = __pyx_t_8; __pyx_filename = __pyx_t_9;
          goto __pyx_L5_except_error;
        }
      }
    }
    goto __pyx_L5_except_error;

    /* "psycopg_c/_psycopg/copy.pyx":213
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         _format_row_text(row, tx, out)
 *     except Exception as e:
*/
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "psycopg_c/_psycopg/copy.pyx":210
 * 
 * 
 * def format_row_text(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("psycopg_c._psycopg.format_row_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_e);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":222
 * 
 * 
 * cdef int _append_text_none(bytearray out, Py_ssize_t *pos, int with_tab) except -1:             # <<<<<<<<<<<<<<
 *     cdef char *target
 * 
*/

static int __pyx_f_9psycopg_c_8_psycopg__append_text_none(PyObject *__pyx_v_out, Py_ssize_t *__pyx_v_pos, int __pyx_v_with_tab) {
  char *__pyx_v_target;
  int __pyx_r;
  int __pyx_t_1;
  char *__pyx_t_2;
  long __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "psycopg_c/_psycopg/copy.pyx":225
 *     cdef char *target
 * 
 *     if with_tab:             # <<<<<<<<<<<<<<
 *         target = CDumper.ensure_size(out, pos[0], 3)
 *         memcpy(target, b"\t\\N", 3)
*/
  __pyx_t_1 = (__pyx_v_with_tab != 0);
  if (__pyx_t_1) {

    /* "psycopg_c/_psycopg/copy.pyx":226
 * 
 *     if with_tab:
 *         target = CDumper.ensure_size(out, pos[0], 3)             # <<<<<<<<<<<<<<
 *         memcpy(target, b"\t\\N", 3)
 *         pos[0] += 3
*/
    __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, (__pyx_v_pos[0]), 3); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(7, 226, __pyx_L1_error)
    __pyx_v_target = __pyx_t_2;

    /* "psycopg_c/_psycopg/copy.pyx":227
 *     if with_tab:
 *         target = CDumper.ensure_size(out, pos[0], 3)
 *         memcpy(target, b"\t\\N", 3)             # <<<<<<<<<<<<<<
 *         pos[0] += 3
 *     else:
*/
    (void)(memcpy(__pyx_v_target, __pyx_k_N, 3));

    /* "psycopg_c/_psycopg/copy.pyx":228
 *         target = CDumper.ensure_size(out, pos[0], 3)
 *         memcpy(target, b"\t\\N", 3)
 *         pos[0] += 3             # <<<<<<<<<<<<<<
 *     else:
 *         target = CDumper.ensure_size(out, pos[0], 2)
*/
    __pyx_t_3 = 0;
    (__pyx_v_pos[__pyx_t_3]) = ((__pyx_v_pos[__pyx_t_3]) + 3);

    /* "psycopg_c/_psycopg/copy.pyx":225
 *     cdef char *target
 * 
 *     if with_tab:             # <<<<<<<<<<<<<<
 *         target = CDumper.ensure_size(out, pos[0], 3)
 *         memcpy(target, b"\t\\N", 3)
*/
    goto __pyx_L3;
  }

  /* "psycopg_c/_psycopg/copy.pyx":230
 *         pos[0] += 3
 *     else:
 *         target = CDumper.ensure_size(out, pos[0], 2)             # <<<<<<<<<<<<<<
 *         memcpy(target, b"\\N", 2)
 *         pos[0] += 2
*/
  /*else*/ {
    __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_out, (__pyx_v_pos[0]), 2); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(7, 230, __pyx_L1_error)
    __pyx_v_target = __pyx_t_2;

    /* "psycopg_c/_psycopg/copy.pyx":231
 *     else:
 *         target = CDumper.ensure_size(out, pos[0], 2)
 *         memcpy(target, b"\\N", 2)             # <<<<<<<<<<<<<<
 *         pos[0] += 2
 * 
*/
    (void)(memcpy(__pyx_v_target, __pyx_k_N_2, 2));

    /* "psycopg_c/_psycopg/copy.pyx":232
 *         target = CDumper.ensure_size(out, pos[0], 2)
 *         memcpy(target, b"\\N", 2)
 *         pos[0] += 2             # <<<<<<<<<<<<<<
 * 
 *     return 0
*/
    __pyx_t_3 = 0;
    (__pyx_v_pos[__pyx_t_3]) = ((__pyx_v_pos[__pyx_t_3]) + 2);
  }
  __pyx_L3:;

  /* "psycopg_c/_psycopg/copy.pyx":234
 *         pos[0] += 2
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/copy.pyx":222
 * 
 * 
 * cdef int _append_text_none(bytearray out, Py_ssize_t *pos, int with_tab) except -1:             # <<<<<<<<<<<<<<
 *     cdef char *target
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg._append_text_none", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":237
 * 
 * 
 * def parse_row_binary(data, tx: Transformer) -> tuple[Any, ...]:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *ptr
 *     cdef Py_ssize_t bufsize
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_5parse_row_binary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_5parse_row_binary = {"parse_row_binary", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_5parse_row_binary, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_5parse_row_binary(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse_row_binary (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_data,&__pyx_mstate_global->__pyx_n_u_tx,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(7, 237, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 237, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 237, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_row_binary", 0) < (0)) __PYX_ERR(7, 237, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_row_binary", 1, 2, 2, i); __PYX_ERR(7, 237, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 237, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 237, __pyx_L3_error)
    }
    __pyx_v_data = values[0];
    __pyx_v_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse_row_binary", 1, 2, 2, __pyx_nargs); __PYX_ERR(7, 237, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.parse_row_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tx), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, 0, "tx", 0))) __PYX_ERR(7, 237, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_4parse_row_binary(__pyx_self, __pyx_v_data, __pyx_v_tx);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_4parse_row_binary(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx) {
  unsigned char *__pyx_v_ptr;
  Py_ssize_t __pyx_v_bufsize;
  unsigned char *__pyx_v_bufend;
  uint16_t __pyx_v_benfields;
  int __pyx_v_nfields;
  PyObject *__pyx_v_row = 0;
  int __pyx_v_col;
  int32_t __pyx_v_belength;
  Py_ssize_t __pyx_v_length;
  PyObject *__pyx_v_field = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse_row_binary", 0);

  /* "psycopg_c/_psycopg/copy.pyx":240
 *     cdef unsigned char *ptr
 *     cdef Py_ssize_t bufsize
 *     _buffer_as_string_and_size(data, <char **>&ptr, &bufsize)             # <<<<<<<<<<<<<<
 *     cdef unsigned char *bufend = ptr + bufsize
 * 
*/
  __pyx_t_1 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_data, ((char **)(&__pyx_v_ptr)), (&__pyx_v_bufsize)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(7, 240, __pyx_L1_error)

  /* "psycopg_c/_psycopg/copy.pyx":241
 *     cdef Py_ssize_t bufsize
 *     _buffer_as_string_and_size(data, <char **>&ptr, &bufsize)
 *     cdef unsigned char *bufend = ptr + bufsize             # <<<<<<<<<<<<<<
 * 
 *     cdef uint16_t benfields
*/
  __pyx_v_bufend = (__pyx_v_ptr + __pyx_v_bufsize);

  /* "psycopg_c/_psycopg/copy.pyx":244
 * 
 *     cdef uint16_t benfields
 *     memcpy(&benfields, ptr, sizeof(benfields))             # <<<<<<<<<<<<<<
 *     cdef int nfields = endian.be16toh(benfields)
 *     ptr += sizeof(benfields)
*/
  (void)(memcpy((&__pyx_v_benfields), __pyx_v_ptr, (sizeof(__pyx_v_benfields))));

  /* "psycopg_c/_psycopg/copy.pyx":245
 *     cdef uint16_t benfields
 *     memcpy(&benfields, ptr, sizeof(benfields))
 *     cdef int nfields = endian.be16toh(benfields)             # <<<<<<<<<<<<<<
 *     ptr += sizeof(benfields)
 *     cdef list row = PyList_New(nfields)
*/
  __pyx_v_nfields = be16toh(__pyx_v_benfields);

  /* "psycopg_c/_psycopg/copy.pyx":246
 *     memcpy(&benfields, ptr, sizeof(benfields))
 *     cdef int nfields = endian.be16toh(benfields)
 *     ptr += sizeof(benfields)             # <<<<<<<<<<<<<<
 *     cdef list row = PyList_New(nfields)
 * 
*/
  __pyx_v_ptr = (__pyx_v_ptr + (sizeof(__pyx_v_benfields)));

  /* "psycopg_c/_psycopg/copy.pyx":247
 *     cdef int nfields = endian.be16toh(benfields)
 *     ptr += sizeof(benfields)
 *     cdef list row = PyList_New(nfields)             # <<<<<<<<<<<<<<
 * 
 *     cdef int col
*/
  __pyx_t_2 = PyList_New(__pyx_v_nfields); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_row = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":253
 *     cdef Py_ssize_t length
 * 
 *     for col in range(nfields):             # <<<<<<<<<<<<<<
 *         memcpy(&belength, ptr, sizeof(belength))
 *         ptr += sizeof(belength)
*/
  __pyx_t_1 = __pyx_v_nfields;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_col = __pyx_t_4;

    /* "psycopg_c/_psycopg/copy.pyx":254
 * 
 *     for col in range(nfields):
 *         memcpy(&belength, ptr, sizeof(belength))             # <<<<<<<<<<<<<<
 *         ptr += sizeof(belength)
 *         if belength == _binary_null:
*/
    (void)(memcpy((&__pyx_v_belength), __pyx_v_ptr, (sizeof(__pyx_v_belength))));

    /* "psycopg_c/_psycopg/copy.pyx":255
 *     for col in range(nfields):
 *         memcpy(&belength, ptr, sizeof(belength))
 *         ptr += sizeof(belength)             # <<<<<<<<<<<<<<
 *         if belength == _binary_null:
 *             field = None
*/
    __pyx_v_ptr = (__pyx_v_ptr + (sizeof(__pyx_v_belength)));

    /* "psycopg_c/_psycopg/copy.pyx":256
 *         memcpy(&belength, ptr, sizeof(belength))
 *         ptr += sizeof(belength)
 *         if belength == _binary_null:             # <<<<<<<<<<<<<<
 *             field = None
 *         else:
*/
    __pyx_t_5 = (__pyx_v_belength == __pyx_v_9psycopg_c_8_psycopg__binary_null);
    if (__pyx_t_5) {

      /* "psycopg_c/_psycopg/copy.pyx":257
 *         ptr += sizeof(belength)
 *         if belength == _binary_null:
 *             field = None             # <<<<<<<<<<<<<<
 *         else:
 *             length = endian.be32toh(belength)
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_field, ((PyObject*)Py_None));

      /* "psycopg_c/_psycopg/copy.pyx":256
 *         memcpy(&belength, ptr, sizeof(belength))
 *         ptr += sizeof(belength)
 *         if belength == _binary_null:             # <<<<<<<<<<<<<<
 *             field = None
 *         else:
*/
      goto __pyx_L5;
    }

    /* "psycopg_c/_psycopg/copy.pyx":259
 *             field = None
 *         else:
 *             length = endian.be32toh(belength)             # <<<<<<<<<<<<<<
 *             if ptr + length > bufend:
 *                 raise e.DataError("bad copy data: length exceeding data")
*/
    /*else*/ {
      __pyx_v_length = be32toh(__pyx_v_belength);

      /* "psycopg_c/_psycopg/copy.pyx":260
 *         else:
 *             length = endian.be32toh(belength)
 *             if ptr + length > bufend:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("bad copy data: length exceeding data")
 *             field = PyMemoryView_FromObject(
*/
      __pyx_t_5 = ((__pyx_v_ptr + __pyx_v_length) > __pyx_v_bufend);
      if (unlikely(__pyx_t_5)) {

        /* "psycopg_c/_psycopg/copy.pyx":261
 *             length = endian.be32toh(belength)
 *             if ptr + length > bufend:
 *                 raise e.DataError("bad copy data: length exceeding data")             # <<<<<<<<<<<<<<
 *             field = PyMemoryView_FromObject(
 *                 ViewBuffer._from_buffer(data, ptr, length))
*/
        __pyx_t_6 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 261, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 261, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_9 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_8))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_8);
          assert(__pyx_t_6);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
          __pyx_t_9 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_bad_copy_data_length_exceeding_d};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 261, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(7, 261, __pyx_L1_error)

        /* "psycopg_c/_psycopg/copy.pyx":260
 *         else:
 *             length = endian.be32toh(belength)
 *             if ptr + length > bufend:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("bad copy data: length exceeding data")
 *             field = PyMemoryView_FromObject(
*/
      }

      /* "psycopg_c/_psycopg/copy.pyx":263
 *                 raise e.DataError("bad copy data: length exceeding data")
 *             field = PyMemoryView_FromObject(
 *                 ViewBuffer._from_buffer(data, ptr, length))             # <<<<<<<<<<<<<<
 *             ptr += length
 * 
*/
      __pyx_t_2 = ((PyObject *)__pyx_vtabptr_9psycopg_c_2pq_ViewBuffer->_from_buffer(__pyx_v_data, __pyx_v_ptr, __pyx_v_length)); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 263, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "psycopg_c/_psycopg/copy.pyx":262
 *             if ptr + length > bufend:
 *                 raise e.DataError("bad copy data: length exceeding data")
 *             field = PyMemoryView_FromObject(             # <<<<<<<<<<<<<<
 *                 ViewBuffer._from_buffer(data, ptr, length))
 *             ptr += length
*/
      __pyx_t_8 = PyMemoryView_FromObject(__pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 262, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_field, ((PyObject*)__pyx_t_8));
      __pyx_t_8 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":264
 *             field = PyMemoryView_FromObject(
 *                 ViewBuffer._from_buffer(data, ptr, length))
 *             ptr += length             # <<<<<<<<<<<<<<
 * 
 *         Py_INCREF(field)
*/
      __pyx_v_ptr = (__pyx_v_ptr + __pyx_v_length);
    }
    __pyx_L5:;

    /* "psycopg_c/_psycopg/copy.pyx":266
 *             ptr += length
 * 
 *         Py_INCREF(field)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(row, col, field)
 * 
*/
    Py_INCREF(__pyx_v_field);

    /* "psycopg_c/_psycopg/copy.pyx":267
 * 
 *         Py_INCREF(field)
 *         PyList_SET_ITEM(row, col, field)             # <<<<<<<<<<<<<<
 * 
 *     return tx.load_sequence(row)
*/
    PyList_SET_ITEM(__pyx_v_row, __pyx_v_col, __pyx_v_field);
  }

  /* "psycopg_c/_psycopg/copy.pyx":269
 *         PyList_SET_ITEM(row, col, field)
 * 
 *     return tx.load_sequence(row)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_8 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_tx->__pyx_vtab)->load_sequence(__pyx_v_tx, __pyx_v_row, 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 269, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  if (!(likely(PyTuple_CheckExact(__pyx_t_8))||((__pyx_t_8) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_8))) __PYX_ERR(7, 269, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/copy.pyx":237
 * 
 * 
 * def parse_row_binary(data, tx: Transformer) -> tuple[Any, ...]:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *ptr
 *     cdef Py_ssize_t bufsize
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("psycopg_c._psycopg.parse_row_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_row);
  __Pyx_XDECREF(__pyx_v_field);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/copy.pyx":272
 * 
 * 
 * def parse_row_text(data, tx: Transformer) -> tuple[Any, ...]:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *fstart
 *     cdef Py_ssize_t size
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7parse_row_text(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_7parse_row_text = {"parse_row_text", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_7parse_row_text, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_7parse_row_text(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_data = 0;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("parse_row_text (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_data,&__pyx_mstate_global->__pyx_n_u_tx,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(7, 272, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 272, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 272, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "parse_row_text", 0) < (0)) __PYX_ERR(7, 272, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("parse_row_text", 1, 2, 2, i); __PYX_ERR(7, 272, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(7, 272, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(7, 272, __pyx_L3_error)
    }
    __pyx_v_data = values[0];
    __pyx_v_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("parse_row_text", 1, 2, 2, __pyx_nargs); __PYX_ERR(7, 272, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.parse_row_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_tx), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, 0, "tx", 0))) __PYX_ERR(7, 272, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_6parse_row_text(__pyx_self, __pyx_v_data, __pyx_v_tx);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_6parse_row_text(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_data, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx) {
  unsigned char *__pyx_v_fstart;
  Py_ssize_t __pyx_v_size;
  int __pyx_v_nfields;
  PyObject *__pyx_v_row = 0;
  unsigned char *__pyx_v_fend;
  unsigned char *__pyx_v_rowend;
  unsigned char *__pyx_v_src;
  unsigned char *__pyx_v_tgt;
  int __pyx_v_col;
  int __pyx_v_num_bs;
  PyObject *__pyx_v_field = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  size_t __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("parse_row_text", 0);

  /* "psycopg_c/_psycopg/copy.pyx":275
 *     cdef unsigned char *fstart
 *     cdef Py_ssize_t size
 *     _buffer_as_string_and_size(data, <char **>&fstart, &size)             # <<<<<<<<<<<<<<
 * 
 *     # politely assume that the number of fields will be what in the result
*/
  __pyx_t_1 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_data, ((char **)(&__pyx_v_fstart)), (&__pyx_v_size)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(7, 275, __pyx_L1_error)

  /* "psycopg_c/_psycopg/copy.pyx":278
 * 
 *     # politely assume that the number of fields will be what in the result
 *     cdef int nfields = tx._nfields             # <<<<<<<<<<<<<<
 *     cdef list row = PyList_New(nfields)
 * 
*/
  __pyx_t_1 = __pyx_v_tx->_nfields;
  __pyx_v_nfields = __pyx_t_1;

  /* "psycopg_c/_psycopg/copy.pyx":279
 *     # politely assume that the number of fields will be what in the result
 *     cdef int nfields = tx._nfields
 *     cdef list row = PyList_New(nfields)             # <<<<<<<<<<<<<<
 * 
 *     cdef unsigned char *fend
*/
  __pyx_t_2 = PyList_New(__pyx_v_nfields); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_row = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":282
 * 
 *     cdef unsigned char *fend
 *     cdef unsigned char *rowend = fstart + size             # <<<<<<<<<<<<<<
 *     cdef unsigned char *src
 *     cdef unsigned char *tgt
*/
  __pyx_v_rowend = (__pyx_v_fstart + __pyx_v_size);

  /* "psycopg_c/_psycopg/copy.pyx":288
 *     cdef int num_bs
 * 
 *     for col in range(nfields):             # <<<<<<<<<<<<<<
 *         fend = fstart
 *         num_bs = 0
*/
  __pyx_t_1 = __pyx_v_nfields;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_col = __pyx_t_4;

    /* "psycopg_c/_psycopg/copy.pyx":289
 * 
 *     for col in range(nfields):
 *         fend = fstart             # <<<<<<<<<<<<<<
 *         num_bs = 0
 *         # Scan to the end of the field, remember if you see any backslash
*/
    __pyx_v_fend = __pyx_v_fstart;

    /* "psycopg_c/_psycopg/copy.pyx":290
 *     for col in range(nfields):
 *         fend = fstart
 *         num_bs = 0             # <<<<<<<<<<<<<<
 *         # Scan to the end of the field, remember if you see any backslash
 *         while fend[0] != b'\t' and fend[0] != b'\n' and fend < rowend:
*/
    __pyx_v_num_bs = 0;

    /* "psycopg_c/_psycopg/copy.pyx":292
 *         num_bs = 0
 *         # Scan to the end of the field, remember if you see any backslash
 *         while fend[0] != b'\t' and fend[0] != b'\n' and fend < rowend:             # <<<<<<<<<<<<<<
 *             if fend[0] == b'\\':
 *                 num_bs += 1
*/
    while (1) {
      __pyx_t_6 = ((__pyx_v_fend[0]) != '\t');
      if (__pyx_t_6) {
      } else {
        __pyx_t_5 = __pyx_t_6;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_6 = ((__pyx_v_fend[0]) != '\n');
      if (__pyx_t_6) {
      } else {
        __pyx_t_5 = __pyx_t_6;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_6 = (__pyx_v_fend < __pyx_v_rowend);
      __pyx_t_5 = __pyx_t_6;
      __pyx_L7_bool_binop_done:;
      if (!__pyx_t_5) break;

      /* "psycopg_c/_psycopg/copy.pyx":293
 *         # Scan to the end of the field, remember if you see any backslash
 *         while fend[0] != b'\t' and fend[0] != b'\n' and fend < rowend:
 *             if fend[0] == b'\\':             # <<<<<<<<<<<<<<
 *                 num_bs += 1
 *                 # skip the next char to avoid counting escaped backslashes twice
*/
      __pyx_t_5 = ((__pyx_v_fend[0]) == '\\');
      if (__pyx_t_5) {

        /* "psycopg_c/_psycopg/copy.pyx":294
 *         while fend[0] != b'\t' and fend[0] != b'\n' and fend < rowend:
 *             if fend[0] == b'\\':
 *                 num_bs += 1             # <<<<<<<<<<<<<<
 *                 # skip the next char to avoid counting escaped backslashes twice
 *                 fend += 1
*/
        __pyx_v_num_bs = (__pyx_v_num_bs + 1);

        /* "psycopg_c/_psycopg/copy.pyx":296
 *                 num_bs += 1
 *                 # skip the next char to avoid counting escaped backslashes twice
 *                 fend += 1             # <<<<<<<<<<<<<<
 *             fend += 1
 * 
*/
        __pyx_v_fend = (__pyx_v_fend + 1);

        /* "psycopg_c/_psycopg/copy.pyx":293
 *         # Scan to the end of the field, remember if you see any backslash
 *         while fend[0] != b'\t' and fend[0] != b'\n' and fend < rowend:
 *             if fend[0] == b'\\':             # <<<<<<<<<<<<<<
 *                 num_bs += 1
 *                 # skip the next char to avoid counting escaped backslashes twice
*/
      }

      /* "psycopg_c/_psycopg/copy.pyx":297
 *                 # skip the next char to avoid counting escaped backslashes twice
 *                 fend += 1
 *             fend += 1             # <<<<<<<<<<<<<<
 * 
 *         # Check if we stopped for the right reason
*/
      __pyx_v_fend = (__pyx_v_fend + 1);
    }

    /* "psycopg_c/_psycopg/copy.pyx":300
 * 
 *         # Check if we stopped for the right reason
 *         if fend >= rowend:             # <<<<<<<<<<<<<<
 *             raise e.DataError("bad copy data: field delimiter not found")
 *         elif fend[0] == b'\t' and col == nfields - 1:
*/
    __pyx_t_5 = (__pyx_v_fend >= __pyx_v_rowend);
    if (unlikely(__pyx_t_5)) {

      /* "psycopg_c/_psycopg/copy.pyx":301
 *         # Check if we stopped for the right reason
 *         if fend >= rowend:
 *             raise e.DataError("bad copy data: field delimiter not found")             # <<<<<<<<<<<<<<
 *         elif fend[0] == b'\t' and col == nfields - 1:
 *             raise e.DataError("bad copy data: got a tab at the end of the row")
*/
      __pyx_t_7 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 301, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_9);
        assert(__pyx_t_7);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_bad_copy_data_field_delimiter_no};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 301, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(7, 301, __pyx_L1_error)

      /* "psycopg_c/_psycopg/copy.pyx":300
 * 
 *         # Check if we stopped for the right reason
 *         if fend >= rowend:             # <<<<<<<<<<<<<<
 *             raise e.DataError("bad copy data: field delimiter not found")
 *         elif fend[0] == b'\t' and col == nfields - 1:
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":302
 *         if fend >= rowend:
 *             raise e.DataError("bad copy data: field delimiter not found")
 *         elif fend[0] == b'\t' and col == nfields - 1:             # <<<<<<<<<<<<<<
 *             raise e.DataError("bad copy data: got a tab at the end of the row")
 *         elif fend[0] == b'\n' and col != nfields - 1:
*/
    __pyx_t_6 = ((__pyx_v_fend[0]) == '\t');
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_col == (__pyx_v_nfields - 1));
    __pyx_t_5 = __pyx_t_6;
    __pyx_L12_bool_binop_done:;
    if (unlikely(__pyx_t_5)) {

      /* "psycopg_c/_psycopg/copy.pyx":303
 *             raise e.DataError("bad copy data: field delimiter not found")
 *         elif fend[0] == b'\t' and col == nfields - 1:
 *             raise e.DataError("bad copy data: got a tab at the end of the row")             # <<<<<<<<<<<<<<
 *         elif fend[0] == b'\n' and col != nfields - 1:
 *             raise e.DataError(
*/
      __pyx_t_9 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_8)) __PYX_ERR(7, 303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_9);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_mstate_global->__pyx_kp_u_bad_copy_data_got_a_tab_at_the_e};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 303, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(7, 303, __pyx_L1_error)

      /* "psycopg_c/_psycopg/copy.pyx":302
 *         if fend >= rowend:
 *             raise e.DataError("bad copy data: field delimiter not found")
 *         elif fend[0] == b'\t' and col == nfields - 1:             # <<<<<<<<<<<<<<
 *             raise e.DataError("bad copy data: got a tab at the end of the row")
 *         elif fend[0] == b'\n' and col != nfields - 1:
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":304
 *         elif fend[0] == b'\t' and col == nfields - 1:
 *             raise e.DataError("bad copy data: got a tab at the end of the row")
 *         elif fend[0] == b'\n' and col != nfields - 1:             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 "bad copy format: got a newline before the end of the row")
*/
    __pyx_t_6 = ((__pyx_v_fend[0]) == '\n');
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L14_bool_binop_done;
    }
    __pyx_t_6 = (__pyx_v_col != (__pyx_v_nfields - 1));
    __pyx_t_5 = __pyx_t_6;
    __pyx_L14_bool_binop_done:;
    if (unlikely(__pyx_t_5)) {

      /* "psycopg_c/_psycopg/copy.pyx":305
 *             raise e.DataError("bad copy data: got a tab at the end of the row")
 *         elif fend[0] == b'\n' and col != nfields - 1:
 *             raise e.DataError(             # <<<<<<<<<<<<<<
 *                 "bad copy format: got a newline before the end of the row")
 * 
*/
      __pyx_t_8 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_9)) __PYX_ERR(7, 305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 305, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_10 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_10 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_mstate_global->__pyx_kp_u_bad_copy_format_got_a_newline_be};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 305, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(7, 305, __pyx_L1_error)

      /* "psycopg_c/_psycopg/copy.pyx":304
 *         elif fend[0] == b'\t' and col == nfields - 1:
 *             raise e.DataError("bad copy data: got a tab at the end of the row")
 *         elif fend[0] == b'\n' and col != nfields - 1:             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 "bad copy format: got a newline before the end of the row")
*/
    }

    /* "psycopg_c/_psycopg/copy.pyx":309
 * 
 *         # Is this a NULL?
 *         if fend - fstart == 2 and fstart[0] == b'\\' and fstart[1] == b'N':             # <<<<<<<<<<<<<<
 *             field = None
 * 
*/
    __pyx_t_6 = ((__pyx_v_fend - __pyx_v_fstart) == 2);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_6 = ((__pyx_v_fstart[0]) == '\\');
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L17_bool_binop_done;
    }
    __pyx_t_6 = ((__pyx_v_fstart[1]) == 'N');
    __pyx_t_5 = __pyx_t_6;
    __pyx_L17_bool_binop_done:;
    if (__pyx_t_5) {

      /* "psycopg_c/_psycopg/copy.pyx":310
 *         # Is this a NULL?
 *         if fend - fstart == 2 and fstart[0] == b'\\' and fstart[1] == b'N':
 *             field = None             # <<<<<<<<<<<<<<
 * 
 *         # Is this a field with no backslash?
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_field, Py_None);

      /* "psycopg_c/_psycopg/copy.pyx":309
 * 
 *         # Is this a NULL?
 *         if fend - fstart == 2 and fstart[0] == b'\\' and fstart[1] == b'N':             # <<<<<<<<<<<<<<
 *             field = None
 * 
*/
      goto __pyx_L16;
    }

    /* "psycopg_c/_psycopg/copy.pyx":313
 * 
 *         # Is this a field with no backslash?
 *         elif num_bs == 0:             # <<<<<<<<<<<<<<
 *             # Nothing to unescape: we don't need a copy
 *             field = PyMemoryView_FromObject(
*/
    __pyx_t_5 = (__pyx_v_num_bs == 0);
    if (__pyx_t_5) {

      /* "psycopg_c/_psycopg/copy.pyx":316
 *             # Nothing to unescape: we don't need a copy
 *             field = PyMemoryView_FromObject(
 *                 ViewBuffer._from_buffer(data, fstart, fend - fstart))             # <<<<<<<<<<<<<<
 * 
 *         # This is a field containing backslashes
*/
      __pyx_t_2 = ((PyObject *)__pyx_vtabptr_9psycopg_c_2pq_ViewBuffer->_from_buffer(__pyx_v_data, __pyx_v_fstart, (__pyx_v_fend - __pyx_v_fstart))); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 316, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);

      /* "psycopg_c/_psycopg/copy.pyx":315
 *         elif num_bs == 0:
 *             # Nothing to unescape: we don't need a copy
 *             field = PyMemoryView_FromObject(             # <<<<<<<<<<<<<<
 *                 ViewBuffer._from_buffer(data, fstart, fend - fstart))
 * 
*/
      __pyx_t_7 = PyMemoryView_FromObject(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 315, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF_SET(__pyx_v_field, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":313
 * 
 *         # Is this a field with no backslash?
 *         elif num_bs == 0:             # <<<<<<<<<<<<<<
 *             # Nothing to unescape: we don't need a copy
 *             field = PyMemoryView_FromObject(
*/
      goto __pyx_L16;
    }

    /* "psycopg_c/_psycopg/copy.pyx":321
 *         else:
 *             # We need a copy of the buffer to unescape
 *             field = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 *             PyByteArray_Resize(field, fend - fstart - num_bs)
 *             tgt = <unsigned char *>PyByteArray_AS_STRING(field)
*/
    /*else*/ {
      __pyx_t_7 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 321, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __Pyx_XDECREF_SET(__pyx_v_field, __pyx_t_7);
      __pyx_t_7 = 0;

      /* "psycopg_c/_psycopg/copy.pyx":322
 *             # We need a copy of the buffer to unescape
 *             field = PyByteArray_FromStringAndSize("", 0)
 *             PyByteArray_Resize(field, fend - fstart - num_bs)             # <<<<<<<<<<<<<<
 *             tgt = <unsigned char *>PyByteArray_AS_STRING(field)
 *             src = fstart
*/
      __pyx_t_11 = PyByteArray_Resize(__pyx_v_field, ((__pyx_v_fend - __pyx_v_fstart) - __pyx_v_num_bs)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(7, 322, __pyx_L1_error)

      /* "psycopg_c/_psycopg/copy.pyx":323
 *             field = PyByteArray_FromStringAndSize("", 0)
 *             PyByteArray_Resize(field, fend - fstart - num_bs)
 *             tgt = <unsigned char *>PyByteArray_AS_STRING(field)             # <<<<<<<<<<<<<<
 *             src = fstart
 *             while (src < fend):
*/
      __pyx_v_tgt = ((unsigned char *)PyByteArray_AS_STRING(__pyx_v_field));

      /* "psycopg_c/_psycopg/copy.pyx":324
 *             PyByteArray_Resize(field, fend - fstart - num_bs)
 *             tgt = <unsigned char *>PyByteArray_AS_STRING(field)
 *             src = fstart             # <<<<<<<<<<<<<<
 *             while (src < fend):
 *                 if src[0] != b'\\':
*/
      __pyx_v_src = __pyx_v_fstart;

      /* "psycopg_c/_psycopg/copy.pyx":325
 *             tgt = <unsigned char *>PyByteArray_AS_STRING(field)
 *             src = fstart
 *             while (src < fend):             # <<<<<<<<<<<<<<
 *                 if src[0] != b'\\':
 *                     tgt[0] = src[0]
*/
      while (1) {
        __pyx_t_5 = (__pyx_v_src < __pyx_v_fend);
        if (!__pyx_t_5) break;

        /* "psycopg_c/_psycopg/copy.pyx":326
 *             src = fstart
 *             while (src < fend):
 *                 if src[0] != b'\\':             # <<<<<<<<<<<<<<
 *                     tgt[0] = src[0]
 *                 else:
*/
        __pyx_t_5 = ((__pyx_v_src[0]) != '\\');
        if (__pyx_t_5) {

          /* "psycopg_c/_psycopg/copy.pyx":327
 *             while (src < fend):
 *                 if src[0] != b'\\':
 *                     tgt[0] = src[0]             # <<<<<<<<<<<<<<
 *                 else:
 *                     src += 1
*/
          (__pyx_v_tgt[0]) = (__pyx_v_src[0]);

          /* "psycopg_c/_psycopg/copy.pyx":326
 *             src = fstart
 *             while (src < fend):
 *                 if src[0] != b'\\':             # <<<<<<<<<<<<<<
 *                     tgt[0] = src[0]
 *                 else:
*/
          goto __pyx_L22;
        }

        /* "psycopg_c/_psycopg/copy.pyx":329
 *                     tgt[0] = src[0]
 *                 else:
 *                     src += 1             # <<<<<<<<<<<<<<
 *                     tgt[0] = copy_unescape_lut[src[0]]
 *                 src += 1
*/
        /*else*/ {
          __pyx_v_src = (__pyx_v_src + 1);

          /* "psycopg_c/_psycopg/copy.pyx":330
 *                 else:
 *                     src += 1
 *                     tgt[0] = copy_unescape_lut[src[0]]             # <<<<<<<<<<<<<<
 *                 src += 1
 *                 tgt += 1
*/
          (__pyx_v_tgt[0]) = (copy_unescape_lut[(__pyx_v_src[0])]);
        }
        __pyx_L22:;

        /* "psycopg_c/_psycopg/copy.pyx":331
 *                     src += 1
 *                     tgt[0] = copy_unescape_lut[src[0]]
 *                 src += 1             # <<<<<<<<<<<<<<
 *                 tgt += 1
 * 
*/
        __pyx_v_src = (__pyx_v_src + 1);

        /* "psycopg_c/_psycopg/copy.pyx":332
 *                     tgt[0] = copy_unescape_lut[src[0]]
 *                 src += 1
 *                 tgt += 1             # <<<<<<<<<<<<<<
 * 
 *         Py_INCREF(field)
*/
        __pyx_v_tgt = (__pyx_v_tgt + 1);
      }
    }
    __pyx_L16:;

    /* "psycopg_c/_psycopg/copy.pyx":334
 *                 tgt += 1
 * 
 *         Py_INCREF(field)             # <<<<<<<<<<<<<<
 *         PyList_SET_ITEM(row, col, field)
 * 
*/
    Py_INCREF(__pyx_v_field);

    /* "psycopg_c/_psycopg/copy.pyx":335
 * 
 *         Py_INCREF(field)
 *         PyList_SET_ITEM(row, col, field)             # <<<<<<<<<<<<<<
 * 
 *         # Start of the field
*/
    PyList_SET_ITEM(__pyx_v_row, __pyx_v_col, __pyx_v_field);

    /* "psycopg_c/_psycopg/copy.pyx":338
 * 
 *         # Start of the field
 *         fstart = fend + 1             # <<<<<<<<<<<<<<
 * 
 *     # Convert the array of buffers into Python objects
*/
    __pyx_v_fstart = (__pyx_v_fend + 1);
  }

  /* "psycopg_c/_psycopg/copy.pyx":341
 * 
 *     # Convert the array of buffers into Python objects
 *     return tx.load_sequence(row)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_tx->__pyx_vtab)->load_sequence(__pyx_v_tx, __pyx_v_row, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(7, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!(likely(PyTuple_CheckExact(__pyx_t_7))||((__pyx_t_7) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_7))) __PYX_ERR(7, 341, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/copy.pyx":272
 * 
 * 
 * def parse_row_text(data, tx: Transformer) -> tuple[Any, ...]:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *fstart
 *     cdef Py_ssize_t size
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_AddTraceback("psycopg_c._psycopg.parse_row_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_row);
  __Pyx_XDECREF(__pyx_v_field);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_10generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":32
 * 
 * 
 * def connect(conninfo: str, *, timeout: float = 0.0) -> PQGenConn[abc.PGconn]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to create a database connection without blocking.
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9connect(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_8connect, "\n    Generator to create a database connection without blocking.\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9connect = {"connect", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_9connect, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9psycopg_c_8_psycopg_8connect};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9connect(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_conninfo = 0;
  double __pyx_v_timeout;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_conninfo,&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(8, 32, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(8, 32, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "connect", 0) < (0)) __PYX_ERR(8, 32, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("connect", 1, 1, 1, i); __PYX_ERR(8, 32, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(8, 32, __pyx_L3_error)
    }
    __pyx_v_conninfo = ((PyObject*)values[0]);
    if (values[1]) {
      __pyx_v_timeout = __Pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_timeout == (double)-1) && PyErr_Occurred())) __PYX_ERR(8, 32, __pyx_L3_error)
    } else {
      __pyx_v_timeout = ((double)((double)0.0));
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("connect", 1, 1, 1, __pyx_nargs); __PYX_ERR(8, 32, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_conninfo), (&PyUnicode_Type), 0, "conninfo", 2))) __PYX_ERR(8, 32, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_8connect(__pyx_self, __pyx_v_conninfo, __pyx_v_timeout);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_8connect(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_conninfo, double __pyx_v_timeout) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("connect", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct__connect(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 32, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_conninfo = __pyx_v_conninfo;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_conninfo);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_conninfo);
  __pyx_cur_scope->__pyx_v_timeout = __pyx_v_timeout;
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_10generator, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_connect, __pyx_mstate_global->__pyx_n_u_connect, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 32, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_10generator(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  PGconn *__pyx_t_5;
  int __pyx_t_6;
  double __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("connect", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L15_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 32, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":36
 *     Generator to create a database connection without blocking.
 *     """
 *     cdef pq.PGconn conn = pq.PGconn.connect_start(conninfo.encode())             # <<<<<<<<<<<<<<
 *     cdef libpq.PGconn *pgconn_ptr = conn._pgconn_ptr
 *     cdef int conn_status = libpq.PQstatus(pgconn_ptr)
*/
  __pyx_t_2 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = PyUnicode_AsEncodedString(__pyx_cur_scope->__pyx_v_conninfo, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 36, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_connect_start, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 36, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn))))) __PYX_ERR(8, 36, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_conn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":37
 *     """
 *     cdef pq.PGconn conn = pq.PGconn.connect_start(conninfo.encode())
 *     cdef libpq.PGconn *pgconn_ptr = conn._pgconn_ptr             # <<<<<<<<<<<<<<
 *     cdef int conn_status = libpq.PQstatus(pgconn_ptr)
 *     cdef int poll_status
*/
  __pyx_t_5 = __pyx_cur_scope->__pyx_v_conn->_pgconn_ptr;
  __pyx_cur_scope->__pyx_v_pgconn_ptr = __pyx_t_5;

  /* "psycopg_c/_psycopg/generators.pyx":38
 *     cdef pq.PGconn conn = pq.PGconn.connect_start(conninfo.encode())
 *     cdef libpq.PGconn *pgconn_ptr = conn._pgconn_ptr
 *     cdef int conn_status = libpq.PQstatus(pgconn_ptr)             # <<<<<<<<<<<<<<
 *     cdef int poll_status
 *     cdef object wait, ready
*/
  __pyx_cur_scope->__pyx_v_conn_status = PQstatus(__pyx_cur_scope->__pyx_v_pgconn_ptr);

  /* "psycopg_c/_psycopg/generators.pyx":41
 *     cdef int poll_status
 *     cdef object wait, ready
 *     cdef double deadline = 0.0             # <<<<<<<<<<<<<<
 * 
 *     if timeout:
*/
  __pyx_cur_scope->__pyx_v_deadline = 0.0;

  /* "psycopg_c/_psycopg/generators.pyx":43
 *     cdef double deadline = 0.0
 * 
 *     if timeout:             # <<<<<<<<<<<<<<
 *         deadline = monotonic() + timeout
 * 
*/
  __pyx_t_6 = (__pyx_cur_scope->__pyx_v_timeout != 0);
  if (__pyx_t_6) {

    /* "psycopg_c/_psycopg/generators.pyx":44
 * 
 *     if timeout:
 *         deadline = monotonic() + timeout             # <<<<<<<<<<<<<<
 * 
 *     logger.debug("connection started: %s", conn)
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_monotonic); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 44, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_t_2 = PyFloat_FromDouble(__pyx_cur_scope->__pyx_v_timeout); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_Add(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 44, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyFloat_AsDouble(__pyx_t_3); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(8, 44, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_cur_scope->__pyx_v_deadline = __pyx_t_7;

    /* "psycopg_c/_psycopg/generators.pyx":43
 *     cdef double deadline = 0.0
 * 
 *     if timeout:             # <<<<<<<<<<<<<<
 *         deadline = monotonic() + timeout
 * 
*/
  }

  /* "psycopg_c/_psycopg/generators.pyx":46
 *         deadline = monotonic() + timeout
 * 
 *     logger.debug("connection started: %s", conn)             # <<<<<<<<<<<<<<
 *     while True:
 *         if conn_status == libpq.CONNECTION_BAD:
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_logger); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_debug); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 46, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_connection_started_s, ((PyObject *)__pyx_cur_scope->__pyx_v_conn)};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 46, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":47
 * 
 *     logger.debug("connection started: %s", conn)
 *     while True:             # <<<<<<<<<<<<<<
 *         if conn_status == libpq.CONNECTION_BAD:
 *             encoding = conninfo_encoding(conninfo)
*/
  while (1) {

    /* "psycopg_c/_psycopg/generators.pyx":48
 *     logger.debug("connection started: %s", conn)
 *     while True:
 *         if conn_status == libpq.CONNECTION_BAD:             # <<<<<<<<<<<<<<
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(
*/
    __pyx_t_6 = (__pyx_cur_scope->__pyx_v_conn_status == CONNECTION_BAD);
    if (unlikely(__pyx_t_6)) {

      /* "psycopg_c/_psycopg/generators.pyx":49
 *     while True:
 *         if conn_status == libpq.CONNECTION_BAD:
 *             encoding = conninfo_encoding(conninfo)             # <<<<<<<<<<<<<<
 *             raise e.OperationalError(
 *                 f"connection is bad: {conn.get_error_message(encoding)}",
*/
      __pyx_t_8 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_conninfo_encoding); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 49, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_cur_scope->__pyx_v_conninfo};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 49, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_encoding = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":50
 *         if conn_status == libpq.CONNECTION_BAD:
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(             # <<<<<<<<<<<<<<
 *                 f"connection is bad: {conn.get_error_message(encoding)}",
 *                 pgconn=conn
*/
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 50, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 50, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":51
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(
 *                 f"connection is bad: {conn.get_error_message(encoding)}",             # <<<<<<<<<<<<<<
 *                 pgconn=conn
 *             )
*/
      __pyx_t_9 = ((PyObject *)__pyx_cur_scope->__pyx_v_conn);
      __Pyx_INCREF(__pyx_t_9);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_encoding};
        __pyx_t_8 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_error_message, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 51, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
      }
      __pyx_t_9 = __Pyx_PyObject_FormatSimple(__pyx_t_8, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 51, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_connection_is_bad, __pyx_t_9); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 51, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":52
 *             raise e.OperationalError(
 *                 f"connection is bad: {conn.get_error_message(encoding)}",
 *                 pgconn=conn             # <<<<<<<<<<<<<<
 *             )
 * 
*/
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_2, __pyx_t_8};
        __pyx_t_9 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 50, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pgconn, ((PyObject *)__pyx_cur_scope->__pyx_v_conn), __pyx_t_9, __pyx_callargs+2, 0) < (0)) __PYX_ERR(8, 50, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_9);
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 50, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(8, 50, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":48
 *     logger.debug("connection started: %s", conn)
 *     while True:
 *         if conn_status == libpq.CONNECTION_BAD:             # <<<<<<<<<<<<<<
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(
*/
    }

    /* "psycopg_c/_psycopg/generators.pyx":55
 *             )
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             poll_status = libpq.PQconnectPoll(pgconn_ptr)
 *         logger.debug("connection polled: %s", conn)
*/
    {
        PyThreadState * _save;
        _save = PyEval_SaveThread();
        __Pyx_FastGIL_Remember();
        /*try:*/ {

          /* "psycopg_c/_psycopg/generators.pyx":56
 * 
 *         with nogil:
 *             poll_status = libpq.PQconnectPoll(pgconn_ptr)             # <<<<<<<<<<<<<<
 *         logger.debug("connection polled: %s", conn)
 * 
*/
          __pyx_cur_scope->__pyx_v_poll_status = PQconnectPoll(__pyx_cur_scope->__pyx_v_pgconn_ptr);
        }

        /* "psycopg_c/_psycopg/generators.pyx":55
 *             )
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             poll_status = libpq.PQconnectPoll(pgconn_ptr)
 *         logger.debug("connection polled: %s", conn)
*/
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_FastGIL_Forget();
            PyEval_RestoreThread(_save);
            goto __pyx_L12;
          }
          __pyx_L12:;
        }
    }

    /* "psycopg_c/_psycopg/generators.pyx":57
 *         with nogil:
 *             poll_status = libpq.PQconnectPoll(pgconn_ptr)
 *         logger.debug("connection polled: %s", conn)             # <<<<<<<<<<<<<<
 * 
 *         if (
*/
    __pyx_t_1 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_logger); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_debug); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_4 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_1);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_4 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_connection_polled_s, ((PyObject *)__pyx_cur_scope->__pyx_v_conn)};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 57, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/generators.pyx":59
 *         logger.debug("connection polled: %s", conn)
 * 
 *         if (             # <<<<<<<<<<<<<<
 *             poll_status == libpq.PGRES_POLLING_READING
 *             or poll_status == libpq.PGRES_POLLING_WRITING
*/
    switch (__pyx_cur_scope->__pyx_v_poll_status) {
      case PGRES_POLLING_READING:

      /* "psycopg_c/_psycopg/generators.pyx":60
 * 
 *         if (
 *             poll_status == libpq.PGRES_POLLING_READING             # <<<<<<<<<<<<<<
 *             or poll_status == libpq.PGRES_POLLING_WRITING
 *         ):
*/
      case PGRES_POLLING_WRITING:

      /* "psycopg_c/_psycopg/generators.pyx":63
 *             or poll_status == libpq.PGRES_POLLING_WRITING
 *         ):
 *             wait = WAIT_R if poll_status == libpq.PGRES_POLLING_READING else WAIT_W             # <<<<<<<<<<<<<<
 *             while True:
 *                 ready = yield (libpq.PQsocket(pgconn_ptr), wait)
*/
      __pyx_t_6 = (__pyx_cur_scope->__pyx_v_poll_status == PGRES_POLLING_READING);
      if (__pyx_t_6) {
        __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_R);
        __pyx_t_3 = __pyx_v_9psycopg_c_8_psycopg_WAIT_R;
      } else {
        __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_W);
        __pyx_t_3 = __pyx_v_9psycopg_c_8_psycopg_WAIT_W;
      }
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_wait);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_wait, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":64
 *         ):
 *             wait = WAIT_R if poll_status == libpq.PGRES_POLLING_READING else WAIT_W
 *             while True:             # <<<<<<<<<<<<<<
 *                 ready = yield (libpq.PQsocket(pgconn_ptr), wait)
 *                 if deadline and monotonic() > deadline:
*/
      while (1) {

        /* "psycopg_c/_psycopg/generators.pyx":65
 *             wait = WAIT_R if poll_status == libpq.PGRES_POLLING_READING else WAIT_W
 *             while True:
 *                 ready = yield (libpq.PQsocket(pgconn_ptr), wait)             # <<<<<<<<<<<<<<
 *                 if deadline and monotonic() > deadline:
 *                     raise e.ConnectionTimeout("connection timeout expired")
*/
        __pyx_t_3 = __Pyx_PyLong_From_int(PQsocket(__pyx_cur_scope->__pyx_v_pgconn_ptr)); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_8 = PyTuple_New(2); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 65, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_3);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_3) != (0)) __PYX_ERR(8, 65, __pyx_L1_error);
        __Pyx_INCREF(__pyx_cur_scope->__pyx_v_wait);
        __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_wait);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_cur_scope->__pyx_v_wait) != (0)) __PYX_ERR(8, 65, __pyx_L1_error);
        __pyx_t_3 = 0;
        __pyx_r = __pyx_t_8;
        __pyx_t_8 = 0;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, yielding value */
        __pyx_generator->resume_label = 1;
        return __pyx_r;
        __pyx_L15_resume_from_yield:;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 65, __pyx_L1_error)
        __pyx_t_8 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_ready);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_ready, __pyx_t_8);
        __Pyx_GIVEREF(__pyx_t_8);
        __pyx_t_8 = 0;

        /* "psycopg_c/_psycopg/generators.pyx":66
 *             while True:
 *                 ready = yield (libpq.PQsocket(pgconn_ptr), wait)
 *                 if deadline and monotonic() > deadline:             # <<<<<<<<<<<<<<
 *                     raise e.ConnectionTimeout("connection timeout expired")
 *                 if ready:
*/
        __pyx_t_10 = (__pyx_cur_scope->__pyx_v_deadline != 0);
        if (__pyx_t_10) {
        } else {
          __pyx_t_6 = __pyx_t_10;
          goto __pyx_L17_bool_binop_done;
        }
        __pyx_t_3 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_monotonic); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_4 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_1))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_1);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
          __pyx_t_4 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
          __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (1-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 66, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
        }
        __pyx_t_1 = PyFloat_FromDouble(__pyx_cur_scope->__pyx_v_deadline); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 66, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_3 = PyObject_RichCompare(__pyx_t_8, __pyx_t_1, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 66, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(8, 66, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_6 = __pyx_t_10;
        __pyx_L17_bool_binop_done:;
        if (unlikely(__pyx_t_6)) {

          /* "psycopg_c/_psycopg/generators.pyx":67
 *                 ready = yield (libpq.PQsocket(pgconn_ptr), wait)
 *                 if deadline and monotonic() > deadline:
 *                     raise e.ConnectionTimeout("connection timeout expired")             # <<<<<<<<<<<<<<
 *                 if ready:
 *                     break
*/
          __pyx_t_1 = NULL;
          __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 67, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_8);
          __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_ConnectionTimeout); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 67, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_9);
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __pyx_t_4 = 1;
          #if CYTHON_UNPACK_METHODS
          if (unlikely(PyMethod_Check(__pyx_t_9))) {
            __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_9);
            assert(__pyx_t_1);
            PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
            __Pyx_INCREF(__pyx_t_1);
            __Pyx_INCREF(__pyx__function);
            __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
            __pyx_t_4 = 0;
          }
          #endif
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_mstate_global->__pyx_kp_u_connection_timeout_expired};
            __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 67, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_3);
          }
          __Pyx_Raise(__pyx_t_3, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __PYX_ERR(8, 67, __pyx_L1_error)

          /* "psycopg_c/_psycopg/generators.pyx":66
 *             while True:
 *                 ready = yield (libpq.PQsocket(pgconn_ptr), wait)
 *                 if deadline and monotonic() > deadline:             # <<<<<<<<<<<<<<
 *                     raise e.ConnectionTimeout("connection timeout expired")
 *                 if ready:
*/
        }

        /* "psycopg_c/_psycopg/generators.pyx":68
 *                 if deadline and monotonic() > deadline:
 *                     raise e.ConnectionTimeout("connection timeout expired")
 *                 if ready:             # <<<<<<<<<<<<<<
 *                     break
 * 
*/
        __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ready); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(8, 68, __pyx_L1_error)
        if (__pyx_t_6) {

          /* "psycopg_c/_psycopg/generators.pyx":69
 *                     raise e.ConnectionTimeout("connection timeout expired")
 *                 if ready:
 *                     break             # <<<<<<<<<<<<<<
 * 
 *         elif poll_status == libpq.PGRES_POLLING_OK:
*/
          goto __pyx_L14_break;

          /* "psycopg_c/_psycopg/generators.pyx":68
 *                 if deadline and monotonic() > deadline:
 *                     raise e.ConnectionTimeout("connection timeout expired")
 *                 if ready:             # <<<<<<<<<<<<<<
 *                     break
 * 
*/
        }
      }
      __pyx_L14_break:;

      /* "psycopg_c/_psycopg/generators.pyx":59
 *         logger.debug("connection polled: %s", conn)
 * 
 *         if (             # <<<<<<<<<<<<<<
 *             poll_status == libpq.PGRES_POLLING_READING
 *             or poll_status == libpq.PGRES_POLLING_WRITING
*/
      break;
      case PGRES_POLLING_OK:

      /* "psycopg_c/_psycopg/generators.pyx":72
 * 
 *         elif poll_status == libpq.PGRES_POLLING_OK:
 *             break             # <<<<<<<<<<<<<<
 *         elif poll_status == libpq.PGRES_POLLING_FAILED:
 *             encoding = conninfo_encoding(conninfo)
*/
      goto __pyx_L6_break;

      /* "psycopg_c/_psycopg/generators.pyx":71
 *                     break
 * 
 *         elif poll_status == libpq.PGRES_POLLING_OK:             # <<<<<<<<<<<<<<
 *             break
 *         elif poll_status == libpq.PGRES_POLLING_FAILED:
*/
      break;
      case PGRES_POLLING_FAILED:

      /* "psycopg_c/_psycopg/generators.pyx":74
 *             break
 *         elif poll_status == libpq.PGRES_POLLING_FAILED:
 *             encoding = conninfo_encoding(conninfo)             # <<<<<<<<<<<<<<
 *             raise e.OperationalError(
 *                 f"connection failed: {conn.get_error_message(encoding)}",
*/
      __pyx_t_9 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_conninfo_encoding); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 74, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_1);
        assert(__pyx_t_9);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_cur_scope->__pyx_v_conninfo};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 74, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_cur_scope->__pyx_v_encoding = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":75
 *         elif poll_status == libpq.PGRES_POLLING_FAILED:
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(             # <<<<<<<<<<<<<<
 *                 f"connection failed: {conn.get_error_message(encoding)}",
 *                 pgconn=e.finish_pgconn(conn),
*/
      __pyx_t_1 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 75, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 75, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":76
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(
 *                 f"connection failed: {conn.get_error_message(encoding)}",             # <<<<<<<<<<<<<<
 *                 pgconn=e.finish_pgconn(conn),
 *             )
*/
      __pyx_t_2 = ((PyObject *)__pyx_cur_scope->__pyx_v_conn);
      __Pyx_INCREF(__pyx_t_2);
      __pyx_t_4 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_cur_scope->__pyx_v_encoding};
        __pyx_t_9 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_error_message, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 76, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __pyx_t_2 = __Pyx_PyObject_FormatSimple(__pyx_t_9, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_connection_failed, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 76, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":77
 *             raise e.OperationalError(
 *                 f"connection failed: {conn.get_error_message(encoding)}",
 *                 pgconn=e.finish_pgconn(conn),             # <<<<<<<<<<<<<<
 *             )
 *         else:
*/
      __pyx_t_11 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_12)) __PYX_ERR(8, 77, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_finish_pgconn); if (unlikely(!__pyx_t_13)) __PYX_ERR(8, 77, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
        assert(__pyx_t_11);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, ((PyObject *)__pyx_cur_scope->__pyx_v_conn)};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 77, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_8))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_8);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_1, __pyx_t_9};
        __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(8, 75, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pgconn, __pyx_t_2, __pyx_t_13, __pyx_callargs+2, 0) < (0)) __PYX_ERR(8, 75, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 75, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(8, 75, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":73
 *         elif poll_status == libpq.PGRES_POLLING_OK:
 *             break
 *         elif poll_status == libpq.PGRES_POLLING_FAILED:             # <<<<<<<<<<<<<<
 *             encoding = conninfo_encoding(conninfo)
 *             raise e.OperationalError(
*/
      break;
      default:

      /* "psycopg_c/_psycopg/generators.pyx":80
 *             )
 *         else:
 *             raise e.InternalError(             # <<<<<<<<<<<<<<
 *                 f"unexpected poll status: {poll_status}",
 *                 pgconn=e.finish_pgconn(conn),
*/
      __pyx_t_8 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_13)) __PYX_ERR(8, 80, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_InternalError); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 80, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":81
 *         else:
 *             raise e.InternalError(
 *                 f"unexpected poll status: {poll_status}",             # <<<<<<<<<<<<<<
 *                 pgconn=e.finish_pgconn(conn),
 *             )
*/
      __pyx_t_13 = __Pyx_PyUnicode_From_int(__pyx_cur_scope->__pyx_v_poll_status, 0, ' ', 'd'); if (unlikely(!__pyx_t_13)) __PYX_ERR(8, 81, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_unexpected_poll_status, __pyx_t_13); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 81, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":82
 *             raise e.InternalError(
 *                 f"unexpected poll status: {poll_status}",
 *                 pgconn=e.finish_pgconn(conn),             # <<<<<<<<<<<<<<
 *             )
 * 
*/
      __pyx_t_1 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_11)) __PYX_ERR(8, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_finish_pgconn); if (unlikely(!__pyx_t_12)) __PYX_ERR(8, 82, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_12);
        assert(__pyx_t_1);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, ((PyObject *)__pyx_cur_scope->__pyx_v_conn)};
        __pyx_t_13 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_13)) __PYX_ERR(8, 82, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_13);
      }
      __pyx_t_4 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_2);
        assert(__pyx_t_8);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_8);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
        __pyx_t_4 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_8, __pyx_t_9};
        __pyx_t_12 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_12)) __PYX_ERR(8, 80, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_12);
        if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_pgconn, __pyx_t_13, __pyx_t_12, __pyx_callargs+2, 0) < (0)) __PYX_ERR(8, 80, __pyx_L1_error)
        __pyx_t_3 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_12);
        __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 80, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __PYX_ERR(8, 80, __pyx_L1_error)
      break;
    }
  }
  __pyx_L6_break:;

  /* "psycopg_c/_psycopg/generators.pyx":85
 *             )
 * 
 *     conn.nonblocking = 1             # <<<<<<<<<<<<<<
 *     return conn
 * 
*/
  if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_v_conn), __pyx_mstate_global->__pyx_n_u_nonblocking, __pyx_mstate_global->__pyx_int_1) < (0)) __PYX_ERR(8, 85, __pyx_L1_error)

  /* "psycopg_c/_psycopg/generators.pyx":86
 * 
 *     conn.nonblocking = 1
 *     return conn             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_conn);
  __pyx_r = ((PyObject *)__pyx_cur_scope->__pyx_v_conn);
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":32
 * 
 * 
 * def connect(conninfo: str, *, timeout: float = 0.0) -> PQGenConn[abc.PGconn]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to create a database connection without blocking.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("connect", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_13generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":89
 * 
 * 
 * def cancel(pq.PGcancelConn cancel_conn, *, timeout: float = 0.0) -> PQGenConn[None]:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancelConn *pgcancelconn_ptr = cancel_conn.pgcancelconn_ptr
 *     cdef int status
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12cancel(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12cancel = {"cancel", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_12cancel, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12cancel(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9psycopg_c_2pq_PGcancelConn *__pyx_v_cancel_conn = 0;
  double __pyx_v_timeout;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cancel_conn,&__pyx_mstate_global->__pyx_n_u_timeout,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(8, 89, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(8, 89, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "cancel", 0) < (0)) __PYX_ERR(8, 89, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("cancel", 1, 1, 1, i); __PYX_ERR(8, 89, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(8, 89, __pyx_L3_error)
    }
    __pyx_v_cancel_conn = ((struct __pyx_obj_9psycopg_c_2pq_PGcancelConn *)values[0]);
    if (values[1]) {
      __pyx_v_timeout = __Pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_timeout == (double)-1) && PyErr_Occurred())) __PYX_ERR(8, 89, __pyx_L3_error)
    } else {
      __pyx_v_timeout = ((double)((double)0.0));
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("cancel", 1, 1, 1, __pyx_nargs); __PYX_ERR(8, 89, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_cancel_conn), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGcancelConn, 1, "cancel_conn", 0))) __PYX_ERR(8, 89, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11cancel(__pyx_self, __pyx_v_cancel_conn, __pyx_v_timeout);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11cancel(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGcancelConn *__pyx_v_cancel_conn, double __pyx_v_timeout) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cancel", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 89, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_cancel_conn = __pyx_v_cancel_conn;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_cancel_conn);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_cancel_conn);
  __pyx_cur_scope->__pyx_v_timeout = __pyx_v_timeout;
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_13generator1, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_cancel, __pyx_mstate_global->__pyx_n_u_cancel, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 89, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_13generator1(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PGcancelConn *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  double __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("cancel", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L15_resume_from_yield;
    case 2: goto __pyx_L16_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 89, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":90
 * 
 * def cancel(pq.PGcancelConn cancel_conn, *, timeout: float = 0.0) -> PQGenConn[None]:
 *     cdef libpq.PGcancelConn *pgcancelconn_ptr = cancel_conn.pgcancelconn_ptr             # <<<<<<<<<<<<<<
 *     cdef int status
 *     cdef double deadline = 0.0
*/
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_cancel_conn->pgcancelconn_ptr;
  __pyx_cur_scope->__pyx_v_pgcancelconn_ptr = __pyx_t_1;

  /* "psycopg_c/_psycopg/generators.pyx":92
 *     cdef libpq.PGcancelConn *pgcancelconn_ptr = cancel_conn.pgcancelconn_ptr
 *     cdef int status
 *     cdef double deadline = 0.0             # <<<<<<<<<<<<<<
 * 
 *     if timeout:
*/
  __pyx_cur_scope->__pyx_v_deadline = 0.0;

  /* "psycopg_c/_psycopg/generators.pyx":94
 *     cdef double deadline = 0.0
 * 
 *     if timeout:             # <<<<<<<<<<<<<<
 *         deadline = monotonic() + timeout
 * 
*/
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_timeout != 0);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/generators.pyx":95
 * 
 *     if timeout:
 *         deadline = monotonic() + timeout             # <<<<<<<<<<<<<<
 * 
 *     while True:
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_monotonic); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 95, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_t_5 = PyFloat_FromDouble(__pyx_cur_scope->__pyx_v_timeout); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_4 = PyNumber_Add(__pyx_t_3, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 95, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = __Pyx_PyFloat_AsDouble(__pyx_t_4); if (unlikely((__pyx_t_7 == (double)-1) && PyErr_Occurred())) __PYX_ERR(8, 95, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_cur_scope->__pyx_v_deadline = __pyx_t_7;

    /* "psycopg_c/_psycopg/generators.pyx":94
 *     cdef double deadline = 0.0
 * 
 *     if timeout:             # <<<<<<<<<<<<<<
 *         deadline = monotonic() + timeout
 * 
*/
  }

  /* "psycopg_c/_psycopg/generators.pyx":97
 *         deadline = monotonic() + timeout
 * 
 *     while True:             # <<<<<<<<<<<<<<
 *         if deadline and monotonic() > deadline:
 *             raise e.CancellationTimeout("cancellation timeout expired")
*/
  while (1) {

    /* "psycopg_c/_psycopg/generators.pyx":98
 * 
 *     while True:
 *         if deadline and monotonic() > deadline:             # <<<<<<<<<<<<<<
 *             raise e.CancellationTimeout("cancellation timeout expired")
 *         with nogil:
*/
    __pyx_t_8 = (__pyx_cur_scope->__pyx_v_deadline != 0);
    if (__pyx_t_8) {
    } else {
      __pyx_t_2 = __pyx_t_8;
      goto __pyx_L8_bool_binop_done;
    }
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_monotonic); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 98, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
    }
    __pyx_t_3 = PyFloat_FromDouble(__pyx_cur_scope->__pyx_v_deadline); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_4, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 98, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(8, 98, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_2 = __pyx_t_8;
    __pyx_L8_bool_binop_done:;
    if (unlikely(__pyx_t_2)) {

      /* "psycopg_c/_psycopg/generators.pyx":99
 *     while True:
 *         if deadline and monotonic() > deadline:
 *             raise e.CancellationTimeout("cancellation timeout expired")             # <<<<<<<<<<<<<<
 *         with nogil:
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)
*/
      __pyx_t_3 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 99, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_CancellationTimeout); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 99, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_9);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_cancellation_timeout_expired};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 99, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(8, 99, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":98
 * 
 *     while True:
 *         if deadline and monotonic() > deadline:             # <<<<<<<<<<<<<<
 *             raise e.CancellationTimeout("cancellation timeout expired")
 *         with nogil:
*/
    }

    /* "psycopg_c/_psycopg/generators.pyx":100
 *         if deadline and monotonic() > deadline:
 *             raise e.CancellationTimeout("cancellation timeout expired")
 *         with nogil:             # <<<<<<<<<<<<<<
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)
 *         if status == libpq.PGRES_POLLING_OK:
*/
    {
        PyThreadState * _save;
        _save = PyEval_SaveThread();
        __Pyx_FastGIL_Remember();
        /*try:*/ {

          /* "psycopg_c/_psycopg/generators.pyx":101
 *             raise e.CancellationTimeout("cancellation timeout expired")
 *         with nogil:
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)             # <<<<<<<<<<<<<<
 *         if status == libpq.PGRES_POLLING_OK:
 *             break
*/
          __pyx_cur_scope->__pyx_v_status = PQcancelPoll(__pyx_cur_scope->__pyx_v_pgcancelconn_ptr);
        }

        /* "psycopg_c/_psycopg/generators.pyx":100
 *         if deadline and monotonic() > deadline:
 *             raise e.CancellationTimeout("cancellation timeout expired")
 *         with nogil:             # <<<<<<<<<<<<<<
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)
 *         if status == libpq.PGRES_POLLING_OK:
*/
        /*finally:*/ {
          /*normal exit:*/{
            __Pyx_FastGIL_Forget();
            PyEval_RestoreThread(_save);
            goto __pyx_L14;
          }
          __pyx_L14:;
        }
    }

    /* "psycopg_c/_psycopg/generators.pyx":102
 *         with nogil:
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)
 *         if status == libpq.PGRES_POLLING_OK:             # <<<<<<<<<<<<<<
 *             break
 *         elif status == libpq.PGRES_POLLING_READING:
*/
    switch (__pyx_cur_scope->__pyx_v_status) {
      case PGRES_POLLING_OK:

      /* "psycopg_c/_psycopg/generators.pyx":103
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)
 *         if status == libpq.PGRES_POLLING_OK:
 *             break             # <<<<<<<<<<<<<<
 *         elif status == libpq.PGRES_POLLING_READING:
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_R
*/
      goto __pyx_L6_break;

      /* "psycopg_c/_psycopg/generators.pyx":102
 *         with nogil:
 *             status = libpq.PQcancelPoll(pgcancelconn_ptr)
 *         if status == libpq.PGRES_POLLING_OK:             # <<<<<<<<<<<<<<
 *             break
 *         elif status == libpq.PGRES_POLLING_READING:
*/
      break;
      case PGRES_POLLING_READING:

      /* "psycopg_c/_psycopg/generators.pyx":105
 *             break
 *         elif status == libpq.PGRES_POLLING_READING:
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_R             # <<<<<<<<<<<<<<
 *         elif status == libpq.PGRES_POLLING_WRITING:
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_W
*/
      __pyx_t_5 = __Pyx_PyLong_From_int(PQcancelSocket(__pyx_cur_scope->__pyx_v_pgcancelconn_ptr)); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 105, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = PyTuple_New(2); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 105, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_5);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 0, __pyx_t_5) != (0)) __PYX_ERR(8, 105, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_R);
      __Pyx_GIVEREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_R);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_9, 1, __pyx_v_9psycopg_c_8_psycopg_WAIT_R) != (0)) __PYX_ERR(8, 105, __pyx_L1_error);
      __pyx_t_5 = 0;
      __pyx_r = __pyx_t_9;
      __pyx_t_9 = 0;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L15_resume_from_yield:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 105, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":104
 *         if status == libpq.PGRES_POLLING_OK:
 *             break
 *         elif status == libpq.PGRES_POLLING_READING:             # <<<<<<<<<<<<<<
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_R
 *         elif status == libpq.PGRES_POLLING_WRITING:
*/
      break;
      case PGRES_POLLING_WRITING:

      /* "psycopg_c/_psycopg/generators.pyx":107
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_R
 *         elif status == libpq.PGRES_POLLING_WRITING:
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_W             # <<<<<<<<<<<<<<
 *         elif status == libpq.PGRES_POLLING_FAILED:
 *             raise e.OperationalError(
*/
      __pyx_t_9 = __Pyx_PyLong_From_int(PQcancelSocket(__pyx_cur_scope->__pyx_v_pgcancelconn_ptr)); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 107, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_9);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_9) != (0)) __PYX_ERR(8, 107, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_W);
      __Pyx_GIVEREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_W);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_9psycopg_c_8_psycopg_WAIT_W) != (0)) __PYX_ERR(8, 107, __pyx_L1_error);
      __pyx_t_9 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 2;
      return __pyx_r;
      __pyx_L16_resume_from_yield:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 107, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":106
 *         elif status == libpq.PGRES_POLLING_READING:
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_R
 *         elif status == libpq.PGRES_POLLING_WRITING:             # <<<<<<<<<<<<<<
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_W
 *         elif status == libpq.PGRES_POLLING_FAILED:
*/
      break;
      case PGRES_POLLING_FAILED:

      /* "psycopg_c/_psycopg/generators.pyx":109
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_W
 *         elif status == libpq.PGRES_POLLING_FAILED:
 *             raise e.OperationalError(             # <<<<<<<<<<<<<<
 *                 f"cancellation failed: {cancel_conn.get_error_message()}"
 *             )
*/
      __pyx_t_9 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 109, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":110
 *         elif status == libpq.PGRES_POLLING_FAILED:
 *             raise e.OperationalError(
 *                 f"cancellation failed: {cancel_conn.get_error_message()}"             # <<<<<<<<<<<<<<
 *             )
 *         else:
*/
      __pyx_t_10 = ((PyObject *)__pyx_cur_scope->__pyx_v_cancel_conn);
      __Pyx_INCREF(__pyx_t_10);
      __pyx_t_6 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, NULL};
        __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_error_message, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 110, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_10 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_10)) __PYX_ERR(8, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_cancellation_failed, __pyx_t_10); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 110, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_9);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_3};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 109, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(8, 109, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":108
 *         elif status == libpq.PGRES_POLLING_WRITING:
 *             yield libpq.PQcancelSocket(pgcancelconn_ptr), WAIT_W
 *         elif status == libpq.PGRES_POLLING_FAILED:             # <<<<<<<<<<<<<<
 *             raise e.OperationalError(
 *                 f"cancellation failed: {cancel_conn.get_error_message()}"
*/
      break;
      default:

      /* "psycopg_c/_psycopg/generators.pyx":113
 *             )
 *         else:
 *             raise e.InternalError(f"unexpected poll status: {status}")             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_4 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_InternalError); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_From_int(__pyx_cur_scope->__pyx_v_status, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_10 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_unexpected_poll_status, __pyx_t_3); if (unlikely(!__pyx_t_10)) __PYX_ERR(8, 113, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_9))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_9);
        assert(__pyx_t_4);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_9);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_9, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_10};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_9, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 113, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(8, 113, __pyx_L1_error)
      break;
    }
  }
  __pyx_L6_break:;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":89
 * 
 * 
 * def cancel(pq.PGcancelConn cancel_conn, *, timeout: float = 0.0) -> PQGenConn[None]:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancelConn *pgcancelconn_ptr = cancel_conn.pgcancelconn_ptr
 *     cdef int status
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("cancel", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_16generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":116
 * 
 * 
 * def execute(pq.PGconn pgconn) -> PQGen[list[abc.PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator sending a query and returning results without blocking.
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15execute(PyObject *__pyx_self, PyObject *__pyx_v_pgconn); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_14execute, "\n    Generator sending a query and returning results without blocking.\n\n    The query must have already been sent using `pgconn.send_query()` or\n    similar. Flush the query and then return the result using nonblocking\n    functions.\n\n    Return the list of results returned by the database (whether success\n    or error).\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15execute = {"execute", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15execute, METH_O, __pyx_doc_9psycopg_c_8_psycopg_14execute};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15execute(PyObject *__pyx_self, PyObject *__pyx_v_pgconn) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("execute (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pgconn), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn, 1, "pgconn", 0))) __PYX_ERR(8, 116, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14execute(__pyx_self, ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_v_pgconn));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14execute(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("execute", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 116, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_pgconn = __pyx_v_pgconn;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_16generator2, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_execute, __pyx_mstate_global->__pyx_n_u_execute, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 116, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.execute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_16generator2(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  __Pyx_PySendResult __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("execute", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L4_resume_from_yield_from;
    case 2: goto __pyx_L5_resume_from_yield_from;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 116, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":127
 *     or error).
 *     """
 *     yield from send(pgconn)             # <<<<<<<<<<<<<<
 *     rv = yield from fetch_many(pgconn)
 *     return rv
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_send); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_Generator_Yield_From(__pyx_generator, __pyx_t_1, &__pyx_r);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_5 == PYGEN_NEXT)) {
    __Pyx_GOTREF(__pyx_r);
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 1;
    return __pyx_r;
    __pyx_L4_resume_from_yield_from:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 127, __pyx_L1_error)
  } else if (likely(__pyx_t_5 == PYGEN_RETURN)) {
    __Pyx_GOTREF(__pyx_r);
    __Pyx_DECREF(__pyx_r); __pyx_r = 0;
  } else {
    __Pyx_XGOTREF(__pyx_r);
    __PYX_ERR(8, 127, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":128
 *     """
 *     yield from send(pgconn)
 *     rv = yield from fetch_many(pgconn)             # <<<<<<<<<<<<<<
 *     return rv
 * 
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_fetch_many); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn)};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 128, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_5 = __Pyx_Generator_Yield_From(__pyx_generator, __pyx_t_1, &__pyx_r);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_5 == PYGEN_NEXT)) {
    __Pyx_GOTREF(__pyx_r);
    __Pyx_XGIVEREF(__pyx_r);
    __Pyx_RefNannyFinishContext();
    __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
    /* return from generator, yielding value */
    __pyx_generator->resume_label = 2;
    return __pyx_r;
    __pyx_L5_resume_from_yield_from:;
    if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 128, __pyx_L1_error)
    __pyx_t_1 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_1);
  } else if (likely(__pyx_t_5 == PYGEN_RETURN)) {
    __Pyx_GOTREF(__pyx_r);
    __pyx_t_1 = __pyx_r; __pyx_r = NULL;
  } else {
    __Pyx_XGOTREF(__pyx_r);
    __PYX_ERR(8, 128, __pyx_L1_error)
  }
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_rv = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":129
 *     yield from send(pgconn)
 *     rv = yield from fetch_many(pgconn)
 *     return rv             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_rv);
  __pyx_r = __pyx_cur_scope->__pyx_v_rv;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":116
 * 
 * 
 * def execute(pq.PGconn pgconn) -> PQGen[list[abc.PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator sending a query and returning results without blocking.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("execute", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_19generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":132
 * 
 * 
 * def send(pq.PGconn pgconn) -> PQGen[None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to send a query to the server without blocking.
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18send(PyObject *__pyx_self, PyObject *__pyx_v_pgconn); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_17send, "\n    Generator to send a query to the server without blocking.\n\n    The query must have already been sent using `pgconn.send_query()` or\n    similar. Flush the query and then return the result using nonblocking\n    functions.\n\n    After this generator has finished you may want to cycle using `fetch()`\n    to retrieve the results available.\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18send = {"send", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18send, METH_O, __pyx_doc_9psycopg_c_8_psycopg_17send};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18send(PyObject *__pyx_self, PyObject *__pyx_v_pgconn) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("send (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pgconn), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn, 1, "pgconn", 0))) __PYX_ERR(8, 132, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17send(__pyx_self, ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_v_pgconn));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17send(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("send", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_3_send(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 132, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_pgconn = __pyx_v_pgconn;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_19generator3, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_send, __pyx_mstate_global->__pyx_n_u_send, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 132, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.send", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_19generator3(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PGconn *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("send", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L9_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 132, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":143
 *     to retrieve the results available.
 *     """
 *     cdef libpq.PGconn *pgconn_ptr = pgconn._pgconn_ptr             # <<<<<<<<<<<<<<
 *     cdef int ready
 *     cdef int cires
*/
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_pgconn->_pgconn_ptr;
  __pyx_cur_scope->__pyx_v_pgconn_ptr = __pyx_t_1;

  /* "psycopg_c/_psycopg/generators.pyx":147
 *     cdef int cires
 * 
 *     while True:             # <<<<<<<<<<<<<<
 *         if pgconn.flush() == 0:
 *             break
*/
  while (1) {

    /* "psycopg_c/_psycopg/generators.pyx":148
 * 
 *     while True:
 *         if pgconn.flush() == 0:             # <<<<<<<<<<<<<<
 *             break
 * 
*/
    __pyx_t_2 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn *)__pyx_cur_scope->__pyx_v_pgconn->__pyx_vtab)->flush(__pyx_cur_scope->__pyx_v_pgconn, 0); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(8, 148, __pyx_L1_error)
    __pyx_t_3 = (__pyx_t_2 == 0);
    if (__pyx_t_3) {

      /* "psycopg_c/_psycopg/generators.pyx":149
 *     while True:
 *         if pgconn.flush() == 0:
 *             break             # <<<<<<<<<<<<<<
 * 
 *         while True:
*/
      goto __pyx_L5_break;

      /* "psycopg_c/_psycopg/generators.pyx":148
 * 
 *     while True:
 *         if pgconn.flush() == 0:             # <<<<<<<<<<<<<<
 *             break
 * 
*/
    }

    /* "psycopg_c/_psycopg/generators.pyx":151
 *             break
 * 
 *         while True:             # <<<<<<<<<<<<<<
 *             ready = yield WAIT_RW
 *             if ready:
*/
    while (1) {

      /* "psycopg_c/_psycopg/generators.pyx":152
 * 
 *         while True:
 *             ready = yield WAIT_RW             # <<<<<<<<<<<<<<
 *             if ready:
 *                 break
*/
      __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_RW);
      __pyx_r = __pyx_v_9psycopg_c_8_psycopg_WAIT_RW;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L9_resume_from_yield:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 152, __pyx_L1_error)
      __pyx_t_4 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_2 == (int)-1) && PyErr_Occurred())) __PYX_ERR(8, 152, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_cur_scope->__pyx_v_ready = __pyx_t_2;

      /* "psycopg_c/_psycopg/generators.pyx":153
 *         while True:
 *             ready = yield WAIT_RW
 *             if ready:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      __pyx_t_3 = (__pyx_cur_scope->__pyx_v_ready != 0);
      if (__pyx_t_3) {

        /* "psycopg_c/_psycopg/generators.pyx":154
 *             ready = yield WAIT_RW
 *             if ready:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         if ready & READY_R:
*/
        goto __pyx_L8_break;

        /* "psycopg_c/_psycopg/generators.pyx":153
 *         while True:
 *             ready = yield WAIT_RW
 *             if ready:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      }
    }
    __pyx_L8_break:;

    /* "psycopg_c/_psycopg/generators.pyx":156
 *                 break
 * 
 *         if ready & READY_R:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 # This call may read notifies which will be saved in the
*/
    __pyx_t_3 = ((__pyx_cur_scope->__pyx_v_ready & __pyx_v_9psycopg_c_8_psycopg_READY_R) != 0);
    if (__pyx_t_3) {

      /* "psycopg_c/_psycopg/generators.pyx":157
 * 
 *         if ready & READY_R:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 # This call may read notifies which will be saved in the
 *                 # PGconn buffer and passed to Python later.
*/
      {
          PyThreadState * _save;
          _save = PyEval_SaveThread();
          __Pyx_FastGIL_Remember();
          /*try:*/ {

            /* "psycopg_c/_psycopg/generators.pyx":160
 *                 # This call may read notifies which will be saved in the
 *                 # PGconn buffer and passed to Python later.
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)             # <<<<<<<<<<<<<<
 *             if 1 != cires:
 *                 raise e.OperationalError(
*/
            __pyx_cur_scope->__pyx_v_cires = PQconsumeInput(__pyx_cur_scope->__pyx_v_pgconn_ptr);
          }

          /* "psycopg_c/_psycopg/generators.pyx":157
 * 
 *         if ready & READY_R:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 # This call may read notifies which will be saved in the
 *                 # PGconn buffer and passed to Python later.
*/
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_FastGIL_Forget();
              PyEval_RestoreThread(_save);
              goto __pyx_L16;
            }
            __pyx_L16:;
          }
      }

      /* "psycopg_c/_psycopg/generators.pyx":161
 *                 # PGconn buffer and passed to Python later.
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:             # <<<<<<<<<<<<<<
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
*/
      __pyx_t_3 = (1 != __pyx_cur_scope->__pyx_v_cires);
      if (unlikely(__pyx_t_3)) {

        /* "psycopg_c/_psycopg/generators.pyx":162
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:
 *                 raise e.OperationalError(             # <<<<<<<<<<<<<<
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 * 
*/
        __pyx_t_5 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 162, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_7)) __PYX_ERR(8, 162, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "psycopg_c/_psycopg/generators.pyx":163
 *             if 1 != cires:
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")             # <<<<<<<<<<<<<<
 * 
 * 
*/
        __pyx_t_8 = ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_error_message, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 163, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 163, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_consuming_input_failed, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 163, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_9 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
          __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 162, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
        }
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __PYX_ERR(8, 162, __pyx_L1_error)

        /* "psycopg_c/_psycopg/generators.pyx":161
 *                 # PGconn buffer and passed to Python later.
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:             # <<<<<<<<<<<<<<
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":156
 *                 break
 * 
 *         if ready & READY_R:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 # This call may read notifies which will be saved in the
*/
    }
  }
  __pyx_L5_break:;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":132
 * 
 * 
 * def send(pq.PGconn pgconn) -> PQGen[None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to send a query to the server without blocking.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("send", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_22generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":166
 * 
 * 
 * def fetch_many(pq.PGconn pgconn) -> PQGen[list[PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving results from the database without blocking.
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21fetch_many(PyObject *__pyx_self, PyObject *__pyx_v_pgconn); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_20fetch_many, "\n    Generator retrieving results from the database without blocking.\n\n    The query must have already been sent to the server, so pgconn.flush() has\n    already returned 0.\n\n    Return the list of results returned by the database (whether success\n    or error).\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21fetch_many = {"fetch_many", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21fetch_many, METH_O, __pyx_doc_9psycopg_c_8_psycopg_20fetch_many};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21fetch_many(PyObject *__pyx_self, PyObject *__pyx_v_pgconn) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fetch_many (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pgconn), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn, 1, "pgconn", 0))) __PYX_ERR(8, 166, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20fetch_many(__pyx_self, ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_v_pgconn));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_10fetch_many_2generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":189
 *             # timeout. Check if we had received an error before, and raise it
 *             # as exception, because it should contain more details. See #988.
 *             if any(result.status == libpq.PGRES_FATAL_ERROR for res in results):             # <<<<<<<<<<<<<<
 *                 break
 *             else:
*/

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10fetch_many_genexpr(PyObject *__pyx_self, PyObject *__pyx_genexpr_arg_0) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("genexpr", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 189, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_outer_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *) __pyx_self;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_outer_scope);
  __pyx_cur_scope->__pyx_genexpr_arg_0 = __pyx_genexpr_arg_0;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_genexpr_arg_0);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_10fetch_many_2generator7, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[4]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_genexpr, __pyx_mstate_global->__pyx_n_u_fetch_many_locals_genexpr, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.fetch_many.genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_10fetch_many_2generator7(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("genexpr", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 189, __pyx_L1_error)
  if (unlikely(!__pyx_cur_scope->__pyx_genexpr_arg_0)) { __Pyx_RaiseUnboundLocalError(".0"); __PYX_ERR(8, 189, __pyx_L1_error) }
  __pyx_t_1 = __pyx_cur_scope->__pyx_genexpr_arg_0; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_SIZE
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(8, 189, __pyx_L1_error)
      #endif
      if (__pyx_t_2 >= __pyx_temp) break;
    }
    __pyx_t_3 = __Pyx_PyList_GetItemRefFast(__pyx_t_1, __pyx_t_2, __Pyx_ReferenceSharing_OwnStrongReference);
    ++__pyx_t_2;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_res);
    __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_res, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    if (unlikely(!__pyx_cur_scope->__pyx_outer_scope->__pyx_v_result)) { __Pyx_RaiseClosureNameError("result"); __PYX_ERR(8, 189, __pyx_L1_error) }
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_cur_scope->__pyx_outer_scope->__pyx_v_result), __pyx_mstate_global->__pyx_n_u_status); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyLong_From_ExecStatusType(PGRES_FATAL_ERROR); if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(8, 189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_6) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(Py_True);
      __pyx_r = Py_True;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_False);
    __pyx_r = Py_False;
    goto __pyx_L0;
  }
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("genexpr", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/generators.pyx":166
 * 
 * 
 * def fetch_many(pq.PGconn pgconn) -> PQGen[list[PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving results from the database without blocking.
*/

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20fetch_many(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *__pyx_cur_scope;
  PyObject *__pyx_gb_9psycopg_c_8_psycopg_10fetch_many_2generator7 = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fetch_many", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 166, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_pgconn = __pyx_v_pgconn;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_22generator4, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_fetch_many, __pyx_mstate_global->__pyx_n_u_fetch_many, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 166, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.fetch_many", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XDECREF(__pyx_gb_9psycopg_c_8_psycopg_10fetch_many_2generator7);
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_22generator4(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  __Pyx_PySendResult __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  PGresult *__pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fetch_many", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L14_resume_from_yield_from;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 166, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":176
 *     or error).
 *     """
 *     cdef list results = []             # <<<<<<<<<<<<<<
 *     cdef int status
 *     cdef pq.PGresult result
*/
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_cur_scope->__pyx_v_results = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":181
 *     cdef libpq.PGresult *pgres
 * 
 *     while True:             # <<<<<<<<<<<<<<
 *         try:
 *             result = yield from fetch(pgconn)
*/
  while (1) {

    /* "psycopg_c/_psycopg/generators.pyx":182
 * 
 *     while True:
 *         try:             # <<<<<<<<<<<<<<
 *             result = yield from fetch(pgconn)
 *         except e.DatabaseError:
*/
    {
      __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      /*try:*/ {

        /* "psycopg_c/_psycopg/generators.pyx":183
 *     while True:
 *         try:
 *             result = yield from fetch(pgconn)             # <<<<<<<<<<<<<<
 *         except e.DatabaseError:
 *             # What might have happened here is that a previuos error
*/
        __pyx_t_5 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_fetch); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 183, __pyx_L6_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
          __pyx_t_7 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn)};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 183, __pyx_L6_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_8 = __Pyx_Generator_Yield_From(__pyx_generator, __pyx_t_1, &__pyx_r);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        if (likely(__pyx_t_8 == PYGEN_NEXT)) {
          __Pyx_GOTREF(__pyx_r);
          __Pyx_XGIVEREF(__pyx_t_2);
          __pyx_cur_scope->__pyx_t_0 = __pyx_t_2;
          __Pyx_XGIVEREF(__pyx_t_3);
          __pyx_cur_scope->__pyx_t_1 = __pyx_t_3;
          __Pyx_XGIVEREF(__pyx_t_4);
          __pyx_cur_scope->__pyx_t_2 = __pyx_t_4;
          __Pyx_XGIVEREF(__pyx_r);
          __Pyx_RefNannyFinishContext();
          __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
          /* return from generator, yielding value */
          __pyx_generator->resume_label = 1;
          return __pyx_r;
          __pyx_L14_resume_from_yield_from:;
          __pyx_t_2 = __pyx_cur_scope->__pyx_t_0;
          __pyx_cur_scope->__pyx_t_0 = 0;
          __Pyx_XGOTREF(__pyx_t_2);
          __pyx_t_3 = __pyx_cur_scope->__pyx_t_1;
          __pyx_cur_scope->__pyx_t_1 = 0;
          __Pyx_XGOTREF(__pyx_t_3);
          __pyx_t_4 = __pyx_cur_scope->__pyx_t_2;
          __pyx_cur_scope->__pyx_t_2 = 0;
          __Pyx_XGOTREF(__pyx_t_4);
          if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 183, __pyx_L6_error)
          __pyx_t_1 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_1);
        } else if (likely(__pyx_t_8 == PYGEN_RETURN)) {
          __Pyx_GOTREF(__pyx_r);
          __pyx_t_1 = __pyx_r; __pyx_r = NULL;
        } else {
          __Pyx_XGOTREF(__pyx_r);
          __PYX_ERR(8, 183, __pyx_L6_error)
        }
        if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGresult))))) __PYX_ERR(8, 183, __pyx_L6_error)
        __Pyx_XGOTREF((PyObject *)__pyx_cur_scope->__pyx_v_result);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_result, ((struct __pyx_obj_9psycopg_c_2pq_PGresult *)__pyx_t_1));
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_1 = 0;

        /* "psycopg_c/_psycopg/generators.pyx":182
 * 
 *     while True:
 *         try:             # <<<<<<<<<<<<<<
 *             result = yield from fetch(pgconn)
 *         except e.DatabaseError:
*/
      }
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      goto __pyx_L13_try_end;
      __pyx_L6_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":184
 *         try:
 *             result = yield from fetch(pgconn)
 *         except e.DatabaseError:             # <<<<<<<<<<<<<<
 *             # What might have happened here is that a previuos error
 *             # disconnected the connection, for example a idle in transaction
*/
      __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_6, &__pyx_t_5);
      __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 184, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_9);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_DatabaseError); if (unlikely(!__pyx_t_10)) __PYX_ERR(8, 184, __pyx_L8_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_t_11 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_10);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_ErrRestore(__pyx_t_1, __pyx_t_6, __pyx_t_5);
      __pyx_t_1 = 0; __pyx_t_6 = 0; __pyx_t_5 = 0;
      if (__pyx_t_11) {
        __Pyx_AddTraceback("psycopg_c._psycopg.fetch_many", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_1) < 0) __PYX_ERR(8, 184, __pyx_L8_except_error)
        __Pyx_XGOTREF(__pyx_t_5);
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);

        /* "psycopg_c/_psycopg/generators.pyx":189
 *             # timeout. Check if we had received an error before, and raise it
 *             # as exception, because it should contain more details. See #988.
 *             if any(result.status == libpq.PGRES_FATAL_ERROR for res in results):             # <<<<<<<<<<<<<<
 *                 break
 *             else:
*/
        __pyx_t_10 = __pyx_pf_9psycopg_c_8_psycopg_10fetch_many_genexpr(((PyObject*)__pyx_cur_scope), __pyx_cur_scope->__pyx_v_results); if (unlikely(!__pyx_t_10)) __PYX_ERR(8, 189, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __pyx_t_9 = __Pyx_Generator_GetInlinedResult(__pyx_t_10); if (unlikely(!__pyx_t_9)) __PYX_ERR(8, 189, __pyx_L8_except_error)
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_12 = __Pyx_PyObject_IsTrue(__pyx_t_9); if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(8, 189, __pyx_L8_except_error)
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        if (likely(__pyx_t_12)) {

          /* "psycopg_c/_psycopg/generators.pyx":190
 *             # as exception, because it should contain more details. See #988.
 *             if any(result.status == libpq.PGRES_FATAL_ERROR for res in results):
 *                 break             # <<<<<<<<<<<<<<
 *             else:
 *                 raise
*/
          goto __pyx_L16_except_break;

          /* "psycopg_c/_psycopg/generators.pyx":189
 *             # timeout. Check if we had received an error before, and raise it
 *             # as exception, because it should contain more details. See #988.
 *             if any(result.status == libpq.PGRES_FATAL_ERROR for res in results):             # <<<<<<<<<<<<<<
 *                 break
 *             else:
*/
        }

        /* "psycopg_c/_psycopg/generators.pyx":192
 *                 break
 *             else:
 *                 raise             # <<<<<<<<<<<<<<
 * 
 *         if result is None:
*/
        /*else*/ {
          __Pyx_GIVEREF(__pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_6);
          __Pyx_XGIVEREF(__pyx_t_1);
          __Pyx_ErrRestoreWithState(__pyx_t_5, __pyx_t_6, __pyx_t_1);
          __pyx_t_5 = 0;  __pyx_t_6 = 0;  __pyx_t_1 = 0; 
          __PYX_ERR(8, 192, __pyx_L8_except_error)
        }
        __pyx_L16_except_break:;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L11_try_break;
      }
      goto __pyx_L8_except_error;

      /* "psycopg_c/_psycopg/generators.pyx":182
 * 
 *     while True:
 *         try:             # <<<<<<<<<<<<<<
 *             result = yield from fetch(pgconn)
 *         except e.DatabaseError:
*/
      __pyx_L8_except_error:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L1_error;
      __pyx_L11_try_break:;
      __Pyx_XGIVEREF(__pyx_t_2);
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
      goto __pyx_L5_break;
      __pyx_L13_try_end:;
    }

    /* "psycopg_c/_psycopg/generators.pyx":194
 *                 raise
 * 
 *         if result is None:             # <<<<<<<<<<<<<<
 *             break
 * 
*/
    __pyx_t_12 = (((PyObject *)__pyx_cur_scope->__pyx_v_result) == Py_None);
    if (__pyx_t_12) {

      /* "psycopg_c/_psycopg/generators.pyx":195
 * 
 *         if result is None:
 *             break             # <<<<<<<<<<<<<<
 * 
 *         results.append(result)
*/
      goto __pyx_L5_break;

      /* "psycopg_c/_psycopg/generators.pyx":194
 *                 raise
 * 
 *         if result is None:             # <<<<<<<<<<<<<<
 *             break
 * 
*/
    }

    /* "psycopg_c/_psycopg/generators.pyx":197
 *             break
 * 
 *         results.append(result)             # <<<<<<<<<<<<<<
 *         pgres = result._pgresult_ptr
 * 
*/
    __pyx_t_1 = ((PyObject *)__pyx_cur_scope->__pyx_v_result);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_13 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_results, __pyx_t_1); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(8, 197, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/generators.pyx":198
 * 
 *         results.append(result)
 *         pgres = result._pgresult_ptr             # <<<<<<<<<<<<<<
 * 
 *         status = libpq.PQresultStatus(pgres)
*/
    __pyx_t_14 = __pyx_cur_scope->__pyx_v_result->_pgresult_ptr;
    __pyx_cur_scope->__pyx_v_pgres = __pyx_t_14;

    /* "psycopg_c/_psycopg/generators.pyx":200
 *         pgres = result._pgresult_ptr
 * 
 *         status = libpq.PQresultStatus(pgres)             # <<<<<<<<<<<<<<
 *         if (
 *             status == libpq.PGRES_COPY_IN
*/
    __pyx_cur_scope->__pyx_v_status = PQresultStatus(__pyx_cur_scope->__pyx_v_pgres);

    /* "psycopg_c/_psycopg/generators.pyx":201
 * 
 *         status = libpq.PQresultStatus(pgres)
 *         if (             # <<<<<<<<<<<<<<
 *             status == libpq.PGRES_COPY_IN
 *             or status == libpq.PGRES_COPY_OUT
*/
    switch (__pyx_cur_scope->__pyx_v_status) {
      case PGRES_COPY_IN:

      /* "psycopg_c/_psycopg/generators.pyx":202
 *         status = libpq.PQresultStatus(pgres)
 *         if (
 *             status == libpq.PGRES_COPY_IN             # <<<<<<<<<<<<<<
 *             or status == libpq.PGRES_COPY_OUT
 *             or status == libpq.PGRES_COPY_BOTH
*/
      case PGRES_COPY_OUT:

      /* "psycopg_c/_psycopg/generators.pyx":203
 *         if (
 *             status == libpq.PGRES_COPY_IN
 *             or status == libpq.PGRES_COPY_OUT             # <<<<<<<<<<<<<<
 *             or status == libpq.PGRES_COPY_BOTH
 *         ):
*/
      case PGRES_COPY_BOTH:

      /* "psycopg_c/_psycopg/generators.pyx":208
 *             # After entering copy mode the libpq will create a phony result
 *             # for every request so let's break the endless loop.
 *             break             # <<<<<<<<<<<<<<
 * 
 *         if status == libpq.PGRES_PIPELINE_SYNC:
*/
      goto __pyx_L5_break;

      /* "psycopg_c/_psycopg/generators.pyx":201
 * 
 *         status = libpq.PQresultStatus(pgres)
 *         if (             # <<<<<<<<<<<<<<
 *             status == libpq.PGRES_COPY_IN
 *             or status == libpq.PGRES_COPY_OUT
*/
      break;
      default: break;
    }

    /* "psycopg_c/_psycopg/generators.pyx":210
 *             break
 * 
 *         if status == libpq.PGRES_PIPELINE_SYNC:             # <<<<<<<<<<<<<<
 *             # PIPELINE_SYNC is not followed by a NULL, but we return it alone
 *             # similarly to other result sets.
*/
    __pyx_t_12 = (__pyx_cur_scope->__pyx_v_status == PGRES_PIPELINE_SYNC);
    if (__pyx_t_12) {

      /* "psycopg_c/_psycopg/generators.pyx":213
 *             # PIPELINE_SYNC is not followed by a NULL, but we return it alone
 *             # similarly to other result sets.
 *             break             # <<<<<<<<<<<<<<
 * 
 *     return results
*/
      goto __pyx_L5_break;

      /* "psycopg_c/_psycopg/generators.pyx":210
 *             break
 * 
 *         if status == libpq.PGRES_PIPELINE_SYNC:             # <<<<<<<<<<<<<<
 *             # PIPELINE_SYNC is not followed by a NULL, but we return it alone
 *             # similarly to other result sets.
*/
    }
  }
  __pyx_L5_break:;

  /* "psycopg_c/_psycopg/generators.pyx":215
 *             break
 * 
 *     return results             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_results);
  __pyx_r = __pyx_cur_scope->__pyx_v_results;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":166
 * 
 * 
 * def fetch_many(pq.PGconn pgconn) -> PQGen[list[PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving results from the database without blocking.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("fetch_many", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_25generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":218
 * 
 * 
 * def fetch(pq.PGconn pgconn) -> PQGen[PGresult | None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving a single result from the database without blocking.
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_24fetch(PyObject *__pyx_self, PyObject *__pyx_v_pgconn); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_23fetch, "\n    Generator retrieving a single result from the database without blocking.\n\n    The query must have already been sent to the server, so pgconn.flush() has\n    already returned 0.\n\n    Return a result from the database (whether success or error).\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_24fetch = {"fetch", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_24fetch, METH_O, __pyx_doc_9psycopg_c_8_psycopg_23fetch};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_24fetch(PyObject *__pyx_self, PyObject *__pyx_v_pgconn) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fetch (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pgconn), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn, 1, "pgconn", 0))) __PYX_ERR(8, 218, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_23fetch(__pyx_self, ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_v_pgconn));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  goto __pyx_L5_cleaned_up;
  __pyx_L0:;
  __pyx_L5_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23fetch(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("fetch", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 218, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_pgconn = __pyx_v_pgconn;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_25generator5, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_fetch, __pyx_mstate_global->__pyx_n_u_fetch, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.fetch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_25generator5(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PGconn *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  size_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("fetch", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L10_resume_from_yield;
    case 2: goto __pyx_L24_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 218, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":227
 *     Return a result from the database (whether success or error).
 *     """
 *     cdef libpq.PGconn *pgconn_ptr = pgconn._pgconn_ptr             # <<<<<<<<<<<<<<
 *     cdef int cires, ibres
 *     cdef libpq.PGresult *pgres
*/
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_pgconn->_pgconn_ptr;
  __pyx_cur_scope->__pyx_v_pgconn_ptr = __pyx_t_1;

  /* "psycopg_c/_psycopg/generators.pyx":232
 *     cdef object ready
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         ibres = libpq.PQisBusy(pgconn_ptr)
 *     if ibres:
*/
  {
      PyThreadState * _save;
      _save = PyEval_SaveThread();
      __Pyx_FastGIL_Remember();
      /*try:*/ {

        /* "psycopg_c/_psycopg/generators.pyx":233
 * 
 *     with nogil:
 *         ibres = libpq.PQisBusy(pgconn_ptr)             # <<<<<<<<<<<<<<
 *     if ibres:
 *         while True:
*/
        __pyx_cur_scope->__pyx_v_ibres = PQisBusy(__pyx_cur_scope->__pyx_v_pgconn_ptr);
      }

      /* "psycopg_c/_psycopg/generators.pyx":232
 *     cdef object ready
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         ibres = libpq.PQisBusy(pgconn_ptr)
 *     if ibres:
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_FastGIL_Forget();
          PyEval_RestoreThread(_save);
          goto __pyx_L6;
        }
        __pyx_L6:;
      }
  }

  /* "psycopg_c/_psycopg/generators.pyx":234
 *     with nogil:
 *         ibres = libpq.PQisBusy(pgconn_ptr)
 *     if ibres:             # <<<<<<<<<<<<<<
 *         while True:
 *             ready = yield WAIT_R
*/
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_ibres != 0);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/generators.pyx":235
 *         ibres = libpq.PQisBusy(pgconn_ptr)
 *     if ibres:
 *         while True:             # <<<<<<<<<<<<<<
 *             ready = yield WAIT_R
 *             if ready:
*/
    while (1) {

      /* "psycopg_c/_psycopg/generators.pyx":236
 *     if ibres:
 *         while True:
 *             ready = yield WAIT_R             # <<<<<<<<<<<<<<
 *             if ready:
 *                 break
*/
      __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_R);
      __pyx_r = __pyx_v_9psycopg_c_8_psycopg_WAIT_R;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L10_resume_from_yield:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 236, __pyx_L1_error)
      __pyx_t_3 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_ready);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_ready, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":237
 *         while True:
 *             ready = yield WAIT_R
 *             if ready:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ready); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(8, 237, __pyx_L1_error)
      if (__pyx_t_2) {

        /* "psycopg_c/_psycopg/generators.pyx":238
 *             ready = yield WAIT_R
 *             if ready:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         while True:
*/
        goto __pyx_L9_break;

        /* "psycopg_c/_psycopg/generators.pyx":237
 *         while True:
 *             ready = yield WAIT_R
 *             if ready:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      }
    }
    __pyx_L9_break:;

    /* "psycopg_c/_psycopg/generators.pyx":240
 *                 break
 * 
 *         while True:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
*/
    while (1) {

      /* "psycopg_c/_psycopg/generators.pyx":241
 * 
 *         while True:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *                 if cires == 1:
*/
      {
          PyThreadState * _save;
          _save = PyEval_SaveThread();
          __Pyx_FastGIL_Remember();
          /*try:*/ {

            /* "psycopg_c/_psycopg/generators.pyx":242
 *         while True:
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)             # <<<<<<<<<<<<<<
 *                 if cires == 1:
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
*/
            __pyx_cur_scope->__pyx_v_cires = PQconsumeInput(__pyx_cur_scope->__pyx_v_pgconn_ptr);

            /* "psycopg_c/_psycopg/generators.pyx":243
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *                 if cires == 1:             # <<<<<<<<<<<<<<
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 * 
*/
            __pyx_t_2 = (__pyx_cur_scope->__pyx_v_cires == 1);
            if (__pyx_t_2) {

              /* "psycopg_c/_psycopg/generators.pyx":244
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *                 if cires == 1:
 *                     ibres = libpq.PQisBusy(pgconn_ptr)             # <<<<<<<<<<<<<<
 * 
 *             if 1 != cires:
*/
              __pyx_cur_scope->__pyx_v_ibres = PQisBusy(__pyx_cur_scope->__pyx_v_pgconn_ptr);

              /* "psycopg_c/_psycopg/generators.pyx":243
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *                 if cires == 1:             # <<<<<<<<<<<<<<
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 * 
*/
            }
          }

          /* "psycopg_c/_psycopg/generators.pyx":241
 * 
 *         while True:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *                 if cires == 1:
*/
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_FastGIL_Forget();
              PyEval_RestoreThread(_save);
              goto __pyx_L18;
            }
            __pyx_L18:;
          }
      }

      /* "psycopg_c/_psycopg/generators.pyx":246
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 * 
 *             if 1 != cires:             # <<<<<<<<<<<<<<
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
*/
      __pyx_t_2 = (1 != __pyx_cur_scope->__pyx_v_cires);
      if (unlikely(__pyx_t_2)) {

        /* "psycopg_c/_psycopg/generators.pyx":247
 * 
 *             if 1 != cires:
 *                 raise e.OperationalError(             # <<<<<<<<<<<<<<
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 *             if not ibres:
*/
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 247, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 247, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "psycopg_c/_psycopg/generators.pyx":248
 *             if 1 != cires:
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")             # <<<<<<<<<<<<<<
 *             if not ibres:
 *                 break
*/
        __pyx_t_7 = ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
        __Pyx_INCREF(__pyx_t_7);
        __pyx_t_8 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_7, NULL};
          __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_error_message, __pyx_callargs+__pyx_t_8, (1-__pyx_t_8) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 248, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_5);
        }
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(8, 248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_consuming_input_failed, __pyx_t_7); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 248, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __pyx_t_8 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_6))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
          __pyx_t_8 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
          __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 247, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
        }
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __PYX_ERR(8, 247, __pyx_L1_error)

        /* "psycopg_c/_psycopg/generators.pyx":246
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 * 
 *             if 1 != cires:             # <<<<<<<<<<<<<<
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":249
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 *             if not ibres:             # <<<<<<<<<<<<<<
 *                 break
 *             while True:
*/
      __pyx_t_2 = (!(__pyx_cur_scope->__pyx_v_ibres != 0));
      if (__pyx_t_2) {

        /* "psycopg_c/_psycopg/generators.pyx":250
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 *             if not ibres:
 *                 break             # <<<<<<<<<<<<<<
 *             while True:
 *                 ready = yield WAIT_R
*/
        goto __pyx_L13_break;

        /* "psycopg_c/_psycopg/generators.pyx":249
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 *             if not ibres:             # <<<<<<<<<<<<<<
 *                 break
 *             while True:
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":251
 *             if not ibres:
 *                 break
 *             while True:             # <<<<<<<<<<<<<<
 *                 ready = yield WAIT_R
 *                 if ready:
*/
      while (1) {

        /* "psycopg_c/_psycopg/generators.pyx":252
 *                 break
 *             while True:
 *                 ready = yield WAIT_R             # <<<<<<<<<<<<<<
 *                 if ready:
 *                     break
*/
        __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_R);
        __pyx_r = __pyx_v_9psycopg_c_8_psycopg_WAIT_R;
        __Pyx_XGIVEREF(__pyx_r);
        __Pyx_RefNannyFinishContext();
        __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
        /* return from generator, yielding value */
        __pyx_generator->resume_label = 2;
        return __pyx_r;
        __pyx_L24_resume_from_yield:;
        if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 252, __pyx_L1_error)
        __pyx_t_3 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_3);
        __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_ready);
        __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_ready, __pyx_t_3);
        __Pyx_GIVEREF(__pyx_t_3);
        __pyx_t_3 = 0;

        /* "psycopg_c/_psycopg/generators.pyx":253
 *             while True:
 *                 ready = yield WAIT_R
 *                 if ready:             # <<<<<<<<<<<<<<
 *                     break
 * 
*/
        __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_ready); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(8, 253, __pyx_L1_error)
        if (__pyx_t_2) {

          /* "psycopg_c/_psycopg/generators.pyx":254
 *                 ready = yield WAIT_R
 *                 if ready:
 *                     break             # <<<<<<<<<<<<<<
 * 
 *     _consume_notifies(pgconn)
*/
          goto __pyx_L23_break;

          /* "psycopg_c/_psycopg/generators.pyx":253
 *             while True:
 *                 ready = yield WAIT_R
 *                 if ready:             # <<<<<<<<<<<<<<
 *                     break
 * 
*/
        }
      }
      __pyx_L23_break:;
    }
    __pyx_L13_break:;

    /* "psycopg_c/_psycopg/generators.pyx":234
 *     with nogil:
 *         ibres = libpq.PQisBusy(pgconn_ptr)
 *     if ibres:             # <<<<<<<<<<<<<<
 *         while True:
 *             ready = yield WAIT_R
*/
  }

  /* "psycopg_c/_psycopg/generators.pyx":256
 *                     break
 * 
 *     _consume_notifies(pgconn)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
*/
  __pyx_t_9 = __pyx_f_9psycopg_c_8_psycopg__consume_notifies(__pyx_cur_scope->__pyx_v_pgconn); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(8, 256, __pyx_L1_error)

  /* "psycopg_c/_psycopg/generators.pyx":258
 *     _consume_notifies(pgconn)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         pgres = libpq.PQgetResult(pgconn_ptr)
 *     if pgres is NULL:
*/
  {
      PyThreadState * _save;
      _save = PyEval_SaveThread();
      __Pyx_FastGIL_Remember();
      /*try:*/ {

        /* "psycopg_c/_psycopg/generators.pyx":259
 * 
 *     with nogil:
 *         pgres = libpq.PQgetResult(pgconn_ptr)             # <<<<<<<<<<<<<<
 *     if pgres is NULL:
 *         return None
*/
        __pyx_cur_scope->__pyx_v_pgres = PQgetResult(__pyx_cur_scope->__pyx_v_pgconn_ptr);
      }

      /* "psycopg_c/_psycopg/generators.pyx":258
 *     _consume_notifies(pgconn)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         pgres = libpq.PQgetResult(pgconn_ptr)
 *     if pgres is NULL:
*/
      /*finally:*/ {
        /*normal exit:*/{
          __Pyx_FastGIL_Forget();
          PyEval_RestoreThread(_save);
          goto __pyx_L28;
        }
        __pyx_L28:;
      }
  }

  /* "psycopg_c/_psycopg/generators.pyx":260
 *     with nogil:
 *         pgres = libpq.PQgetResult(pgconn_ptr)
 *     if pgres is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return pq.PGresult._from_ptr(pgres)
*/
  __pyx_t_2 = (__pyx_cur_scope->__pyx_v_pgres == NULL);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/generators.pyx":261
 *         pgres = libpq.PQgetResult(pgconn_ptr)
 *     if pgres is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return pq.PGresult._from_ptr(pgres)
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/generators.pyx":260
 *     with nogil:
 *         pgres = libpq.PQgetResult(pgconn_ptr)
 *     if pgres is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return pq.PGresult._from_ptr(pgres)
*/
  }

  /* "psycopg_c/_psycopg/generators.pyx":262
 *     if pgres is NULL:
 *         return None
 *     return pq.PGresult._from_ptr(pgres)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = ((PyObject *)__pyx_vtabptr_9psycopg_c_2pq_PGresult->_from_ptr(__pyx_cur_scope->__pyx_v_pgres)); if (unlikely(!__pyx_t_3)) __PYX_ERR(8, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":218
 * 
 * 
 * def fetch(pq.PGconn pgconn) -> PQGen[PGresult | None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving a single result from the database without blocking.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("fetch", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static PyObject *__pyx_gb_9psycopg_c_8_psycopg_28generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value); /* proto */

/* "psycopg_c/_psycopg/generators.pyx":265
 * 
 * 
 * def pipeline_communicate(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, commands: deque[PipelineCommand]
 * ) -> PQGen[list[list[PGresult]]]:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_27pipeline_communicate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_26pipeline_communicate, "Generator to send queries from a connection in pipeline mode while also\n    receiving results.\n\n    Return a list results, including single PIPELINE_SYNC elements.\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_27pipeline_communicate = {"pipeline_communicate", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_27pipeline_communicate, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9psycopg_c_8_psycopg_26pipeline_communicate};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_27pipeline_communicate(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn = 0;
  PyObject *__pyx_v_commands = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pipeline_communicate (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pgconn,&__pyx_mstate_global->__pyx_n_u_commands,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(8, 265, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(8, 265, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(8, 265, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "pipeline_communicate", 0) < (0)) __PYX_ERR(8, 265, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("pipeline_communicate", 1, 2, 2, i); __PYX_ERR(8, 265, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(8, 265, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(8, 265, __pyx_L3_error)
    }
    __pyx_v_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)values[0]);
    __pyx_v_commands = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("pipeline_communicate", 1, 2, 2, __pyx_nargs); __PYX_ERR(8, 265, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.pipeline_communicate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_pgconn), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGconn, 1, "pgconn", 0))) __PYX_ERR(8, 266, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_26pipeline_communicate(__pyx_self, __pyx_v_pgconn, __pyx_v_commands);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_26pipeline_communicate(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn, PyObject *__pyx_v_commands) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *__pyx_cur_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pipeline_communicate", 0);
  __pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate, __pyx_mstate_global->__pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *)Py_None);
    __Pyx_INCREF(Py_None);
    __PYX_ERR(8, 265, __pyx_L1_error)
  } else {
    __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
  }
  __pyx_cur_scope->__pyx_v_pgconn = __pyx_v_pgconn;
  __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
  __pyx_cur_scope->__pyx_v_commands = __pyx_v_commands;
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_commands);
  __Pyx_GIVEREF(__pyx_cur_scope->__pyx_v_commands);
  {
    __pyx_CoroutineObject *gen = __Pyx_Generator_New((__pyx_coroutine_body_t) __pyx_gb_9psycopg_c_8_psycopg_28generator6, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7]), (PyObject *) __pyx_cur_scope, __pyx_mstate_global->__pyx_n_u_pipeline_communicate, __pyx_mstate_global->__pyx_n_u_pipeline_communicate, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg); if (unlikely(!gen)) __PYX_ERR(8, 265, __pyx_L1_error)
    __Pyx_DECREF(__pyx_cur_scope);
    __Pyx_RefNannyFinishContext();
    return (PyObject *) gen;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.pipeline_communicate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_DECREF((PyObject *)__pyx_cur_scope);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_gb_9psycopg_c_8_psycopg_28generator6(__pyx_CoroutineObject *__pyx_generator, CYTHON_UNUSED PyThreadState *__pyx_tstate, PyObject *__pyx_sent_value) /* generator body */
{
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *__pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *)__pyx_generator->closure);
  PyObject *__pyx_r = NULL;
  PGconn *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  size_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("pipeline_communicate", 0);
  switch (__pyx_generator->resume_label) {
    case 0: goto __pyx_L3_first_run;
    case 1: goto __pyx_L8_resume_from_yield;
    default: /* CPython raises the right error here */
    __Pyx_RefNannyFinishContext();
    return NULL;
  }
  __pyx_L3_first_run:;
  if (unlikely(__pyx_sent_value != Py_None)) {
    if (unlikely(__pyx_sent_value)) PyErr_SetString(PyExc_TypeError, "can't send non-None value to a just-started generator");
    __PYX_ERR(8, 265, __pyx_L1_error)
  }

  /* "psycopg_c/_psycopg/generators.pyx":273
 *     Return a list results, including single PIPELINE_SYNC elements.
 *     """
 *     cdef libpq.PGconn *pgconn_ptr = pgconn._pgconn_ptr             # <<<<<<<<<<<<<<
 *     cdef int cires
 *     cdef int status
*/
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_pgconn->_pgconn_ptr;
  __pyx_cur_scope->__pyx_v_pgconn_ptr = __pyx_t_1;

  /* "psycopg_c/_psycopg/generators.pyx":278
 *     cdef int cready
 *     cdef libpq.PGresult *pgres
 *     cdef list res = []             # <<<<<<<<<<<<<<
 *     cdef list results = []
 *     cdef pq.PGresult r
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 278, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_res = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":279
 *     cdef libpq.PGresult *pgres
 *     cdef list res = []
 *     cdef list results = []             # <<<<<<<<<<<<<<
 *     cdef pq.PGresult r
 * 
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_cur_scope->__pyx_v_results = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":282
 *     cdef pq.PGresult r
 * 
 *     while True:             # <<<<<<<<<<<<<<
 *         while True:
 *             # I don't quite get why, but we can receive a None upon async
*/
  while (1) {

    /* "psycopg_c/_psycopg/generators.pyx":283
 * 
 *     while True:
 *         while True:             # <<<<<<<<<<<<<<
 *             # I don't quite get why, but we can receive a None upon async
 *             # task cancellation. See #1005.
*/
    while (1) {

      /* "psycopg_c/_psycopg/generators.pyx":286
 *             # I don't quite get why, but we can receive a None upon async
 *             # task cancellation. See #1005.
 *             ready = yield WAIT_RW             # <<<<<<<<<<<<<<
 *             if ready is None:
 *                 continue
*/
      __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_RW);
      __pyx_r = __pyx_v_9psycopg_c_8_psycopg_WAIT_RW;
      __Pyx_XGIVEREF(__pyx_r);
      __Pyx_RefNannyFinishContext();
      __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
      /* return from generator, yielding value */
      __pyx_generator->resume_label = 1;
      return __pyx_r;
      __pyx_L8_resume_from_yield:;
      if (unlikely(!__pyx_sent_value)) __PYX_ERR(8, 286, __pyx_L1_error)
      __pyx_t_2 = __pyx_sent_value; __Pyx_INCREF(__pyx_t_2);
      __Pyx_XGOTREF(__pyx_cur_scope->__pyx_v_ready);
      __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_ready, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":287
 *             # task cancellation. See #1005.
 *             ready = yield WAIT_RW
 *             if ready is None:             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
      __pyx_t_3 = (__pyx_cur_scope->__pyx_v_ready == Py_None);
      if (__pyx_t_3) {

        /* "psycopg_c/_psycopg/generators.pyx":288
 *             ready = yield WAIT_RW
 *             if ready is None:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             cready = ready
*/
        goto __pyx_L6_continue;

        /* "psycopg_c/_psycopg/generators.pyx":287
 *             # task cancellation. See #1005.
 *             ready = yield WAIT_RW
 *             if ready is None:             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":290
 *                 continue
 * 
 *             cready = ready             # <<<<<<<<<<<<<<
 *             if cready:
 *                 break
*/
      __pyx_t_4 = __Pyx_PyLong_As_int(__pyx_cur_scope->__pyx_v_ready); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(8, 290, __pyx_L1_error)
      __pyx_cur_scope->__pyx_v_cready = __pyx_t_4;

      /* "psycopg_c/_psycopg/generators.pyx":291
 * 
 *             cready = ready
 *             if cready:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      __pyx_t_3 = (__pyx_cur_scope->__pyx_v_cready != 0);
      if (__pyx_t_3) {

        /* "psycopg_c/_psycopg/generators.pyx":292
 *             cready = ready
 *             if cready:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         if cready & READY_R:
*/
        goto __pyx_L7_break;

        /* "psycopg_c/_psycopg/generators.pyx":291
 * 
 *             cready = ready
 *             if cready:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
      }
      __pyx_L6_continue:;
    }
    __pyx_L7_break:;

    /* "psycopg_c/_psycopg/generators.pyx":294
 *                 break
 * 
 *         if cready & READY_R:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
*/
    __pyx_t_3 = ((__pyx_cur_scope->__pyx_v_cready & __pyx_v_9psycopg_c_8_psycopg_READY_R) != 0);
    if (__pyx_t_3) {

      /* "psycopg_c/_psycopg/generators.pyx":295
 * 
 *         if cready & READY_R:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:
*/
      {
          PyThreadState * _save;
          _save = PyEval_SaveThread();
          __Pyx_FastGIL_Remember();
          /*try:*/ {

            /* "psycopg_c/_psycopg/generators.pyx":296
 *         if cready & READY_R:
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)             # <<<<<<<<<<<<<<
 *             if 1 != cires:
 *                 raise e.OperationalError(
*/
            __pyx_cur_scope->__pyx_v_cires = PQconsumeInput(__pyx_cur_scope->__pyx_v_pgconn_ptr);
          }

          /* "psycopg_c/_psycopg/generators.pyx":295
 * 
 *         if cready & READY_R:
 *             with nogil:             # <<<<<<<<<<<<<<
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:
*/
          /*finally:*/ {
            /*normal exit:*/{
              __Pyx_FastGIL_Forget();
              PyEval_RestoreThread(_save);
              goto __pyx_L16;
            }
            __pyx_L16:;
          }
      }

      /* "psycopg_c/_psycopg/generators.pyx":297
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:             # <<<<<<<<<<<<<<
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
*/
      __pyx_t_3 = (1 != __pyx_cur_scope->__pyx_v_cires);
      if (unlikely(__pyx_t_3)) {

        /* "psycopg_c/_psycopg/generators.pyx":298
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:
 *                 raise e.OperationalError(             # <<<<<<<<<<<<<<
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 * 
*/
        __pyx_t_5 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_7)) __PYX_ERR(8, 298, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

        /* "psycopg_c/_psycopg/generators.pyx":299
 *             if 1 != cires:
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")             # <<<<<<<<<<<<<<
 * 
 *             _consume_notifies(pgconn)
*/
        __pyx_t_8 = ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
        __Pyx_INCREF(__pyx_t_8);
        __pyx_t_9 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_8, NULL};
          __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_error_message, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
          if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 299, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
        }
        __pyx_t_8 = __Pyx_PyObject_FormatSimple(__pyx_t_6, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(8, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_consuming_input_failed, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 299, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __pyx_t_9 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_5);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_5);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_9 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 298, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(8, 298, __pyx_L1_error)

        /* "psycopg_c/_psycopg/generators.pyx":297
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
 *             if 1 != cires:             # <<<<<<<<<<<<<<
 *                 raise e.OperationalError(
 *                     f"consuming input failed: {pgconn.get_error_message()}")
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":301
 *                     f"consuming input failed: {pgconn.get_error_message()}")
 * 
 *             _consume_notifies(pgconn)             # <<<<<<<<<<<<<<
 * 
 *             res: list[PGresult] = []
*/
      __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__consume_notifies(__pyx_cur_scope->__pyx_v_pgconn); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(8, 301, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":303
 *             _consume_notifies(pgconn)
 * 
 *             res: list[PGresult] = []             # <<<<<<<<<<<<<<
 *             while True:
 *                 with nogil:
*/
      __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 303, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_res);
      __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_res, ((PyObject*)__pyx_t_2));
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":304
 * 
 *             res: list[PGresult] = []
 *             while True:             # <<<<<<<<<<<<<<
 *                 with nogil:
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
*/
      while (1) {

        /* "psycopg_c/_psycopg/generators.pyx":305
 *             res: list[PGresult] = []
 *             while True:
 *                 with nogil:             # <<<<<<<<<<<<<<
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 *                     if ibres:
*/
        {
            PyThreadState * _save;
            _save = PyEval_SaveThread();
            __Pyx_FastGIL_Remember();
            /*try:*/ {

              /* "psycopg_c/_psycopg/generators.pyx":306
 *             while True:
 *                 with nogil:
 *                     ibres = libpq.PQisBusy(pgconn_ptr)             # <<<<<<<<<<<<<<
 *                     if ibres:
 *                         break
*/
              __pyx_cur_scope->__pyx_v_ibres = PQisBusy(__pyx_cur_scope->__pyx_v_pgconn_ptr);

              /* "psycopg_c/_psycopg/generators.pyx":307
 *                 with nogil:
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 *                     if ibres:             # <<<<<<<<<<<<<<
 *                         break
 *                     pgres = libpq.PQgetResult(pgconn_ptr)
*/
              __pyx_t_3 = (__pyx_cur_scope->__pyx_v_ibres != 0);
              if (__pyx_t_3) {

                /* "psycopg_c/_psycopg/generators.pyx":308
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 *                     if ibres:
 *                         break             # <<<<<<<<<<<<<<
 *                     pgres = libpq.PQgetResult(pgconn_ptr)
 * 
*/
                goto __pyx_L21_break;

                /* "psycopg_c/_psycopg/generators.pyx":307
 *                 with nogil:
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 *                     if ibres:             # <<<<<<<<<<<<<<
 *                         break
 *                     pgres = libpq.PQgetResult(pgconn_ptr)
*/
              }

              /* "psycopg_c/_psycopg/generators.pyx":309
 *                     if ibres:
 *                         break
 *                     pgres = libpq.PQgetResult(pgconn_ptr)             # <<<<<<<<<<<<<<
 * 
 *                 if pgres is NULL:
*/
              __pyx_cur_scope->__pyx_v_pgres = PQgetResult(__pyx_cur_scope->__pyx_v_pgconn_ptr);
            }

            /* "psycopg_c/_psycopg/generators.pyx":305
 *             res: list[PGresult] = []
 *             while True:
 *                 with nogil:             # <<<<<<<<<<<<<<
 *                     ibres = libpq.PQisBusy(pgconn_ptr)
 *                     if ibres:
*/
            /*finally:*/ {
              /*normal exit:*/{
                __Pyx_FastGIL_Forget();
                PyEval_RestoreThread(_save);
                goto __pyx_L24;
              }
              __pyx_L21_break: {
                __Pyx_FastGIL_Forget();
                PyEval_RestoreThread(_save);
                goto __pyx_L19_break;
              }
              __pyx_L24:;
            }
        }

        /* "psycopg_c/_psycopg/generators.pyx":311
 *                     pgres = libpq.PQgetResult(pgconn_ptr)
 * 
 *                 if pgres is NULL:             # <<<<<<<<<<<<<<
 *                     if not res:
 *                         break
*/
        __pyx_t_3 = (__pyx_cur_scope->__pyx_v_pgres == NULL);
        if (__pyx_t_3) {

          /* "psycopg_c/_psycopg/generators.pyx":312
 * 
 *                 if pgres is NULL:
 *                     if not res:             # <<<<<<<<<<<<<<
 *                         break
 *                     results.append(res)
*/
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_cur_scope->__pyx_v_res);
            if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(8, 312, __pyx_L1_error)
            __pyx_t_3 = (__pyx_temp != 0);
          }

          __pyx_t_10 = (!__pyx_t_3);
          if (__pyx_t_10) {

            /* "psycopg_c/_psycopg/generators.pyx":313
 *                 if pgres is NULL:
 *                     if not res:
 *                         break             # <<<<<<<<<<<<<<
 *                     results.append(res)
 *                     res = []
*/
            goto __pyx_L19_break;

            /* "psycopg_c/_psycopg/generators.pyx":312
 * 
 *                 if pgres is NULL:
 *                     if not res:             # <<<<<<<<<<<<<<
 *                         break
 *                     results.append(res)
*/
          }

          /* "psycopg_c/_psycopg/generators.pyx":314
 *                     if not res:
 *                         break
 *                     results.append(res)             # <<<<<<<<<<<<<<
 *                     res = []
 *                 else:
*/
          __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_results, __pyx_cur_scope->__pyx_v_res); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(8, 314, __pyx_L1_error)

          /* "psycopg_c/_psycopg/generators.pyx":315
 *                         break
 *                     results.append(res)
 *                     res = []             # <<<<<<<<<<<<<<
 *                 else:
 *                     status = libpq.PQresultStatus(pgres)
*/
          __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 315, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_GOTREF(__pyx_cur_scope->__pyx_v_res);
          __Pyx_DECREF_SET(__pyx_cur_scope->__pyx_v_res, ((PyObject*)__pyx_t_2));
          __Pyx_GIVEREF(__pyx_t_2);
          __pyx_t_2 = 0;

          /* "psycopg_c/_psycopg/generators.pyx":311
 *                     pgres = libpq.PQgetResult(pgconn_ptr)
 * 
 *                 if pgres is NULL:             # <<<<<<<<<<<<<<
 *                     if not res:
 *                         break
*/
          goto __pyx_L26;
        }

        /* "psycopg_c/_psycopg/generators.pyx":317
 *                     res = []
 *                 else:
 *                     status = libpq.PQresultStatus(pgres)             # <<<<<<<<<<<<<<
 *                     r = pq.PGresult._from_ptr(pgres)
 *                     if status == libpq.PGRES_PIPELINE_SYNC:
*/
        /*else*/ {
          __pyx_cur_scope->__pyx_v_status = PQresultStatus(__pyx_cur_scope->__pyx_v_pgres);

          /* "psycopg_c/_psycopg/generators.pyx":318
 *                 else:
 *                     status = libpq.PQresultStatus(pgres)
 *                     r = pq.PGresult._from_ptr(pgres)             # <<<<<<<<<<<<<<
 *                     if status == libpq.PGRES_PIPELINE_SYNC:
 *                         results.append([r])
*/
          __pyx_t_2 = ((PyObject *)__pyx_vtabptr_9psycopg_c_2pq_PGresult->_from_ptr(__pyx_cur_scope->__pyx_v_pgres)); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 318, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_XGOTREF((PyObject *)__pyx_cur_scope->__pyx_v_r);
          __Pyx_XDECREF_SET(__pyx_cur_scope->__pyx_v_r, ((struct __pyx_obj_9psycopg_c_2pq_PGresult *)__pyx_t_2));
          __Pyx_GIVEREF(__pyx_t_2);
          __pyx_t_2 = 0;

          /* "psycopg_c/_psycopg/generators.pyx":319
 *                     status = libpq.PQresultStatus(pgres)
 *                     r = pq.PGresult._from_ptr(pgres)
 *                     if status == libpq.PGRES_PIPELINE_SYNC:             # <<<<<<<<<<<<<<
 *                         results.append([r])
 *                     elif (
*/
          switch (__pyx_cur_scope->__pyx_v_status) {
            case PGRES_PIPELINE_SYNC:

            /* "psycopg_c/_psycopg/generators.pyx":320
 *                     r = pq.PGresult._from_ptr(pgres)
 *                     if status == libpq.PGRES_PIPELINE_SYNC:
 *                         results.append([r])             # <<<<<<<<<<<<<<
 *                     elif (
 *                         status == libpq.PGRES_COPY_IN
*/
            __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 320, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
            __Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_r);
            __Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_r);
            if (__Pyx_PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_cur_scope->__pyx_v_r)) != (0)) __PYX_ERR(8, 320, __pyx_L1_error);
            __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_results, __pyx_t_2); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(8, 320, __pyx_L1_error)
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

            /* "psycopg_c/_psycopg/generators.pyx":319
 *                     status = libpq.PQresultStatus(pgres)
 *                     r = pq.PGresult._from_ptr(pgres)
 *                     if status == libpq.PGRES_PIPELINE_SYNC:             # <<<<<<<<<<<<<<
 *                         results.append([r])
 *                     elif (
*/
            break;
            case PGRES_COPY_IN:

            /* "psycopg_c/_psycopg/generators.pyx":322
 *                         results.append([r])
 *                     elif (
 *                         status == libpq.PGRES_COPY_IN             # <<<<<<<<<<<<<<
 *                         or status == libpq.PGRES_COPY_OUT
 *                         or status == libpq.PGRES_COPY_BOTH
*/
            case PGRES_COPY_OUT:

            /* "psycopg_c/_psycopg/generators.pyx":323
 *                     elif (
 *                         status == libpq.PGRES_COPY_IN
 *                         or status == libpq.PGRES_COPY_OUT             # <<<<<<<<<<<<<<
 *                         or status == libpq.PGRES_COPY_BOTH
 *                     ):
*/
            case PGRES_COPY_BOTH:

            /* "psycopg_c/_psycopg/generators.pyx":331
 *                         # prepared statements).
 *                         # Bail out from the resulting infinite loop.
 *                         raise e.NotSupportedError(             # <<<<<<<<<<<<<<
 *                             "COPY cannot be used in pipeline mode"
 *                         )
*/
            __pyx_t_7 = NULL;
            __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 331, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_6);
            __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_NotSupportedError); if (unlikely(!__pyx_t_5)) __PYX_ERR(8, 331, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_5);
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __pyx_t_9 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_5))) {
              __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
              assert(__pyx_t_7);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
              __Pyx_INCREF(__pyx_t_7);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
              __pyx_t_9 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_mstate_global->__pyx_kp_u_COPY_cannot_be_used_in_pipeline};
              __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
              __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 331, __pyx_L1_error)
              __Pyx_GOTREF(__pyx_t_2);
            }
            __Pyx_Raise(__pyx_t_2, 0, 0, 0);
            __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
            __PYX_ERR(8, 331, __pyx_L1_error)

            /* "psycopg_c/_psycopg/generators.pyx":321
 *                     if status == libpq.PGRES_PIPELINE_SYNC:
 *                         results.append([r])
 *                     elif (             # <<<<<<<<<<<<<<
 *                         status == libpq.PGRES_COPY_IN
 *                         or status == libpq.PGRES_COPY_OUT
*/
            break;
            default:

            /* "psycopg_c/_psycopg/generators.pyx":335
 *                         )
 *                     else:
 *                         res.append(r)             # <<<<<<<<<<<<<<
 * 
 *         if cready & READY_W:
*/
            __pyx_t_11 = __Pyx_PyList_Append(__pyx_cur_scope->__pyx_v_res, ((PyObject *)__pyx_cur_scope->__pyx_v_r)); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(8, 335, __pyx_L1_error)
            break;
          }
        }
        __pyx_L26:;
      }
      __pyx_L19_break:;

      /* "psycopg_c/_psycopg/generators.pyx":294
 *                 break
 * 
 *         if cready & READY_R:             # <<<<<<<<<<<<<<
 *             with nogil:
 *                 cires = libpq.PQconsumeInput(pgconn_ptr)
*/
    }

    /* "psycopg_c/_psycopg/generators.pyx":337
 *                         res.append(r)
 * 
 *         if cready & READY_W:             # <<<<<<<<<<<<<<
 *             pgconn.flush()
 *             if not commands:
*/
    __pyx_t_10 = ((__pyx_cur_scope->__pyx_v_cready & __pyx_v_9psycopg_c_8_psycopg_READY_W) != 0);
    if (__pyx_t_10) {

      /* "psycopg_c/_psycopg/generators.pyx":338
 * 
 *         if cready & READY_W:
 *             pgconn.flush()             # <<<<<<<<<<<<<<
 *             if not commands:
 *                 break
*/
      __pyx_t_4 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn *)__pyx_cur_scope->__pyx_v_pgconn->__pyx_vtab)->flush(__pyx_cur_scope->__pyx_v_pgconn, 0); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(8, 338, __pyx_L1_error)

      /* "psycopg_c/_psycopg/generators.pyx":339
 *         if cready & READY_W:
 *             pgconn.flush()
 *             if not commands:             # <<<<<<<<<<<<<<
 *                 break
 *             commands.popleft()()
*/
      __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_cur_scope->__pyx_v_commands); if (unlikely((__pyx_t_10 < 0))) __PYX_ERR(8, 339, __pyx_L1_error)
      __pyx_t_3 = (!__pyx_t_10);
      if (__pyx_t_3) {

        /* "psycopg_c/_psycopg/generators.pyx":340
 *             pgconn.flush()
 *             if not commands:
 *                 break             # <<<<<<<<<<<<<<
 *             commands.popleft()()
 * 
*/
        goto __pyx_L5_break;

        /* "psycopg_c/_psycopg/generators.pyx":339
 *         if cready & READY_W:
 *             pgconn.flush()
 *             if not commands:             # <<<<<<<<<<<<<<
 *                 break
 *             commands.popleft()()
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":341
 *             if not commands:
 *                 break
 *             commands.popleft()()             # <<<<<<<<<<<<<<
 * 
 *     return results
*/
      __pyx_t_5 = NULL;
      __pyx_t_6 = __pyx_cur_scope->__pyx_v_commands;
      __Pyx_INCREF(__pyx_t_6);
      __pyx_t_9 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
        __pyx_t_7 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_popleft, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_7)) __PYX_ERR(8, 341, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
      }
      __pyx_t_9 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_7))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
        __pyx_t_9 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 341, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":337
 *                         res.append(r)
 * 
 *         if cready & READY_W:             # <<<<<<<<<<<<<<
 *             pgconn.flush()
 *             if not commands:
*/
    }
  }
  __pyx_L5_break:;

  /* "psycopg_c/_psycopg/generators.pyx":343
 *             commands.popleft()()
 * 
 *     return results             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_cur_scope->__pyx_v_results);
  __pyx_r = __pyx_cur_scope->__pyx_v_results;
  goto __pyx_L0;
  CYTHON_MAYBE_UNUSED_VAR(__pyx_cur_scope);

  /* "psycopg_c/_psycopg/generators.pyx":265
 * 
 * 
 * def pipeline_communicate(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, commands: deque[PipelineCommand]
 * ) -> PQGen[list[list[PGresult]]]:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  if (__Pyx_PyErr_Occurred()) {
    __Pyx_Generator_Replace_StopIteration(0);
    __Pyx_AddTraceback("pipeline_communicate", __pyx_clineno, __pyx_lineno, __pyx_filename);
  }
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  #if !CYTHON_USE_EXC_INFO_STACK
  __Pyx_Coroutine_ResetAndClearException(__pyx_generator);
  #endif
  __pyx_generator->resume_label = -1;
  __Pyx_Coroutine_clear((PyObject*)__pyx_generator);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/generators.pyx":346
 * 
 * 
 * cdef int _consume_notifies(pq.PGconn pgconn) except -1:             # <<<<<<<<<<<<<<
 *     cdef object notify_handler = pgconn.notify_handler
 *     cdef libpq.PGconn *pgconn_ptr
*/

static int __pyx_f_9psycopg_c_8_psycopg__consume_notifies(struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
  PyObject *__pyx_v_notify_handler = 0;
  PGconn *__pyx_v_pgconn_ptr;
  PGnotify *__pyx_v_notify;
  PyObject *__pyx_v_pynotify = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PGconn *__pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_consume_notifies", 0);

  /* "psycopg_c/_psycopg/generators.pyx":347
 * 
 * cdef int _consume_notifies(pq.PGconn pgconn) except -1:
 *     cdef object notify_handler = pgconn.notify_handler             # <<<<<<<<<<<<<<
 *     cdef libpq.PGconn *pgconn_ptr
 *     cdef libpq.PGnotify *notify
*/
  __pyx_t_1 = __pyx_v_pgconn->notify_handler;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_notify_handler = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":351
 *     cdef libpq.PGnotify *notify
 * 
 *     if notify_handler is not None:             # <<<<<<<<<<<<<<
 *         while True:
 *             pynotify = pgconn.notifies()
*/
  __pyx_t_2 = (__pyx_v_notify_handler != Py_None);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/generators.pyx":352
 * 
 *     if notify_handler is not None:
 *         while True:             # <<<<<<<<<<<<<<
 *             pynotify = pgconn.notifies()
 *             if pynotify is None:
*/
    while (1) {

      /* "psycopg_c/_psycopg/generators.pyx":353
 *     if notify_handler is not None:
 *         while True:
 *             pynotify = pgconn.notifies()             # <<<<<<<<<<<<<<
 *             if pynotify is None:
 *                 break
*/
      __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn *)__pyx_v_pgconn->__pyx_vtab)->notifies(__pyx_v_pgconn, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 353, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_pynotify, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/generators.pyx":354
 *         while True:
 *             pynotify = pgconn.notifies()
 *             if pynotify is None:             # <<<<<<<<<<<<<<
 *                 break
 *             PyObject_CallFunctionObjArgs(
*/
      __pyx_t_2 = (__pyx_v_pynotify == Py_None);
      if (__pyx_t_2) {

        /* "psycopg_c/_psycopg/generators.pyx":355
 *             pynotify = pgconn.notifies()
 *             if pynotify is None:
 *                 break             # <<<<<<<<<<<<<<
 *             PyObject_CallFunctionObjArgs(
 *                 notify_handler, <PyObject *>pynotify, NULL
*/
        goto __pyx_L5_break;

        /* "psycopg_c/_psycopg/generators.pyx":354
 *         while True:
 *             pynotify = pgconn.notifies()
 *             if pynotify is None:             # <<<<<<<<<<<<<<
 *                 break
 *             PyObject_CallFunctionObjArgs(
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":356
 *             if pynotify is None:
 *                 break
 *             PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 notify_handler, <PyObject *>pynotify, NULL
 *             )
*/
      __pyx_t_1 = PyObject_CallFunctionObjArgs(__pyx_v_notify_handler, ((PyObject *)__pyx_v_pynotify), NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 356, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5_break:;

    /* "psycopg_c/_psycopg/generators.pyx":351
 *     cdef libpq.PGnotify *notify
 * 
 *     if notify_handler is not None:             # <<<<<<<<<<<<<<
 *         while True:
 *             pynotify = pgconn.notifies()
*/
    goto __pyx_L3;
  }

  /* "psycopg_c/_psycopg/generators.pyx":360
 *             )
 *     else:
 *         pgconn_ptr = pgconn._pgconn_ptr             # <<<<<<<<<<<<<<
 *         while True:
 *             notify = libpq.PQnotifies(pgconn_ptr)
*/
  /*else*/ {
    __pyx_t_3 = __pyx_v_pgconn->_pgconn_ptr;
    __pyx_v_pgconn_ptr = __pyx_t_3;

    /* "psycopg_c/_psycopg/generators.pyx":361
 *     else:
 *         pgconn_ptr = pgconn._pgconn_ptr
 *         while True:             # <<<<<<<<<<<<<<
 *             notify = libpq.PQnotifies(pgconn_ptr)
 *             if notify is NULL:
*/
    while (1) {

      /* "psycopg_c/_psycopg/generators.pyx":362
 *         pgconn_ptr = pgconn._pgconn_ptr
 *         while True:
 *             notify = libpq.PQnotifies(pgconn_ptr)             # <<<<<<<<<<<<<<
 *             if notify is NULL:
 *                 break
*/
      __pyx_v_notify = PQnotifies(__pyx_v_pgconn_ptr);

      /* "psycopg_c/_psycopg/generators.pyx":363
 *         while True:
 *             notify = libpq.PQnotifies(pgconn_ptr)
 *             if notify is NULL:             # <<<<<<<<<<<<<<
 *                 break
 *             libpq.PQfreemem(notify)
*/
      __pyx_t_2 = (__pyx_v_notify == NULL);
      if (__pyx_t_2) {

        /* "psycopg_c/_psycopg/generators.pyx":364
 *             notify = libpq.PQnotifies(pgconn_ptr)
 *             if notify is NULL:
 *                 break             # <<<<<<<<<<<<<<
 *             libpq.PQfreemem(notify)
 * 
*/
        goto __pyx_L8_break;

        /* "psycopg_c/_psycopg/generators.pyx":363
 *         while True:
 *             notify = libpq.PQnotifies(pgconn_ptr)
 *             if notify is NULL:             # <<<<<<<<<<<<<<
 *                 break
 *             libpq.PQfreemem(notify)
*/
      }

      /* "psycopg_c/_psycopg/generators.pyx":365
 *             if notify is NULL:
 *                 break
 *             libpq.PQfreemem(notify)             # <<<<<<<<<<<<<<
 * 
 *     return 0
*/
      PQfreemem(__pyx_v_notify);
    }
    __pyx_L8_break:;
  }
  __pyx_L3:;

  /* "psycopg_c/_psycopg/generators.pyx":367
 *             libpq.PQfreemem(notify)
 * 
 *     return 0             # <<<<<<<<<<<<<<
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/generators.pyx":346
 * 
 * 
 * cdef int _consume_notifies(pq.PGconn pgconn) except -1:             # <<<<<<<<<<<<<<
 *     cdef object notify_handler = pgconn.notify_handler
 *     cdef libpq.PGconn *pgconn_ptr
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg._consume_notifies", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_notify_handler);
  __Pyx_XDECREF(__pyx_v_pynotify);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9RowLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9RowLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowLoader___reduce_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.cloader, self.loadfunc, self.pyloader)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self->cloader);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->cloader);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->cloader)) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->loadfunc);
  __Pyx_GIVEREF(__pyx_v_self->loadfunc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->loadfunc) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->pyloader);
  __Pyx_GIVEREF(__pyx_v_self->pyloader);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->pyloader) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.cloader, self.loadfunc, self.pyloader)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.cloader, self.loadfunc, self.pyloader)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(6, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(6, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.cloader is not None or self.loadfunc is not None or self.pyloader is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.cloader, self.loadfunc, self.pyloader)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.cloader is not None or self.loadfunc is not None or self.pyloader is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, None), state
*/
  /*else*/ {
    __pyx_t_3 = (((PyObject *)__pyx_v_self->cloader) != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->loadfunc != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->pyloader != Py_None);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.cloader is not None or self.loadfunc is not None or self.pyloader is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.cloader is not None or self.loadfunc is not None or self.pyloader is not None
 *     if use_setstate:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowLoader); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_172291013);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_172291013);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_172291013) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.cloader is not None or self.loadfunc is not None or self.pyloader is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, None), state
 *     else:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_RowLoader__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowLoader); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_172291013);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_172291013);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_172291013) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg.RowLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RowLoader__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9RowLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9RowLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowLoader_2__setstate_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_RowLoader__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(6, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(6, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowLoader__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RowLoader__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.RowLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9RowDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9RowDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowDumper___reduce_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.cdumper, self.dumpfunc, self.format, self.oid, self.pydumper)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
*/
  __pyx_t_1 = PyTuple_New(5); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF((PyObject *)__pyx_v_self->cdumper);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->cdumper);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->cdumper)) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->dumpfunc);
  __Pyx_GIVEREF(__pyx_v_self->dumpfunc);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_self->dumpfunc) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->format);
  __Pyx_GIVEREF(__pyx_v_self->format);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_self->format) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->oid);
  __Pyx_GIVEREF(__pyx_v_self->oid);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_self->oid) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_self->pydumper);
  __Pyx_GIVEREF(__pyx_v_self->pydumper);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_v_self->pydumper) != (0)) __PYX_ERR(6, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.cdumper, self.dumpfunc, self.format, self.oid, self.pydumper)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None and _dict:
 *         state += (_dict,)
*/
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.cdumper, self.dumpfunc, self.format, self.oid, self.pydumper)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
  __pyx_t_3 = (__pyx_v__dict != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v__dict); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(6, 7, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
*/
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict) != (0)) __PYX_ERR(6, 8, __pyx_L1_error);
    __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
    __pyx_t_4 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None and _dict:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.cdumper is not None or self.dumpfunc is not None or self.format is not None or self.oid is not None or self.pydumper is not None
*/
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.cdumper, self.dumpfunc, self.format, self.oid, self.pydumper)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None and _dict:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
*/
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.cdumper is not None or self.dumpfunc is not None or self.format is not None or self.oid is not None or self.pydumper is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, None), state
*/
  /*else*/ {
    __pyx_t_3 = (((PyObject *)__pyx_v_self->cdumper) != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->dumpfunc != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->format != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->oid != Py_None);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_3 = (__pyx_v_self->pydumper != Py_None);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L6_bool_binop_done:;
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.cdumper is not None or self.dumpfunc is not None or self.format is not None or self.oid is not None or self.pydumper is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, None), state
 *     else:
*/
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.cdumper is not None or self.dumpfunc is not None or self.format is not None or self.oid is not None or self.pydumper is not None
 *     if use_setstate:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, state)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowDumper); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_93828620);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_93828620);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_93828620) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state) != (0)) __PYX_ERR(6, 13, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.cdumper is not None or self.dumpfunc is not None or self.format is not None or self.oid is not None or self.pydumper is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, None), state
 *     else:
*/
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, None), state
 *     else:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_RowDumper__set_state(self, __pyx_state)
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowDumper); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self)))) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_93828620);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_int_93828620);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_mstate_global->__pyx_int_93828620) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1) != (0)) __PYX_ERR(6, 15, __pyx_L1_error);
    __pyx_t_5 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg.RowDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RowDumper__set_state(self, __pyx_state)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9RowDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9RowDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9RowDumper_2__setstate_cython__(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_RowDumper__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
*/
  __pyx_t_1 = __pyx_v___pyx_state;
  __Pyx_INCREF(__pyx_t_1);
  if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(6, 17, __pyx_L1_error)
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(6, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowDumper__set_state(__pyx_v_self, ((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RowDumper__set_state(self, __pyx_state)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.RowDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":100
 *     cdef dict _oid_types
 * 
 *     def __cinit__(self, context: "AdaptContext" | None = None):             # <<<<<<<<<<<<<<
 *         if context is not None:
 *             self.adapters = context.adapters
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_11Transformer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_11Transformer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_context = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_context,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 100, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 100, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(9, 100, __pyx_L3_error)
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    } else {
      switch (__pyx_nargs) {
        case  1:
        values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 100, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[0]) values[0] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_context = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 1, __pyx_nargs); __PYX_ERR(9, 100, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_context);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_11Transformer___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_context) {
  PyObject *__pyx_v_postgres = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "psycopg_c/_psycopg/transform.pyx":101
 * 
 *     def __cinit__(self, context: "AdaptContext" | None = None):
 *         if context is not None:             # <<<<<<<<<<<<<<
 *             self.adapters = context.adapters
 *             self.connection = context.connection
*/
  __pyx_t_1 = (__pyx_v_context != Py_None);
  if (__pyx_t_1) {

    /* "psycopg_c/_psycopg/transform.pyx":102
 *     def __cinit__(self, context: "AdaptContext" | None = None):
 *         if context is not None:
 *             self.adapters = context.adapters             # <<<<<<<<<<<<<<
 *             self.connection = context.connection
 *         else:
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_mstate_global->__pyx_n_u_adapters); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->adapters);
    __Pyx_DECREF(__pyx_v_self->adapters);
    __pyx_v_self->adapters = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":103
 *         if context is not None:
 *             self.adapters = context.adapters
 *             self.connection = context.connection             # <<<<<<<<<<<<<<
 *         else:
 *             from psycopg import postgres
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_context, __pyx_mstate_global->__pyx_n_u_connection); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 103, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->connection);
    __Pyx_DECREF(__pyx_v_self->connection);
    __pyx_v_self->connection = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":101
 * 
 *     def __cinit__(self, context: "AdaptContext" | None = None):
 *         if context is not None:             # <<<<<<<<<<<<<<
 *             self.adapters = context.adapters
 *             self.connection = context.connection
*/
    goto __pyx_L3;
  }

  /* "psycopg_c/_psycopg/transform.pyx":105
 *             self.connection = context.connection
 *         else:
 *             from psycopg import postgres             # <<<<<<<<<<<<<<
 *             self.adapters = postgres.adapters
 *             self.connection = None
*/
  /*else*/ {
    {
      PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_postgres};
      __pyx_t_3 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 105, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_t_3;
    __Pyx_GOTREF(__pyx_t_2);
    {
      PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_postgres};
      __pyx_t_4 = 0; {
        __pyx_t_5 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_4]); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 105, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        switch (__pyx_t_4) {
          case 0:
          __Pyx_INCREF(__pyx_t_5);
          __pyx_v_postgres = __pyx_t_5;
          break;
          default:;
        }
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":106
 *         else:
 *             from psycopg import postgres
 *             self.adapters = postgres.adapters             # <<<<<<<<<<<<<<
 *             self.connection = None
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_postgres, __pyx_mstate_global->__pyx_n_u_adapters); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __Pyx_GOTREF(__pyx_v_self->adapters);
    __Pyx_DECREF(__pyx_v_self->adapters);
    __pyx_v_self->adapters = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":107
 *             from psycopg import postgres
 *             self.adapters = postgres.adapters
 *             self.connection = None             # <<<<<<<<<<<<<<
 * 
 *         self.types = self.formats = None
*/
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_self->connection);
    __Pyx_DECREF(__pyx_v_self->connection);
    __pyx_v_self->connection = Py_None;
  }
  __pyx_L3:;

  /* "psycopg_c/_psycopg/transform.pyx":109
 *             self.connection = None
 * 
 *         self.types = self.formats = None             # <<<<<<<<<<<<<<
 *         self._none_oid = -1
 * 
*/
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->types);
  __Pyx_DECREF(__pyx_v_self->types);
  __pyx_v_self->types = Py_None;
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF(__pyx_v_self->formats);
  __Pyx_DECREF(__pyx_v_self->formats);
  __pyx_v_self->formats = Py_None;

  /* "psycopg_c/_psycopg/transform.pyx":110
 * 
 *         self.types = self.formats = None
 *         self._none_oid = -1             # <<<<<<<<<<<<<<
 * 
 *     @classmethod
*/
  __pyx_v_self->_none_oid = -1;

  /* "psycopg_c/_psycopg/transform.pyx":100
 *     cdef dict _oid_types
 * 
 *     def __cinit__(self, context: "AdaptContext" | None = None):             # <<<<<<<<<<<<<<
 *         if context is not None:
 *             self.adapters = context.adapters
*/

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_postgres);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":112
 *         self._none_oid = -1
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_context(cls, context: "AdaptContext" | None):
 *         """
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_3from_context(PyObject *__pyx_v_cls, PyObject *__pyx_v_context); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_11Transformer_2from_context, "\n        Return a Transformer from an AdaptContext.\n\n        If the context is a Transformer instance, just return it.\n        ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_3from_context = {"from_context", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_3from_context, METH_O, __pyx_doc_9psycopg_c_8_psycopg_11Transformer_2from_context};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_3from_context(PyObject *__pyx_v_cls, PyObject *__pyx_v_context) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("from_context (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_2from_context(((PyTypeObject*)__pyx_v_cls), ((PyObject *)__pyx_v_context));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_2from_context(CYTHON_UNUSED PyTypeObject *__pyx_v_cls, PyObject *__pyx_v_context) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("from_context", 0);

  /* "psycopg_c/_psycopg/transform.pyx":119
 *         If the context is a Transformer instance, just return it.
 *         """
 *         return _tx_from_context(context)             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_9psycopg_c_8_psycopg__tx_from_context(__pyx_v_context)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":112
 *         self._none_oid = -1
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_context(cls, context: "AdaptContext" | None):
 *         """
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.from_context", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":121
 *         return _tx_from_context(context)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def encoding(self) -> str:
 *         if not self._encoding:
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_8encoding_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_8encoding_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_8encoding___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8encoding___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "psycopg_c/_psycopg/transform.pyx":123
 *     @property
 *     def encoding(self) -> str:
 *         if not self._encoding:             # <<<<<<<<<<<<<<
 *             self._encoding = conn_encoding(self.connection)
 *         return self._encoding
*/
  if (__pyx_v_self->_encoding == Py_None) __pyx_t_1 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyUnicode_IS_TRUE(__pyx_v_self->_encoding);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(9, 123, __pyx_L1_error)
    __pyx_t_1 = (__pyx_temp != 0);
  }

  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":124
 *     def encoding(self) -> str:
 *         if not self._encoding:
 *             self._encoding = conn_encoding(self.connection)             # <<<<<<<<<<<<<<
 *         return self._encoding
 * 
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_conn_encoding); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self->connection};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 124, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_3))) __PYX_ERR(9, 124, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_encoding);
    __Pyx_DECREF(__pyx_v_self->_encoding);
    __pyx_v_self->_encoding = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":123
 *     @property
 *     def encoding(self) -> str:
 *         if not self._encoding:             # <<<<<<<<<<<<<<
 *             self._encoding = conn_encoding(self.connection)
 *         return self._encoding
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":125
 *         if not self._encoding:
 *             self._encoding = conn_encoding(self.connection)
 *         return self._encoding             # <<<<<<<<<<<<<<
 * 
 *     @property
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_encoding);
  __pyx_r = __pyx_v_self->_encoding;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":121
 *         return _tx_from_context(context)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def encoding(self) -> str:
 *         if not self._encoding:
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.encoding.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":127
 *         return self._encoding
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def pgresult(self) -> PGresult | None:
 *         return self._pgresult
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_8pgresult_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_8pgresult_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_8pgresult___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8pgresult___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "psycopg_c/_psycopg/transform.pyx":129
 *     @property
 *     def pgresult(self) -> PGresult | None:
 *         return self._pgresult             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_pgresult(
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->_pgresult);
  __pyx_r = ((PyObject *)__pyx_v_self->_pgresult);
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":127
 *         return self._encoding
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def pgresult(self) -> PGresult | None:
 *         return self._pgresult
*/

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_5set_pgresult(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_set_pgresult(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_result, int __pyx_skip_dispatch, struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult *__pyx_optional_args) {

  /* "psycopg_c/_psycopg/transform.pyx":134
 *         self,
 *         pq.PGresult result,
 *         object set_loaders = True,             # <<<<<<<<<<<<<<
 *         object format = None
 *     ):
*/
  PyObject *__pyx_v_set_loaders = ((PyObject *)Py_True);

  /* "psycopg_c/_psycopg/transform.pyx":135
 *         pq.PGresult result,
 *         object set_loaders = True,
 *         object format = None             # <<<<<<<<<<<<<<
 *     ):
 *         self._pgresult = result
*/
  PyObject *__pyx_v_format = ((PyObject *)Py_None);
  PGresult *__pyx_v_res;
  PyObject *__pyx_v_loaders = 0;
  PyObject *__pyx_v_row_loader;
  PyObject *__pyx_v_oid = 0;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PGresult *__pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_pgresult", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_set_loaders = __pyx_optional_args->set_loaders;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_format = __pyx_optional_args->format;
      }
    }
  }
  __Pyx_INCREF(__pyx_v_format);

  /* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_set_pgresult); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 131, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_11Transformer_5set_pgresult)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[4] = {__pyx_t_3, ((PyObject *)__pyx_v_result), __pyx_v_set_loaders, __pyx_v_format};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (4-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 131, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "psycopg_c/_psycopg/transform.pyx":137
 *         object format = None
 *     ):
 *         self._pgresult = result             # <<<<<<<<<<<<<<
 * 
 *         if result is None:
*/
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __Pyx_GIVEREF((PyObject *)__pyx_v_result);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->_pgresult);
  __Pyx_DECREF((PyObject *)__pyx_v_self->_pgresult);
  __pyx_v_self->_pgresult = __pyx_v_result;

  /* "psycopg_c/_psycopg/transform.pyx":139
 *         self._pgresult = result
 * 
 *         if result is None:             # <<<<<<<<<<<<<<
 *             self._nfields = self._ntuples = 0
 *             if set_loaders:
*/
  __pyx_t_6 = (((PyObject *)__pyx_v_result) == Py_None);
  if (__pyx_t_6) {

    /* "psycopg_c/_psycopg/transform.pyx":140
 * 
 *         if result is None:
 *             self._nfields = self._ntuples = 0             # <<<<<<<<<<<<<<
 *             if set_loaders:
 *                 self._row_loaders = []
*/
    __pyx_v_self->_nfields = 0;
    __pyx_v_self->_ntuples = 0;

    /* "psycopg_c/_psycopg/transform.pyx":141
 *         if result is None:
 *             self._nfields = self._ntuples = 0
 *             if set_loaders:             # <<<<<<<<<<<<<<
 *                 self._row_loaders = []
 *             return
*/
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_set_loaders); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(9, 141, __pyx_L1_error)
    if (__pyx_t_6) {

      /* "psycopg_c/_psycopg/transform.pyx":142
 *             self._nfields = self._ntuples = 0
 *             if set_loaders:
 *                 self._row_loaders = []             # <<<<<<<<<<<<<<
 *             return
 * 
*/
      __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 142, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->_row_loaders);
      __Pyx_DECREF(__pyx_v_self->_row_loaders);
      __pyx_v_self->_row_loaders = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":141
 *         if result is None:
 *             self._nfields = self._ntuples = 0
 *             if set_loaders:             # <<<<<<<<<<<<<<
 *                 self._row_loaders = []
 *             return
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":143
 *             if set_loaders:
 *                 self._row_loaders = []
 *             return             # <<<<<<<<<<<<<<
 * 
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":139
 *         self._pgresult = result
 * 
 *         if result is None:             # <<<<<<<<<<<<<<
 *             self._nfields = self._ntuples = 0
 *             if set_loaders:
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":145
 *             return
 * 
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr             # <<<<<<<<<<<<<<
 *         self._nfields = libpq.PQnfields(res)
 *         self._ntuples = libpq.PQntuples(res)
*/
  __pyx_t_7 = __pyx_v_self->_pgresult->_pgresult_ptr;
  __pyx_v_res = __pyx_t_7;

  /* "psycopg_c/_psycopg/transform.pyx":146
 * 
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr
 *         self._nfields = libpq.PQnfields(res)             # <<<<<<<<<<<<<<
 *         self._ntuples = libpq.PQntuples(res)
 * 
*/
  __pyx_v_self->_nfields = PQnfields(__pyx_v_res);

  /* "psycopg_c/_psycopg/transform.pyx":147
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr
 *         self._nfields = libpq.PQnfields(res)
 *         self._ntuples = libpq.PQntuples(res)             # <<<<<<<<<<<<<<
 * 
 *         if not set_loaders:
*/
  __pyx_v_self->_ntuples = PQntuples(__pyx_v_res);

  /* "psycopg_c/_psycopg/transform.pyx":149
 *         self._ntuples = libpq.PQntuples(res)
 * 
 *         if not set_loaders:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_v_set_loaders); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(9, 149, __pyx_L1_error)
  __pyx_t_8 = (!__pyx_t_6);
  if (__pyx_t_8) {

    /* "psycopg_c/_psycopg/transform.pyx":150
 * 
 *         if not set_loaders:
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if not self._nfields:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":149
 *         self._ntuples = libpq.PQntuples(res)
 * 
 *         if not set_loaders:             # <<<<<<<<<<<<<<
 *             return
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":152
 *             return
 * 
 *         if not self._nfields:             # <<<<<<<<<<<<<<
 *             self._row_loaders = []
 *             return
*/
  __pyx_t_8 = (!(__pyx_v_self->_nfields != 0));
  if (__pyx_t_8) {

    /* "psycopg_c/_psycopg/transform.pyx":153
 * 
 *         if not self._nfields:
 *             self._row_loaders = []             # <<<<<<<<<<<<<<
 *             return
 * 
*/
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 153, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF(__pyx_v_self->_row_loaders);
    __Pyx_DECREF(__pyx_v_self->_row_loaders);
    __pyx_v_self->_row_loaders = ((PyObject*)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":154
 *         if not self._nfields:
 *             self._row_loaders = []
 *             return             # <<<<<<<<<<<<<<
 * 
 *         if format is None:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":152
 *             return
 * 
 *         if not self._nfields:             # <<<<<<<<<<<<<<
 *             self._row_loaders = []
 *             return
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":156
 *             return
 * 
 *         if format is None:             # <<<<<<<<<<<<<<
 *             format = libpq.PQfformat(res, 0)
 * 
*/
  __pyx_t_8 = (__pyx_v_format == Py_None);
  if (__pyx_t_8) {

    /* "psycopg_c/_psycopg/transform.pyx":157
 * 
 *         if format is None:
 *             format = libpq.PQfformat(res, 0)             # <<<<<<<<<<<<<<
 * 
 *         cdef list loaders = PyList_New(self._nfields)
*/
    __pyx_t_1 = __Pyx_PyLong_From_int(PQfformat(__pyx_v_res, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 157, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF_SET(__pyx_v_format, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":156
 *             return
 * 
 *         if format is None:             # <<<<<<<<<<<<<<
 *             format = libpq.PQfformat(res, 0)
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":159
 *             format = libpq.PQfformat(res, 0)
 * 
 *         cdef list loaders = PyList_New(self._nfields)             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_loader
 *         cdef object oid
*/
  __pyx_t_1 = PyList_New(__pyx_v_self->_nfields); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 159, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_loaders = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":164
 * 
 *         cdef int i
 *         for i in range(self._nfields):             # <<<<<<<<<<<<<<
 *             oid = libpq.PQftype(res, i)
 *             row_loader = self._c_get_loader(<PyObject *>oid, <PyObject *>format)
*/
  __pyx_t_9 = __pyx_v_self->_nfields;
  __pyx_t_10 = __pyx_t_9;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "psycopg_c/_psycopg/transform.pyx":165
 *         cdef int i
 *         for i in range(self._nfields):
 *             oid = libpq.PQftype(res, i)             # <<<<<<<<<<<<<<
 *             row_loader = self._c_get_loader(<PyObject *>oid, <PyObject *>format)
 *             Py_INCREF(<object>row_loader)
*/
    __pyx_t_1 = __Pyx_PyLong_From_Oid(PQftype(__pyx_v_res, __pyx_v_i)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_oid, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":166
 *         for i in range(self._nfields):
 *             oid = libpq.PQftype(res, i)
 *             row_loader = self._c_get_loader(<PyObject *>oid, <PyObject *>format)             # <<<<<<<<<<<<<<
 *             Py_INCREF(<object>row_loader)
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)
*/
    __pyx_t_12 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->_c_get_loader(__pyx_v_self, ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_v_format)); if (unlikely(__pyx_t_12 == ((void *)NULL))) __PYX_ERR(9, 166, __pyx_L1_error)
    __pyx_v_row_loader = __pyx_t_12;

    /* "psycopg_c/_psycopg/transform.pyx":167
 *             oid = libpq.PQftype(res, i)
 *             row_loader = self._c_get_loader(<PyObject *>oid, <PyObject *>format)
 *             Py_INCREF(<object>row_loader)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)
 * 
*/
    Py_INCREF(((PyObject *)__pyx_v_row_loader));

    /* "psycopg_c/_psycopg/transform.pyx":168
 *             row_loader = self._c_get_loader(<PyObject *>oid, <PyObject *>format)
 *             Py_INCREF(<object>row_loader)
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)             # <<<<<<<<<<<<<<
 * 
 *         self._row_loaders = loaders
*/
    PyList_SET_ITEM(__pyx_v_loaders, __pyx_v_i, ((PyObject *)__pyx_v_row_loader));
  }

  /* "psycopg_c/_psycopg/transform.pyx":170
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)
 * 
 *         self._row_loaders = loaders             # <<<<<<<<<<<<<<
 * 
 *     def set_dumper_types(self, types: Sequence[int], format: PqFormat) -> None:
*/
  __Pyx_INCREF(__pyx_v_loaders);
  __Pyx_GIVEREF(__pyx_v_loaders);
  __Pyx_GOTREF(__pyx_v_self->_row_loaders);
  __Pyx_DECREF(__pyx_v_self->_row_loaders);
  __pyx_v_self->_row_loaders = __pyx_v_loaders;

  /* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_pgresult", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loaders);
  __Pyx_XDECREF(__pyx_v_oid);
  __Pyx_XDECREF(__pyx_v_format);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_5set_pgresult(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_5set_pgresult = {"set_pgresult", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_5set_pgresult, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_5set_pgresult(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_result = 0;
  PyObject *__pyx_v_set_loaders = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_pgresult (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_result,&__pyx_mstate_global->__pyx_n_u_set_loaders,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 131, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(9, 131, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 131, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 131, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "set_pgresult", 0) < (0)) __PYX_ERR(9, 131, __pyx_L3_error)

      /* "psycopg_c/_psycopg/transform.pyx":134
 *         self,
 *         pq.PGresult result,
 *         object set_loaders = True,             # <<<<<<<<<<<<<<
 *         object format = None
 *     ):
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_True));

      /* "psycopg_c/_psycopg/transform.pyx":135
 *         pq.PGresult result,
 *         object set_loaders = True,
 *         object format = None             # <<<<<<<<<<<<<<
 *     ):
 *         self._pgresult = result
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
      for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("set_pgresult", 0, 1, 3, i); __PYX_ERR(9, 131, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(9, 131, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 131, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 131, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }

      /* "psycopg_c/_psycopg/transform.pyx":134
 *         self,
 *         pq.PGresult result,
 *         object set_loaders = True,             # <<<<<<<<<<<<<<
 *         object format = None
 *     ):
*/
      if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_True));

      /* "psycopg_c/_psycopg/transform.pyx":135
 *         pq.PGresult result,
 *         object set_loaders = True,
 *         object format = None             # <<<<<<<<<<<<<<
 *     ):
 *         self._pgresult = result
*/
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)Py_None));
    }
    __pyx_v_result = ((struct __pyx_obj_9psycopg_c_2pq_PGresult *)values[0]);
    __pyx_v_set_loaders = values[1];
    __pyx_v_format = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_pgresult", 0, 1, 3, __pyx_nargs); __PYX_ERR(9, 131, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_pgresult", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_result), __pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_PGresult, 1, "result", 0))) __PYX_ERR(9, 133, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_4set_pgresult(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_result, __pyx_v_set_loaders, __pyx_v_format);

  /* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_4set_pgresult(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, struct __pyx_obj_9psycopg_c_2pq_PGresult *__pyx_v_result, PyObject *__pyx_v_set_loaders, PyObject *__pyx_v_format) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_pgresult", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.set_loaders = __pyx_v_set_loaders;
  __pyx_t_2.format = __pyx_v_format;
  __pyx_t_1 = __pyx_vtabptr_9psycopg_c_8_psycopg_Transformer->set_pgresult(__pyx_v_self, __pyx_v_result, 1, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_pgresult", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":172
 *         self._row_loaders = loaders
 * 
 *     def set_dumper_types(self, types: Sequence[int], format: PqFormat) -> None:             # <<<<<<<<<<<<<<
 *         # NOTE: impl detail - final _row_dumpers must be a list type
 *         # (assumed by format_row_binary and format_row_text)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_7set_dumper_types(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_7set_dumper_types = {"set_dumper_types", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_7set_dumper_types, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_7set_dumper_types(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_types = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_dumper_types (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_types,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 172, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 172, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 172, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "set_dumper_types", 0) < (0)) __PYX_ERR(9, 172, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("set_dumper_types", 1, 2, 2, i); __PYX_ERR(9, 172, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 172, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 172, __pyx_L3_error)
    }
    __pyx_v_types = values[0];
    __pyx_v_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_dumper_types", 1, 2, 2, __pyx_nargs); __PYX_ERR(9, 172, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_dumper_types", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_6set_dumper_types(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_types, __pyx_v_format);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_6set_dumper_types(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_types, PyObject *__pyx_v_format) {
  Py_ssize_t __pyx_v_ntypes;
  PyObject *__pyx_v_dumpers = NULL;
  int __pyx_v_i;
  PyObject *__pyx_v_oid = NULL;
  PyObject *__pyx_v_dumper_ptr;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_dumper_types", 0);

  /* "psycopg_c/_psycopg/transform.pyx":175
 *         # NOTE: impl detail - final _row_dumpers must be a list type
 *         # (assumed by format_row_binary and format_row_text)
 *         cdef Py_ssize_t ntypes = len(types)             # <<<<<<<<<<<<<<
 *         dumpers = PyList_New(ntypes)
 *         cdef int i
*/
  __pyx_t_1 = PyObject_Length(__pyx_v_types); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(9, 175, __pyx_L1_error)
  __pyx_v_ntypes = __pyx_t_1;

  /* "psycopg_c/_psycopg/transform.pyx":176
 *         # (assumed by format_row_binary and format_row_text)
 *         cdef Py_ssize_t ntypes = len(types)
 *         dumpers = PyList_New(ntypes)             # <<<<<<<<<<<<<<
 *         cdef int i
 *         for i in range(ntypes):
*/
  __pyx_t_2 = PyList_New(__pyx_v_ntypes); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_dumpers = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":178
 *         dumpers = PyList_New(ntypes)
 *         cdef int i
 *         for i in range(ntypes):             # <<<<<<<<<<<<<<
 *             oid = types[i]
 *             dumper_ptr = self.get_dumper_by_oid(
*/
  __pyx_t_1 = __pyx_v_ntypes;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "psycopg_c/_psycopg/transform.pyx":179
 *         cdef int i
 *         for i in range(ntypes):
 *             oid = types[i]             # <<<<<<<<<<<<<<
 *             dumper_ptr = self.get_dumper_by_oid(
 *                 <PyObject *>oid, <PyObject *>format)
*/
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_types, __pyx_v_i, int, 1, __Pyx_PyLong_From_int, 0, 1, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_oid, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":180
 *         for i in range(ntypes):
 *             oid = types[i]
 *             dumper_ptr = self.get_dumper_by_oid(             # <<<<<<<<<<<<<<
 *                 <PyObject *>oid, <PyObject *>format)
 *             Py_INCREF(<object>dumper_ptr)
*/
    __pyx_t_5 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->get_dumper_by_oid(__pyx_v_self, ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_v_format)); if (unlikely(__pyx_t_5 == ((void *)NULL))) __PYX_ERR(9, 180, __pyx_L1_error)
    __pyx_v_dumper_ptr = __pyx_t_5;

    /* "psycopg_c/_psycopg/transform.pyx":182
 *             dumper_ptr = self.get_dumper_by_oid(
 *                 <PyObject *>oid, <PyObject *>format)
 *             Py_INCREF(<object>dumper_ptr)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(dumpers, i, <object>dumper_ptr)
 * 
*/
    Py_INCREF(((PyObject *)__pyx_v_dumper_ptr));

    /* "psycopg_c/_psycopg/transform.pyx":183
 *                 <PyObject *>oid, <PyObject *>format)
 *             Py_INCREF(<object>dumper_ptr)
 *             PyList_SET_ITEM(dumpers, i, <object>dumper_ptr)             # <<<<<<<<<<<<<<
 * 
 *         self._row_dumpers = dumpers
*/
    PyList_SET_ITEM(__pyx_v_dumpers, __pyx_v_i, ((PyObject *)__pyx_v_dumper_ptr));
  }

  /* "psycopg_c/_psycopg/transform.pyx":185
 *             PyList_SET_ITEM(dumpers, i, <object>dumper_ptr)
 * 
 *         self._row_dumpers = dumpers             # <<<<<<<<<<<<<<
 *         self.types = tuple(types)
 *         self.formats = [format] * ntypes
*/
  __Pyx_INCREF(__pyx_v_dumpers);
  __Pyx_GIVEREF(__pyx_v_dumpers);
  __Pyx_GOTREF(__pyx_v_self->_row_dumpers);
  __Pyx_DECREF(__pyx_v_self->_row_dumpers);
  __pyx_v_self->_row_dumpers = __pyx_v_dumpers;

  /* "psycopg_c/_psycopg/transform.pyx":186
 * 
 *         self._row_dumpers = dumpers
 *         self.types = tuple(types)             # <<<<<<<<<<<<<<
 *         self.formats = [format] * ntypes
 * 
*/
  __pyx_t_2 = __Pyx_PySequence_Tuple(__pyx_v_types); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->types);
  __Pyx_DECREF(__pyx_v_self->types);
  __pyx_v_self->types = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":187
 *         self._row_dumpers = dumpers
 *         self.types = tuple(types)
 *         self.formats = [format] * ntypes             # <<<<<<<<<<<<<<
 * 
 *     def set_loader_types(self, types: Sequence[int], format: PqFormat) -> None:
*/
  __pyx_t_2 = PyList_New(1 * ((__pyx_v_ntypes<0) ? 0:__pyx_v_ntypes)); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 187, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < __pyx_v_ntypes; __pyx_temp++) {
      __Pyx_INCREF(__pyx_v_format);
      __Pyx_GIVEREF(__pyx_v_format);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_2, __pyx_temp, __pyx_v_format) != (0)) __PYX_ERR(9, 187, __pyx_L1_error);
    }
  }
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->formats);
  __Pyx_DECREF(__pyx_v_self->formats);
  __pyx_v_self->formats = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":172
 *         self._row_loaders = loaders
 * 
 *     def set_dumper_types(self, types: Sequence[int], format: PqFormat) -> None:             # <<<<<<<<<<<<<<
 *         # NOTE: impl detail - final _row_dumpers must be a list type
 *         # (assumed by format_row_binary and format_row_text)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_dumper_types", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dumpers);
  __Pyx_XDECREF(__pyx_v_oid);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":189
 *         self.formats = [format] * ntypes
 * 
 *     def set_loader_types(self, types: Sequence[int], format: PqFormat) -> None:             # <<<<<<<<<<<<<<
 *         cdef types_fast = PySequence_Fast(types, "'types' is not a valid sequence")
 *         cdef Py_ssize_t ntypes = PySequence_Fast_GET_SIZE(types_fast)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_9set_loader_types(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_9set_loader_types = {"set_loader_types", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_9set_loader_types, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_9set_loader_types(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_types = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_loader_types (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_types,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 189, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 189, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 189, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "set_loader_types", 0) < (0)) __PYX_ERR(9, 189, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("set_loader_types", 1, 2, 2, i); __PYX_ERR(9, 189, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 189, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 189, __pyx_L3_error)
    }
    __pyx_v_types = values[0];
    __pyx_v_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_loader_types", 1, 2, 2, __pyx_nargs); __PYX_ERR(9, 189, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_loader_types", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_8set_loader_types(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_types, __pyx_v_format);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8set_loader_types(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_types, PyObject *__pyx_v_format) {
  PyObject *__pyx_v_types_fast = 0;
  Py_ssize_t __pyx_v_ntypes;
  PyObject *__pyx_v_loaders = 0;
  PyObject *__pyx_v_oid;
  PyObject *__pyx_v_row_loader;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_loader_types", 0);

  /* "psycopg_c/_psycopg/transform.pyx":190
 * 
 *     def set_loader_types(self, types: Sequence[int], format: PqFormat) -> None:
 *         cdef types_fast = PySequence_Fast(types, "'types' is not a valid sequence")             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t ntypes = PySequence_Fast_GET_SIZE(types_fast)
 *         cdef list loaders = PyList_New(ntypes)
*/
  __pyx_t_1 = PySequence_Fast(__pyx_v_types, ((char *)"'types' is not a valid sequence")); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_types_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":191
 *     def set_loader_types(self, types: Sequence[int], format: PqFormat) -> None:
 *         cdef types_fast = PySequence_Fast(types, "'types' is not a valid sequence")
 *         cdef Py_ssize_t ntypes = PySequence_Fast_GET_SIZE(types_fast)             # <<<<<<<<<<<<<<
 *         cdef list loaders = PyList_New(ntypes)
 * 
*/
  __pyx_v_ntypes = PySequence_Fast_GET_SIZE(__pyx_v_types_fast);

  /* "psycopg_c/_psycopg/transform.pyx":192
 *         cdef types_fast = PySequence_Fast(types, "'types' is not a valid sequence")
 *         cdef Py_ssize_t ntypes = PySequence_Fast_GET_SIZE(types_fast)
 *         cdef list loaders = PyList_New(ntypes)             # <<<<<<<<<<<<<<
 * 
 *         # these are used more as Python object than C
*/
  __pyx_t_1 = PyList_New(__pyx_v_ntypes); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_loaders = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":197
 *         cdef PyObject *oid
 *         cdef PyObject *row_loader
 *         for i in range(ntypes):             # <<<<<<<<<<<<<<
 *             oid = PySequence_Fast_GET_ITEM(types_fast, i)
 *             row_loader = self._c_get_loader(oid, <PyObject *>format)
*/
  __pyx_t_2 = __pyx_v_ntypes;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "psycopg_c/_psycopg/transform.pyx":198
 *         cdef PyObject *row_loader
 *         for i in range(ntypes):
 *             oid = PySequence_Fast_GET_ITEM(types_fast, i)             # <<<<<<<<<<<<<<
 *             row_loader = self._c_get_loader(oid, <PyObject *>format)
 *             Py_INCREF(<object>row_loader)
*/
    __pyx_v_oid = PySequence_Fast_GET_ITEM(__pyx_v_types_fast, __pyx_v_i);

    /* "psycopg_c/_psycopg/transform.pyx":199
 *         for i in range(ntypes):
 *             oid = PySequence_Fast_GET_ITEM(types_fast, i)
 *             row_loader = self._c_get_loader(oid, <PyObject *>format)             # <<<<<<<<<<<<<<
 *             Py_INCREF(<object>row_loader)
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)
*/
    __pyx_t_5 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->_c_get_loader(__pyx_v_self, __pyx_v_oid, ((PyObject *)__pyx_v_format)); if (unlikely(__pyx_t_5 == ((void *)NULL))) __PYX_ERR(9, 199, __pyx_L1_error)
    __pyx_v_row_loader = __pyx_t_5;

    /* "psycopg_c/_psycopg/transform.pyx":200
 *             oid = PySequence_Fast_GET_ITEM(types_fast, i)
 *             row_loader = self._c_get_loader(oid, <PyObject *>format)
 *             Py_INCREF(<object>row_loader)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)
 * 
*/
    Py_INCREF(((PyObject *)__pyx_v_row_loader));

    /* "psycopg_c/_psycopg/transform.pyx":201
 *             row_loader = self._c_get_loader(oid, <PyObject *>format)
 *             Py_INCREF(<object>row_loader)
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)             # <<<<<<<<<<<<<<
 * 
 *         self._row_loaders = loaders
*/
    PyList_SET_ITEM(__pyx_v_loaders, __pyx_v_i, ((PyObject *)__pyx_v_row_loader));
  }

  /* "psycopg_c/_psycopg/transform.pyx":203
 *             PyList_SET_ITEM(loaders, i, <object>row_loader)
 * 
 *         self._row_loaders = loaders             # <<<<<<<<<<<<<<
 * 
 *     cpdef as_literal(self, obj):
*/
  __Pyx_INCREF(__pyx_v_loaders);
  __Pyx_GIVEREF(__pyx_v_loaders);
  __Pyx_GOTREF(__pyx_v_self->_row_loaders);
  __Pyx_DECREF(__pyx_v_self->_row_loaders);
  __pyx_v_self->_row_loaders = __pyx_v_loaders;

  /* "psycopg_c/_psycopg/transform.pyx":189
 *         self.formats = [format] * ntypes
 * 
 *     def set_loader_types(self, types: Sequence[int], format: PqFormat) -> None:             # <<<<<<<<<<<<<<
 *         cdef types_fast = PySequence_Fast(types, "'types' is not a valid sequence")
 *         cdef Py_ssize_t ntypes = PySequence_Fast_GET_SIZE(types_fast)
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.set_loader_types", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_types_fast);
  __Pyx_XDECREF(__pyx_v_loaders);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":205
 *         self._row_loaders = loaders
 * 
 *     cpdef as_literal(self, obj):             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>PG_TEXT)
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_11as_literal(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_as_literal(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_row_dumper;
  PyObject *__pyx_v_dumper = NULL;
  PyObject *__pyx_v_rv = NULL;
  PyObject *__pyx_v_oid = NULL;
  PyObject *__pyx_v_type_ptr;
  PyObject *__pyx_v_type_sql = NULL;
  PyObject *__pyx_v_ti = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  PyObject *__pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_literal", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_as_literal); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_11Transformer_11as_literal)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_obj};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 205, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "psycopg_c/_psycopg/transform.pyx":207
 *     cpdef as_literal(self, obj):
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>PG_TEXT)             # <<<<<<<<<<<<<<
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_PG_TEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);

  /* "psycopg_c/_psycopg/transform.pyx":206
 * 
 *     cpdef as_literal(self, obj):
 *         cdef PyObject *row_dumper = self.get_row_dumper(             # <<<<<<<<<<<<<<
 *             <PyObject *>obj, <PyObject *>PG_TEXT)
 * 
*/
  __pyx_t_6 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->get_row_dumper(__pyx_v_self, ((PyObject *)__pyx_v_obj), ((PyObject *)__pyx_t_1)); if (unlikely(__pyx_t_6 == ((void *)NULL))) __PYX_ERR(9, 206, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_row_dumper = __pyx_t_6;

  /* "psycopg_c/_psycopg/transform.pyx":209
 *             <PyObject *>obj, <PyObject *>PG_TEXT)
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:             # <<<<<<<<<<<<<<
 *             dumper = (<RowDumper>row_dumper).cdumper
 *         else:
*/
  __pyx_t_7 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper) != Py_None);
  if (__pyx_t_7) {

    /* "psycopg_c/_psycopg/transform.pyx":210
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:
 *             dumper = (<RowDumper>row_dumper).cdumper             # <<<<<<<<<<<<<<
 *         else:
 *             dumper = (<RowDumper>row_dumper).pydumper
*/
    __pyx_t_1 = ((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->cdumper);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_dumper = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":209
 *             <PyObject *>obj, <PyObject *>PG_TEXT)
 * 
 *         if (<RowDumper>row_dumper).cdumper is not None:             # <<<<<<<<<<<<<<
 *             dumper = (<RowDumper>row_dumper).cdumper
 *         else:
*/
    goto __pyx_L3;
  }

  /* "psycopg_c/_psycopg/transform.pyx":212
 *             dumper = (<RowDumper>row_dumper).cdumper
 *         else:
 *             dumper = (<RowDumper>row_dumper).pydumper             # <<<<<<<<<<<<<<
 * 
 *         rv = dumper.quote(obj)
*/
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->pydumper;
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_dumper = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L3:;

  /* "psycopg_c/_psycopg/transform.pyx":214
 *             dumper = (<RowDumper>row_dumper).pydumper
 * 
 *         rv = dumper.quote(obj)             # <<<<<<<<<<<<<<
 *         oid = dumper.oid
 *         # If the result is quoted and the oid not unknown or text,
*/
  __pyx_t_2 = __pyx_v_dumper;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_obj};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_quote, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_rv = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":215
 * 
 *         rv = dumper.quote(obj)
 *         oid = dumper.oid             # <<<<<<<<<<<<<<
 *         # If the result is quoted and the oid not unknown or text,
 *         # add an explicit type cast.
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dumper, __pyx_mstate_global->__pyx_n_u_oid); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 215, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_oid = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":219
 *         # add an explicit type cast.
 *         # Check the last char because the first one might be 'E'.
 *         if oid and oid != oids.TEXT_OID and rv and rv[-1] == 39:             # <<<<<<<<<<<<<<
 *             if self._oid_types is None:
 *                 self._oid_types = {}
*/
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_oid); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(9, 219, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_1 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TEXT_OID); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(__pyx_v_oid, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(9, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_v_rv); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(9, 219, __pyx_L1_error)
  if (__pyx_t_8) {
  } else {
    __pyx_t_7 = __pyx_t_8;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_v_rv, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = (__Pyx_PyLong_BoolEqObjC(__pyx_t_2, __pyx_mstate_global->__pyx_int_39, 39, 0)); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(9, 219, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __pyx_t_8;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_7) {

    /* "psycopg_c/_psycopg/transform.pyx":220
 *         # Check the last char because the first one might be 'E'.
 *         if oid and oid != oids.TEXT_OID and rv and rv[-1] == 39:
 *             if self._oid_types is None:             # <<<<<<<<<<<<<<
 *                 self._oid_types = {}
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)
*/
    __pyx_t_7 = (__pyx_v_self->_oid_types == ((PyObject*)Py_None));
    if (__pyx_t_7) {

      /* "psycopg_c/_psycopg/transform.pyx":221
 *         if oid and oid != oids.TEXT_OID and rv and rv[-1] == 39:
 *             if self._oid_types is None:
 *                 self._oid_types = {}             # <<<<<<<<<<<<<<
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)
 *             if type_ptr == NULL:
*/
      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 221, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_v_self->_oid_types);
      __Pyx_DECREF(__pyx_v_self->_oid_types);
      __pyx_v_self->_oid_types = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":220
 *         # Check the last char because the first one might be 'E'.
 *         if oid and oid != oids.TEXT_OID and rv and rv[-1] == 39:
 *             if self._oid_types is None:             # <<<<<<<<<<<<<<
 *                 self._oid_types = {}
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":222
 *             if self._oid_types is None:
 *                 self._oid_types = {}
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)             # <<<<<<<<<<<<<<
 *             if type_ptr == NULL:
 *                 type_sql = b""
*/
    __pyx_t_2 = __pyx_v_self->_oid_types;
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_type_ptr = PyDict_GetItem(__pyx_t_2, __pyx_v_oid);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":223
 *                 self._oid_types = {}
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)
 *             if type_ptr == NULL:             # <<<<<<<<<<<<<<
 *                 type_sql = b""
 *                 ti = self.adapters.types.get(oid)
*/
    __pyx_t_7 = (__pyx_v_type_ptr == NULL);
    if (__pyx_t_7) {

      /* "psycopg_c/_psycopg/transform.pyx":224
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)
 *             if type_ptr == NULL:
 *                 type_sql = b""             # <<<<<<<<<<<<<<
 *                 ti = self.adapters.types.get(oid)
 *                 if ti is not None:
*/
      __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b__4);
      __pyx_v_type_sql = __pyx_mstate_global->__pyx_kp_b__4;

      /* "psycopg_c/_psycopg/transform.pyx":225
 *             if type_ptr == NULL:
 *                 type_sql = b""
 *                 ti = self.adapters.types.get(oid)             # <<<<<<<<<<<<<<
 *                 if ti is not None:
 *                     if oid < 8192:
*/
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->adapters, __pyx_mstate_global->__pyx_n_u_types); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __pyx_t_4;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_v_oid};
        __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 225, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_v_ti = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":226
 *                 type_sql = b""
 *                 ti = self.adapters.types.get(oid)
 *                 if ti is not None:             # <<<<<<<<<<<<<<
 *                     if oid < 8192:
 *                         # builtin: prefer "timestamptz" to "timestamp with time zone"
*/
      __pyx_t_7 = (__pyx_v_ti != Py_None);
      if (__pyx_t_7) {

        /* "psycopg_c/_psycopg/transform.pyx":227
 *                 ti = self.adapters.types.get(oid)
 *                 if ti is not None:
 *                     if oid < 8192:             # <<<<<<<<<<<<<<
 *                         # builtin: prefer "timestamptz" to "timestamp with time zone"
 *                         type_sql = ti.name.encode(self.encoding)
*/
        __pyx_t_2 = PyObject_RichCompare(__pyx_v_oid, __pyx_mstate_global->__pyx_int_8192, Py_LT); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 227, __pyx_L1_error)
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(9, 227, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        if (__pyx_t_7) {

          /* "psycopg_c/_psycopg/transform.pyx":229
 *                     if oid < 8192:
 *                         # builtin: prefer "timestamptz" to "timestamp with time zone"
 *                         type_sql = ti.name.encode(self.encoding)             # <<<<<<<<<<<<<<
 *                     else:
 *                         type_sql = ti.regtype.encode(self.encoding)
*/
          __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_ti, __pyx_mstate_global->__pyx_n_u_name); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 229, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_4 = __pyx_t_1;
          __Pyx_INCREF(__pyx_t_4);
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_encoding); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 229, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_3};
            __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 229, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_DECREF_SET(__pyx_v_type_sql, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "psycopg_c/_psycopg/transform.pyx":227
 *                 ti = self.adapters.types.get(oid)
 *                 if ti is not None:
 *                     if oid < 8192:             # <<<<<<<<<<<<<<
 *                         # builtin: prefer "timestamptz" to "timestamp with time zone"
 *                         type_sql = ti.name.encode(self.encoding)
*/
          goto __pyx_L12;
        }

        /* "psycopg_c/_psycopg/transform.pyx":231
 *                         type_sql = ti.name.encode(self.encoding)
 *                     else:
 *                         type_sql = ti.regtype.encode(self.encoding)             # <<<<<<<<<<<<<<
 *                     if oid == ti.array_oid:
 *                         type_sql += b"[]"
*/
        /*else*/ {
          __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_ti, __pyx_mstate_global->__pyx_n_u_regtype); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 231, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __pyx_t_1 = __pyx_t_3;
          __Pyx_INCREF(__pyx_t_1);
          __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_encoding); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 231, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __pyx_t_5 = 0;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_4};
            __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
            __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
            __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
            if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 231, __pyx_L1_error)
            __Pyx_GOTREF(__pyx_t_2);
          }
          __Pyx_DECREF_SET(__pyx_v_type_sql, __pyx_t_2);
          __pyx_t_2 = 0;
        }
        __pyx_L12:;

        /* "psycopg_c/_psycopg/transform.pyx":232
 *                     else:
 *                         type_sql = ti.regtype.encode(self.encoding)
 *                     if oid == ti.array_oid:             # <<<<<<<<<<<<<<
 *                         type_sql += b"[]"
 * 
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ti, __pyx_mstate_global->__pyx_n_u_array_oid); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 232, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_3 = PyObject_RichCompare(__pyx_v_oid, __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 232, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(9, 232, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (__pyx_t_7) {

          /* "psycopg_c/_psycopg/transform.pyx":233
 *                         type_sql = ti.regtype.encode(self.encoding)
 *                     if oid == ti.array_oid:
 *                         type_sql += b"[]"             # <<<<<<<<<<<<<<
 * 
 *                 type_ptr = <PyObject *>type_sql
*/
          __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_type_sql, __pyx_mstate_global->__pyx_kp_b__5); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 233, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_3);
          __Pyx_DECREF_SET(__pyx_v_type_sql, __pyx_t_3);
          __pyx_t_3 = 0;

          /* "psycopg_c/_psycopg/transform.pyx":232
 *                     else:
 *                         type_sql = ti.regtype.encode(self.encoding)
 *                     if oid == ti.array_oid:             # <<<<<<<<<<<<<<
 *                         type_sql += b"[]"
 * 
*/
        }

        /* "psycopg_c/_psycopg/transform.pyx":226
 *                 type_sql = b""
 *                 ti = self.adapters.types.get(oid)
 *                 if ti is not None:             # <<<<<<<<<<<<<<
 *                     if oid < 8192:
 *                         # builtin: prefer "timestamptz" to "timestamp with time zone"
*/
      }

      /* "psycopg_c/_psycopg/transform.pyx":235
 *                         type_sql += b"[]"
 * 
 *                 type_ptr = <PyObject *>type_sql             # <<<<<<<<<<<<<<
 *                 PyDict_SetItem(<object>self._oid_types, oid, type_sql)
 * 
*/
      __pyx_v_type_ptr = ((PyObject *)__pyx_v_type_sql);

      /* "psycopg_c/_psycopg/transform.pyx":236
 * 
 *                 type_ptr = <PyObject *>type_sql
 *                 PyDict_SetItem(<object>self._oid_types, oid, type_sql)             # <<<<<<<<<<<<<<
 * 
 *             if <object>type_ptr:
*/
      __pyx_t_3 = __pyx_v_self->_oid_types;
      __Pyx_INCREF(__pyx_t_3);
      __pyx_t_9 = PyDict_SetItem(__pyx_t_3, __pyx_v_oid, __pyx_v_type_sql); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(9, 236, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":223
 *                 self._oid_types = {}
 *             type_ptr = PyDict_GetItem(<object>self._oid_types, oid)
 *             if type_ptr == NULL:             # <<<<<<<<<<<<<<
 *                 type_sql = b""
 *                 ti = self.adapters.types.get(oid)
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":238
 *                 PyDict_SetItem(<object>self._oid_types, oid, type_sql)
 * 
 *             if <object>type_ptr:             # <<<<<<<<<<<<<<
 *                 rv = b"%s::%s" % (rv, <object>type_ptr)
 * 
*/
    __pyx_t_7 = __Pyx_PyObject_IsTrue(((PyObject *)__pyx_v_type_ptr)); if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(9, 238, __pyx_L1_error)
    if (__pyx_t_7) {

      /* "psycopg_c/_psycopg/transform.pyx":239
 * 
 *             if <object>type_ptr:
 *                 rv = b"%s::%s" % (rv, <object>type_ptr)             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(rv, bytes):
*/
      __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_v_rv);
      __Pyx_GIVEREF(__pyx_v_rv);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_rv) != (0)) __PYX_ERR(9, 239, __pyx_L1_error);
      __Pyx_INCREF(((PyObject *)__pyx_v_type_ptr));
      __Pyx_GIVEREF(((PyObject *)__pyx_v_type_ptr));
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_type_ptr)) != (0)) __PYX_ERR(9, 239, __pyx_L1_error);
      __pyx_t_2 = PyNumber_Remainder(__pyx_mstate_global->__pyx_kp_b_s_s, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 239, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF_SET(__pyx_v_rv, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":238
 *                 PyDict_SetItem(<object>self._oid_types, oid, type_sql)
 * 
 *             if <object>type_ptr:             # <<<<<<<<<<<<<<
 *                 rv = b"%s::%s" % (rv, <object>type_ptr)
 * 
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":219
 *         # add an explicit type cast.
 *         # Check the last char because the first one might be 'E'.
 *         if oid and oid != oids.TEXT_OID and rv and rv[-1] == 39:             # <<<<<<<<<<<<<<
 *             if self._oid_types is None:
 *                 self._oid_types = {}
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":241
 *                 rv = b"%s::%s" % (rv, <object>type_ptr)
 * 
 *         if not isinstance(rv, bytes):             # <<<<<<<<<<<<<<
 *             rv = bytes(rv)
 * 
*/
  __pyx_t_7 = PyBytes_Check(__pyx_v_rv); 
  __pyx_t_8 = (!__pyx_t_7);
  if (__pyx_t_8) {

    /* "psycopg_c/_psycopg/transform.pyx":242
 * 
 *         if not isinstance(rv, bytes):
 *             rv = bytes(rv)             # <<<<<<<<<<<<<<
 * 
 *         return rv
*/
    __pyx_t_3 = NULL;
    __pyx_t_5 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_rv};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 242, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_DECREF_SET(__pyx_v_rv, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":241
 *                 rv = b"%s::%s" % (rv, <object>type_ptr)
 * 
 *         if not isinstance(rv, bytes):             # <<<<<<<<<<<<<<
 *             rv = bytes(rv)
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":244
 *             rv = bytes(rv)
 * 
 *         return rv             # <<<<<<<<<<<<<<
 * 
 *     def get_dumper(self, obj, format) -> "Dumper":
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rv);
  __pyx_r = __pyx_v_rv;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":205
 *         self._row_loaders = loaders
 * 
 *     cpdef as_literal(self, obj):             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>PG_TEXT)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.as_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dumper);
  __Pyx_XDECREF(__pyx_v_rv);
  __Pyx_XDECREF(__pyx_v_oid);
  __Pyx_XDECREF(__pyx_v_type_sql);
  __Pyx_XDECREF(__pyx_v_ti);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_11as_literal(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_11as_literal = {"as_literal", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_11as_literal, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_11as_literal(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("as_literal (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_10as_literal(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_10as_literal(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("as_literal", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_11Transformer_as_literal(__pyx_v_self, __pyx_v_obj, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.as_literal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":246
 *         return rv
 * 
 *     def get_dumper(self, obj, format) -> "Dumper":             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>format)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_13get_dumper(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_13get_dumper = {"get_dumper", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_13get_dumper, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_13get_dumper(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_dumper (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 246, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 246, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_dumper", 0) < (0)) __PYX_ERR(9, 246, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_dumper", 1, 2, 2, i); __PYX_ERR(9, 246, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 246, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 246, __pyx_L3_error)
    }
    __pyx_v_obj = values[0];
    __pyx_v_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_dumper", 1, 2, 2, __pyx_nargs); __PYX_ERR(9, 246, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.get_dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_12get_dumper(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_12get_dumper(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
  PyObject *__pyx_v_row_dumper;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dumper", 0);

  /* "psycopg_c/_psycopg/transform.pyx":247
 * 
 *     def get_dumper(self, obj, format) -> "Dumper":
 *         cdef PyObject *row_dumper = self.get_row_dumper(             # <<<<<<<<<<<<<<
 *             <PyObject *>obj, <PyObject *>format)
 *         return (<RowDumper>row_dumper).pydumper
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->get_row_dumper(__pyx_v_self, ((PyObject *)__pyx_v_obj), ((PyObject *)__pyx_v_format)); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(9, 247, __pyx_L1_error)
  __pyx_v_row_dumper = __pyx_t_1;

  /* "psycopg_c/_psycopg/transform.pyx":249
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>format)
 *         return (<RowDumper>row_dumper).pydumper             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *get_row_dumper(self, PyObject *obj, PyObject *fmt) except NULL:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->pydumper);
  __pyx_r = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_row_dumper)->pydumper;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":246
 *         return rv
 * 
 *     def get_dumper(self, obj, format) -> "Dumper":             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>format)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.get_dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":251
 *         return (<RowDumper>row_dumper).pydumper
 * 
 *     cdef PyObject *get_row_dumper(self, PyObject *obj, PyObject *fmt) except NULL:             # <<<<<<<<<<<<<<
 *         """
 *         Return a borrowed reference to the RowDumper for the given obj/fmt.
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_get_row_dumper(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_fmt) {
  PyObject *__pyx_v_cache;
  PyObject *__pyx_v_ptr;
  PyObject *__pyx_v_ptr1;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_row_dumper = 0;
  PyTypeObject *__pyx_v_key = NULL;
  PyObject *__pyx_v_bfmt = NULL;
  char __pyx_v_cfmt;
  PyObject *__pyx_v_dcls = NULL;
  PyObject *__pyx_v_dumper = NULL;
  PyObject *__pyx_v_key1 = NULL;
  PyObject *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_row_dumper", 0);

  /* "psycopg_c/_psycopg/transform.pyx":262
 * 
 *         # Normally, the type of the object dictates how to dump it
 *         key = type(<object>obj)             # <<<<<<<<<<<<<<
 * 
 *         # Establish where would the dumper be cached
*/
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_obj))));
  __pyx_v_key = ((PyTypeObject*)((PyObject *)Py_TYPE(((PyObject *)__pyx_v_obj))));

  /* "psycopg_c/_psycopg/transform.pyx":265
 * 
 *         # Establish where would the dumper be cached
 *         bfmt = PyUnicode_AsUTF8String(<object>fmt)             # <<<<<<<<<<<<<<
 *         cdef char cfmt = PyBytes_AS_STRING(bfmt)[0]
 *         if cfmt == b's':
*/
  __pyx_t_1 = PyUnicode_AsUTF8String(((PyObject *)__pyx_v_fmt)); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bfmt = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":266
 *         # Establish where would the dumper be cached
 *         bfmt = PyUnicode_AsUTF8String(<object>fmt)
 *         cdef char cfmt = PyBytes_AS_STRING(bfmt)[0]             # <<<<<<<<<<<<<<
 *         if cfmt == b's':
 *             if self._auto_dumpers is None:
*/
  __pyx_v_cfmt = (PyBytes_AS_STRING(__pyx_v_bfmt)[0]);

  /* "psycopg_c/_psycopg/transform.pyx":267
 *         bfmt = PyUnicode_AsUTF8String(<object>fmt)
 *         cdef char cfmt = PyBytes_AS_STRING(bfmt)[0]
 *         if cfmt == b's':             # <<<<<<<<<<<<<<
 *             if self._auto_dumpers is None:
 *                 self._auto_dumpers = {}
*/
  switch (__pyx_v_cfmt) {
    case 's':

    /* "psycopg_c/_psycopg/transform.pyx":268
 *         cdef char cfmt = PyBytes_AS_STRING(bfmt)[0]
 *         if cfmt == b's':
 *             if self._auto_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._auto_dumpers = {}
 *             cache = <PyObject *>self._auto_dumpers
*/
    __pyx_t_2 = (__pyx_v_self->_auto_dumpers == ((PyObject*)Py_None));
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/transform.pyx":269
 *         if cfmt == b's':
 *             if self._auto_dumpers is None:
 *                 self._auto_dumpers = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._auto_dumpers
 *         elif cfmt == b'b':
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 269, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->_auto_dumpers);
      __Pyx_DECREF(__pyx_v_self->_auto_dumpers);
      __pyx_v_self->_auto_dumpers = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":268
 *         cdef char cfmt = PyBytes_AS_STRING(bfmt)[0]
 *         if cfmt == b's':
 *             if self._auto_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._auto_dumpers = {}
 *             cache = <PyObject *>self._auto_dumpers
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":270
 *             if self._auto_dumpers is None:
 *                 self._auto_dumpers = {}
 *             cache = <PyObject *>self._auto_dumpers             # <<<<<<<<<<<<<<
 *         elif cfmt == b'b':
 *             if self._binary_dumpers is None:
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_auto_dumpers);

    /* "psycopg_c/_psycopg/transform.pyx":267
 *         bfmt = PyUnicode_AsUTF8String(<object>fmt)
 *         cdef char cfmt = PyBytes_AS_STRING(bfmt)[0]
 *         if cfmt == b's':             # <<<<<<<<<<<<<<
 *             if self._auto_dumpers is None:
 *                 self._auto_dumpers = {}
*/
    break;
    case 'b':

    /* "psycopg_c/_psycopg/transform.pyx":272
 *             cache = <PyObject *>self._auto_dumpers
 *         elif cfmt == b'b':
 *             if self._binary_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._binary_dumpers = {}
 *             cache = <PyObject *>self._binary_dumpers
*/
    __pyx_t_2 = (__pyx_v_self->_binary_dumpers == ((PyObject*)Py_None));
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/transform.pyx":273
 *         elif cfmt == b'b':
 *             if self._binary_dumpers is None:
 *                 self._binary_dumpers = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._binary_dumpers
 *         elif cfmt == b't':
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 273, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->_binary_dumpers);
      __Pyx_DECREF(__pyx_v_self->_binary_dumpers);
      __pyx_v_self->_binary_dumpers = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":272
 *             cache = <PyObject *>self._auto_dumpers
 *         elif cfmt == b'b':
 *             if self._binary_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._binary_dumpers = {}
 *             cache = <PyObject *>self._binary_dumpers
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":274
 *             if self._binary_dumpers is None:
 *                 self._binary_dumpers = {}
 *             cache = <PyObject *>self._binary_dumpers             # <<<<<<<<<<<<<<
 *         elif cfmt == b't':
 *             if self._text_dumpers is None:
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_binary_dumpers);

    /* "psycopg_c/_psycopg/transform.pyx":271
 *                 self._auto_dumpers = {}
 *             cache = <PyObject *>self._auto_dumpers
 *         elif cfmt == b'b':             # <<<<<<<<<<<<<<
 *             if self._binary_dumpers is None:
 *                 self._binary_dumpers = {}
*/
    break;
    case 't':

    /* "psycopg_c/_psycopg/transform.pyx":276
 *             cache = <PyObject *>self._binary_dumpers
 *         elif cfmt == b't':
 *             if self._text_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._text_dumpers = {}
 *             cache = <PyObject *>self._text_dumpers
*/
    __pyx_t_2 = (__pyx_v_self->_text_dumpers == ((PyObject*)Py_None));
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/transform.pyx":277
 *         elif cfmt == b't':
 *             if self._text_dumpers is None:
 *                 self._text_dumpers = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._text_dumpers
 *         else:
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 277, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->_text_dumpers);
      __Pyx_DECREF(__pyx_v_self->_text_dumpers);
      __pyx_v_self->_text_dumpers = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":276
 *             cache = <PyObject *>self._binary_dumpers
 *         elif cfmt == b't':
 *             if self._text_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._text_dumpers = {}
 *             cache = <PyObject *>self._text_dumpers
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":278
 *             if self._text_dumpers is None:
 *                 self._text_dumpers = {}
 *             cache = <PyObject *>self._text_dumpers             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError(
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_text_dumpers);

    /* "psycopg_c/_psycopg/transform.pyx":275
 *                 self._binary_dumpers = {}
 *             cache = <PyObject *>self._binary_dumpers
 *         elif cfmt == b't':             # <<<<<<<<<<<<<<
 *             if self._text_dumpers is None:
 *                 self._text_dumpers = {}
*/
    break;
    default:

    /* "psycopg_c/_psycopg/transform.pyx":280
 *             cache = <PyObject *>self._text_dumpers
 *         else:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 f"format should be a psycopg.adapt.Format, not {<object>fmt}")
 * 
*/
    __pyx_t_3 = NULL;

    /* "psycopg_c/_psycopg/transform.pyx":281
 *         else:
 *             raise ValueError(
 *                 f"format should be a psycopg.adapt.Format, not {<object>fmt}")             # <<<<<<<<<<<<<<
 * 
 *         # Reuse an existing Dumper class for objects of the same type
*/
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(((PyObject *)__pyx_v_fmt), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_format_should_be_a_psycopg_adapt, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 280, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(9, 280, __pyx_L1_error)
    break;
  }

  /* "psycopg_c/_psycopg/transform.pyx":284
 * 
 *         # Reuse an existing Dumper class for objects of the same type
 *         ptr = PyDict_GetItem(<object>cache, key)             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             dcls = PyObject_CallFunctionObjArgs(
*/
  __pyx_v_ptr = PyDict_GetItem(((PyObject *)__pyx_v_cache), ((PyObject *)__pyx_v_key));

  /* "psycopg_c/_psycopg/transform.pyx":285
 *         # Reuse an existing Dumper class for objects of the same type
 *         ptr = PyDict_GetItem(<object>cache, key)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper, <PyObject *>key, fmt, NULL)
*/
  __pyx_t_2 = (__pyx_v_ptr == NULL);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":287
 *         if ptr == NULL:
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper, <PyObject *>key, fmt, NULL)             # <<<<<<<<<<<<<<
 *             dumper = PyObject_CallFunctionObjArgs(
 *                 dcls, <PyObject *>key, <PyObject *>self, NULL)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->adapters, __pyx_mstate_global->__pyx_n_u_get_dumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 287, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "psycopg_c/_psycopg/transform.pyx":286
 *         ptr = PyDict_GetItem(<object>cache, key)
 *         if ptr == NULL:
 *             dcls = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 self.adapters.get_dumper, <PyObject *>key, fmt, NULL)
 *             dumper = PyObject_CallFunctionObjArgs(
*/
    __pyx_t_5 = PyObject_CallFunctionObjArgs(__pyx_t_1, ((PyObject *)__pyx_v_key), __pyx_v_fmt, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 286, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_v_dcls = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":288
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper, <PyObject *>key, fmt, NULL)
 *             dumper = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 dcls, <PyObject *>key, <PyObject *>self, NULL)
 * 
*/
    __pyx_t_5 = PyObject_CallFunctionObjArgs(__pyx_v_dcls, ((PyObject *)__pyx_v_key), ((PyObject *)__pyx_v_self), NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_dumper = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":291
 *                 dcls, <PyObject *>key, <PyObject *>self, NULL)
 * 
 *             row_dumper = _as_row_dumper(dumper)             # <<<<<<<<<<<<<<
 *             PyDict_SetItem(<object>cache, key, row_dumper)
 *             ptr = <PyObject *>row_dumper
*/
    __pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__as_row_dumper(__pyx_v_dumper); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 291, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper))))) __PYX_ERR(9, 291, __pyx_L1_error)
    __pyx_v_row_dumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":292
 * 
 *             row_dumper = _as_row_dumper(dumper)
 *             PyDict_SetItem(<object>cache, key, row_dumper)             # <<<<<<<<<<<<<<
 *             ptr = <PyObject *>row_dumper
 * 
*/
    __pyx_t_7 = PyDict_SetItem(((PyObject *)__pyx_v_cache), ((PyObject *)__pyx_v_key), ((PyObject *)__pyx_v_row_dumper)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(9, 292, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":293
 *             row_dumper = _as_row_dumper(dumper)
 *             PyDict_SetItem(<object>cache, key, row_dumper)
 *             ptr = <PyObject *>row_dumper             # <<<<<<<<<<<<<<
 * 
 *         # Check if the dumper requires an upgrade to handle this specific value
*/
    __pyx_v_ptr = ((PyObject *)__pyx_v_row_dumper);

    /* "psycopg_c/_psycopg/transform.pyx":285
 *         # Reuse an existing Dumper class for objects of the same type
 *         ptr = PyDict_GetItem(<object>cache, key)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper, <PyObject *>key, fmt, NULL)
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":296
 * 
 *         # Check if the dumper requires an upgrade to handle this specific value
 *         if (<RowDumper>ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *             key1 = (<RowDumper>ptr).cdumper.get_key(<object>obj, <object>fmt)
 *         else:
*/
  __pyx_t_2 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->cdumper) != Py_None);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":297
 *         # Check if the dumper requires an upgrade to handle this specific value
 *         if (<RowDumper>ptr).cdumper is not None:
 *             key1 = (<RowDumper>ptr).cdumper.get_key(<object>obj, <object>fmt)             # <<<<<<<<<<<<<<
 *         else:
 *             key1 = PyObject_CallFunctionObjArgs(
*/
    __pyx_t_5 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->cdumper->__pyx_vtab)->get_key(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->cdumper, ((PyObject *)__pyx_v_obj), ((PyObject *)__pyx_v_fmt), 0); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_v_key1 = __pyx_t_5;
    __pyx_t_5 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":296
 * 
 *         # Check if the dumper requires an upgrade to handle this specific value
 *         if (<RowDumper>ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *             key1 = (<RowDumper>ptr).cdumper.get_key(<object>obj, <object>fmt)
 *         else:
*/
    goto __pyx_L7;
  }

  /* "psycopg_c/_psycopg/transform.pyx":299
 *             key1 = (<RowDumper>ptr).cdumper.get_key(<object>obj, <object>fmt)
 *         else:
 *             key1 = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>ptr).pydumper.get_key, obj, fmt, NULL)
 *         if key1 is key:
*/
  /*else*/ {

    /* "psycopg_c/_psycopg/transform.pyx":300
 *         else:
 *             key1 = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>ptr).pydumper.get_key, obj, fmt, NULL)             # <<<<<<<<<<<<<<
 *         if key1 is key:
 *             return ptr
*/
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->pydumper, __pyx_mstate_global->__pyx_n_u_get_key); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 300, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);

    /* "psycopg_c/_psycopg/transform.pyx":299
 *             key1 = (<RowDumper>ptr).cdumper.get_key(<object>obj, <object>fmt)
 *         else:
 *             key1 = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>ptr).pydumper.get_key, obj, fmt, NULL)
 *         if key1 is key:
*/
    __pyx_t_1 = PyObject_CallFunctionObjArgs(__pyx_t_5, __pyx_v_obj, __pyx_v_fmt, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_key1 = __pyx_t_1;
    __pyx_t_1 = 0;
  }
  __pyx_L7:;

  /* "psycopg_c/_psycopg/transform.pyx":301
 *             key1 = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>ptr).pydumper.get_key, obj, fmt, NULL)
 *         if key1 is key:             # <<<<<<<<<<<<<<
 *             return ptr
 * 
*/
  __pyx_t_2 = (__pyx_v_key1 == ((PyObject *)__pyx_v_key));
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":302
 *                 (<RowDumper>ptr).pydumper.get_key, obj, fmt, NULL)
 *         if key1 is key:
 *             return ptr             # <<<<<<<<<<<<<<
 * 
 *         # If it does, ask the dumper to create its own upgraded version
*/
    __pyx_r = __pyx_v_ptr;
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":301
 *             key1 = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>ptr).pydumper.get_key, obj, fmt, NULL)
 *         if key1 is key:             # <<<<<<<<<<<<<<
 *             return ptr
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":305
 * 
 *         # If it does, ask the dumper to create its own upgraded version
 *         ptr1 = PyDict_GetItem(<object>cache, key1)             # <<<<<<<<<<<<<<
 *         if ptr1 != NULL:
 *             return ptr1
*/
  __pyx_v_ptr1 = PyDict_GetItem(((PyObject *)__pyx_v_cache), __pyx_v_key1);

  /* "psycopg_c/_psycopg/transform.pyx":306
 *         # If it does, ask the dumper to create its own upgraded version
 *         ptr1 = PyDict_GetItem(<object>cache, key1)
 *         if ptr1 != NULL:             # <<<<<<<<<<<<<<
 *             return ptr1
 * 
*/
  __pyx_t_2 = (__pyx_v_ptr1 != NULL);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":307
 *         ptr1 = PyDict_GetItem(<object>cache, key1)
 *         if ptr1 != NULL:
 *             return ptr1             # <<<<<<<<<<<<<<
 * 
 *         if (<RowDumper>ptr).cdumper is not None:
*/
    __pyx_r = __pyx_v_ptr1;
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":306
 *         # If it does, ask the dumper to create its own upgraded version
 *         ptr1 = PyDict_GetItem(<object>cache, key1)
 *         if ptr1 != NULL:             # <<<<<<<<<<<<<<
 *             return ptr1
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":309
 *             return ptr1
 * 
 *         if (<RowDumper>ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *             dumper = (<RowDumper>ptr).cdumper.upgrade(<object>obj, <object>fmt)
 *         else:
*/
  __pyx_t_2 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->cdumper) != Py_None);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":310
 * 
 *         if (<RowDumper>ptr).cdumper is not None:
 *             dumper = (<RowDumper>ptr).cdumper.upgrade(<object>obj, <object>fmt)             # <<<<<<<<<<<<<<
 *         else:
 *             dumper = PyObject_CallFunctionObjArgs(
*/
    __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->cdumper->__pyx_vtab)->upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->cdumper, ((PyObject *)__pyx_v_obj), ((PyObject *)__pyx_v_fmt), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_dumper, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":309
 *             return ptr1
 * 
 *         if (<RowDumper>ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *             dumper = (<RowDumper>ptr).cdumper.upgrade(<object>obj, <object>fmt)
 *         else:
*/
    goto __pyx_L10;
  }

  /* "psycopg_c/_psycopg/transform.pyx":312
 *             dumper = (<RowDumper>ptr).cdumper.upgrade(<object>obj, <object>fmt)
 *         else:
 *             dumper = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>ptr).pydumper.upgrade, obj, fmt, NULL)
 * 
*/
  /*else*/ {

    /* "psycopg_c/_psycopg/transform.pyx":313
 *         else:
 *             dumper = PyObject_CallFunctionObjArgs(
 *                 (<RowDumper>ptr).pydumper.upgrade, obj, fmt, NULL)             # <<<<<<<<<<<<<<
 * 
 *         row_dumper = _as_row_dumper(dumper)
*/
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_ptr)->pydumper, __pyx_mstate_global->__pyx_n_u_upgrade); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 313, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);

    /* "psycopg_c/_psycopg/transform.pyx":312
 *             dumper = (<RowDumper>ptr).cdumper.upgrade(<object>obj, <object>fmt)
 *         else:
 *             dumper = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 (<RowDumper>ptr).pydumper.upgrade, obj, fmt, NULL)
 * 
*/
    __pyx_t_5 = PyObject_CallFunctionObjArgs(__pyx_t_1, __pyx_v_obj, __pyx_v_fmt, NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 312, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_dumper, __pyx_t_5);
    __pyx_t_5 = 0;
  }
  __pyx_L10:;

  /* "psycopg_c/_psycopg/transform.pyx":315
 *                 (<RowDumper>ptr).pydumper.upgrade, obj, fmt, NULL)
 * 
 *         row_dumper = _as_row_dumper(dumper)             # <<<<<<<<<<<<<<
 *         PyDict_SetItem(<object>cache, key1, row_dumper)
 *         return <PyObject *>row_dumper
*/
  __pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__as_row_dumper(__pyx_v_dumper); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper))))) __PYX_ERR(9, 315, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_row_dumper, ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_t_5));
  __pyx_t_5 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":316
 * 
 *         row_dumper = _as_row_dumper(dumper)
 *         PyDict_SetItem(<object>cache, key1, row_dumper)             # <<<<<<<<<<<<<<
 *         return <PyObject *>row_dumper
 * 
*/
  __pyx_t_7 = PyDict_SetItem(((PyObject *)__pyx_v_cache), __pyx_v_key1, ((PyObject *)__pyx_v_row_dumper)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(9, 316, __pyx_L1_error)

  /* "psycopg_c/_psycopg/transform.pyx":317
 *         row_dumper = _as_row_dumper(dumper)
 *         PyDict_SetItem(<object>cache, key1, row_dumper)
 *         return <PyObject *>row_dumper             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *get_dumper_by_oid(self, PyObject *oid, PyObject *fmt) except NULL:
*/
  __pyx_r = ((PyObject *)__pyx_v_row_dumper);
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":251
 *         return (<RowDumper>row_dumper).pydumper
 * 
 *     cdef PyObject *get_row_dumper(self, PyObject *obj, PyObject *fmt) except NULL:             # <<<<<<<<<<<<<<
 *         """
 *         Return a borrowed reference to the RowDumper for the given obj/fmt.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.get_row_dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_row_dumper);
  __Pyx_XDECREF((PyObject *)__pyx_v_key);
  __Pyx_XDECREF(__pyx_v_bfmt);
  __Pyx_XDECREF(__pyx_v_dcls);
  __Pyx_XDECREF(__pyx_v_dumper);
  __Pyx_XDECREF(__pyx_v_key1);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":319
 *         return <PyObject *>row_dumper
 * 
 *     cdef PyObject *get_dumper_by_oid(self, PyObject *oid, PyObject *fmt) except NULL:             # <<<<<<<<<<<<<<
 *         """
 *         Return a borrowed reference to the RowDumper for the given oid/fmt.
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_get_dumper_by_oid(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_oid, PyObject *__pyx_v_fmt) {
  PyObject *__pyx_v_ptr;
  PyObject *__pyx_v_cache;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_row_dumper = 0;
  int __pyx_v_cfmt;
  PyObject *__pyx_v_dcls = NULL;
  PyObject *__pyx_v_dumper = NULL;
  PyObject *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_dumper_by_oid", 0);

  /* "psycopg_c/_psycopg/transform.pyx":328
 * 
 *         # Establish where would the dumper be cached
 *         cdef int cfmt = <object>fmt             # <<<<<<<<<<<<<<
 *         if cfmt == 0:
 *             if self._oid_text_dumpers is None:
*/
  __pyx_t_1 = __Pyx_PyLong_As_int(((PyObject *)__pyx_v_fmt)); if (unlikely((__pyx_t_1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 328, __pyx_L1_error)
  __pyx_v_cfmt = __pyx_t_1;

  /* "psycopg_c/_psycopg/transform.pyx":329
 *         # Establish where would the dumper be cached
 *         cdef int cfmt = <object>fmt
 *         if cfmt == 0:             # <<<<<<<<<<<<<<
 *             if self._oid_text_dumpers is None:
 *                 self._oid_text_dumpers = {}
*/
  switch (__pyx_v_cfmt) {
    case 0:

    /* "psycopg_c/_psycopg/transform.pyx":330
 *         cdef int cfmt = <object>fmt
 *         if cfmt == 0:
 *             if self._oid_text_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._oid_text_dumpers = {}
 *             cache = <PyObject *>self._oid_text_dumpers
*/
    __pyx_t_2 = (__pyx_v_self->_oid_text_dumpers == ((PyObject*)Py_None));
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/transform.pyx":331
 *         if cfmt == 0:
 *             if self._oid_text_dumpers is None:
 *                 self._oid_text_dumpers = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._oid_text_dumpers
 *         elif cfmt == 1:
*/
      __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 331, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_v_self->_oid_text_dumpers);
      __Pyx_DECREF(__pyx_v_self->_oid_text_dumpers);
      __pyx_v_self->_oid_text_dumpers = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":330
 *         cdef int cfmt = <object>fmt
 *         if cfmt == 0:
 *             if self._oid_text_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._oid_text_dumpers = {}
 *             cache = <PyObject *>self._oid_text_dumpers
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":332
 *             if self._oid_text_dumpers is None:
 *                 self._oid_text_dumpers = {}
 *             cache = <PyObject *>self._oid_text_dumpers             # <<<<<<<<<<<<<<
 *         elif cfmt == 1:
 *             if self._oid_binary_dumpers is None:
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_oid_text_dumpers);

    /* "psycopg_c/_psycopg/transform.pyx":329
 *         # Establish where would the dumper be cached
 *         cdef int cfmt = <object>fmt
 *         if cfmt == 0:             # <<<<<<<<<<<<<<
 *             if self._oid_text_dumpers is None:
 *                 self._oid_text_dumpers = {}
*/
    break;
    case 1:

    /* "psycopg_c/_psycopg/transform.pyx":334
 *             cache = <PyObject *>self._oid_text_dumpers
 *         elif cfmt == 1:
 *             if self._oid_binary_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._oid_binary_dumpers = {}
 *             cache = <PyObject *>self._oid_binary_dumpers
*/
    __pyx_t_2 = (__pyx_v_self->_oid_binary_dumpers == ((PyObject*)Py_None));
    if (__pyx_t_2) {

      /* "psycopg_c/_psycopg/transform.pyx":335
 *         elif cfmt == 1:
 *             if self._oid_binary_dumpers is None:
 *                 self._oid_binary_dumpers = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._oid_binary_dumpers
 *         else:
*/
      __pyx_t_3 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 335, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __Pyx_GOTREF(__pyx_v_self->_oid_binary_dumpers);
      __Pyx_DECREF(__pyx_v_self->_oid_binary_dumpers);
      __pyx_v_self->_oid_binary_dumpers = ((PyObject*)__pyx_t_3);
      __pyx_t_3 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":334
 *             cache = <PyObject *>self._oid_text_dumpers
 *         elif cfmt == 1:
 *             if self._oid_binary_dumpers is None:             # <<<<<<<<<<<<<<
 *                 self._oid_binary_dumpers = {}
 *             cache = <PyObject *>self._oid_binary_dumpers
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":336
 *             if self._oid_binary_dumpers is None:
 *                 self._oid_binary_dumpers = {}
 *             cache = <PyObject *>self._oid_binary_dumpers             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError(
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_oid_binary_dumpers);

    /* "psycopg_c/_psycopg/transform.pyx":333
 *                 self._oid_text_dumpers = {}
 *             cache = <PyObject *>self._oid_text_dumpers
 *         elif cfmt == 1:             # <<<<<<<<<<<<<<
 *             if self._oid_binary_dumpers is None:
 *                 self._oid_binary_dumpers = {}
*/
    break;
    default:

    /* "psycopg_c/_psycopg/transform.pyx":338
 *             cache = <PyObject *>self._oid_binary_dumpers
 *         else:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 f"format should be a psycopg.pq.Format, not {<object>fmt}")
 * 
*/
    __pyx_t_4 = NULL;

    /* "psycopg_c/_psycopg/transform.pyx":339
 *         else:
 *             raise ValueError(
 *                 f"format should be a psycopg.pq.Format, not {<object>fmt}")             # <<<<<<<<<<<<<<
 * 
 *         # Reuse an existing Dumper class for objects of the same type
*/
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(((PyObject *)__pyx_v_fmt), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_format_should_be_a_psycopg_pq_Fo, __pyx_t_5); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 339, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_6};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(9, 338, __pyx_L1_error)
    break;
  }

  /* "psycopg_c/_psycopg/transform.pyx":342
 * 
 *         # Reuse an existing Dumper class for objects of the same type
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             dcls = PyObject_CallFunctionObjArgs(
*/
  __pyx_v_ptr = PyDict_GetItem(((PyObject *)__pyx_v_cache), ((PyObject *)__pyx_v_oid));

  /* "psycopg_c/_psycopg/transform.pyx":343
 *         # Reuse an existing Dumper class for objects of the same type
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper_by_oid, oid, fmt, NULL)
*/
  __pyx_t_2 = (__pyx_v_ptr == NULL);
  if (__pyx_t_2) {

    /* "psycopg_c/_psycopg/transform.pyx":345
 *         if ptr == NULL:
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper_by_oid, oid, fmt, NULL)             # <<<<<<<<<<<<<<
 *             dumper = PyObject_CallFunctionObjArgs(
 *                 dcls, <PyObject *>NoneType, <PyObject *>self, NULL)
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_self->adapters, __pyx_mstate_global->__pyx_n_u_get_dumper_by_oid); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 345, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "psycopg_c/_psycopg/transform.pyx":344
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
 *         if ptr == NULL:
 *             dcls = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 self.adapters.get_dumper_by_oid, oid, fmt, NULL)
 *             dumper = PyObject_CallFunctionObjArgs(
*/
    __pyx_t_6 = PyObject_CallFunctionObjArgs(__pyx_t_3, __pyx_v_oid, __pyx_v_fmt, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 344, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_dcls = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":347
 *                 self.adapters.get_dumper_by_oid, oid, fmt, NULL)
 *             dumper = PyObject_CallFunctionObjArgs(
 *                 dcls, <PyObject *>NoneType, <PyObject *>self, NULL)             # <<<<<<<<<<<<<<
 * 
 *             row_dumper = _as_row_dumper(dumper)
*/
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_NoneType); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);

    /* "psycopg_c/_psycopg/transform.pyx":346
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper_by_oid, oid, fmt, NULL)
 *             dumper = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 dcls, <PyObject *>NoneType, <PyObject *>self, NULL)
 * 
*/
    __pyx_t_3 = PyObject_CallFunctionObjArgs(__pyx_v_dcls, ((PyObject *)__pyx_t_6), ((PyObject *)__pyx_v_self), NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 346, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_dumper = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":349
 *                 dcls, <PyObject *>NoneType, <PyObject *>self, NULL)
 * 
 *             row_dumper = _as_row_dumper(dumper)             # <<<<<<<<<<<<<<
 *             PyDict_SetItem(<object>cache, <object>oid, row_dumper)
 *             ptr = <PyObject *>row_dumper
*/
    __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg__as_row_dumper(__pyx_v_dumper); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 349, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper))))) __PYX_ERR(9, 349, __pyx_L1_error)
    __pyx_v_row_dumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":350
 * 
 *             row_dumper = _as_row_dumper(dumper)
 *             PyDict_SetItem(<object>cache, <object>oid, row_dumper)             # <<<<<<<<<<<<<<
 *             ptr = <PyObject *>row_dumper
 * 
*/
    __pyx_t_1 = PyDict_SetItem(((PyObject *)__pyx_v_cache), ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_v_row_dumper)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(9, 350, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":351
 *             row_dumper = _as_row_dumper(dumper)
 *             PyDict_SetItem(<object>cache, <object>oid, row_dumper)
 *             ptr = <PyObject *>row_dumper             # <<<<<<<<<<<<<<
 * 
 *         return ptr
*/
    __pyx_v_ptr = ((PyObject *)__pyx_v_row_dumper);

    /* "psycopg_c/_psycopg/transform.pyx":343
 *         # Reuse an existing Dumper class for objects of the same type
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             dcls = PyObject_CallFunctionObjArgs(
 *                 self.adapters.get_dumper_by_oid, oid, fmt, NULL)
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":353
 *             ptr = <PyObject *>row_dumper
 * 
 *         return ptr             # <<<<<<<<<<<<<<
 * 
 *     cpdef dump_sequence(self, object params, object formats):
*/
  __pyx_r = __pyx_v_ptr;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":319
 *         return <PyObject *>row_dumper
 * 
 *     cdef PyObject *get_dumper_by_oid(self, PyObject *oid, PyObject *fmt) except NULL:             # <<<<<<<<<<<<<<
 *         """
 *         Return a borrowed reference to the RowDumper for the given oid/fmt.
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.get_dumper_by_oid", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_row_dumper);
  __Pyx_XDECREF(__pyx_v_dcls);
  __Pyx_XDECREF(__pyx_v_dumper);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":355
 *         return ptr
 * 
 *     cpdef dump_sequence(self, object params, object formats):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef PyObject *dumper_ptr  # borrowed pointer to row dumper
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_15dump_sequence(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_dump_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_params, PyObject *__pyx_v_formats, int __pyx_skip_dispatch) {
  int __pyx_v_i;
  PyObject *__pyx_v_dumper_ptr;
  PyObject *__pyx_v_dumped = 0;
  Py_ssize_t __pyx_v_size;
  PyObject *__pyx_v_params_fast = 0;
  PyObject *__pyx_v_formats_fast = 0;
  Py_ssize_t __pyx_v_nparams;
  PyObject *__pyx_v_out = 0;
  PyObject *__pyx_v_param;
  PyObject *__pyx_v_dumpers = NULL;
  PyObject *__pyx_v_types = 0;
  PyObject *__pyx_v_pqformats = 0;
  PyObject *__pyx_v_format;
  PyObject *__pyx_v_oid = NULL;
  PyObject *__pyx_v_fmt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_sequence", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_dump_sequence); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 355, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_11Transformer_15dump_sequence)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_params, __pyx_v_formats};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 355, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "psycopg_c/_psycopg/transform.pyx":361
 *         cdef Py_ssize_t size
 * 
 *         cdef params_fast = PySequence_Fast(             # <<<<<<<<<<<<<<
 *             params, "'params' is not a valid sequence")
 *         cdef formats_fast = PySequence_Fast(
*/
  __pyx_t_1 = PySequence_Fast(__pyx_v_params, ((char *)"'params' is not a valid sequence")); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 361, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_params_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":363
 *         cdef params_fast = PySequence_Fast(
 *             params, "'params' is not a valid sequence")
 *         cdef formats_fast = PySequence_Fast(             # <<<<<<<<<<<<<<
 *             formats, "'formats' is not a valid sequence")
 * 
*/
  __pyx_t_1 = PySequence_Fast(__pyx_v_formats, ((char *)"'formats' is not a valid sequence")); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 363, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_formats_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":366
 *             formats, "'formats' is not a valid sequence")
 * 
 *         cdef Py_ssize_t nparams = PySequence_Fast_GET_SIZE(params_fast)             # <<<<<<<<<<<<<<
 *         cdef list out = PyList_New(nparams)
 *         cdef PyObject *param
*/
  __pyx_v_nparams = PySequence_Fast_GET_SIZE(__pyx_v_params_fast);

  /* "psycopg_c/_psycopg/transform.pyx":367
 * 
 *         cdef Py_ssize_t nparams = PySequence_Fast_GET_SIZE(params_fast)
 *         cdef list out = PyList_New(nparams)             # <<<<<<<<<<<<<<
 *         cdef PyObject *param
 * 
*/
  __pyx_t_1 = PyList_New(__pyx_v_nparams); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 367, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":370
 *         cdef PyObject *param
 * 
 *         dumpers = self._row_dumpers             # <<<<<<<<<<<<<<
 *         if dumpers:
 *             for i in range(nparams):
*/
  __pyx_t_1 = __pyx_v_self->_row_dumpers;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_dumpers = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":371
 * 
 *         dumpers = self._row_dumpers
 *         if dumpers:             # <<<<<<<<<<<<<<
 *             for i in range(nparams):
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)
*/
  if (__pyx_v_dumpers == Py_None) __pyx_t_6 = 0;
  else
  {
    Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_dumpers);
    if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(9, 371, __pyx_L1_error)
    __pyx_t_6 = (__pyx_temp != 0);
  }

  if (__pyx_t_6) {

    /* "psycopg_c/_psycopg/transform.pyx":372
 *         dumpers = self._row_dumpers
 *         if dumpers:
 *             for i in range(nparams):             # <<<<<<<<<<<<<<
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)
 *                 if param != <PyObject *>None:
*/
    __pyx_t_7 = __pyx_v_nparams;
    __pyx_t_8 = __pyx_t_7;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "psycopg_c/_psycopg/transform.pyx":373
 *         if dumpers:
 *             for i in range(nparams):
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)             # <<<<<<<<<<<<<<
 *                 if param != <PyObject *>None:
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)
*/
      __pyx_v_param = PySequence_Fast_GET_ITEM(__pyx_v_params_fast, __pyx_v_i);

      /* "psycopg_c/_psycopg/transform.pyx":374
 *             for i in range(nparams):
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)
 *                 if param != <PyObject *>None:             # <<<<<<<<<<<<<<
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:
*/
      __pyx_t_6 = (__pyx_v_param != ((PyObject *)Py_None));
      if (__pyx_t_6) {

        /* "psycopg_c/_psycopg/transform.pyx":375
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)
 *                 if param != <PyObject *>None:
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)             # <<<<<<<<<<<<<<
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:
 *                         dumped = PyByteArray_FromStringAndSize("", 0)
*/
        __pyx_v_dumper_ptr = PyList_GET_ITEM(__pyx_v_dumpers, __pyx_v_i);

        /* "psycopg_c/_psycopg/transform.pyx":376
 *                 if param != <PyObject *>None:
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *                         dumped = PyByteArray_FromStringAndSize("", 0)
 *                         size = (<RowDumper>dumper_ptr).cdumper.cdump(
*/
        __pyx_t_6 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->cdumper) != Py_None);
        if (__pyx_t_6) {

          /* "psycopg_c/_psycopg/transform.pyx":377
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:
 *                         dumped = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 *                         size = (<RowDumper>dumper_ptr).cdumper.cdump(
 *                             <object>param, <bytearray>dumped, 0)
*/
          __pyx_t_1 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 377, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
          __Pyx_XDECREF_SET(__pyx_v_dumped, __pyx_t_1);
          __pyx_t_1 = 0;

          /* "psycopg_c/_psycopg/transform.pyx":378
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:
 *                         dumped = PyByteArray_FromStringAndSize("", 0)
 *                         size = (<RowDumper>dumper_ptr).cdumper.cdump(             # <<<<<<<<<<<<<<
 *                             <object>param, <bytearray>dumped, 0)
 *                         PyByteArray_Resize(dumped, size)
*/
          __pyx_t_10 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->cdumper->__pyx_vtab)->cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->cdumper, ((PyObject *)__pyx_v_param), ((PyObject*)__pyx_v_dumped), 0); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1L))) __PYX_ERR(9, 378, __pyx_L1_error)
          __pyx_v_size = __pyx_t_10;

          /* "psycopg_c/_psycopg/transform.pyx":380
 *                         size = (<RowDumper>dumper_ptr).cdumper.cdump(
 *                             <object>param, <bytearray>dumped, 0)
 *                         PyByteArray_Resize(dumped, size)             # <<<<<<<<<<<<<<
 *                     else:
 *                         dumped = PyObject_CallFunctionObjArgs(
*/
          __pyx_t_11 = PyByteArray_Resize(__pyx_v_dumped, __pyx_v_size); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(9, 380, __pyx_L1_error)

          /* "psycopg_c/_psycopg/transform.pyx":376
 *                 if param != <PyObject *>None:
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *                         dumped = PyByteArray_FromStringAndSize("", 0)
 *                         size = (<RowDumper>dumper_ptr).cdumper.cdump(
*/
          goto __pyx_L7;
        }

        /* "psycopg_c/_psycopg/transform.pyx":382
 *                         PyByteArray_Resize(dumped, size)
 *                     else:
 *                         dumped = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                             (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 else:
*/
        /*else*/ {

          /* "psycopg_c/_psycopg/transform.pyx":383
 *                     else:
 *                         dumped = PyObject_CallFunctionObjArgs(
 *                             (<RowDumper>dumper_ptr).dumpfunc, param, NULL)             # <<<<<<<<<<<<<<
 *                 else:
 *                     dumped = None
*/
          __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->dumpfunc;
          __Pyx_INCREF(__pyx_t_1);

          /* "psycopg_c/_psycopg/transform.pyx":382
 *                         PyByteArray_Resize(dumped, size)
 *                     else:
 *                         dumped = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                             (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 else:
*/
          __pyx_t_2 = PyObject_CallFunctionObjArgs(__pyx_t_1, __pyx_v_param, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 382, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
          __Pyx_XDECREF_SET(__pyx_v_dumped, __pyx_t_2);
          __pyx_t_2 = 0;
        }
        __pyx_L7:;

        /* "psycopg_c/_psycopg/transform.pyx":374
 *             for i in range(nparams):
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)
 *                 if param != <PyObject *>None:             # <<<<<<<<<<<<<<
 *                     dumper_ptr = PyList_GET_ITEM(dumpers, i)
 *                     if (<RowDumper>dumper_ptr).cdumper is not None:
*/
        goto __pyx_L6;
      }

      /* "psycopg_c/_psycopg/transform.pyx":385
 *                             (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 else:
 *                     dumped = None             # <<<<<<<<<<<<<<
 * 
 *                 Py_INCREF(dumped)
*/
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __Pyx_XDECREF_SET(__pyx_v_dumped, Py_None);
      }
      __pyx_L6:;

      /* "psycopg_c/_psycopg/transform.pyx":387
 *                     dumped = None
 * 
 *                 Py_INCREF(dumped)             # <<<<<<<<<<<<<<
 *                 PyList_SET_ITEM(out, i, dumped)
 * 
*/
      Py_INCREF(__pyx_v_dumped);

      /* "psycopg_c/_psycopg/transform.pyx":388
 * 
 *                 Py_INCREF(dumped)
 *                 PyList_SET_ITEM(out, i, dumped)             # <<<<<<<<<<<<<<
 * 
 *             return out
*/
      PyList_SET_ITEM(__pyx_v_out, __pyx_v_i, __pyx_v_dumped);
    }

    /* "psycopg_c/_psycopg/transform.pyx":390
 *                 PyList_SET_ITEM(out, i, dumped)
 * 
 *             return out             # <<<<<<<<<<<<<<
 * 
 *         cdef tuple types = PyTuple_New(nparams)
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_out);
    __pyx_r = __pyx_v_out;
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":371
 * 
 *         dumpers = self._row_dumpers
 *         if dumpers:             # <<<<<<<<<<<<<<
 *             for i in range(nparams):
 *                 param = PySequence_Fast_GET_ITEM(params_fast, i)
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":392
 *             return out
 * 
 *         cdef tuple types = PyTuple_New(nparams)             # <<<<<<<<<<<<<<
 *         cdef list pqformats = PyList_New(nparams)
 *         cdef PyObject *format
*/
  __pyx_t_2 = PyTuple_New(__pyx_v_nparams); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_types = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":393
 * 
 *         cdef tuple types = PyTuple_New(nparams)
 *         cdef list pqformats = PyList_New(nparams)             # <<<<<<<<<<<<<<
 *         cdef PyObject *format
 * 
*/
  __pyx_t_2 = PyList_New(__pyx_v_nparams); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_pqformats = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":396
 *         cdef PyObject *format
 * 
 *         for i in range(nparams):             # <<<<<<<<<<<<<<
 *             param = PySequence_Fast_GET_ITEM(params_fast, i)
 *             if param != <PyObject *>None:
*/
  __pyx_t_7 = __pyx_v_nparams;
  __pyx_t_8 = __pyx_t_7;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "psycopg_c/_psycopg/transform.pyx":397
 * 
 *         for i in range(nparams):
 *             param = PySequence_Fast_GET_ITEM(params_fast, i)             # <<<<<<<<<<<<<<
 *             if param != <PyObject *>None:
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)
*/
    __pyx_v_param = PySequence_Fast_GET_ITEM(__pyx_v_params_fast, __pyx_v_i);

    /* "psycopg_c/_psycopg/transform.pyx":398
 *         for i in range(nparams):
 *             param = PySequence_Fast_GET_ITEM(params_fast, i)
 *             if param != <PyObject *>None:             # <<<<<<<<<<<<<<
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)
 *                 dumper_ptr = self.get_row_dumper(param, format)
*/
    __pyx_t_6 = (__pyx_v_param != ((PyObject *)Py_None));
    if (__pyx_t_6) {

      /* "psycopg_c/_psycopg/transform.pyx":399
 *             param = PySequence_Fast_GET_ITEM(params_fast, i)
 *             if param != <PyObject *>None:
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)             # <<<<<<<<<<<<<<
 *                 dumper_ptr = self.get_row_dumper(param, format)
 *                 if (<RowDumper>dumper_ptr).cdumper is not None:
*/
      __pyx_v_format = PySequence_Fast_GET_ITEM(__pyx_v_formats_fast, __pyx_v_i);

      /* "psycopg_c/_psycopg/transform.pyx":400
 *             if param != <PyObject *>None:
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)
 *                 dumper_ptr = self.get_row_dumper(param, format)             # <<<<<<<<<<<<<<
 *                 if (<RowDumper>dumper_ptr).cdumper is not None:
 *                     dumped = PyByteArray_FromStringAndSize("", 0)
*/
      __pyx_t_12 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->get_row_dumper(__pyx_v_self, __pyx_v_param, __pyx_v_format); if (unlikely(__pyx_t_12 == ((void *)NULL))) __PYX_ERR(9, 400, __pyx_L1_error)
      __pyx_v_dumper_ptr = __pyx_t_12;

      /* "psycopg_c/_psycopg/transform.pyx":401
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)
 *                 dumper_ptr = self.get_row_dumper(param, format)
 *                 if (<RowDumper>dumper_ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *                     dumped = PyByteArray_FromStringAndSize("", 0)
 *                     size = (<RowDumper>dumper_ptr).cdumper.cdump(
*/
      __pyx_t_6 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->cdumper) != Py_None);
      if (__pyx_t_6) {

        /* "psycopg_c/_psycopg/transform.pyx":402
 *                 dumper_ptr = self.get_row_dumper(param, format)
 *                 if (<RowDumper>dumper_ptr).cdumper is not None:
 *                     dumped = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 *                     size = (<RowDumper>dumper_ptr).cdumper.cdump(
 *                         <object>param, <bytearray>dumped, 0)
*/
        __pyx_t_2 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 402, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_dumped, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "psycopg_c/_psycopg/transform.pyx":403
 *                 if (<RowDumper>dumper_ptr).cdumper is not None:
 *                     dumped = PyByteArray_FromStringAndSize("", 0)
 *                     size = (<RowDumper>dumper_ptr).cdumper.cdump(             # <<<<<<<<<<<<<<
 *                         <object>param, <bytearray>dumped, 0)
 *                     PyByteArray_Resize(dumped, size)
*/
        __pyx_t_10 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->cdumper->__pyx_vtab)->cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->cdumper, ((PyObject *)__pyx_v_param), ((PyObject*)__pyx_v_dumped), 0); if (unlikely(__pyx_t_10 == ((Py_ssize_t)-1L))) __PYX_ERR(9, 403, __pyx_L1_error)
        __pyx_v_size = __pyx_t_10;

        /* "psycopg_c/_psycopg/transform.pyx":405
 *                     size = (<RowDumper>dumper_ptr).cdumper.cdump(
 *                         <object>param, <bytearray>dumped, 0)
 *                     PyByteArray_Resize(dumped, size)             # <<<<<<<<<<<<<<
 *                 else:
 *                     dumped = PyObject_CallFunctionObjArgs(
*/
        __pyx_t_11 = PyByteArray_Resize(__pyx_v_dumped, __pyx_v_size); if (unlikely(__pyx_t_11 == ((int)-1))) __PYX_ERR(9, 405, __pyx_L1_error)

        /* "psycopg_c/_psycopg/transform.pyx":401
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)
 *                 dumper_ptr = self.get_row_dumper(param, format)
 *                 if (<RowDumper>dumper_ptr).cdumper is not None:             # <<<<<<<<<<<<<<
 *                     dumped = PyByteArray_FromStringAndSize("", 0)
 *                     size = (<RowDumper>dumper_ptr).cdumper.cdump(
*/
        goto __pyx_L11;
      }

      /* "psycopg_c/_psycopg/transform.pyx":407
 *                     PyByteArray_Resize(dumped, size)
 *                 else:
 *                     dumped = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                         (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 oid = (<RowDumper>dumper_ptr).oid
*/
      /*else*/ {

        /* "psycopg_c/_psycopg/transform.pyx":408
 *                 else:
 *                     dumped = PyObject_CallFunctionObjArgs(
 *                         (<RowDumper>dumper_ptr).dumpfunc, param, NULL)             # <<<<<<<<<<<<<<
 *                 oid = (<RowDumper>dumper_ptr).oid
 *                 fmt = (<RowDumper>dumper_ptr).format
*/
        __pyx_t_2 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->dumpfunc;
        __Pyx_INCREF(__pyx_t_2);

        /* "psycopg_c/_psycopg/transform.pyx":407
 *                     PyByteArray_Resize(dumped, size)
 *                 else:
 *                     dumped = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                         (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 oid = (<RowDumper>dumper_ptr).oid
*/
        __pyx_t_1 = PyObject_CallFunctionObjArgs(__pyx_t_2, __pyx_v_param, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 407, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_dumped, __pyx_t_1);
        __pyx_t_1 = 0;
      }
      __pyx_L11:;

      /* "psycopg_c/_psycopg/transform.pyx":409
 *                     dumped = PyObject_CallFunctionObjArgs(
 *                         (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 oid = (<RowDumper>dumper_ptr).oid             # <<<<<<<<<<<<<<
 *                 fmt = (<RowDumper>dumper_ptr).format
 *             else:
*/
      __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->oid;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_oid, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":410
 *                         (<RowDumper>dumper_ptr).dumpfunc, param, NULL)
 *                 oid = (<RowDumper>dumper_ptr).oid
 *                 fmt = (<RowDumper>dumper_ptr).format             # <<<<<<<<<<<<<<
 *             else:
 *                 dumped = None
*/
      __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v_dumper_ptr)->format;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_fmt, __pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":398
 *         for i in range(nparams):
 *             param = PySequence_Fast_GET_ITEM(params_fast, i)
 *             if param != <PyObject *>None:             # <<<<<<<<<<<<<<
 *                 format = PySequence_Fast_GET_ITEM(formats_fast, i)
 *                 dumper_ptr = self.get_row_dumper(param, format)
*/
      goto __pyx_L10;
    }

    /* "psycopg_c/_psycopg/transform.pyx":412
 *                 fmt = (<RowDumper>dumper_ptr).format
 *             else:
 *                 dumped = None             # <<<<<<<<<<<<<<
 *                 if self._none_oid < 0:
 *                     self._none_oid = self.adapters.get_dumper(NoneType, "s").oid
*/
    /*else*/ {
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_dumped, Py_None);

      /* "psycopg_c/_psycopg/transform.pyx":413
 *             else:
 *                 dumped = None
 *                 if self._none_oid < 0:             # <<<<<<<<<<<<<<
 *                     self._none_oid = self.adapters.get_dumper(NoneType, "s").oid
 *                 oid = self._none_oid
*/
      __pyx_t_6 = (__pyx_v_self->_none_oid < 0);
      if (__pyx_t_6) {

        /* "psycopg_c/_psycopg/transform.pyx":414
 *                 dumped = None
 *                 if self._none_oid < 0:
 *                     self._none_oid = self.adapters.get_dumper(NoneType, "s").oid             # <<<<<<<<<<<<<<
 *                 oid = self._none_oid
 *                 fmt = PQ_TEXT
*/
        __pyx_t_2 = __pyx_v_self->adapters;
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_NoneType); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = 0;
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_4, __pyx_mstate_global->__pyx_n_u_s};
          __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_dumper, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 414, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_oid); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 414, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __pyx_t_11 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_11 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 414, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_v_self->_none_oid = __pyx_t_11;

        /* "psycopg_c/_psycopg/transform.pyx":413
 *             else:
 *                 dumped = None
 *                 if self._none_oid < 0:             # <<<<<<<<<<<<<<
 *                     self._none_oid = self.adapters.get_dumper(NoneType, "s").oid
 *                 oid = self._none_oid
*/
      }

      /* "psycopg_c/_psycopg/transform.pyx":415
 *                 if self._none_oid < 0:
 *                     self._none_oid = self.adapters.get_dumper(NoneType, "s").oid
 *                 oid = self._none_oid             # <<<<<<<<<<<<<<
 *                 fmt = PQ_TEXT
 * 
*/
      __pyx_t_4 = __Pyx_PyLong_From_int(__pyx_v_self->_none_oid); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 415, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_oid, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":416
 *                     self._none_oid = self.adapters.get_dumper(NoneType, "s").oid
 *                 oid = self._none_oid
 *                 fmt = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *             Py_INCREF(dumped)
*/
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 416, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_fmt, __pyx_t_4);
      __pyx_t_4 = 0;
    }
    __pyx_L10:;

    /* "psycopg_c/_psycopg/transform.pyx":418
 *                 fmt = PQ_TEXT
 * 
 *             Py_INCREF(dumped)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(out, i, dumped)
 * 
*/
    Py_INCREF(__pyx_v_dumped);

    /* "psycopg_c/_psycopg/transform.pyx":419
 * 
 *             Py_INCREF(dumped)
 *             PyList_SET_ITEM(out, i, dumped)             # <<<<<<<<<<<<<<
 * 
 *             Py_INCREF(oid)
*/
    PyList_SET_ITEM(__pyx_v_out, __pyx_v_i, __pyx_v_dumped);

    /* "psycopg_c/_psycopg/transform.pyx":421
 *             PyList_SET_ITEM(out, i, dumped)
 * 
 *             Py_INCREF(oid)             # <<<<<<<<<<<<<<
 *             PyTuple_SET_ITEM(types, i, oid)
 * 
*/
    Py_INCREF(__pyx_v_oid);

    /* "psycopg_c/_psycopg/transform.pyx":422
 * 
 *             Py_INCREF(oid)
 *             PyTuple_SET_ITEM(types, i, oid)             # <<<<<<<<<<<<<<
 * 
 *             Py_INCREF(fmt)
*/
    PyTuple_SET_ITEM(__pyx_v_types, __pyx_v_i, __pyx_v_oid);

    /* "psycopg_c/_psycopg/transform.pyx":424
 *             PyTuple_SET_ITEM(types, i, oid)
 * 
 *             Py_INCREF(fmt)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(pqformats, i, fmt)
 * 
*/
    Py_INCREF(__pyx_v_fmt);

    /* "psycopg_c/_psycopg/transform.pyx":425
 * 
 *             Py_INCREF(fmt)
 *             PyList_SET_ITEM(pqformats, i, fmt)             # <<<<<<<<<<<<<<
 * 
 *         self.types = types
*/
    PyList_SET_ITEM(__pyx_v_pqformats, __pyx_v_i, __pyx_v_fmt);
  }

  /* "psycopg_c/_psycopg/transform.pyx":427
 *             PyList_SET_ITEM(pqformats, i, fmt)
 * 
 *         self.types = types             # <<<<<<<<<<<<<<
 *         self.formats = pqformats
 *         return out
*/
  __Pyx_INCREF(__pyx_v_types);
  __Pyx_GIVEREF(__pyx_v_types);
  __Pyx_GOTREF(__pyx_v_self->types);
  __Pyx_DECREF(__pyx_v_self->types);
  __pyx_v_self->types = __pyx_v_types;

  /* "psycopg_c/_psycopg/transform.pyx":428
 * 
 *         self.types = types
 *         self.formats = pqformats             # <<<<<<<<<<<<<<
 *         return out
 * 
*/
  __Pyx_INCREF(__pyx_v_pqformats);
  __Pyx_GIVEREF(__pyx_v_pqformats);
  __Pyx_GOTREF(__pyx_v_self->formats);
  __Pyx_DECREF(__pyx_v_self->formats);
  __pyx_v_self->formats = __pyx_v_pqformats;

  /* "psycopg_c/_psycopg/transform.pyx":429
 *         self.types = types
 *         self.formats = pqformats
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":355
 *         return ptr
 * 
 *     cpdef dump_sequence(self, object params, object formats):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef PyObject *dumper_ptr  # borrowed pointer to row dumper
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.dump_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_dumped);
  __Pyx_XDECREF(__pyx_v_params_fast);
  __Pyx_XDECREF(__pyx_v_formats_fast);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_dumpers);
  __Pyx_XDECREF(__pyx_v_types);
  __Pyx_XDECREF(__pyx_v_pqformats);
  __Pyx_XDECREF(__pyx_v_oid);
  __Pyx_XDECREF(__pyx_v_fmt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_15dump_sequence(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_15dump_sequence = {"dump_sequence", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_15dump_sequence, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_15dump_sequence(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_params = 0;
  PyObject *__pyx_v_formats = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("dump_sequence (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_params,&__pyx_mstate_global->__pyx_n_u_formats,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 355, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 355, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 355, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "dump_sequence", 0) < (0)) __PYX_ERR(9, 355, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("dump_sequence", 1, 2, 2, i); __PYX_ERR(9, 355, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 355, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 355, __pyx_L3_error)
    }
    __pyx_v_params = values[0];
    __pyx_v_formats = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("dump_sequence", 1, 2, 2, __pyx_nargs); __PYX_ERR(9, 355, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.dump_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_14dump_sequence(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_params, __pyx_v_formats);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_14dump_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_params, PyObject *__pyx_v_formats) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("dump_sequence", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_11Transformer_dump_sequence(__pyx_v_self, __pyx_v_params, __pyx_v_formats, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.dump_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":431
 *         return out
 * 
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:             # <<<<<<<<<<<<<<
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_17load_rows(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_17load_rows = {"load_rows", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_17load_rows, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_17load_rows(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_row0;
  int __pyx_v_row1;
  PyObject *__pyx_v_make_row = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_rows (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_row0,&__pyx_mstate_global->__pyx_n_u_row1,&__pyx_mstate_global->__pyx_n_u_make_row,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 431, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(9, 431, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 431, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 431, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "load_rows", 0) < (0)) __PYX_ERR(9, 431, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("load_rows", 1, 3, 3, i); __PYX_ERR(9, 431, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 431, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 431, __pyx_L3_error)
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(9, 431, __pyx_L3_error)
    }
    __pyx_v_row0 = __Pyx_PyLong_As_int(values[0]); if (unlikely((__pyx_v_row0 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 431, __pyx_L3_error)
    __pyx_v_row1 = __Pyx_PyLong_As_int(values[1]); if (unlikely((__pyx_v_row1 == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 431, __pyx_L3_error)
    __pyx_v_make_row = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load_rows", 1, 3, 3, __pyx_nargs); __PYX_ERR(9, 431, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.load_rows", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_16load_rows(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_row0, __pyx_v_row1, __pyx_v_make_row);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_16load_rows(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, int __pyx_v_row0, int __pyx_v_row1, PyObject *__pyx_v_make_row) {
  PGresult *__pyx_v_res;
  __pyx_t_9psycopg_c_8_psycopg_pg_result_int *__pyx_v_ires;
  int __pyx_v_row;
  int __pyx_v_col;
  __pyx_t_9psycopg_c_8_psycopg_PGresAttValue *__pyx_v_attval;
  PyObject *__pyx_v_record = 0;
  PyObject *__pyx_v_records = 0;
  PyObject *__pyx_v_loader;
  PyObject *__pyx_v_row_loaders = NULL;
  PyObject *__pyx_v_pyval = NULL;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PGresult *__pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_rows", 0);

  /* "psycopg_c/_psycopg/transform.pyx":432
 * 
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:
 *         if self._pgresult is None:             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError("result not set")
 * 
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_pgresult) == Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/_psycopg/transform.pyx":433
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")             # <<<<<<<<<<<<<<
 * 
 *         if not (0 <= row0 <= self._ntuples and 0 <= row1 <= self._ntuples):
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_result_not_set};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(9, 433, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":432
 * 
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:
 *         if self._pgresult is None:             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError("result not set")
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":435
 *             raise e.InterfaceError("result not set")
 * 
 *         if not (0 <= row0 <= self._ntuples and 0 <= row1 <= self._ntuples):             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError(
 *                 f"rows must be included between 0 and {self._ntuples}"
*/
  __pyx_t_7 = (0 <= __pyx_v_row0);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_v_row0 <= __pyx_v_self->_ntuples);
  }
  if (__pyx_t_7) {
  } else {
    __pyx_t_1 = __pyx_t_7;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_7 = (0 <= __pyx_v_row1);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_v_row1 <= __pyx_v_self->_ntuples);
  }
  __pyx_t_1 = __pyx_t_7;
  __pyx_L5_bool_binop_done:;
  __pyx_t_7 = (!__pyx_t_1);
  if (unlikely(__pyx_t_7)) {

    /* "psycopg_c/_psycopg/transform.pyx":436
 * 
 *         if not (0 <= row0 <= self._ntuples and 0 <= row1 <= self._ntuples):
 *             raise e.InterfaceError(             # <<<<<<<<<<<<<<
 *                 f"rows must be included between 0 and {self._ntuples}"
 *             )
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 436, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 436, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":437
 *         if not (0 <= row0 <= self._ntuples and 0 <= row1 <= self._ntuples):
 *             raise e.InterfaceError(
 *                 f"rows must be included between 0 and {self._ntuples}"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_3 = __Pyx_PyUnicode_From_int(__pyx_v_self->_ntuples, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_rows_must_be_included_between_0, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(9, 437, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 436, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(9, 436, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":435
 *             raise e.InterfaceError("result not set")
 * 
 *         if not (0 <= row0 <= self._ntuples and 0 <= row1 <= self._ntuples):             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError(
 *                 f"rows must be included between 0 and {self._ntuples}"
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":440
 *             )
 * 
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr             # <<<<<<<<<<<<<<
 *         # cheeky access to the internal PGresult structure
 *         cdef pg_result_int *ires = <pg_result_int*>res
*/
  __pyx_t_9 = __pyx_v_self->_pgresult->_pgresult_ptr;
  __pyx_v_res = __pyx_t_9;

  /* "psycopg_c/_psycopg/transform.pyx":442
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr
 *         # cheeky access to the internal PGresult structure
 *         cdef pg_result_int *ires = <pg_result_int*>res             # <<<<<<<<<<<<<<
 * 
 *         cdef int row
*/
  __pyx_v_ires = ((__pyx_t_9psycopg_c_8_psycopg_pg_result_int *)__pyx_v_res);

  /* "psycopg_c/_psycopg/transform.pyx":449
 *         cdef object record  # not 'tuple' as it would check on assignment
 * 
 *         cdef object records = PyList_New(row1 - row0)             # <<<<<<<<<<<<<<
 * 
 *         cdef PyObject *loader  # borrowed RowLoader
*/
  __pyx_t_2 = PyList_New((__pyx_v_row1 - __pyx_v_row0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 449, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_records = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":453
 *         cdef PyObject *loader  # borrowed RowLoader
 * 
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item             # <<<<<<<<<<<<<<
 * 
 *         for row in range(row0, row1):
*/
  __pyx_t_2 = __pyx_v_self->_row_loaders;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_row_loaders = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":455
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 * 
 *         for row in range(row0, row1):             # <<<<<<<<<<<<<<
 *             record = PyTuple_New(self._nfields)
 * 
*/
  __pyx_t_10 = __pyx_v_row1;
  __pyx_t_11 = __pyx_t_10;
  for (__pyx_t_12 = __pyx_v_row0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
    __pyx_v_row = __pyx_t_12;

    /* "psycopg_c/_psycopg/transform.pyx":456
 * 
 *         for row in range(row0, row1):
 *             record = PyTuple_New(self._nfields)             # <<<<<<<<<<<<<<
 * 
 *             for col in range(self._nfields):
*/
    __pyx_t_2 = PyTuple_New(__pyx_v_self->_nfields); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 456, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_record, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":458
 *             record = PyTuple_New(self._nfields)
 * 
 *             for col in range(self._nfields):             # <<<<<<<<<<<<<<
 *                 attval = &(ires.tuples[row][col])
 *                 if attval.len == -1:  # NULL_LEN
*/
    __pyx_t_13 = __pyx_v_self->_nfields;
    __pyx_t_14 = __pyx_t_13;
    for (__pyx_t_15 = 0; __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
      __pyx_v_col = __pyx_t_15;

      /* "psycopg_c/_psycopg/transform.pyx":459
 * 
 *             for col in range(self._nfields):
 *                 attval = &(ires.tuples[row][col])             # <<<<<<<<<<<<<<
 *                 if attval.len == -1:  # NULL_LEN
 *                     pyval = None
*/
      __pyx_v_attval = (&((__pyx_v_ires->tuples[__pyx_v_row])[__pyx_v_col]));

      /* "psycopg_c/_psycopg/transform.pyx":460
 *             for col in range(self._nfields):
 *                 attval = &(ires.tuples[row][col])
 *                 if attval.len == -1:  # NULL_LEN             # <<<<<<<<<<<<<<
 *                     pyval = None
 *                 else:
*/
      __pyx_t_7 = (__pyx_v_attval->len == -1L);
      if (__pyx_t_7) {

        /* "psycopg_c/_psycopg/transform.pyx":461
 *                 attval = &(ires.tuples[row][col])
 *                 if attval.len == -1:  # NULL_LEN
 *                     pyval = None             # <<<<<<<<<<<<<<
 *                 else:
 *                     loader = PyList_GET_ITEM(row_loaders, col)
*/
        __Pyx_INCREF(Py_None);
        __Pyx_XDECREF_SET(__pyx_v_pyval, Py_None);

        /* "psycopg_c/_psycopg/transform.pyx":460
 *             for col in range(self._nfields):
 *                 attval = &(ires.tuples[row][col])
 *                 if attval.len == -1:  # NULL_LEN             # <<<<<<<<<<<<<<
 *                     pyval = None
 *                 else:
*/
        goto __pyx_L11;
      }

      /* "psycopg_c/_psycopg/transform.pyx":463
 *                     pyval = None
 *                 else:
 *                     loader = PyList_GET_ITEM(row_loaders, col)             # <<<<<<<<<<<<<<
 *                     if (<RowLoader>loader).cloader is not None:
 *                         pyval = (<RowLoader>loader).cloader.cload(
*/
      /*else*/ {
        __pyx_v_loader = PyList_GET_ITEM(__pyx_v_row_loaders, __pyx_v_col);

        /* "psycopg_c/_psycopg/transform.pyx":464
 *                 else:
 *                     loader = PyList_GET_ITEM(row_loaders, col)
 *                     if (<RowLoader>loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                         pyval = (<RowLoader>loader).cloader.cload(
 *                             attval.value, attval.len)
*/
        __pyx_t_7 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader) != Py_None);
        if (__pyx_t_7) {

          /* "psycopg_c/_psycopg/transform.pyx":465
 *                     loader = PyList_GET_ITEM(row_loaders, col)
 *                     if (<RowLoader>loader).cloader is not None:
 *                         pyval = (<RowLoader>loader).cloader.cload(             # <<<<<<<<<<<<<<
 *                             attval.value, attval.len)
 *                     else:
*/
          __pyx_t_2 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader->__pyx_vtab)->cload(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader, __pyx_v_attval->value, __pyx_v_attval->len); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 465, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_2);
          __pyx_t_2 = 0;

          /* "psycopg_c/_psycopg/transform.pyx":464
 *                 else:
 *                     loader = PyList_GET_ITEM(row_loaders, col)
 *                     if (<RowLoader>loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                         pyval = (<RowLoader>loader).cloader.cload(
 *                             attval.value, attval.len)
*/
          goto __pyx_L12;
        }

        /* "psycopg_c/_psycopg/transform.pyx":468
 *                             attval.value, attval.len)
 *                     else:
 *                         b = PyMemoryView_FromObject(             # <<<<<<<<<<<<<<
 *                             ViewBuffer._from_buffer(
 *                                 self._pgresult,
*/
        /*else*/ {

          /* "psycopg_c/_psycopg/transform.pyx":470
 *                         b = PyMemoryView_FromObject(
 *                             ViewBuffer._from_buffer(
 *                                 self._pgresult,             # <<<<<<<<<<<<<<
 *                                 <unsigned char *>attval.value, attval.len))
 *                         pyval = PyObject_CallFunctionObjArgs(
*/
          __pyx_t_2 = ((PyObject *)__pyx_v_self->_pgresult);
          __Pyx_INCREF(__pyx_t_2);

          /* "psycopg_c/_psycopg/transform.pyx":469
 *                     else:
 *                         b = PyMemoryView_FromObject(
 *                             ViewBuffer._from_buffer(             # <<<<<<<<<<<<<<
 *                                 self._pgresult,
 *                                 <unsigned char *>attval.value, attval.len))
*/
          __pyx_t_4 = ((PyObject *)__pyx_vtabptr_9psycopg_c_2pq_ViewBuffer->_from_buffer(__pyx_t_2, ((unsigned char *)__pyx_v_attval->value), __pyx_v_attval->len)); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 469, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

          /* "psycopg_c/_psycopg/transform.pyx":468
 *                             attval.value, attval.len)
 *                     else:
 *                         b = PyMemoryView_FromObject(             # <<<<<<<<<<<<<<
 *                             ViewBuffer._from_buffer(
 *                                 self._pgresult,
*/
          __pyx_t_2 = PyMemoryView_FromObject(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 468, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_XDECREF_SET(__pyx_v_b, ((PyObject*)__pyx_t_2));
          __pyx_t_2 = 0;

          /* "psycopg_c/_psycopg/transform.pyx":473
 *                                 <unsigned char *>attval.value, attval.len))
 *                         pyval = PyObject_CallFunctionObjArgs(
 *                             (<RowLoader>loader).loadfunc, <PyObject *>b, NULL)             # <<<<<<<<<<<<<<
 * 
 *                 Py_INCREF(pyval)
*/
          __pyx_t_2 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->loadfunc;
          __Pyx_INCREF(__pyx_t_2);

          /* "psycopg_c/_psycopg/transform.pyx":472
 *                                 self._pgresult,
 *                                 <unsigned char *>attval.value, attval.len))
 *                         pyval = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                             (<RowLoader>loader).loadfunc, <PyObject *>b, NULL)
 * 
*/
          __pyx_t_4 = PyObject_CallFunctionObjArgs(__pyx_t_2, ((PyObject *)__pyx_v_b), NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 472, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_4);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_4);
          __pyx_t_4 = 0;
        }
        __pyx_L12:;
      }
      __pyx_L11:;

      /* "psycopg_c/_psycopg/transform.pyx":475
 *                             (<RowLoader>loader).loadfunc, <PyObject *>b, NULL)
 * 
 *                 Py_INCREF(pyval)             # <<<<<<<<<<<<<<
 *                 PyTuple_SET_ITEM(record, col, pyval)
 * 
*/
      Py_INCREF(__pyx_v_pyval);

      /* "psycopg_c/_psycopg/transform.pyx":476
 * 
 *                 Py_INCREF(pyval)
 *                 PyTuple_SET_ITEM(record, col, pyval)             # <<<<<<<<<<<<<<
 * 
 *             if make_row is not tuple:
*/
      PyTuple_SET_ITEM(__pyx_v_record, __pyx_v_col, __pyx_v_pyval);
    }

    /* "psycopg_c/_psycopg/transform.pyx":478
 *                 PyTuple_SET_ITEM(record, col, pyval)
 * 
 *             if make_row is not tuple:             # <<<<<<<<<<<<<<
 *                 record = PyObject_CallFunctionObjArgs(
 *                     make_row, <PyObject *>record, NULL)
*/
    __pyx_t_7 = (__pyx_v_make_row != ((PyObject *)(&PyTuple_Type)));
    if (__pyx_t_7) {

      /* "psycopg_c/_psycopg/transform.pyx":479
 * 
 *             if make_row is not tuple:
 *                 record = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                     make_row, <PyObject *>record, NULL)
 * 
*/
      __pyx_t_4 = PyObject_CallFunctionObjArgs(__pyx_v_make_row, ((PyObject *)__pyx_v_record), NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 479, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF_SET(__pyx_v_record, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":478
 *                 PyTuple_SET_ITEM(record, col, pyval)
 * 
 *             if make_row is not tuple:             # <<<<<<<<<<<<<<
 *                 record = PyObject_CallFunctionObjArgs(
 *                     make_row, <PyObject *>record, NULL)
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":482
 *                     make_row, <PyObject *>record, NULL)
 * 
 *             Py_INCREF(record)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(records, row - row0, record)
 * 
*/
    Py_INCREF(__pyx_v_record);

    /* "psycopg_c/_psycopg/transform.pyx":483
 * 
 *             Py_INCREF(record)
 *             PyList_SET_ITEM(records, row - row0, record)             # <<<<<<<<<<<<<<
 * 
 *         return records
*/
    PyList_SET_ITEM(__pyx_v_records, (__pyx_v_row - __pyx_v_row0), __pyx_v_record);
  }

  /* "psycopg_c/_psycopg/transform.pyx":485
 *             PyList_SET_ITEM(records, row - row0, record)
 * 
 *         return records             # <<<<<<<<<<<<<<
 * 
 *     def load_row(self, int row, object make_row) -> Row:
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __pyx_v_records;
  __Pyx_INCREF(__pyx_t_4);
  if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("list", __pyx_t_4))) __PYX_ERR(9, 485, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":431
 *         return out
 * 
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:             # <<<<<<<<<<<<<<
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.load_rows", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_record);
  __Pyx_XDECREF(__pyx_v_records);
  __Pyx_XDECREF(__pyx_v_row_loaders);
  __Pyx_XDECREF(__pyx_v_pyval);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":487
 *         return records
 * 
 *     def load_row(self, int row, object make_row) -> Row:             # <<<<<<<<<<<<<<
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_19load_row(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_19load_row = {"load_row", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_19load_row, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_19load_row(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  int __pyx_v_row;
  PyObject *__pyx_v_make_row = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_row (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_row,&__pyx_mstate_global->__pyx_n_u_make_row,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 487, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 487, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 487, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "load_row", 0) < (0)) __PYX_ERR(9, 487, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("load_row", 1, 2, 2, i); __PYX_ERR(9, 487, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 487, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 487, __pyx_L3_error)
    }
    __pyx_v_row = __Pyx_PyLong_As_int(values[0]); if (unlikely((__pyx_v_row == (int)-1) && PyErr_Occurred())) __PYX_ERR(9, 487, __pyx_L3_error)
    __pyx_v_make_row = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("load_row", 1, 2, 2, __pyx_nargs); __PYX_ERR(9, 487, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.load_row", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_18load_row(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_row, __pyx_v_make_row);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_18load_row(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, int __pyx_v_row, PyObject *__pyx_v_make_row) {
  PGresult *__pyx_v_res;
  __pyx_t_9psycopg_c_8_psycopg_pg_result_int *__pyx_v_ires;
  PyObject *__pyx_v_loader;
  int __pyx_v_col;
  __pyx_t_9psycopg_c_8_psycopg_PGresAttValue *__pyx_v_attval;
  PyObject *__pyx_v_record = 0;
  PyObject *__pyx_v_row_loaders = NULL;
  PyObject *__pyx_v_pyval = NULL;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PGresult *__pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_row", 0);

  /* "psycopg_c/_psycopg/transform.pyx":488
 * 
 *     def load_row(self, int row, object make_row) -> Row:
 *         if self._pgresult is None:             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError("result not set")
 * 
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_self->_pgresult) == Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/_psycopg/transform.pyx":489
 *     def load_row(self, int row, object make_row) -> Row:
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")             # <<<<<<<<<<<<<<
 * 
 *         if not 0 <= row < self._ntuples:
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 489, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_result_not_set};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 489, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(9, 489, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":488
 * 
 *     def load_row(self, int row, object make_row) -> Row:
 *         if self._pgresult is None:             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError("result not set")
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":491
 *             raise e.InterfaceError("result not set")
 * 
 *         if not 0 <= row < self._ntuples:             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError(
 *                 f"row must be included between 0 and {self._ntuples}"
*/
  __pyx_t_1 = (0 <= __pyx_v_row);
  if (__pyx_t_1) {
    __pyx_t_1 = (__pyx_v_row < __pyx_v_self->_ntuples);
  }
  __pyx_t_7 = (!__pyx_t_1);
  if (unlikely(__pyx_t_7)) {

    /* "psycopg_c/_psycopg/transform.pyx":492
 * 
 *         if not 0 <= row < self._ntuples:
 *             raise e.InterfaceError(             # <<<<<<<<<<<<<<
 *                 f"row must be included between 0 and {self._ntuples}"
 *             )
*/
    __pyx_t_5 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 492, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":493
 *         if not 0 <= row < self._ntuples:
 *             raise e.InterfaceError(
 *                 f"row must be included between 0 and {self._ntuples}"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
    __pyx_t_3 = __Pyx_PyUnicode_From_int(__pyx_v_self->_ntuples, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_row_must_be_included_between_0_a, __pyx_t_3); if (unlikely(!__pyx_t_8)) __PYX_ERR(9, 493, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_5);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 492, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(9, 492, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":491
 *             raise e.InterfaceError("result not set")
 * 
 *         if not 0 <= row < self._ntuples:             # <<<<<<<<<<<<<<
 *             raise e.InterfaceError(
 *                 f"row must be included between 0 and {self._ntuples}"
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":496
 *             )
 * 
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr             # <<<<<<<<<<<<<<
 *         # cheeky access to the internal PGresult structure
 *         cdef pg_result_int *ires = <pg_result_int*>res
*/
  __pyx_t_9 = __pyx_v_self->_pgresult->_pgresult_ptr;
  __pyx_v_res = __pyx_t_9;

  /* "psycopg_c/_psycopg/transform.pyx":498
 *         cdef libpq.PGresult *res = self._pgresult._pgresult_ptr
 *         # cheeky access to the internal PGresult structure
 *         cdef pg_result_int *ires = <pg_result_int*>res             # <<<<<<<<<<<<<<
 * 
 *         cdef PyObject *loader  # borrowed RowLoader
*/
  __pyx_v_ires = ((__pyx_t_9psycopg_c_8_psycopg_pg_result_int *)__pyx_v_res);

  /* "psycopg_c/_psycopg/transform.pyx":505
 *         cdef object record  # not 'tuple' as it would check on assignment
 * 
 *         record = PyTuple_New(self._nfields)             # <<<<<<<<<<<<<<
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 * 
*/
  __pyx_t_2 = PyTuple_New(__pyx_v_self->_nfields); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_record = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":506
 * 
 *         record = PyTuple_New(self._nfields)
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item             # <<<<<<<<<<<<<<
 * 
 *         for col in range(self._nfields):
*/
  __pyx_t_2 = __pyx_v_self->_row_loaders;
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_row_loaders = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":508
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 * 
 *         for col in range(self._nfields):             # <<<<<<<<<<<<<<
 *             attval = &(ires.tuples[row][col])
 *             if attval.len == -1:  # NULL_LEN
*/
  __pyx_t_10 = __pyx_v_self->_nfields;
  __pyx_t_11 = __pyx_t_10;
  for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
    __pyx_v_col = __pyx_t_12;

    /* "psycopg_c/_psycopg/transform.pyx":509
 * 
 *         for col in range(self._nfields):
 *             attval = &(ires.tuples[row][col])             # <<<<<<<<<<<<<<
 *             if attval.len == -1:  # NULL_LEN
 *                 pyval = None
*/
    __pyx_v_attval = (&((__pyx_v_ires->tuples[__pyx_v_row])[__pyx_v_col]));

    /* "psycopg_c/_psycopg/transform.pyx":510
 *         for col in range(self._nfields):
 *             attval = &(ires.tuples[row][col])
 *             if attval.len == -1:  # NULL_LEN             # <<<<<<<<<<<<<<
 *                 pyval = None
 *             else:
*/
    __pyx_t_7 = (__pyx_v_attval->len == -1L);
    if (__pyx_t_7) {

      /* "psycopg_c/_psycopg/transform.pyx":511
 *             attval = &(ires.tuples[row][col])
 *             if attval.len == -1:  # NULL_LEN
 *                 pyval = None             # <<<<<<<<<<<<<<
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_pyval, Py_None);

      /* "psycopg_c/_psycopg/transform.pyx":510
 *         for col in range(self._nfields):
 *             attval = &(ires.tuples[row][col])
 *             if attval.len == -1:  # NULL_LEN             # <<<<<<<<<<<<<<
 *                 pyval = None
 *             else:
*/
      goto __pyx_L7;
    }

    /* "psycopg_c/_psycopg/transform.pyx":513
 *                 pyval = None
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)             # <<<<<<<<<<<<<<
 *                 if (<RowLoader>loader).cloader is not None:
 *                     pyval = (<RowLoader>loader).cloader.cload(
*/
    /*else*/ {
      __pyx_v_loader = PyList_GET_ITEM(__pyx_v_row_loaders, __pyx_v_col);

      /* "psycopg_c/_psycopg/transform.pyx":514
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)
 *                 if (<RowLoader>loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                     pyval = (<RowLoader>loader).cloader.cload(
 *                         attval.value, attval.len)
*/
      __pyx_t_7 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader) != Py_None);
      if (__pyx_t_7) {

        /* "psycopg_c/_psycopg/transform.pyx":515
 *                 loader = PyList_GET_ITEM(row_loaders, col)
 *                 if (<RowLoader>loader).cloader is not None:
 *                     pyval = (<RowLoader>loader).cloader.cload(             # <<<<<<<<<<<<<<
 *                         attval.value, attval.len)
 *                 else:
*/
        __pyx_t_2 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader->__pyx_vtab)->cload(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader, __pyx_v_attval->value, __pyx_v_attval->len); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 515, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_2);
        __pyx_t_2 = 0;

        /* "psycopg_c/_psycopg/transform.pyx":514
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)
 *                 if (<RowLoader>loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                     pyval = (<RowLoader>loader).cloader.cload(
 *                         attval.value, attval.len)
*/
        goto __pyx_L8;
      }

      /* "psycopg_c/_psycopg/transform.pyx":518
 *                         attval.value, attval.len)
 *                 else:
 *                     b = PyMemoryView_FromObject(             # <<<<<<<<<<<<<<
 *                         ViewBuffer._from_buffer(
 *                             self._pgresult,
*/
      /*else*/ {

        /* "psycopg_c/_psycopg/transform.pyx":520
 *                     b = PyMemoryView_FromObject(
 *                         ViewBuffer._from_buffer(
 *                             self._pgresult,             # <<<<<<<<<<<<<<
 *                             <unsigned char *>attval.value, attval.len))
 *                     pyval = PyObject_CallFunctionObjArgs(
*/
        __pyx_t_2 = ((PyObject *)__pyx_v_self->_pgresult);
        __Pyx_INCREF(__pyx_t_2);

        /* "psycopg_c/_psycopg/transform.pyx":519
 *                 else:
 *                     b = PyMemoryView_FromObject(
 *                         ViewBuffer._from_buffer(             # <<<<<<<<<<<<<<
 *                             self._pgresult,
 *                             <unsigned char *>attval.value, attval.len))
*/
        __pyx_t_4 = ((PyObject *)__pyx_vtabptr_9psycopg_c_2pq_ViewBuffer->_from_buffer(__pyx_t_2, ((unsigned char *)__pyx_v_attval->value), __pyx_v_attval->len)); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 519, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "psycopg_c/_psycopg/transform.pyx":518
 *                         attval.value, attval.len)
 *                 else:
 *                     b = PyMemoryView_FromObject(             # <<<<<<<<<<<<<<
 *                         ViewBuffer._from_buffer(
 *                             self._pgresult,
*/
        __pyx_t_2 = PyMemoryView_FromObject(__pyx_t_4); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 518, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF_SET(__pyx_v_b, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "psycopg_c/_psycopg/transform.pyx":523
 *                             <unsigned char *>attval.value, attval.len))
 *                     pyval = PyObject_CallFunctionObjArgs(
 *                         (<RowLoader>loader).loadfunc, <PyObject *>b, NULL)             # <<<<<<<<<<<<<<
 * 
 *             Py_INCREF(pyval)
*/
        __pyx_t_2 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->loadfunc;
        __Pyx_INCREF(__pyx_t_2);

        /* "psycopg_c/_psycopg/transform.pyx":522
 *                             self._pgresult,
 *                             <unsigned char *>attval.value, attval.len))
 *                     pyval = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                         (<RowLoader>loader).loadfunc, <PyObject *>b, NULL)
 * 
*/
        __pyx_t_4 = PyObject_CallFunctionObjArgs(__pyx_t_2, ((PyObject *)__pyx_v_b), NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 522, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_4);
        __pyx_t_4 = 0;
      }
      __pyx_L8:;
    }
    __pyx_L7:;

    /* "psycopg_c/_psycopg/transform.pyx":525
 *                         (<RowLoader>loader).loadfunc, <PyObject *>b, NULL)
 * 
 *             Py_INCREF(pyval)             # <<<<<<<<<<<<<<
 *             PyTuple_SET_ITEM(record, col, pyval)
 * 
*/
    Py_INCREF(__pyx_v_pyval);

    /* "psycopg_c/_psycopg/transform.pyx":526
 * 
 *             Py_INCREF(pyval)
 *             PyTuple_SET_ITEM(record, col, pyval)             # <<<<<<<<<<<<<<
 * 
 *         if make_row is not tuple:
*/
    PyTuple_SET_ITEM(__pyx_v_record, __pyx_v_col, __pyx_v_pyval);
  }

  /* "psycopg_c/_psycopg/transform.pyx":528
 *             PyTuple_SET_ITEM(record, col, pyval)
 * 
 *         if make_row is not tuple:             # <<<<<<<<<<<<<<
 *             record = PyObject_CallFunctionObjArgs(
 *                 make_row, <PyObject *>record, NULL)
*/
  __pyx_t_7 = (__pyx_v_make_row != ((PyObject *)(&PyTuple_Type)));
  if (__pyx_t_7) {

    /* "psycopg_c/_psycopg/transform.pyx":529
 * 
 *         if make_row is not tuple:
 *             record = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 make_row, <PyObject *>record, NULL)
 *         return record
*/
    __pyx_t_4 = PyObject_CallFunctionObjArgs(__pyx_v_make_row, ((PyObject *)__pyx_v_record), NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 529, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF_SET(__pyx_v_record, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":528
 *             PyTuple_SET_ITEM(record, col, pyval)
 * 
 *         if make_row is not tuple:             # <<<<<<<<<<<<<<
 *             record = PyObject_CallFunctionObjArgs(
 *                 make_row, <PyObject *>record, NULL)
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":531
 *             record = PyObject_CallFunctionObjArgs(
 *                 make_row, <PyObject *>record, NULL)
 *         return record             # <<<<<<<<<<<<<<
 * 
 *     cpdef object load_sequence(self, record: Sequence[Buffer | None]):
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_record);
  __pyx_r = __pyx_v_record;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":487
 *         return records
 * 
 *     def load_row(self, int row, object make_row) -> Row:             # <<<<<<<<<<<<<<
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.load_row", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_record);
  __Pyx_XDECREF(__pyx_v_row_loaders);
  __Pyx_XDECREF(__pyx_v_pyval);
  __Pyx_XDECREF(__pyx_v_b);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":533
 *         return record
 * 
 *     cpdef object load_sequence(self, record: Sequence[Buffer | None]):             # <<<<<<<<<<<<<<
 *         cdef record_fast = PySequence_Fast(record, "'record' is not a valid sequence")
 *         cdef Py_ssize_t nfields = PySequence_Fast_GET_SIZE(record_fast)
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_21load_sequence(PyObject *__pyx_v_self, PyObject *__pyx_v_record); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer_load_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_record, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_record_fast = 0;
  Py_ssize_t __pyx_v_nfields;
  PyObject *__pyx_v_loader;
  int __pyx_v_col;
  char *__pyx_v_ptr;
  Py_ssize_t __pyx_v_size;
  PyObject *__pyx_v_item;
  PyObject *__pyx_v_out = NULL;
  PyObject *__pyx_v_row_loaders = NULL;
  PyObject *__pyx_v_pyval = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  size_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  Py_ssize_t __pyx_t_8;
  PyObject *__pyx_t_9[5];
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_sequence", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (
  #if !CYTHON_USE_TYPE_SLOTS
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer &&
  __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
  #else
  unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
  #endif
  ) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_load_sequence); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 533, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_11Transformer_21load_sequence)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = NULL;
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; 
        __pyx_t_5 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
          __pyx_t_5 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_record};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 533, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "psycopg_c/_psycopg/transform.pyx":534
 * 
 *     cpdef object load_sequence(self, record: Sequence[Buffer | None]):
 *         cdef record_fast = PySequence_Fast(record, "'record' is not a valid sequence")             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t nfields = PySequence_Fast_GET_SIZE(record_fast)
 *         cdef PyObject *loader  # borrowed RowLoader
*/
  __pyx_t_1 = PySequence_Fast(__pyx_v_record, ((char *)"'record' is not a valid sequence")); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_record_fast = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":535
 *     cpdef object load_sequence(self, record: Sequence[Buffer | None]):
 *         cdef record_fast = PySequence_Fast(record, "'record' is not a valid sequence")
 *         cdef Py_ssize_t nfields = PySequence_Fast_GET_SIZE(record_fast)             # <<<<<<<<<<<<<<
 *         cdef PyObject *loader  # borrowed RowLoader
 *         cdef int col
*/
  __pyx_v_nfields = PySequence_Fast_GET_SIZE(__pyx_v_record_fast);

  /* "psycopg_c/_psycopg/transform.pyx":542
 *         cdef PyObject *item
 * 
 *         out = PyTuple_New(nfields)             # <<<<<<<<<<<<<<
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 *         if PyList_GET_SIZE(row_loaders) != nfields:
*/
  __pyx_t_1 = PyTuple_New(__pyx_v_nfields); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 542, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_out = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":543
 * 
 *         out = PyTuple_New(nfields)
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item             # <<<<<<<<<<<<<<
 *         if PyList_GET_SIZE(row_loaders) != nfields:
 *             raise e.ProgrammingError(
*/
  __pyx_t_1 = __pyx_v_self->_row_loaders;
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_row_loaders = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":544
 *         out = PyTuple_New(nfields)
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 *         if PyList_GET_SIZE(row_loaders) != nfields:             # <<<<<<<<<<<<<<
 *             raise e.ProgrammingError(
 *                 f"cannot load sequence of {nfields} items:"
*/
  __pyx_t_6 = (PyList_GET_SIZE(__pyx_v_row_loaders) != __pyx_v_nfields);
  if (unlikely(__pyx_t_6)) {

    /* "psycopg_c/_psycopg/transform.pyx":545
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 *         if PyList_GET_SIZE(row_loaders) != nfields:
 *             raise e.ProgrammingError(             # <<<<<<<<<<<<<<
 *                 f"cannot load sequence of {nfields} items:"
 *                 f" {len(self._row_loaders)} loaders registered")
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_ProgrammingError); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 545, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":546
 *         if PyList_GET_SIZE(row_loaders) != nfields:
 *             raise e.ProgrammingError(
 *                 f"cannot load sequence of {nfields} items:"             # <<<<<<<<<<<<<<
 *                 f" {len(self._row_loaders)} loaders registered")
 * 
*/
    __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_nfields, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);

    /* "psycopg_c/_psycopg/transform.pyx":547
 *             raise e.ProgrammingError(
 *                 f"cannot load sequence of {nfields} items:"
 *                 f" {len(self._row_loaders)} loaders registered")             # <<<<<<<<<<<<<<
 * 
 *         for col in range(nfields):
*/
    __pyx_t_7 = __pyx_v_self->_row_loaders;
    __Pyx_INCREF(__pyx_t_7);
    if (unlikely(__pyx_t_7 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(9, 547, __pyx_L1_error)
    }
    __pyx_t_8 = __Pyx_PyList_GET_SIZE(__pyx_t_7); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(9, 547, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_t_8, 0, ' ', 'd'); if (unlikely(!__pyx_t_7)) __PYX_ERR(9, 547, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_9[0] = __pyx_mstate_global->__pyx_kp_u_cannot_load_sequence_of;
    __pyx_t_9[1] = __pyx_t_4;
    __pyx_t_9[2] = __pyx_mstate_global->__pyx_kp_u_items;
    __pyx_t_9[3] = __pyx_t_7;
    __pyx_t_9[4] = __pyx_mstate_global->__pyx_kp_u_loaders_registered;

    /* "psycopg_c/_psycopg/transform.pyx":546
 *         if PyList_GET_SIZE(row_loaders) != nfields:
 *             raise e.ProgrammingError(
 *                 f"cannot load sequence of {nfields} items:"             # <<<<<<<<<<<<<<
 *                 f" {len(self._row_loaders)} loaders registered")
 * 
*/
    __pyx_t_10 = __Pyx_PyUnicode_Join(__pyx_t_9, 5, 24 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 8 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 19, 127);
    if (unlikely(!__pyx_t_10)) __PYX_ERR(9, 546, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_5 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
      __pyx_t_5 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_10};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 545, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(9, 545, __pyx_L1_error)

    /* "psycopg_c/_psycopg/transform.pyx":544
 *         out = PyTuple_New(nfields)
 *         row_loaders = self._row_loaders  # avoid an incref/decref per item
 *         if PyList_GET_SIZE(row_loaders) != nfields:             # <<<<<<<<<<<<<<
 *             raise e.ProgrammingError(
 *                 f"cannot load sequence of {nfields} items:"
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":549
 *                 f" {len(self._row_loaders)} loaders registered")
 * 
 *         for col in range(nfields):             # <<<<<<<<<<<<<<
 *             item = PySequence_Fast_GET_ITEM(record_fast, col)
 *             if item == <PyObject *>None:
*/
  __pyx_t_8 = __pyx_v_nfields;
  __pyx_t_11 = __pyx_t_8;
  for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
    __pyx_v_col = __pyx_t_12;

    /* "psycopg_c/_psycopg/transform.pyx":550
 * 
 *         for col in range(nfields):
 *             item = PySequence_Fast_GET_ITEM(record_fast, col)             # <<<<<<<<<<<<<<
 *             if item == <PyObject *>None:
 *                 pyval = None
*/
    __pyx_v_item = PySequence_Fast_GET_ITEM(__pyx_v_record_fast, __pyx_v_col);

    /* "psycopg_c/_psycopg/transform.pyx":551
 *         for col in range(nfields):
 *             item = PySequence_Fast_GET_ITEM(record_fast, col)
 *             if item == <PyObject *>None:             # <<<<<<<<<<<<<<
 *                 pyval = None
 *             else:
*/
    __pyx_t_6 = (__pyx_v_item == ((PyObject *)Py_None));
    if (__pyx_t_6) {

      /* "psycopg_c/_psycopg/transform.pyx":552
 *             item = PySequence_Fast_GET_ITEM(record_fast, col)
 *             if item == <PyObject *>None:
 *                 pyval = None             # <<<<<<<<<<<<<<
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_pyval, Py_None);

      /* "psycopg_c/_psycopg/transform.pyx":551
 *         for col in range(nfields):
 *             item = PySequence_Fast_GET_ITEM(record_fast, col)
 *             if item == <PyObject *>None:             # <<<<<<<<<<<<<<
 *                 pyval = None
 *             else:
*/
      goto __pyx_L6;
    }

    /* "psycopg_c/_psycopg/transform.pyx":554
 *                 pyval = None
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)             # <<<<<<<<<<<<<<
 *                 if (<RowLoader>loader).cloader is not None:
 *                     _buffer_as_string_and_size(<object>item, &ptr, &size)
*/
    /*else*/ {
      __pyx_v_loader = PyList_GET_ITEM(__pyx_v_row_loaders, __pyx_v_col);

      /* "psycopg_c/_psycopg/transform.pyx":555
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)
 *                 if (<RowLoader>loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                     _buffer_as_string_and_size(<object>item, &ptr, &size)
 *                     pyval = (<RowLoader>loader).cloader.cload(ptr, size)
*/
      __pyx_t_6 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader) != Py_None);
      if (__pyx_t_6) {

        /* "psycopg_c/_psycopg/transform.pyx":556
 *                 loader = PyList_GET_ITEM(row_loaders, col)
 *                 if (<RowLoader>loader).cloader is not None:
 *                     _buffer_as_string_and_size(<object>item, &ptr, &size)             # <<<<<<<<<<<<<<
 *                     pyval = (<RowLoader>loader).cloader.cload(ptr, size)
 *                 else:
*/
        __pyx_t_13 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(((PyObject *)__pyx_v_item), (&__pyx_v_ptr), (&__pyx_v_size)); if (unlikely(__pyx_t_13 == ((int)-1))) __PYX_ERR(9, 556, __pyx_L1_error)

        /* "psycopg_c/_psycopg/transform.pyx":557
 *                 if (<RowLoader>loader).cloader is not None:
 *                     _buffer_as_string_and_size(<object>item, &ptr, &size)
 *                     pyval = (<RowLoader>loader).cloader.cload(ptr, size)             # <<<<<<<<<<<<<<
 *                 else:
 *                     pyval = PyObject_CallFunctionObjArgs(
*/
        __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader->__pyx_vtab)->cload(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->cloader, __pyx_v_ptr, __pyx_v_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 557, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "psycopg_c/_psycopg/transform.pyx":555
 *             else:
 *                 loader = PyList_GET_ITEM(row_loaders, col)
 *                 if (<RowLoader>loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                     _buffer_as_string_and_size(<object>item, &ptr, &size)
 *                     pyval = (<RowLoader>loader).cloader.cload(ptr, size)
*/
        goto __pyx_L7;
      }

      /* "psycopg_c/_psycopg/transform.pyx":559
 *                     pyval = (<RowLoader>loader).cloader.cload(ptr, size)
 *                 else:
 *                     pyval = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                         (<RowLoader>loader).loadfunc, item, NULL)
 * 
*/
      /*else*/ {

        /* "psycopg_c/_psycopg/transform.pyx":560
 *                 else:
 *                     pyval = PyObject_CallFunctionObjArgs(
 *                         (<RowLoader>loader).loadfunc, item, NULL)             # <<<<<<<<<<<<<<
 * 
 *             Py_INCREF(pyval)
*/
        __pyx_t_1 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_loader)->loadfunc;
        __Pyx_INCREF(__pyx_t_1);

        /* "psycopg_c/_psycopg/transform.pyx":559
 *                     pyval = (<RowLoader>loader).cloader.cload(ptr, size)
 *                 else:
 *                     pyval = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                         (<RowLoader>loader).loadfunc, item, NULL)
 * 
*/
        __pyx_t_3 = PyObject_CallFunctionObjArgs(__pyx_t_1, __pyx_v_item, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(9, 559, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF_SET(__pyx_v_pyval, __pyx_t_3);
        __pyx_t_3 = 0;
      }
      __pyx_L7:;
    }
    __pyx_L6:;

    /* "psycopg_c/_psycopg/transform.pyx":562
 *                         (<RowLoader>loader).loadfunc, item, NULL)
 * 
 *             Py_INCREF(pyval)             # <<<<<<<<<<<<<<
 *             PyTuple_SET_ITEM(out, col, pyval)
 * 
*/
    Py_INCREF(__pyx_v_pyval);

    /* "psycopg_c/_psycopg/transform.pyx":563
 * 
 *             Py_INCREF(pyval)
 *             PyTuple_SET_ITEM(out, col, pyval)             # <<<<<<<<<<<<<<
 * 
 *         return out
*/
    PyTuple_SET_ITEM(__pyx_v_out, __pyx_v_col, __pyx_v_pyval);
  }

  /* "psycopg_c/_psycopg/transform.pyx":565
 *             PyTuple_SET_ITEM(out, col, pyval)
 * 
 *         return out             # <<<<<<<<<<<<<<
 * 
 *     def get_loader(self, oid: int, format: PqFormat) -> "Loader":
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_out);
  __pyx_r = __pyx_v_out;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":533
 *         return record
 * 
 *     cpdef object load_sequence(self, record: Sequence[Buffer | None]):             # <<<<<<<<<<<<<<
 *         cdef record_fast = PySequence_Fast(record, "'record' is not a valid sequence")
 *         cdef Py_ssize_t nfields = PySequence_Fast_GET_SIZE(record_fast)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.load_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_record_fast);
  __Pyx_XDECREF(__pyx_v_out);
  __Pyx_XDECREF(__pyx_v_row_loaders);
  __Pyx_XDECREF(__pyx_v_pyval);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_21load_sequence(PyObject *__pyx_v_self, PyObject *__pyx_v_record); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_21load_sequence = {"load_sequence", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_21load_sequence, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_21load_sequence(PyObject *__pyx_v_self, PyObject *__pyx_v_record) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("load_sequence (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_20load_sequence(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), ((PyObject *)__pyx_v_record));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_20load_sequence(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_record) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load_sequence", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_11Transformer_load_sequence(__pyx_v_self, __pyx_v_record, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.load_sequence", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":567
 *         return out
 * 
 *     def get_loader(self, oid: int, format: PqFormat) -> "Loader":             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_loader = self._c_get_loader(
 *             <PyObject *>oid, <PyObject *>format)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_23get_loader(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_23get_loader = {"get_loader", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_23get_loader, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_23get_loader(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_oid = 0;
  PyObject *__pyx_v_format = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_loader (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_format,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(9, 567, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 567, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 567, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_loader", 0) < (0)) __PYX_ERR(9, 567, __pyx_L3_error)
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_loader", 1, 2, 2, i); __PYX_ERR(9, 567, __pyx_L3_error) }
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(9, 567, __pyx_L3_error)
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(9, 567, __pyx_L3_error)
    }
    if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(9, 567, __pyx_L3_error)
    __pyx_v_oid = ((PyObject*)values[0]);
    __pyx_v_format = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_loader", 1, 2, 2, __pyx_nargs); __PYX_ERR(9, 567, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.get_loader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(9, 567, __pyx_L1_error)
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_22get_loader(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), __pyx_v_oid, __pyx_v_format);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  goto __pyx_L7_cleaned_up;
  __pyx_L0:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __pyx_L7_cleaned_up:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_22get_loader(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_oid, PyObject *__pyx_v_format) {
  PyObject *__pyx_v_row_loader;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_loader", 0);

  /* "psycopg_c/_psycopg/transform.pyx":568
 * 
 *     def get_loader(self, oid: int, format: PqFormat) -> "Loader":
 *         cdef PyObject *row_loader = self._c_get_loader(             # <<<<<<<<<<<<<<
 *             <PyObject *>oid, <PyObject *>format)
 *         return (<RowLoader>row_loader).pyloader
*/
  __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_vtab)->_c_get_loader(__pyx_v_self, ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_v_format)); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(9, 568, __pyx_L1_error)
  __pyx_v_row_loader = __pyx_t_1;

  /* "psycopg_c/_psycopg/transform.pyx":570
 *         cdef PyObject *row_loader = self._c_get_loader(
 *             <PyObject *>oid, <PyObject *>format)
 *         return (<RowLoader>row_loader).pyloader             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *_c_get_loader(self, PyObject *oid, PyObject *fmt) except NULL:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->pyloader);
  __pyx_r = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->pyloader;
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":567
 *         return out
 * 
 *     def get_loader(self, oid: int, format: PqFormat) -> "Loader":             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_loader = self._c_get_loader(
 *             <PyObject *>oid, <PyObject *>format)
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.get_loader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":572
 *         return (<RowLoader>row_loader).pyloader
 * 
 *     cdef PyObject *_c_get_loader(self, PyObject *oid, PyObject *fmt) except NULL:             # <<<<<<<<<<<<<<
 *         """
 *         Return a borrowed reference to the RowLoader instance for given oid/fmt
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11Transformer__c_get_loader(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, PyObject *__pyx_v_oid, PyObject *__pyx_v_fmt) {
  PyObject *__pyx_v_ptr;
  PyObject *__pyx_v_cache;
  PyObject *__pyx_v_loader_cls = NULL;
  PyObject *__pyx_v_loader = NULL;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_v_row_loader = 0;
  PyObject *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_c_get_loader", 0);

  /* "psycopg_c/_psycopg/transform.pyx":579
 *         cdef PyObject *cache
 * 
 *         if <object>fmt == PQ_TEXT:             # <<<<<<<<<<<<<<
 *             if self._text_loaders is None:
 *                 self._text_loaders = {}
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_RichCompare(((PyObject *)__pyx_v_fmt), __pyx_t_1, Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(9, 579, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_3) {

    /* "psycopg_c/_psycopg/transform.pyx":580
 * 
 *         if <object>fmt == PQ_TEXT:
 *             if self._text_loaders is None:             # <<<<<<<<<<<<<<
 *                 self._text_loaders = {}
 *             cache = <PyObject *>self._text_loaders
*/
    __pyx_t_3 = (__pyx_v_self->_text_loaders == ((PyObject*)Py_None));
    if (__pyx_t_3) {

      /* "psycopg_c/_psycopg/transform.pyx":581
 *         if <object>fmt == PQ_TEXT:
 *             if self._text_loaders is None:
 *                 self._text_loaders = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._text_loaders
 *         elif <object>fmt == PQ_BINARY:
*/
      __pyx_t_2 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 581, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __Pyx_GOTREF(__pyx_v_self->_text_loaders);
      __Pyx_DECREF(__pyx_v_self->_text_loaders);
      __pyx_v_self->_text_loaders = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":580
 * 
 *         if <object>fmt == PQ_TEXT:
 *             if self._text_loaders is None:             # <<<<<<<<<<<<<<
 *                 self._text_loaders = {}
 *             cache = <PyObject *>self._text_loaders
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":582
 *             if self._text_loaders is None:
 *                 self._text_loaders = {}
 *             cache = <PyObject *>self._text_loaders             # <<<<<<<<<<<<<<
 *         elif <object>fmt == PQ_BINARY:
 *             if self._binary_loaders is None:
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_text_loaders);

    /* "psycopg_c/_psycopg/transform.pyx":579
 *         cdef PyObject *cache
 * 
 *         if <object>fmt == PQ_TEXT:             # <<<<<<<<<<<<<<
 *             if self._text_loaders is None:
 *                 self._text_loaders = {}
*/
    goto __pyx_L3;
  }

  /* "psycopg_c/_psycopg/transform.pyx":583
 *                 self._text_loaders = {}
 *             cache = <PyObject *>self._text_loaders
 *         elif <object>fmt == PQ_BINARY:             # <<<<<<<<<<<<<<
 *             if self._binary_loaders is None:
 *                 self._binary_loaders = {}
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_RichCompare(((PyObject *)__pyx_v_fmt), __pyx_t_2, Py_EQ); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(9, 583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(__pyx_t_3)) {

    /* "psycopg_c/_psycopg/transform.pyx":584
 *             cache = <PyObject *>self._text_loaders
 *         elif <object>fmt == PQ_BINARY:
 *             if self._binary_loaders is None:             # <<<<<<<<<<<<<<
 *                 self._binary_loaders = {}
 *             cache = <PyObject *>self._binary_loaders
*/
    __pyx_t_3 = (__pyx_v_self->_binary_loaders == ((PyObject*)Py_None));
    if (__pyx_t_3) {

      /* "psycopg_c/_psycopg/transform.pyx":585
 *         elif <object>fmt == PQ_BINARY:
 *             if self._binary_loaders is None:
 *                 self._binary_loaders = {}             # <<<<<<<<<<<<<<
 *             cache = <PyObject *>self._binary_loaders
 *         else:
*/
      __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 585, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_GIVEREF(__pyx_t_1);
      __Pyx_GOTREF(__pyx_v_self->_binary_loaders);
      __Pyx_DECREF(__pyx_v_self->_binary_loaders);
      __pyx_v_self->_binary_loaders = ((PyObject*)__pyx_t_1);
      __pyx_t_1 = 0;

      /* "psycopg_c/_psycopg/transform.pyx":584
 *             cache = <PyObject *>self._text_loaders
 *         elif <object>fmt == PQ_BINARY:
 *             if self._binary_loaders is None:             # <<<<<<<<<<<<<<
 *                 self._binary_loaders = {}
 *             cache = <PyObject *>self._binary_loaders
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":586
 *             if self._binary_loaders is None:
 *                 self._binary_loaders = {}
 *             cache = <PyObject *>self._binary_loaders             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError(
*/
    __pyx_v_cache = ((PyObject *)__pyx_v_self->_binary_loaders);

    /* "psycopg_c/_psycopg/transform.pyx":583
 *                 self._text_loaders = {}
 *             cache = <PyObject *>self._text_loaders
 *         elif <object>fmt == PQ_BINARY:             # <<<<<<<<<<<<<<
 *             if self._binary_loaders is None:
 *                 self._binary_loaders = {}
*/
    goto __pyx_L3;
  }

  /* "psycopg_c/_psycopg/transform.pyx":588
 *             cache = <PyObject *>self._binary_loaders
 *         else:
 *             raise ValueError(             # <<<<<<<<<<<<<<
 *                 f"format should be a psycopg.pq.Format, not {format}")
 * 
*/
  /*else*/ {
    __pyx_t_2 = NULL;

    /* "psycopg_c/_psycopg/transform.pyx":589
 *         else:
 *             raise ValueError(
 *                 f"format should be a psycopg.pq.Format, not {format}")             # <<<<<<<<<<<<<<
 * 
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
*/
    __pyx_t_4 = __Pyx_GetBuiltinName(__pyx_mstate_global->__pyx_n_u_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_format_should_be_a_psycopg_pq_Fo, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 588, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(9, 588, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "psycopg_c/_psycopg/transform.pyx":591
 *                 f"format should be a psycopg.pq.Format, not {format}")
 * 
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)             # <<<<<<<<<<<<<<
 *         if ptr != NULL:
 *             return ptr
*/
  __pyx_v_ptr = PyDict_GetItem(((PyObject *)__pyx_v_cache), ((PyObject *)__pyx_v_oid));

  /* "psycopg_c/_psycopg/transform.pyx":592
 * 
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             return ptr
 * 
*/
  __pyx_t_3 = (__pyx_v_ptr != NULL);
  if (__pyx_t_3) {

    /* "psycopg_c/_psycopg/transform.pyx":593
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
 *         if ptr != NULL:
 *             return ptr             # <<<<<<<<<<<<<<
 * 
 *         loader_cls = self.adapters.get_loader(<object>oid, <object>fmt)
*/
    __pyx_r = __pyx_v_ptr;
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":592
 * 
 *         ptr = PyDict_GetItem(<object>cache, <object>oid)
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             return ptr
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":595
 *             return ptr
 * 
 *         loader_cls = self.adapters.get_loader(<object>oid, <object>fmt)             # <<<<<<<<<<<<<<
 *         if loader_cls is None:
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)
*/
  __pyx_t_4 = __pyx_v_self->adapters;
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_v_fmt)};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_loader, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 595, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_v_loader_cls = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":596
 * 
 *         loader_cls = self.adapters.get_loader(<object>oid, <object>fmt)
 *         if loader_cls is None:             # <<<<<<<<<<<<<<
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)
 *             if loader_cls is None:
*/
  __pyx_t_3 = (__pyx_v_loader_cls == Py_None);
  if (__pyx_t_3) {

    /* "psycopg_c/_psycopg/transform.pyx":597
 *         loader_cls = self.adapters.get_loader(<object>oid, <object>fmt)
 *         if loader_cls is None:
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)             # <<<<<<<<<<<<<<
 *             if loader_cls is None:
 *                 raise e.InterfaceError("unknown oid loader not found")
*/
    __pyx_t_4 = __pyx_v_self->adapters;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INVALID_OID); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 597, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = 0;
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_2, ((PyObject *)__pyx_v_fmt)};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_get_loader, __pyx_callargs+__pyx_t_6, (3-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 597, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_DECREF_SET(__pyx_v_loader_cls, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":598
 *         if loader_cls is None:
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)
 *             if loader_cls is None:             # <<<<<<<<<<<<<<
 *                 raise e.InterfaceError("unknown oid loader not found")
 * 
*/
    __pyx_t_3 = (__pyx_v_loader_cls == Py_None);
    if (unlikely(__pyx_t_3)) {

      /* "psycopg_c/_psycopg/transform.pyx":599
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)
 *             if loader_cls is None:
 *                 raise e.InterfaceError("unknown oid loader not found")             # <<<<<<<<<<<<<<
 * 
 *         loader = PyObject_CallFunctionObjArgs(
*/
      __pyx_t_2 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(9, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_5)) __PYX_ERR(9, 599, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_5);
        assert(__pyx_t_2);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_unknown_oid_loader_not_found};
        __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 599, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
      }
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(9, 599, __pyx_L1_error)

      /* "psycopg_c/_psycopg/transform.pyx":598
 *         if loader_cls is None:
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)
 *             if loader_cls is None:             # <<<<<<<<<<<<<<
 *                 raise e.InterfaceError("unknown oid loader not found")
 * 
*/
    }

    /* "psycopg_c/_psycopg/transform.pyx":596
 * 
 *         loader_cls = self.adapters.get_loader(<object>oid, <object>fmt)
 *         if loader_cls is None:             # <<<<<<<<<<<<<<
 *             loader_cls = self.adapters.get_loader(oids.INVALID_OID, <object>fmt)
 *             if loader_cls is None:
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":601
 *                 raise e.InterfaceError("unknown oid loader not found")
 * 
 *         loader = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *             loader_cls, oid, <PyObject *>self, NULL)
 * 
*/
  __pyx_t_1 = PyObject_CallFunctionObjArgs(__pyx_v_loader_cls, __pyx_v_oid, ((PyObject *)__pyx_v_self), NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_loader = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":604
 *             loader_cls, oid, <PyObject *>self, NULL)
 * 
 *         cdef RowLoader row_loader = RowLoader()             # <<<<<<<<<<<<<<
 *         row_loader.pyloader = loader
 *         row_loader.loadfunc = loader.load
*/
  __pyx_t_5 = NULL;
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 604, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_row_loader = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":605
 * 
 *         cdef RowLoader row_loader = RowLoader()
 *         row_loader.pyloader = loader             # <<<<<<<<<<<<<<
 *         row_loader.loadfunc = loader.load
 *         if isinstance(loader, CLoader):
*/
  __Pyx_INCREF(__pyx_v_loader);
  __Pyx_GIVEREF(__pyx_v_loader);
  __Pyx_GOTREF(__pyx_v_row_loader->pyloader);
  __Pyx_DECREF(__pyx_v_row_loader->pyloader);
  __pyx_v_row_loader->pyloader = __pyx_v_loader;

  /* "psycopg_c/_psycopg/transform.pyx":606
 *         cdef RowLoader row_loader = RowLoader()
 *         row_loader.pyloader = loader
 *         row_loader.loadfunc = loader.load             # <<<<<<<<<<<<<<
 *         if isinstance(loader, CLoader):
 *             row_loader.cloader = <CLoader>loader
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_loader, __pyx_mstate_global->__pyx_n_u_load); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_row_loader->loadfunc);
  __Pyx_DECREF(__pyx_v_row_loader->loadfunc);
  __pyx_v_row_loader->loadfunc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":607
 *         row_loader.pyloader = loader
 *         row_loader.loadfunc = loader.load
 *         if isinstance(loader, CLoader):             # <<<<<<<<<<<<<<
 *             row_loader.cloader = <CLoader>loader
 * 
*/
  __pyx_t_3 = __Pyx_TypeCheck(__pyx_v_loader, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); 
  if (__pyx_t_3) {

    /* "psycopg_c/_psycopg/transform.pyx":608
 *         row_loader.loadfunc = loader.load
 *         if isinstance(loader, CLoader):
 *             row_loader.cloader = <CLoader>loader             # <<<<<<<<<<<<<<
 * 
 *         PyDict_SetItem(<object>cache, <object>oid, row_loader)
*/
    __pyx_t_1 = __pyx_v_loader;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_row_loader->cloader);
    __Pyx_DECREF((PyObject *)__pyx_v_row_loader->cloader);
    __pyx_v_row_loader->cloader = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":607
 *         row_loader.pyloader = loader
 *         row_loader.loadfunc = loader.load
 *         if isinstance(loader, CLoader):             # <<<<<<<<<<<<<<
 *             row_loader.cloader = <CLoader>loader
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":610
 *             row_loader.cloader = <CLoader>loader
 * 
 *         PyDict_SetItem(<object>cache, <object>oid, row_loader)             # <<<<<<<<<<<<<<
 *         return <PyObject *>row_loader
 * 
*/
  __pyx_t_7 = PyDict_SetItem(((PyObject *)__pyx_v_cache), ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_v_row_loader)); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(9, 610, __pyx_L1_error)

  /* "psycopg_c/_psycopg/transform.pyx":611
 * 
 *         PyDict_SetItem(<object>cache, <object>oid, row_loader)
 *         return <PyObject *>row_loader             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_r = ((PyObject *)__pyx_v_row_loader);
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":572
 *         return (<RowLoader>row_loader).pyloader
 * 
 *     cdef PyObject *_c_get_loader(self, PyObject *oid, PyObject *fmt) except NULL:             # <<<<<<<<<<<<<<
 *         """
 *         Return a borrowed reference to the RowLoader instance for given oid/fmt
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer._c_get_loader", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_loader_cls);
  __Pyx_XDECREF(__pyx_v_loader);
  __Pyx_XDECREF((PyObject *)__pyx_v_row_loader);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":73
 *     """
 * 
 *     cdef readonly object connection             # <<<<<<<<<<<<<<
 *     cdef readonly object adapters
 *     cdef readonly object types
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_10connection_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_10connection_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_10connection___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_10connection___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->connection);
  __pyx_r = __pyx_v_self->connection;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":74
 * 
 *     cdef readonly object connection
 *     cdef readonly object adapters             # <<<<<<<<<<<<<<
 *     cdef readonly object types
 *     cdef readonly object formats
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_8adapters_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_8adapters_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_8adapters___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_8adapters___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->adapters);
  __pyx_r = __pyx_v_self->adapters;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":75
 *     cdef readonly object connection
 *     cdef readonly object adapters
 *     cdef readonly object types             # <<<<<<<<<<<<<<
 *     cdef readonly object formats
 *     cdef str _encoding
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_5types_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_5types_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_5types___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_5types___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->types);
  __pyx_r = __pyx_v_self->types;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":76
 *     cdef readonly object adapters
 *     cdef readonly object types
 *     cdef readonly object formats             # <<<<<<<<<<<<<<
 *     cdef str _encoding
 *     cdef int _none_oid
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_7formats_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_7formats_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_7formats___get__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_7formats___get__(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->formats);
  __pyx_r = __pyx_v_self->formats;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_25__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_25__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_25__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_25__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_24__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_24__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_27__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11Transformer_27__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_27__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11Transformer_27__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11Transformer_26__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11Transformer_26__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.Transformer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":614
 * 
 * 
 * cdef object _as_row_dumper(object dumper):             # <<<<<<<<<<<<<<
 *     cdef RowDumper row_dumper = RowDumper()
 * 
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__as_row_dumper(PyObject *__pyx_v_dumper) {
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v_row_dumper = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  size_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_as_row_dumper", 0);

  /* "psycopg_c/_psycopg/transform.pyx":615
 * 
 * cdef object _as_row_dumper(object dumper):
 *     cdef RowDumper row_dumper = RowDumper()             # <<<<<<<<<<<<<<
 * 
 *     row_dumper.pydumper = dumper
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 615, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_v_row_dumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":617
 *     cdef RowDumper row_dumper = RowDumper()
 * 
 *     row_dumper.pydumper = dumper             # <<<<<<<<<<<<<<
 *     row_dumper.dumpfunc = dumper.dump
 *     row_dumper.oid = dumper.oid
*/
  __Pyx_INCREF(__pyx_v_dumper);
  __Pyx_GIVEREF(__pyx_v_dumper);
  __Pyx_GOTREF(__pyx_v_row_dumper->pydumper);
  __Pyx_DECREF(__pyx_v_row_dumper->pydumper);
  __pyx_v_row_dumper->pydumper = __pyx_v_dumper;

  /* "psycopg_c/_psycopg/transform.pyx":618
 * 
 *     row_dumper.pydumper = dumper
 *     row_dumper.dumpfunc = dumper.dump             # <<<<<<<<<<<<<<
 *     row_dumper.oid = dumper.oid
 *     row_dumper.format = dumper.format
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dumper, __pyx_mstate_global->__pyx_n_u_dump); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_row_dumper->dumpfunc);
  __Pyx_DECREF(__pyx_v_row_dumper->dumpfunc);
  __pyx_v_row_dumper->dumpfunc = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":619
 *     row_dumper.pydumper = dumper
 *     row_dumper.dumpfunc = dumper.dump
 *     row_dumper.oid = dumper.oid             # <<<<<<<<<<<<<<
 *     row_dumper.format = dumper.format
 * 
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dumper, __pyx_mstate_global->__pyx_n_u_oid); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_row_dumper->oid);
  __Pyx_DECREF(__pyx_v_row_dumper->oid);
  __pyx_v_row_dumper->oid = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":620
 *     row_dumper.dumpfunc = dumper.dump
 *     row_dumper.oid = dumper.oid
 *     row_dumper.format = dumper.format             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(dumper, CDumper):
*/
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_dumper, __pyx_mstate_global->__pyx_n_u_format); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v_row_dumper->format);
  __Pyx_DECREF(__pyx_v_row_dumper->format);
  __pyx_v_row_dumper->format = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":622
 *     row_dumper.format = dumper.format
 * 
 *     if isinstance(dumper, CDumper):             # <<<<<<<<<<<<<<
 *         row_dumper.cdumper = <CDumper>dumper
 * 
*/
  __pyx_t_4 = __Pyx_TypeCheck(__pyx_v_dumper, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); 
  if (__pyx_t_4) {

    /* "psycopg_c/_psycopg/transform.pyx":623
 * 
 *     if isinstance(dumper, CDumper):
 *         row_dumper.cdumper = <CDumper>dumper             # <<<<<<<<<<<<<<
 * 
 *     return row_dumper
*/
    __pyx_t_1 = __pyx_v_dumper;
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_GOTREF((PyObject *)__pyx_v_row_dumper->cdumper);
    __Pyx_DECREF((PyObject *)__pyx_v_row_dumper->cdumper);
    __pyx_v_row_dumper->cdumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/_psycopg/transform.pyx":622
 *     row_dumper.format = dumper.format
 * 
 *     if isinstance(dumper, CDumper):             # <<<<<<<<<<<<<<
 *         row_dumper.cdumper = <CDumper>dumper
 * 
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":625
 *         row_dumper.cdumper = <CDumper>dumper
 * 
 *     return row_dumper             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_row_dumper);
  __pyx_r = ((PyObject *)__pyx_v_row_dumper);
  goto __pyx_L0;

  /* "psycopg_c/_psycopg/transform.pyx":614
 * 
 * 
 * cdef object _as_row_dumper(object dumper):             # <<<<<<<<<<<<<<
 *     cdef RowDumper row_dumper = RowDumper()
 * 
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg._as_row_dumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_row_dumper);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/transform.pyx":628
 * 
 * 
 * cdef Transformer _tx_from_context(object context):             # <<<<<<<<<<<<<<
 *     if isinstance(context, Transformer):
 *         return context
*/

static struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_f_9psycopg_c_8_psycopg__tx_from_context(PyObject *__pyx_v_context) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_tx_from_context", 0);

  /* "psycopg_c/_psycopg/transform.pyx":629
 * 
 * cdef Transformer _tx_from_context(object context):
 *     if isinstance(context, Transformer):             # <<<<<<<<<<<<<<
 *         return context
 *     else:
*/
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_context, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer); 
  if (__pyx_t_1) {

    /* "psycopg_c/_psycopg/transform.pyx":630
 * cdef Transformer _tx_from_context(object context):
 *     if isinstance(context, Transformer):
 *         return context             # <<<<<<<<<<<<<<
 *     else:
 *         return Transformer(context)
*/
    __Pyx_XDECREF((PyObject *)__pyx_r);
    if (!(likely(((__pyx_v_context) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_context, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer))))) __PYX_ERR(9, 630, __pyx_L1_error)
    __Pyx_INCREF(__pyx_v_context);
    __pyx_r = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_v_context);
    goto __pyx_L0;

    /* "psycopg_c/_psycopg/transform.pyx":629
 * 
 * cdef Transformer _tx_from_context(object context):
 *     if isinstance(context, Transformer):             # <<<<<<<<<<<<<<
 *         return context
 *     else:
*/
  }

  /* "psycopg_c/_psycopg/transform.pyx":632
 *         return context
 *     else:
 *         return Transformer(context)             # <<<<<<<<<<<<<<
*/
  /*else*/ {
    __Pyx_XDECREF((PyObject *)__pyx_r);
    __pyx_t_3 = NULL;
    __pyx_t_4 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_context};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 632, __pyx_L1_error)
      __Pyx_GOTREF((PyObject *)__pyx_t_2);
    }
    __pyx_r = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "psycopg_c/_psycopg/transform.pyx":628
 * 
 * 
 * cdef Transformer _tx_from_context(object context):             # <<<<<<<<<<<<<<
 *     if isinstance(context, Transformer):
 *         return context
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("psycopg_c._psycopg._tx_from_context", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/_psycopg/waiting.pyx":201
 * 
 * 
 * def wait_c(gen: PQGen[RV], int fileno, interval = 0.0) -> RV:             # <<<<<<<<<<<<<<
 *     """
 *     Wait for a generator using poll or select.
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_30wait_c(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_9psycopg_c_8_psycopg_29wait_c, "\n    Wait for a generator using poll or select.\n    ");
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_30wait_c = {"wait_c", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_30wait_c, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_9psycopg_c_8_psycopg_29wait_c};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_30wait_c(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_gen = 0;
  int __pyx_v_fileno;
  PyObject *__pyx_v_interval = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wait_c (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_SIZE
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_gen,&__pyx_mstate_global->__pyx_n_u_fileno,&__pyx_mstate_global->__pyx_n_u_interval,0};
    const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
    if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(10, 201, __pyx_L3_error)
    if (__pyx_kwds_len > 0) {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(10, 201, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(10, 201, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  1:
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(10, 201, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      const Py_ssize_t kwd_pos_args = __pyx_nargs;
      if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "wait_c", 0) < (0)) __PYX_ERR(10, 201, __pyx_L3_error)
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_float_0_0)));
      for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
        if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("wait_c", 0, 2, 3, i); __PYX_ERR(10, 201, __pyx_L3_error) }
      }
    } else {
      switch (__pyx_nargs) {
        case  3:
        values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(10, 201, __pyx_L3_error)
        CYTHON_FALLTHROUGH;
        case  2:
        values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(10, 201, __pyx_L3_error)
        values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
        if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(10, 201, __pyx_L3_error)
        break;
        default: goto __pyx_L5_argtuple_error;
      }
      if (!values[2]) values[2] = __Pyx_NewRef(((PyObject *)((PyObject*)__pyx_mstate_global->__pyx_float_0_0)));
    }
    __pyx_v_gen = values[0];
    __pyx_v_fileno = __Pyx_PyLong_As_int(values[1]); if (unlikely((__pyx_v_fileno == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 201, __pyx_L3_error)
    __pyx_v_interval = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("wait_c", 0, 2, 3, __pyx_nargs); __PYX_ERR(10, 201, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_AddTraceback("psycopg_c._psycopg.wait_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_29wait_c(__pyx_self, __pyx_v_gen, __pyx_v_fileno, __pyx_v_interval);

  /* function exit code */
  for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
    Py_XDECREF(values[__pyx_temp]);
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_29wait_c(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_gen, int __pyx_v_fileno, PyObject *__pyx_v_interval) {
  float __pyx_v_cinterval;
  int __pyx_v_wait;
  int __pyx_v_ready;
  PyObject *__pyx_v_pyready;
  PyObject *__pyx_v_send = NULL;
  PyObject *__pyx_v_ex = NULL;
  PyObject *__pyx_v_rv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  size_t __pyx_t_4;
  double __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  int __pyx_t_18;
  char const *__pyx_t_19;
  PyObject *__pyx_t_20 = NULL;
  PyObject *__pyx_t_21 = NULL;
  PyObject *__pyx_t_22 = NULL;
  PyObject *__pyx_t_23 = NULL;
  PyObject *__pyx_t_24 = NULL;
  PyObject *__pyx_t_25 = NULL;
  char const *__pyx_t_26;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wait_c", 0);

  /* "psycopg_c/_psycopg/waiting.pyx":209
 *     cdef PyObject *pyready
 * 
 *     if interval is None:             # <<<<<<<<<<<<<<
 *         raise ValueError("indefinite wait not supported anymore")
 * 
*/
  __pyx_t_1 = (__pyx_v_interval == Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/_psycopg/waiting.pyx":210
 * 
 *     if interval is None:
 *         raise ValueError("indefinite wait not supported anymore")             # <<<<<<<<<<<<<<
 * 
 *     cinterval = <float>float(interval)
*/
    __pyx_t_3 = NULL;
    __pyx_t_4 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_indefinite_wait_not_supported_an};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(10, 210, __pyx_L1_error)

    /* "psycopg_c/_psycopg/waiting.pyx":209
 *     cdef PyObject *pyready
 * 
 *     if interval is None:             # <<<<<<<<<<<<<<
 *         raise ValueError("indefinite wait not supported anymore")
 * 
*/
  }

  /* "psycopg_c/_psycopg/waiting.pyx":212
 *         raise ValueError("indefinite wait not supported anymore")
 * 
 *     cinterval = <float>float(interval)             # <<<<<<<<<<<<<<
 *     if cinterval < 0.0:
 *         cinterval = 0.0
*/
  __pyx_t_5 = __Pyx_PyObject_AsDouble(__pyx_v_interval); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_5, ((double)((double)-1))) && PyErr_Occurred())) __PYX_ERR(10, 212, __pyx_L1_error)
  __pyx_v_cinterval = ((float)__pyx_t_5);

  /* "psycopg_c/_psycopg/waiting.pyx":213
 * 
 *     cinterval = <float>float(interval)
 *     if cinterval < 0.0:             # <<<<<<<<<<<<<<
 *         cinterval = 0.0
 * 
*/
  __pyx_t_1 = (__pyx_v_cinterval < 0.0);
  if (__pyx_t_1) {

    /* "psycopg_c/_psycopg/waiting.pyx":214
 *     cinterval = <float>float(interval)
 *     if cinterval < 0.0:
 *         cinterval = 0.0             # <<<<<<<<<<<<<<
 * 
 *     send = gen.send
*/
    __pyx_v_cinterval = 0.0;

    /* "psycopg_c/_psycopg/waiting.pyx":213
 * 
 *     cinterval = <float>float(interval)
 *     if cinterval < 0.0:             # <<<<<<<<<<<<<<
 *         cinterval = 0.0
 * 
*/
  }

  /* "psycopg_c/_psycopg/waiting.pyx":216
 *         cinterval = 0.0
 * 
 *     send = gen.send             # <<<<<<<<<<<<<<
 * 
 *     try:
*/
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_gen, __pyx_mstate_global->__pyx_n_u_send); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_send = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/waiting.pyx":218
 *     send = gen.send
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         wait = next(gen)
 * 
*/
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_6, &__pyx_t_7, &__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    /*try:*/ {

      /* "psycopg_c/_psycopg/waiting.pyx":219
 * 
 *     try:
 *         wait = next(gen)             # <<<<<<<<<<<<<<
 * 
 *         while True:
*/
      __pyx_t_2 = __Pyx_PyIter_Next(__pyx_v_gen); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 219, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_9 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_9 == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 219, __pyx_L5_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_v_wait = __pyx_t_9;

      /* "psycopg_c/_psycopg/waiting.pyx":221
 *         wait = next(gen)
 * 
 *         while True:             # <<<<<<<<<<<<<<
 *             ready = wait_c_impl(fileno, wait, cinterval)
 *             if ready == READY_NONE:
*/
      while (1) {

        /* "psycopg_c/_psycopg/waiting.pyx":222
 * 
 *         while True:
 *             ready = wait_c_impl(fileno, wait, cinterval)             # <<<<<<<<<<<<<<
 *             if ready == READY_NONE:
 *                 pyready = <PyObject *>PY_READY_NONE
*/
        __pyx_t_9 = wait_c_impl(__pyx_v_fileno, __pyx_v_wait, __pyx_v_cinterval); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(10, 222, __pyx_L5_error)
        __pyx_v_ready = __pyx_t_9;

        /* "psycopg_c/_psycopg/waiting.pyx":223
 *         while True:
 *             ready = wait_c_impl(fileno, wait, cinterval)
 *             if ready == READY_NONE:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_NONE
 *             elif ready == READY_R:
*/
        __pyx_t_1 = (__pyx_v_ready == __pyx_v_9psycopg_c_8_psycopg_READY_NONE);
        if (__pyx_t_1) {

          /* "psycopg_c/_psycopg/waiting.pyx":224
 *             ready = wait_c_impl(fileno, wait, cinterval)
 *             if ready == READY_NONE:
 *                 pyready = <PyObject *>PY_READY_NONE             # <<<<<<<<<<<<<<
 *             elif ready == READY_R:
 *                 pyready = <PyObject *>PY_READY_R
*/
          __pyx_v_pyready = ((PyObject *)__pyx_v_9psycopg_c_8_psycopg_PY_READY_NONE);

          /* "psycopg_c/_psycopg/waiting.pyx":223
 *         while True:
 *             ready = wait_c_impl(fileno, wait, cinterval)
 *             if ready == READY_NONE:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_NONE
 *             elif ready == READY_R:
*/
          goto __pyx_L13;
        }

        /* "psycopg_c/_psycopg/waiting.pyx":225
 *             if ready == READY_NONE:
 *                 pyready = <PyObject *>PY_READY_NONE
 *             elif ready == READY_R:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_R
 *             elif ready == READY_RW:
*/
        __pyx_t_1 = (__pyx_v_ready == __pyx_v_9psycopg_c_8_psycopg_READY_R);
        if (__pyx_t_1) {

          /* "psycopg_c/_psycopg/waiting.pyx":226
 *                 pyready = <PyObject *>PY_READY_NONE
 *             elif ready == READY_R:
 *                 pyready = <PyObject *>PY_READY_R             # <<<<<<<<<<<<<<
 *             elif ready == READY_RW:
 *                 pyready = <PyObject *>PY_READY_RW
*/
          __pyx_v_pyready = ((PyObject *)__pyx_v_9psycopg_c_8_psycopg_PY_READY_R);

          /* "psycopg_c/_psycopg/waiting.pyx":225
 *             if ready == READY_NONE:
 *                 pyready = <PyObject *>PY_READY_NONE
 *             elif ready == READY_R:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_R
 *             elif ready == READY_RW:
*/
          goto __pyx_L13;
        }

        /* "psycopg_c/_psycopg/waiting.pyx":227
 *             elif ready == READY_R:
 *                 pyready = <PyObject *>PY_READY_R
 *             elif ready == READY_RW:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_RW
 *             elif ready == READY_W:
*/
        __pyx_t_1 = (__pyx_v_ready == __pyx_v_9psycopg_c_8_psycopg_READY_RW);
        if (__pyx_t_1) {

          /* "psycopg_c/_psycopg/waiting.pyx":228
 *                 pyready = <PyObject *>PY_READY_R
 *             elif ready == READY_RW:
 *                 pyready = <PyObject *>PY_READY_RW             # <<<<<<<<<<<<<<
 *             elif ready == READY_W:
 *                 pyready = <PyObject *>PY_READY_W
*/
          __pyx_v_pyready = ((PyObject *)__pyx_v_9psycopg_c_8_psycopg_PY_READY_RW);

          /* "psycopg_c/_psycopg/waiting.pyx":227
 *             elif ready == READY_R:
 *                 pyready = <PyObject *>PY_READY_R
 *             elif ready == READY_RW:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_RW
 *             elif ready == READY_W:
*/
          goto __pyx_L13;
        }

        /* "psycopg_c/_psycopg/waiting.pyx":229
 *             elif ready == READY_RW:
 *                 pyready = <PyObject *>PY_READY_RW
 *             elif ready == READY_W:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
*/
        __pyx_t_1 = (__pyx_v_ready == __pyx_v_9psycopg_c_8_psycopg_READY_W);
        if (__pyx_t_1) {

          /* "psycopg_c/_psycopg/waiting.pyx":230
 *                 pyready = <PyObject *>PY_READY_RW
 *             elif ready == READY_W:
 *                 pyready = <PyObject *>PY_READY_W             # <<<<<<<<<<<<<<
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
 *                 try:
*/
          __pyx_v_pyready = ((PyObject *)__pyx_v_9psycopg_c_8_psycopg_PY_READY_W);

          /* "psycopg_c/_psycopg/waiting.pyx":229
 *             elif ready == READY_RW:
 *                 pyready = <PyObject *>PY_READY_RW
 *             elif ready == READY_W:             # <<<<<<<<<<<<<<
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
*/
          goto __pyx_L13;
        }

        /* "psycopg_c/_psycopg/waiting.pyx":231
 *             elif ready == READY_W:
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?             # <<<<<<<<<<<<<<
 *                 try:
 *                     fstat(fileno)
*/
        __pyx_t_1 = (__pyx_v_ready == CWAIT_SOCKET_ERROR);
        if (likely(__pyx_t_1)) {

          /* "psycopg_c/_psycopg/waiting.pyx":232
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
 *                 try:             # <<<<<<<<<<<<<<
 *                     fstat(fileno)
 *                 except Exception as ex:
*/
          {
            __Pyx_PyThreadState_declare
            __Pyx_PyThreadState_assign
            __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
            __Pyx_XGOTREF(__pyx_t_10);
            __Pyx_XGOTREF(__pyx_t_11);
            __Pyx_XGOTREF(__pyx_t_12);
            /*try:*/ {

              /* "psycopg_c/_psycopg/waiting.pyx":233
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
 *                 try:
 *                     fstat(fileno)             # <<<<<<<<<<<<<<
 *                 except Exception as ex:
 *                     raise e.OperationalError("connection socket closed") from ex
*/
              __pyx_t_3 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_fstat); if (unlikely(!__pyx_t_13)) __PYX_ERR(10, 233, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_14 = __Pyx_PyLong_From_int(__pyx_v_fileno); if (unlikely(!__pyx_t_14)) __PYX_ERR(10, 233, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_4 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_13))) {
                __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_13);
                assert(__pyx_t_3);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
                __Pyx_INCREF(__pyx_t_3);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
                __pyx_t_4 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_14};
                __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 233, __pyx_L14_error)
                __Pyx_GOTREF(__pyx_t_2);
              }
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

              /* "psycopg_c/_psycopg/waiting.pyx":232
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
 *                 try:             # <<<<<<<<<<<<<<
 *                     fstat(fileno)
 *                 except Exception as ex:
*/
            }

            /* "psycopg_c/_psycopg/waiting.pyx":237
 *                     raise e.OperationalError("connection socket closed") from ex
 *                 else:
 *                     raise e.OperationalError("connection socket closed")             # <<<<<<<<<<<<<<
 *             else:
 *                 raise AssertionError(f"unexpected ready value: {ready}")
*/
            /*else:*/ {
              __pyx_t_13 = NULL;
              __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_14)) __PYX_ERR(10, 237, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_14);
              __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_3)) __PYX_ERR(10, 237, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_3);
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __pyx_t_4 = 1;
              #if CYTHON_UNPACK_METHODS
              if (unlikely(PyMethod_Check(__pyx_t_3))) {
                __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_3);
                assert(__pyx_t_13);
                PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
                __Pyx_INCREF(__pyx_t_13);
                __Pyx_INCREF(__pyx__function);
                __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
                __pyx_t_4 = 0;
              }
              #endif
              {
                PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_mstate_global->__pyx_kp_u_connection_socket_closed};
                __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
                __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
                if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 237, __pyx_L16_except_error)
                __Pyx_GOTREF(__pyx_t_2);
              }
              __Pyx_Raise(__pyx_t_2, 0, 0, 0);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __PYX_ERR(10, 237, __pyx_L16_except_error)
            }
            __pyx_L14_error:;
            __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
            __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
            __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

            /* "psycopg_c/_psycopg/waiting.pyx":234
 *                 try:
 *                     fstat(fileno)
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     raise e.OperationalError("connection socket closed") from ex
 *                 else:
*/
            __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
            if (__pyx_t_9) {
              __Pyx_AddTraceback("psycopg_c._psycopg.wait_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
              if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_13) < 0) __PYX_ERR(10, 234, __pyx_L16_except_error)
              __Pyx_XGOTREF(__pyx_t_2);
              __Pyx_XGOTREF(__pyx_t_3);
              __Pyx_XGOTREF(__pyx_t_13);
              __Pyx_INCREF(__pyx_t_3);
              __pyx_v_ex = __pyx_t_3;
              /*try:*/ {

                /* "psycopg_c/_psycopg/waiting.pyx":235
 *                     fstat(fileno)
 *                 except Exception as ex:
 *                     raise e.OperationalError("connection socket closed") from ex             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise e.OperationalError("connection socket closed")
*/
                __pyx_t_15 = NULL;
                __Pyx_GetModuleGlobalName(__pyx_t_16, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_16)) __PYX_ERR(10, 235, __pyx_L27_error)
                __Pyx_GOTREF(__pyx_t_16);
                __pyx_t_17 = __Pyx_PyObject_GetAttrStr(__pyx_t_16, __pyx_mstate_global->__pyx_n_u_OperationalError); if (unlikely(!__pyx_t_17)) __PYX_ERR(10, 235, __pyx_L27_error)
                __Pyx_GOTREF(__pyx_t_17);
                __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
                __pyx_t_4 = 1;
                #if CYTHON_UNPACK_METHODS
                if (unlikely(PyMethod_Check(__pyx_t_17))) {
                  __pyx_t_15 = PyMethod_GET_SELF(__pyx_t_17);
                  assert(__pyx_t_15);
                  PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_17);
                  __Pyx_INCREF(__pyx_t_15);
                  __Pyx_INCREF(__pyx__function);
                  __Pyx_DECREF_SET(__pyx_t_17, __pyx__function);
                  __pyx_t_4 = 0;
                }
                #endif
                {
                  PyObject *__pyx_callargs[2] = {__pyx_t_15, __pyx_mstate_global->__pyx_kp_u_connection_socket_closed};
                  __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_17, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
                  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                  __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
                  if (unlikely(!__pyx_t_14)) __PYX_ERR(10, 235, __pyx_L27_error)
                  __Pyx_GOTREF(__pyx_t_14);
                }
                __Pyx_Raise(__pyx_t_14, 0, 0, __pyx_v_ex);
                __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
                __PYX_ERR(10, 235, __pyx_L27_error)
              }

              /* "psycopg_c/_psycopg/waiting.pyx":234
 *                 try:
 *                     fstat(fileno)
 *                 except Exception as ex:             # <<<<<<<<<<<<<<
 *                     raise e.OperationalError("connection socket closed") from ex
 *                 else:
*/
              /*finally:*/ {
                __pyx_L27_error:;
                /*exception exit:*/{
                  __Pyx_PyThreadState_declare
                  __Pyx_PyThreadState_assign
                  __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
                  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
                  __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
                  __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
                  __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
                   __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
                  if ( unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
                  __Pyx_XGOTREF(__pyx_t_20);
                  __Pyx_XGOTREF(__pyx_t_21);
                  __Pyx_XGOTREF(__pyx_t_22);
                  __Pyx_XGOTREF(__pyx_t_23);
                  __Pyx_XGOTREF(__pyx_t_24);
                  __Pyx_XGOTREF(__pyx_t_25);
                  __pyx_t_9 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
                  {
                    __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
                  }
                  __Pyx_XGIVEREF(__pyx_t_23);
                  __Pyx_XGIVEREF(__pyx_t_24);
                  __Pyx_XGIVEREF(__pyx_t_25);
                  __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
                  __Pyx_XGIVEREF(__pyx_t_20);
                  __Pyx_XGIVEREF(__pyx_t_21);
                  __Pyx_XGIVEREF(__pyx_t_22);
                  __Pyx_ErrRestore(__pyx_t_20, __pyx_t_21, __pyx_t_22);
                  __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
                  __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
                  goto __pyx_L16_except_error;
                }
              }
            }
            goto __pyx_L16_except_error;

            /* "psycopg_c/_psycopg/waiting.pyx":232
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?
 *                 try:             # <<<<<<<<<<<<<<
 *                     fstat(fileno)
 *                 except Exception as ex:
*/
            __pyx_L16_except_error:;
            __Pyx_XGIVEREF(__pyx_t_10);
            __Pyx_XGIVEREF(__pyx_t_11);
            __Pyx_XGIVEREF(__pyx_t_12);
            __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
            goto __pyx_L5_error;
          }

          /* "psycopg_c/_psycopg/waiting.pyx":231
 *             elif ready == READY_W:
 *                 pyready = <PyObject *>PY_READY_W
 *             elif ready == CWAIT_SOCKET_ERROR:  # FD closed?             # <<<<<<<<<<<<<<
 *                 try:
 *                     fstat(fileno)
*/
        }

        /* "psycopg_c/_psycopg/waiting.pyx":239
 *                     raise e.OperationalError("connection socket closed")
 *             else:
 *                 raise AssertionError(f"unexpected ready value: {ready}")             # <<<<<<<<<<<<<<
 * 
 *             wait = PyObject_CallFunctionObjArgs(send, pyready, NULL)
*/
        /*else*/ {
          __pyx_t_3 = NULL;
          __pyx_t_2 = __Pyx_PyUnicode_From_int(__pyx_v_ready, 0, ' ', 'd'); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 239, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_14 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_unexpected_ready_value, __pyx_t_2); if (unlikely(!__pyx_t_14)) __PYX_ERR(10, 239, __pyx_L5_error)
          __Pyx_GOTREF(__pyx_t_14);
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __pyx_t_4 = 1;
          {
            PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_14};
            __pyx_t_13 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_AssertionError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
            __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
            __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
            if (unlikely(!__pyx_t_13)) __PYX_ERR(10, 239, __pyx_L5_error)
            __Pyx_GOTREF(__pyx_t_13);
          }
          __Pyx_Raise(__pyx_t_13, 0, 0, 0);
          __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
          __PYX_ERR(10, 239, __pyx_L5_error)
        }
        __pyx_L13:;

        /* "psycopg_c/_psycopg/waiting.pyx":241
 *                 raise AssertionError(f"unexpected ready value: {ready}")
 * 
 *             wait = PyObject_CallFunctionObjArgs(send, pyready, NULL)             # <<<<<<<<<<<<<<
 * 
 *     except StopIteration as ex:
*/
        __pyx_t_13 = PyObject_CallFunctionObjArgs(__pyx_v_send, __pyx_v_pyready, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(10, 241, __pyx_L5_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_18 = __Pyx_PyLong_As_int(__pyx_t_13); if (unlikely((__pyx_t_18 == (int)-1) && PyErr_Occurred())) __PYX_ERR(10, 241, __pyx_L5_error)
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_v_wait = __pyx_t_18;
      }

      /* "psycopg_c/_psycopg/waiting.pyx":218
 *     send = gen.send
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         wait = next(gen)
 * 
*/
    }
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L10_try_end;
    __pyx_L5_error:;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "psycopg_c/_psycopg/waiting.pyx":243
 *             wait = PyObject_CallFunctionObjArgs(send, pyready, NULL)
 * 
 *     except StopIteration as ex:             # <<<<<<<<<<<<<<
 *         rv: RV = ex.value
 *         return rv
*/
    __pyx_t_18 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_StopIteration))));
    if (__pyx_t_18) {
      __Pyx_AddTraceback("psycopg_c._psycopg.wait_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_14, &__pyx_t_3) < 0) __PYX_ERR(10, 243, __pyx_L7_except_error)
      __Pyx_XGOTREF(__pyx_t_13);
      __Pyx_XGOTREF(__pyx_t_14);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_14);
      __Pyx_XDECREF_SET(__pyx_v_ex, __pyx_t_14);
      /*try:*/ {

        /* "psycopg_c/_psycopg/waiting.pyx":244
 * 
 *     except StopIteration as ex:
 *         rv: RV = ex.value             # <<<<<<<<<<<<<<
 *         return rv
*/
        __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_ex, __pyx_mstate_global->__pyx_n_u_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 244, __pyx_L38_error)
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_v_rv = __pyx_t_2;
        __pyx_t_2 = 0;

        /* "psycopg_c/_psycopg/waiting.pyx":245
 *     except StopIteration as ex:
 *         rv: RV = ex.value
 *         return rv             # <<<<<<<<<<<<<<
*/
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_v_rv);
        __pyx_r = __pyx_v_rv;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        goto __pyx_L37_return;
      }

      /* "psycopg_c/_psycopg/waiting.pyx":243
 *             wait = PyObject_CallFunctionObjArgs(send, pyready, NULL)
 * 
 *     except StopIteration as ex:             # <<<<<<<<<<<<<<
 *         rv: RV = ex.value
 *         return rv
*/
      /*finally:*/ {
        __pyx_L38_error:;
        /*exception exit:*/{
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_25 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0;
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
           __Pyx_ExceptionSwap(&__pyx_t_25, &__pyx_t_24, &__pyx_t_23);
          if ( unlikely(__Pyx_GetException(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10) < 0)) __Pyx_ErrFetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_12);
          __Pyx_XGOTREF(__pyx_t_11);
          __Pyx_XGOTREF(__pyx_t_10);
          __Pyx_XGOTREF(__pyx_t_25);
          __Pyx_XGOTREF(__pyx_t_24);
          __Pyx_XGOTREF(__pyx_t_23);
          __pyx_t_18 = __pyx_lineno; __pyx_t_9 = __pyx_clineno; __pyx_t_26 = __pyx_filename;
          {
            __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          }
          __Pyx_XGIVEREF(__pyx_t_25);
          __Pyx_XGIVEREF(__pyx_t_24);
          __Pyx_XGIVEREF(__pyx_t_23);
          __Pyx_ExceptionReset(__pyx_t_25, __pyx_t_24, __pyx_t_23);
          __Pyx_XGIVEREF(__pyx_t_12);
          __Pyx_XGIVEREF(__pyx_t_11);
          __Pyx_XGIVEREF(__pyx_t_10);
          __Pyx_ErrRestore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          __pyx_t_12 = 0; __pyx_t_11 = 0; __pyx_t_10 = 0; __pyx_t_25 = 0; __pyx_t_24 = 0; __pyx_t_23 = 0;
          __pyx_lineno = __pyx_t_18; __pyx_clineno = __pyx_t_9; __pyx_filename = __pyx_t_26;
          goto __pyx_L7_except_error;
        }
        __pyx_L37_return: {
          __pyx_t_23 = __pyx_r;
          __pyx_r = 0;
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
          __pyx_r = __pyx_t_23;
          __pyx_t_23 = 0;
          goto __pyx_L8_except_return;
        }
      }
    }
    goto __pyx_L7_except_error;

    /* "psycopg_c/_psycopg/waiting.pyx":218
 *     send = gen.send
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         wait = next(gen)
 * 
*/
    __pyx_L7_except_error:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L1_error;
    __pyx_L8_except_return:;
    __Pyx_XGIVEREF(__pyx_t_6);
    __Pyx_XGIVEREF(__pyx_t_7);
    __Pyx_XGIVEREF(__pyx_t_8);
    __Pyx_ExceptionReset(__pyx_t_6, __pyx_t_7, __pyx_t_8);
    goto __pyx_L0;
    __pyx_L10_try_end:;
  }

  /* "psycopg_c/_psycopg/waiting.pyx":201
 * 
 * 
 * def wait_c(gen: PQGen[RV], int fileno, interval = 0.0) -> RV:             # <<<<<<<<<<<<<<
 *     """
 *     Wait for a generator using poll or select.
*/

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_14);
  __Pyx_XDECREF(__pyx_t_15);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("psycopg_c._psycopg.wait_c", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_send);
  __Pyx_XDECREF(__pyx_v_ex);
  __Pyx_XDECREF(__pyx_v_rv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/types/array.pyx":46
 *     cdef size_t sclen
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self.cdelim == b"\x00":
 *             self.row_loader = self._tx._c_get_loader(
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11ArrayLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4;
  char __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cload", 0);

  /* "psycopg_c/types/array.pyx":47
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self.cdelim == b"\x00":             # <<<<<<<<<<<<<<
 *             self.row_loader = self._tx._c_get_loader(
 *                 <PyObject *>self.base_oid, <PyObject *>PQ_TEXT)
*/
  __pyx_t_1 = (__pyx_v_self->cdelim == '\x00');
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":49
 *         if self.cdelim == b"\x00":
 *             self.row_loader = self._tx._c_get_loader(
 *                 <PyObject *>self.base_oid, <PyObject *>PQ_TEXT)             # <<<<<<<<<<<<<<
 *             self.cdelim = self.delimiter[0]
 * 
*/
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_base_oid); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 49, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);

    /* "psycopg_c/types/array.pyx":48
 *     cdef object cload(self, const char *data, size_t length):
 *         if self.cdelim == b"\x00":
 *             self.row_loader = self._tx._c_get_loader(             # <<<<<<<<<<<<<<
 *                 <PyObject *>self.base_oid, <PyObject *>PQ_TEXT)
 *             self.cdelim = self.delimiter[0]
*/
    __pyx_t_4 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_self->__pyx_base._tx->__pyx_vtab)->_c_get_loader(__pyx_v_self->__pyx_base._tx, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_3)); if (unlikely(__pyx_t_4 == ((void *)NULL))) __PYX_ERR(11, 48, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_self->row_loader = __pyx_t_4;

    /* "psycopg_c/types/array.pyx":50
 *             self.row_loader = self._tx._c_get_loader(
 *                 <PyObject *>self.base_oid, <PyObject *>PQ_TEXT)
 *             self.cdelim = self.delimiter[0]             # <<<<<<<<<<<<<<
 * 
 *         return _array_load_text(
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_delimiter); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 50, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_5 = __Pyx_PyLong_As_char(__pyx_t_2); if (unlikely((__pyx_t_5 == (char)-1) && PyErr_Occurred())) __PYX_ERR(11, 50, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_self->cdelim = __pyx_t_5;

    /* "psycopg_c/types/array.pyx":47
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self.cdelim == b"\x00":             # <<<<<<<<<<<<<<
 *             self.row_loader = self._tx._c_get_loader(
 *                 <PyObject *>self.base_oid, <PyObject *>PQ_TEXT)
*/
  }

  /* "psycopg_c/types/array.pyx":52
 *             self.cdelim = self.delimiter[0]
 * 
 *         return _array_load_text(             # <<<<<<<<<<<<<<
 *             data, length, self.row_loader, self.cdelim,
 *             &(self.scratch), &(self.sclen))
*/
  __Pyx_XDECREF(__pyx_r);

  /* "psycopg_c/types/array.pyx":54
 *         return _array_load_text(
 *             data, length, self.row_loader, self.cdelim,
 *             &(self.scratch), &(self.sclen))             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__array_load_text(__pyx_v_data, __pyx_v_length, __pyx_v_self->row_loader, __pyx_v_self->cdelim, (&__pyx_v_self->scratch), (&__pyx_v_self->sclen)); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/array.pyx":46
 *     cdef size_t sclen
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self.cdelim == b"\x00":
 *             self.row_loader = self._tx._c_get_loader(
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("psycopg_c._psycopg.ArrayLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/types/array.pyx":56
 *             &(self.scratch), &(self.sclen))
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         PyMem_Free(self.scratch)
 * 
*/

/* Python wrapper */
static void __pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_1__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader___dealloc__(((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader___dealloc__(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self) {

  /* "psycopg_c/types/array.pyx":57
 * 
 *     def __dealloc__(self):
 *         PyMem_Free(self.scratch)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  PyMem_Free(__pyx_v_self->scratch);

  /* "psycopg_c/types/array.pyx":56
 *             &(self.scratch), &(self.sclen))
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         PyMem_Free(self.scratch)
 * 
*/

  /* function exit code */
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11ArrayLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.ArrayLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11ArrayLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ArrayLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.ArrayLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/types/array.pyx":67
 *     cdef PyObject *row_loader
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         rv = _array_load_binary(data, length, self._tx, &(self.row_loader))
 *         return rv
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_17ArrayBinaryLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
  PyObject *__pyx_v_rv = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("cload", 0);

  /* "psycopg_c/types/array.pyx":68
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         rv = _array_load_binary(data, length, self._tx, &(self.row_loader))             # <<<<<<<<<<<<<<
 *         return rv
 * 
*/
  __pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base._tx);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__array_load_binary(__pyx_v_data, __pyx_v_length, ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)__pyx_t_1), (&__pyx_v_self->row_loader)); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_rv = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/types/array.pyx":69
 *     cdef object cload(self, const char *data, size_t length):
 *         rv = _array_load_binary(data, length, self._tx, &(self.row_loader))
 *         return rv             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rv);
  __pyx_r = __pyx_v_rv;
  goto __pyx_L0;

  /* "psycopg_c/types/array.pyx":67
 *     cdef PyObject *row_loader
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         rv = _array_load_binary(data, length, self._tx, &(self.row_loader))
 *         return rv
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("psycopg_c._psycopg.ArrayBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_rv);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17ArrayBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17ArrayBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ArrayBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 0);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.ArrayBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17ArrayBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17ArrayBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ArrayBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 0);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
  __Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(6, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("psycopg_c._psycopg.ArrayBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/types/array.pyx":72
 * 
 * 
 * cdef object _array_load_text(             # <<<<<<<<<<<<<<
 *     const char *buf, size_t length, PyObject *row_loader, char cdelim,
 *     char **scratch, size_t *sclen
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__array_load_text(char const *__pyx_v_buf, size_t __pyx_v_length, PyObject *__pyx_v_row_loader, char __pyx_v_cdelim, char **__pyx_v_scratch, size_t *__pyx_v_sclen) {
  char const *__pyx_v_end;
  PyObject *__pyx_v_stack = 0;
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_rv = NULL;
  PyObject *__pyx_v_tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_cloader = 0;
  PyObject *__pyx_v_pyload = 0;
  PyObject *__pyx_v_v = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  size_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_array_load_text", 0);

  /* "psycopg_c/types/array.pyx":76
 *     char **scratch, size_t *sclen
 * ):
 *     if length == 0:             # <<<<<<<<<<<<<<
 *         raise e.DataError("malformed array: empty data")
 * 
*/
  __pyx_t_1 = (__pyx_v_length == 0);
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/types/array.pyx":77
 * ):
 *     if length == 0:
 *         raise e.DataError("malformed array: empty data")             # <<<<<<<<<<<<<<
 * 
 *     cdef const char *end = buf + length
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_5)) __PYX_ERR(11, 77, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
      __pyx_t_6 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_malformed_array_empty_data};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 77, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(11, 77, __pyx_L1_error)

    /* "psycopg_c/types/array.pyx":76
 *     char **scratch, size_t *sclen
 * ):
 *     if length == 0:             # <<<<<<<<<<<<<<
 *         raise e.DataError("malformed array: empty data")
 * 
*/
  }

  /* "psycopg_c/types/array.pyx":79
 *         raise e.DataError("malformed array: empty data")
 * 
 *     cdef const char *end = buf + length             # <<<<<<<<<<<<<<
 * 
 *     # Remove the dimensions information prefix (``[...]=``)
*/
  __pyx_v_end = (__pyx_v_buf + __pyx_v_length);

  /* "psycopg_c/types/array.pyx":82
 * 
 *     # Remove the dimensions information prefix (``[...]=``)
 *     if buf[0] == b"[":             # <<<<<<<<<<<<<<
 *         buf = strchr(buf + 1, b'=')
 *         if buf == NULL:
*/
  __pyx_t_1 = ((__pyx_v_buf[0]) == '[');
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":83
 *     # Remove the dimensions information prefix (``[...]=``)
 *     if buf[0] == b"[":
 *         buf = strchr(buf + 1, b'=')             # <<<<<<<<<<<<<<
 *         if buf == NULL:
 *             raise e.DataError("malformed array: no '=' after dimension information")
*/
    __pyx_v_buf = strchr((__pyx_v_buf + 1), '=');

    /* "psycopg_c/types/array.pyx":84
 *     if buf[0] == b"[":
 *         buf = strchr(buf + 1, b'=')
 *         if buf == NULL:             # <<<<<<<<<<<<<<
 *             raise e.DataError("malformed array: no '=' after dimension information")
 *         buf += 1
*/
    __pyx_t_1 = (__pyx_v_buf == NULL);
    if (unlikely(__pyx_t_1)) {

      /* "psycopg_c/types/array.pyx":85
 *         buf = strchr(buf + 1, b'=')
 *         if buf == NULL:
 *             raise e.DataError("malformed array: no '=' after dimension information")             # <<<<<<<<<<<<<<
 *         buf += 1
 * 
*/
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 85, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 85, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_mstate_global->__pyx_kp_u_malformed_array_no_after_dimensi};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 85, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(11, 85, __pyx_L1_error)

      /* "psycopg_c/types/array.pyx":84
 *     if buf[0] == b"[":
 *         buf = strchr(buf + 1, b'=')
 *         if buf == NULL:             # <<<<<<<<<<<<<<
 *             raise e.DataError("malformed array: no '=' after dimension information")
 *         buf += 1
*/
    }

    /* "psycopg_c/types/array.pyx":86
 *         if buf == NULL:
 *             raise e.DataError("malformed array: no '=' after dimension information")
 *         buf += 1             # <<<<<<<<<<<<<<
 * 
 *     # TODO: further optimization: pre-scan the array to find the array
*/
    __pyx_v_buf = (__pyx_v_buf + 1);

    /* "psycopg_c/types/array.pyx":82
 * 
 *     # Remove the dimensions information prefix (``[...]=``)
 *     if buf[0] == b"[":             # <<<<<<<<<<<<<<
 *         buf = strchr(buf + 1, b'=')
 *         if buf == NULL:
*/
  }

  /* "psycopg_c/types/array.pyx":92
 *     # append, which is the dominating operation
 * 
 *     cdef list stack = []             # <<<<<<<<<<<<<<
 *     cdef list a = []
 *     rv = a
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_stack = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/types/array.pyx":93
 * 
 *     cdef list stack = []
 *     cdef list a = []             # <<<<<<<<<<<<<<
 *     rv = a
 *     cdef PyObject *tmp
*/
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_a = ((PyObject*)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/types/array.pyx":94
 *     cdef list stack = []
 *     cdef list a = []
 *     rv = a             # <<<<<<<<<<<<<<
 *     cdef PyObject *tmp
 * 
*/
  __Pyx_INCREF(__pyx_v_a);
  __pyx_v_rv = __pyx_v_a;

  /* "psycopg_c/types/array.pyx":97
 *     cdef PyObject *tmp
 * 
 *     cdef CLoader cloader = None             # <<<<<<<<<<<<<<
 *     cdef object pyload = None
 *     if (<RowLoader>row_loader).cloader is not None:
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_cloader = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)Py_None);

  /* "psycopg_c/types/array.pyx":98
 * 
 *     cdef CLoader cloader = None
 *     cdef object pyload = None             # <<<<<<<<<<<<<<
 *     if (<RowLoader>row_loader).cloader is not None:
 *         cloader = (<RowLoader>row_loader).cloader
*/
  __Pyx_INCREF(Py_None);
  __pyx_v_pyload = Py_None;

  /* "psycopg_c/types/array.pyx":99
 *     cdef CLoader cloader = None
 *     cdef object pyload = None
 *     if (<RowLoader>row_loader).cloader is not None:             # <<<<<<<<<<<<<<
 *         cloader = (<RowLoader>row_loader).cloader
 *     else:
*/
  __pyx_t_1 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->cloader) != Py_None);
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":100
 *     cdef object pyload = None
 *     if (<RowLoader>row_loader).cloader is not None:
 *         cloader = (<RowLoader>row_loader).cloader             # <<<<<<<<<<<<<<
 *     else:
 *         pyload = (<RowLoader>row_loader).loadfunc
*/
    __pyx_t_2 = ((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->cloader);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_cloader, ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "psycopg_c/types/array.pyx":99
 *     cdef CLoader cloader = None
 *     cdef object pyload = None
 *     if (<RowLoader>row_loader).cloader is not None:             # <<<<<<<<<<<<<<
 *         cloader = (<RowLoader>row_loader).cloader
 *     else:
*/
    goto __pyx_L6;
  }

  /* "psycopg_c/types/array.pyx":102
 *         cloader = (<RowLoader>row_loader).cloader
 *     else:
 *         pyload = (<RowLoader>row_loader).loadfunc             # <<<<<<<<<<<<<<
 * 
 *     while buf < end:
*/
  /*else*/ {
    __pyx_t_2 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->loadfunc;
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_pyload, __pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L6:;

  /* "psycopg_c/types/array.pyx":104
 *         pyload = (<RowLoader>row_loader).loadfunc
 * 
 *     while buf < end:             # <<<<<<<<<<<<<<
 *         if buf[0] == b'{':
 *             if stack:
*/
  while (1) {
    __pyx_t_1 = (__pyx_v_buf < __pyx_v_end);
    if (!__pyx_t_1) break;

    /* "psycopg_c/types/array.pyx":105
 * 
 *     while buf < end:
 *         if buf[0] == b'{':             # <<<<<<<<<<<<<<
 *             if stack:
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
*/
    __pyx_t_1 = ((__pyx_v_buf[0]) == '{');
      if (__pyx_t_1) {

        /* "psycopg_c/types/array.pyx":106
 *     while buf < end:
 *         if buf[0] == b'{':
 *             if stack:             # <<<<<<<<<<<<<<
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
 *                 PyList_Append(<object>tmp, a)
*/
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_stack);
          if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(11, 106, __pyx_L1_error)
          __pyx_t_1 = (__pyx_temp != 0);
        }

        if (__pyx_t_1) {

          /* "psycopg_c/types/array.pyx":107
 *         if buf[0] == b'{':
 *             if stack:
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)             # <<<<<<<<<<<<<<
 *                 PyList_Append(<object>tmp, a)
 *             PyList_Append(stack, a)
*/
          __pyx_v_tmp = PyList_GET_ITEM(__pyx_v_stack, (PyList_GET_SIZE(__pyx_v_stack) - 1));

          /* "psycopg_c/types/array.pyx":108
 *             if stack:
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
 *                 PyList_Append(<object>tmp, a)             # <<<<<<<<<<<<<<
 *             PyList_Append(stack, a)
 *             a = []
*/
          __pyx_t_7 = PyList_Append(((PyObject *)__pyx_v_tmp), __pyx_v_a); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(11, 108, __pyx_L1_error)

          /* "psycopg_c/types/array.pyx":106
 *     while buf < end:
 *         if buf[0] == b'{':
 *             if stack:             # <<<<<<<<<<<<<<
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
 *                 PyList_Append(<object>tmp, a)
*/
        }

        /* "psycopg_c/types/array.pyx":109
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
 *                 PyList_Append(<object>tmp, a)
 *             PyList_Append(stack, a)             # <<<<<<<<<<<<<<
 *             a = []
 *             buf += 1
*/
        __pyx_t_7 = PyList_Append(__pyx_v_stack, __pyx_v_a); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(11, 109, __pyx_L1_error)

        /* "psycopg_c/types/array.pyx":110
 *                 PyList_Append(<object>tmp, a)
 *             PyList_Append(stack, a)
 *             a = []             # <<<<<<<<<<<<<<
 *             buf += 1
 * 
*/
        __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 110, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF_SET(__pyx_v_a, ((PyObject*)__pyx_t_2));
        __pyx_t_2 = 0;

        /* "psycopg_c/types/array.pyx":111
 *             PyList_Append(stack, a)
 *             a = []
 *             buf += 1             # <<<<<<<<<<<<<<
 * 
 *         elif buf[0] == b'}':
*/
        __pyx_v_buf = (__pyx_v_buf + 1);

        /* "psycopg_c/types/array.pyx":105
 * 
 *     while buf < end:
 *         if buf[0] == b'{':             # <<<<<<<<<<<<<<
 *             if stack:
 *                 tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
*/
        goto __pyx_L9;
      }

      /* "psycopg_c/types/array.pyx":113
 *             buf += 1
 * 
 *         elif buf[0] == b'}':             # <<<<<<<<<<<<<<
 *             if not stack:
 *                 raise e.DataError("malformed array: unexpected '}'")
*/
    __pyx_t_1 = ((__pyx_v_buf[0]) == '}');
    if (__pyx_t_1) {

      /* "psycopg_c/types/array.pyx":114
 * 
 *         elif buf[0] == b'}':
 *             if not stack:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("malformed array: unexpected '}'")
 *             rv = stack.pop()
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_stack);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(11, 114, __pyx_L1_error)
        __pyx_t_1 = (__pyx_temp != 0);
      }

      __pyx_t_8 = (!__pyx_t_1);
      if (unlikely(__pyx_t_8)) {

        /* "psycopg_c/types/array.pyx":115
 *         elif buf[0] == b'}':
 *             if not stack:
 *                 raise e.DataError("malformed array: unexpected '}'")             # <<<<<<<<<<<<<<
 *             rv = stack.pop()
 *             buf += 1
*/
        __pyx_t_4 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_5)) __PYX_ERR(11, 115, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 115, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          assert(__pyx_t_4);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_malformed_array_unexpected};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 115, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(11, 115, __pyx_L1_error)

        /* "psycopg_c/types/array.pyx":114
 * 
 *         elif buf[0] == b'}':
 *             if not stack:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("malformed array: unexpected '}'")
 *             rv = stack.pop()
*/
      }

      /* "psycopg_c/types/array.pyx":116
 *             if not stack:
 *                 raise e.DataError("malformed array: unexpected '}'")
 *             rv = stack.pop()             # <<<<<<<<<<<<<<
 *             buf += 1
 * 
*/
      __pyx_t_2 = __Pyx_PyList_Pop(__pyx_v_stack); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 116, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF_SET(__pyx_v_rv, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/types/array.pyx":117
 *                 raise e.DataError("malformed array: unexpected '}'")
 *             rv = stack.pop()
 *             buf += 1             # <<<<<<<<<<<<<<
 * 
 *         elif buf[0] == cdelim:
*/
      __pyx_v_buf = (__pyx_v_buf + 1);

      /* "psycopg_c/types/array.pyx":113
 *             buf += 1
 * 
 *         elif buf[0] == b'}':             # <<<<<<<<<<<<<<
 *             if not stack:
 *                 raise e.DataError("malformed array: unexpected '}'")
*/
      goto __pyx_L9;
    }

    /* "psycopg_c/types/array.pyx":119
 *             buf += 1
 * 
 *         elif buf[0] == cdelim:             # <<<<<<<<<<<<<<
 *             buf += 1
 * 
*/
    __pyx_t_8 = ((__pyx_v_buf[0]) == __pyx_v_cdelim);
    if (__pyx_t_8) {

      /* "psycopg_c/types/array.pyx":120
 * 
 *         elif buf[0] == cdelim:
 *             buf += 1             # <<<<<<<<<<<<<<
 * 
 *         else:
*/
      __pyx_v_buf = (__pyx_v_buf + 1);

      /* "psycopg_c/types/array.pyx":119
 *             buf += 1
 * 
 *         elif buf[0] == cdelim:             # <<<<<<<<<<<<<<
 *             buf += 1
 * 
*/
      goto __pyx_L9;
    }

    /* "psycopg_c/types/array.pyx":123
 * 
 *         else:
 *             v = _parse_token(             # <<<<<<<<<<<<<<
 *                 &buf, end, cdelim, scratch, sclen, cloader, pyload)
 *             if not stack:
*/
    /*else*/ {

      /* "psycopg_c/types/array.pyx":124
 *         else:
 *             v = _parse_token(
 *                 &buf, end, cdelim, scratch, sclen, cloader, pyload)             # <<<<<<<<<<<<<<
 *             if not stack:
 *                 raise e.DataError("malformed array: missing initial '{'")
*/
      __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__parse_token((&__pyx_v_buf), __pyx_v_end, __pyx_v_cdelim, __pyx_v_scratch, __pyx_v_sclen, __pyx_v_cloader, __pyx_v_pyload); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 123, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_XDECREF_SET(__pyx_v_v, __pyx_t_2);
      __pyx_t_2 = 0;

      /* "psycopg_c/types/array.pyx":125
 *             v = _parse_token(
 *                 &buf, end, cdelim, scratch, sclen, cloader, pyload)
 *             if not stack:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("malformed array: missing initial '{'")
 *             tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
*/
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_v_stack);
        if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(11, 125, __pyx_L1_error)
        __pyx_t_8 = (__pyx_temp != 0);
      }

      __pyx_t_1 = (!__pyx_t_8);
      if (unlikely(__pyx_t_1)) {

        /* "psycopg_c/types/array.pyx":126
 *                 &buf, end, cdelim, scratch, sclen, cloader, pyload)
 *             if not stack:
 *                 raise e.DataError("malformed array: missing initial '{'")             # <<<<<<<<<<<<<<
 *             tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
 *             PyList_Append(<object>tmp, v)
*/
        __pyx_t_3 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 126, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_5)) __PYX_ERR(11, 126, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_6 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
          assert(__pyx_t_3);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
          __pyx_t_6 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_malformed_array_missing_initial};
          __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 126, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
        }
        __Pyx_Raise(__pyx_t_2, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __PYX_ERR(11, 126, __pyx_L1_error)

        /* "psycopg_c/types/array.pyx":125
 *             v = _parse_token(
 *                 &buf, end, cdelim, scratch, sclen, cloader, pyload)
 *             if not stack:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("malformed array: missing initial '{'")
 *             tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
*/
      }

      /* "psycopg_c/types/array.pyx":127
 *             if not stack:
 *                 raise e.DataError("malformed array: missing initial '{'")
 *             tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)             # <<<<<<<<<<<<<<
 *             PyList_Append(<object>tmp, v)
 * 
*/
      __pyx_v_tmp = PyList_GET_ITEM(__pyx_v_stack, (PyList_GET_SIZE(__pyx_v_stack) - 1));

      /* "psycopg_c/types/array.pyx":128
 *                 raise e.DataError("malformed array: missing initial '{'")
 *             tmp = PyList_GET_ITEM(stack, PyList_GET_SIZE(stack) - 1)
 *             PyList_Append(<object>tmp, v)             # <<<<<<<<<<<<<<
 * 
 *     return rv
*/
      __pyx_t_7 = PyList_Append(((PyObject *)__pyx_v_tmp), __pyx_v_v); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(11, 128, __pyx_L1_error)
    }
    __pyx_L9:;
  }

  /* "psycopg_c/types/array.pyx":130
 *             PyList_Append(<object>tmp, v)
 * 
 *     return rv             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rv);
  __pyx_r = __pyx_v_rv;
  goto __pyx_L0;

  /* "psycopg_c/types/array.pyx":72
 * 
 * 
 * cdef object _array_load_text(             # <<<<<<<<<<<<<<
 *     const char *buf, size_t length, PyObject *row_loader, char cdelim,
 *     char **scratch, size_t *sclen
*/

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("psycopg_c._psycopg._array_load_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_stack);
  __Pyx_XDECREF(__pyx_v_a);
  __Pyx_XDECREF(__pyx_v_rv);
  __Pyx_XDECREF((PyObject *)__pyx_v_cloader);
  __Pyx_XDECREF(__pyx_v_pyload);
  __Pyx_XDECREF(__pyx_v_v);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "psycopg_c/types/array.pyx":133
 * 
 * 
 * cdef object _parse_token(             # <<<<<<<<<<<<<<
 *     const char **bufptr, const char *bufend, char cdelim,
 *     char **scratch, size_t *sclen, CLoader cloader, object load
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__parse_token(char const **__pyx_v_bufptr, char const *__pyx_v_bufend, char __pyx_v_cdelim, char **__pyx_v_scratch, size_t *__pyx_v_sclen, struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *__pyx_v_cloader, PyObject *__pyx_v_load) {
  char const *__pyx_v_start;
  int __pyx_v_has_quotes;
  int __pyx_v_quoted;
  int __pyx_v_num_escapes;
  int __pyx_v_escaped;
  char const *__pyx_v_end;
  Py_ssize_t __pyx_v_length;
  char const *__pyx_v_src;
  char *__pyx_v_tgt;
  size_t __pyx_v_unesclen;
  PyObject *__pyx_v_b = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_parse_token", 0);

  /* "psycopg_c/types/array.pyx":137
 *     char **scratch, size_t *sclen, CLoader cloader, object load
 * ):
 *     cdef const char *start = bufptr[0]             # <<<<<<<<<<<<<<
 *     cdef int has_quotes = start[0] == b'"'
 *     cdef int quoted = has_quotes
*/
  __pyx_v_start = (__pyx_v_bufptr[0]);

  /* "psycopg_c/types/array.pyx":138
 * ):
 *     cdef const char *start = bufptr[0]
 *     cdef int has_quotes = start[0] == b'"'             # <<<<<<<<<<<<<<
 *     cdef int quoted = has_quotes
 *     cdef int num_escapes = 0
*/
  __pyx_v_has_quotes = ((__pyx_v_start[0]) == '"');

  /* "psycopg_c/types/array.pyx":139
 *     cdef const char *start = bufptr[0]
 *     cdef int has_quotes = start[0] == b'"'
 *     cdef int quoted = has_quotes             # <<<<<<<<<<<<<<
 *     cdef int num_escapes = 0
 *     cdef int escaped = 0
*/
  __pyx_v_quoted = __pyx_v_has_quotes;

  /* "psycopg_c/types/array.pyx":140
 *     cdef int has_quotes = start[0] == b'"'
 *     cdef int quoted = has_quotes
 *     cdef int num_escapes = 0             # <<<<<<<<<<<<<<
 *     cdef int escaped = 0
 * 
*/
  __pyx_v_num_escapes = 0;

  /* "psycopg_c/types/array.pyx":141
 *     cdef int quoted = has_quotes
 *     cdef int num_escapes = 0
 *     cdef int escaped = 0             # <<<<<<<<<<<<<<
 * 
 *     if has_quotes:
*/
  __pyx_v_escaped = 0;

  /* "psycopg_c/types/array.pyx":143
 *     cdef int escaped = 0
 * 
 *     if has_quotes:             # <<<<<<<<<<<<<<
 *         start += 1
 *     cdef const char *end = start
*/
  __pyx_t_1 = (__pyx_v_has_quotes != 0);
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":144
 * 
 *     if has_quotes:
 *         start += 1             # <<<<<<<<<<<<<<
 *     cdef const char *end = start
 * 
*/
    __pyx_v_start = (__pyx_v_start + 1);

    /* "psycopg_c/types/array.pyx":143
 *     cdef int escaped = 0
 * 
 *     if has_quotes:             # <<<<<<<<<<<<<<
 *         start += 1
 *     cdef const char *end = start
*/
  }

  /* "psycopg_c/types/array.pyx":145
 *     if has_quotes:
 *         start += 1
 *     cdef const char *end = start             # <<<<<<<<<<<<<<
 * 
 *     while end < bufend:
*/
  __pyx_v_end = __pyx_v_start;

  /* "psycopg_c/types/array.pyx":147
 *     cdef const char *end = start
 * 
 *     while end < bufend:             # <<<<<<<<<<<<<<
 *         if (end[0] == cdelim or end[0] == b'}') and not quoted:
 *             break
*/
  while (1) {
    __pyx_t_1 = (__pyx_v_end < __pyx_v_bufend);
    if (!__pyx_t_1) break;

    /* "psycopg_c/types/array.pyx":148
 * 
 *     while end < bufend:
 *         if (end[0] == cdelim or end[0] == b'}') and not quoted:             # <<<<<<<<<<<<<<
 *             break
 *         elif end[0] == b'\\' and not escaped:
*/
    __pyx_t_2 = ((__pyx_v_end[0]) == __pyx_v_cdelim);
    if (!__pyx_t_2) {
    } else {
      goto __pyx_L8_next_and;
    }
  __pyx_t_2 = ((__pyx_v_end[0]) == '}');
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_L8_next_and:;
  __pyx_t_2 = (!(__pyx_v_quoted != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":149
 *     while end < bufend:
 *         if (end[0] == cdelim or end[0] == b'}') and not quoted:
 *             break             # <<<<<<<<<<<<<<
 *         elif end[0] == b'\\' and not escaped:
 *             num_escapes += 1
*/
    goto __pyx_L5_break;

    /* "psycopg_c/types/array.pyx":148
 * 
 *     while end < bufend:
 *         if (end[0] == cdelim or end[0] == b'}') and not quoted:             # <<<<<<<<<<<<<<
 *             break
 *         elif end[0] == b'\\' and not escaped:
*/
  }

  /* "psycopg_c/types/array.pyx":150
 *         if (end[0] == cdelim or end[0] == b'}') and not quoted:
 *             break
 *         elif end[0] == b'\\' and not escaped:             # <<<<<<<<<<<<<<
 *             num_escapes += 1
 *             escaped = 1
*/
  __pyx_t_2 = ((__pyx_v_end[0]) == '\\');
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_escaped != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":151
 *             break
 *         elif end[0] == b'\\' and not escaped:
 *             num_escapes += 1             # <<<<<<<<<<<<<<
 *             escaped = 1
 *             end += 1
*/
    __pyx_v_num_escapes = (__pyx_v_num_escapes + 1);

    /* "psycopg_c/types/array.pyx":152
 *         elif end[0] == b'\\' and not escaped:
 *             num_escapes += 1
 *             escaped = 1             # <<<<<<<<<<<<<<
 *             end += 1
 *             continue
*/
    __pyx_v_escaped = 1;

    /* "psycopg_c/types/array.pyx":153
 *             num_escapes += 1
 *             escaped = 1
 *             end += 1             # <<<<<<<<<<<<<<
 *             continue
 *         elif end[0] == b'"' and not escaped:
*/
    __pyx_v_end = (__pyx_v_end + 1);

    /* "psycopg_c/types/array.pyx":154
 *             escaped = 1
 *             end += 1
 *             continue             # <<<<<<<<<<<<<<
 *         elif end[0] == b'"' and not escaped:
 *             quoted = 0
*/
    goto __pyx_L4_continue;

    /* "psycopg_c/types/array.pyx":150
 *         if (end[0] == cdelim or end[0] == b'}') and not quoted:
 *             break
 *         elif end[0] == b'\\' and not escaped:             # <<<<<<<<<<<<<<
 *             num_escapes += 1
 *             escaped = 1
*/
  }

  /* "psycopg_c/types/array.pyx":155
 *             end += 1
 *             continue
 *         elif end[0] == b'"' and not escaped:             # <<<<<<<<<<<<<<
 *             quoted = 0
 *         escaped = 0
*/
  __pyx_t_2 = ((__pyx_v_end[0]) == '"');
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L12_bool_binop_done;
  }
  __pyx_t_2 = (!(__pyx_v_escaped != 0));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L12_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":156
 *             continue
 *         elif end[0] == b'"' and not escaped:
 *             quoted = 0             # <<<<<<<<<<<<<<
 *         escaped = 0
 *         end += 1
*/
    __pyx_v_quoted = 0;

    /* "psycopg_c/types/array.pyx":155
 *             end += 1
 *             continue
 *         elif end[0] == b'"' and not escaped:             # <<<<<<<<<<<<<<
 *             quoted = 0
 *         escaped = 0
*/
  }

  /* "psycopg_c/types/array.pyx":157
 *         elif end[0] == b'"' and not escaped:
 *             quoted = 0
 *         escaped = 0             # <<<<<<<<<<<<<<
 *         end += 1
 *     else:
*/
  __pyx_v_escaped = 0;

  /* "psycopg_c/types/array.pyx":158
 *             quoted = 0
 *         escaped = 0
 *         end += 1             # <<<<<<<<<<<<<<
 *     else:
 *         raise e.DataError("malformed array: hit the end of the buffer")
*/
  __pyx_v_end = (__pyx_v_end + 1);
  __pyx_L4_continue:;
}

/* "psycopg_c/types/array.pyx":160
 *         end += 1
 *     else:
 *         raise e.DataError("malformed array: hit the end of the buffer")             # <<<<<<<<<<<<<<
 * 
 *     # Return the new position for the buffer
*/
/*else*/ {
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_5)) __PYX_ERR(11, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_6)) __PYX_ERR(11, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_malformed_array_hit_the_end_of_t};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(11, 160, __pyx_L1_error)
}
__pyx_L5_break:;

/* "psycopg_c/types/array.pyx":163
 * 
 *     # Return the new position for the buffer
 *     bufptr[0] = end             # <<<<<<<<<<<<<<
 *     if has_quotes:
 *         end -= 1
*/
(__pyx_v_bufptr[0]) = __pyx_v_end;

/* "psycopg_c/types/array.pyx":164
 *     # Return the new position for the buffer
 *     bufptr[0] = end
 *     if has_quotes:             # <<<<<<<<<<<<<<
 *         end -= 1
 * 
*/
__pyx_t_1 = (__pyx_v_has_quotes != 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/array.pyx":165
 *     bufptr[0] = end
 *     if has_quotes:
 *         end -= 1             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t length = (end - start)
*/
  __pyx_v_end = (__pyx_v_end - 1);

  /* "psycopg_c/types/array.pyx":164
 *     # Return the new position for the buffer
 *     bufptr[0] = end
 *     if has_quotes:             # <<<<<<<<<<<<<<
 *         end -= 1
 * 
*/
}

/* "psycopg_c/types/array.pyx":167
 *         end -= 1
 * 
 *     cdef Py_ssize_t length = (end - start)             # <<<<<<<<<<<<<<
 *     if length == 4 and not has_quotes \
 *             and start[0] == b'N' and start[1] == b'U' \
*/
__pyx_v_length = (__pyx_v_end - __pyx_v_start);

/* "psycopg_c/types/array.pyx":168
 * 
 *     cdef Py_ssize_t length = (end - start)
 *     if length == 4 and not has_quotes \             # <<<<<<<<<<<<<<
 *             and start[0] == b'N' and start[1] == b'U' \
 *             and start[2] == b'L' and start[3] == b'L':
*/
__pyx_t_2 = (__pyx_v_length == 4);
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L16_bool_binop_done;
}

/* "psycopg_c/types/array.pyx":169
 *     cdef Py_ssize_t length = (end - start)
 *     if length == 4 and not has_quotes \
 *             and start[0] == b'N' and start[1] == b'U' \             # <<<<<<<<<<<<<<
 *             and start[2] == b'L' and start[3] == b'L':
 *         return None
*/
__pyx_t_2 = (!(__pyx_v_has_quotes != 0));
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L16_bool_binop_done;
}
__pyx_t_2 = ((__pyx_v_start[0]) == 'N');
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L16_bool_binop_done;
}

/* "psycopg_c/types/array.pyx":170
 *     if length == 4 and not has_quotes \
 *             and start[0] == b'N' and start[1] == b'U' \
 *             and start[2] == b'L' and start[3] == b'L':             # <<<<<<<<<<<<<<
 *         return None
 * 
*/
__pyx_t_2 = ((__pyx_v_start[1]) == 'U');
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L16_bool_binop_done;
}
__pyx_t_2 = ((__pyx_v_start[2]) == 'L');
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L16_bool_binop_done;
}
__pyx_t_2 = ((__pyx_v_start[3]) == 'L');
__pyx_t_1 = __pyx_t_2;
__pyx_L16_bool_binop_done:;

/* "psycopg_c/types/array.pyx":168
 * 
 *     cdef Py_ssize_t length = (end - start)
 *     if length == 4 and not has_quotes \             # <<<<<<<<<<<<<<
 *             and start[0] == b'N' and start[1] == b'U' \
 *             and start[2] == b'L' and start[3] == b'L':
*/
if (__pyx_t_1) {

  /* "psycopg_c/types/array.pyx":171
 *             and start[0] == b'N' and start[1] == b'U' \
 *             and start[2] == b'L' and start[3] == b'L':
 *         return None             # <<<<<<<<<<<<<<
 * 
 *     cdef const char *src
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "psycopg_c/types/array.pyx":168
 * 
 *     cdef Py_ssize_t length = (end - start)
 *     if length == 4 and not has_quotes \             # <<<<<<<<<<<<<<
 *             and start[0] == b'N' and start[1] == b'U' \
 *             and start[2] == b'L' and start[3] == b'L':
*/
}

/* "psycopg_c/types/array.pyx":177
 *     cdef size_t unesclen
 * 
 *     if not num_escapes:             # <<<<<<<<<<<<<<
 *         if cloader is not None:
 *             return cloader.cload(start, length)
*/
__pyx_t_1 = (!(__pyx_v_num_escapes != 0));
if (__pyx_t_1) {

  /* "psycopg_c/types/array.pyx":178
 * 
 *     if not num_escapes:
 *         if cloader is not None:             # <<<<<<<<<<<<<<
 *             return cloader.cload(start, length)
 *         else:
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_cloader) != Py_None);
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":179
 *     if not num_escapes:
 *         if cloader is not None:
 *             return cloader.cload(start, length)             # <<<<<<<<<<<<<<
 *         else:
 *             b = start[:length]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)__pyx_v_cloader->__pyx_vtab)->cload(__pyx_v_cloader, __pyx_v_start, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 179, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "psycopg_c/types/array.pyx":178
 * 
 *     if not num_escapes:
 *         if cloader is not None:             # <<<<<<<<<<<<<<
 *             return cloader.cload(start, length)
 *         else:
*/
  }

  /* "psycopg_c/types/array.pyx":181
 *             return cloader.cload(start, length)
 *         else:
 *             b = start[:length]             # <<<<<<<<<<<<<<
 *             return load(b)
 * 
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_start + 0, __pyx_v_length - 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 181, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_b = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "psycopg_c/types/array.pyx":182
 *         else:
 *             b = start[:length]
 *             return load(b)             # <<<<<<<<<<<<<<
 * 
 *     else:
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = NULL;
    __Pyx_INCREF(__pyx_v_load);
    __pyx_t_4 = __pyx_v_load; 
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_v_b};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 182, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "psycopg_c/types/array.pyx":177
 *     cdef size_t unesclen
 * 
 *     if not num_escapes:             # <<<<<<<<<<<<<<
 *         if cloader is not None:
 *             return cloader.cload(start, length)
*/
}

/* "psycopg_c/types/array.pyx":185
 * 
 *     else:
 *         unesclen = length - num_escapes + 1             # <<<<<<<<<<<<<<
 *         if unesclen > sclen[0]:
 *             scratch[0] = <char *>PyMem_Realloc(scratch[0], unesclen)
*/
/*else*/ {
  __pyx_v_unesclen = ((__pyx_v_length - __pyx_v_num_escapes) + 1);

  /* "psycopg_c/types/array.pyx":186
 *     else:
 *         unesclen = length - num_escapes + 1
 *         if unesclen > sclen[0]:             # <<<<<<<<<<<<<<
 *             scratch[0] = <char *>PyMem_Realloc(scratch[0], unesclen)
 *             sclen[0] = unesclen
*/
  __pyx_t_1 = (__pyx_v_unesclen > (__pyx_v_sclen[0]));
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":187
 *         unesclen = length - num_escapes + 1
 *         if unesclen > sclen[0]:
 *             scratch[0] = <char *>PyMem_Realloc(scratch[0], unesclen)             # <<<<<<<<<<<<<<
 *             sclen[0] = unesclen
 * 
*/
    (__pyx_v_scratch[0]) = ((char *)PyMem_Realloc((__pyx_v_scratch[0]), __pyx_v_unesclen));

    /* "psycopg_c/types/array.pyx":188
 *         if unesclen > sclen[0]:
 *             scratch[0] = <char *>PyMem_Realloc(scratch[0], unesclen)
 *             sclen[0] = unesclen             # <<<<<<<<<<<<<<
 * 
 *         src = start
*/
    (__pyx_v_sclen[0]) = __pyx_v_unesclen;

    /* "psycopg_c/types/array.pyx":186
 *     else:
 *         unesclen = length - num_escapes + 1
 *         if unesclen > sclen[0]:             # <<<<<<<<<<<<<<
 *             scratch[0] = <char *>PyMem_Realloc(scratch[0], unesclen)
 *             sclen[0] = unesclen
*/
  }

  /* "psycopg_c/types/array.pyx":190
 *             sclen[0] = unesclen
 * 
 *         src = start             # <<<<<<<<<<<<<<
 *         tgt = scratch[0]
 *         while src < end:
*/
  __pyx_v_src = __pyx_v_start;

  /* "psycopg_c/types/array.pyx":191
 * 
 *         src = start
 *         tgt = scratch[0]             # <<<<<<<<<<<<<<
 *         while src < end:
 *             if src[0] == b'\\':
*/
  __pyx_v_tgt = (__pyx_v_scratch[0]);

  /* "psycopg_c/types/array.pyx":192
 *         src = start
 *         tgt = scratch[0]
 *         while src < end:             # <<<<<<<<<<<<<<
 *             if src[0] == b'\\':
 *                 src += 1
*/
  while (1) {
    __pyx_t_1 = (__pyx_v_src < __pyx_v_end);
    if (!__pyx_t_1) break;

    /* "psycopg_c/types/array.pyx":193
 *         tgt = scratch[0]
 *         while src < end:
 *             if src[0] == b'\\':             # <<<<<<<<<<<<<<
 *                 src += 1
 *             tgt[0] = src[0]
*/
    __pyx_t_1 = ((__pyx_v_src[0]) == '\\');
    if (__pyx_t_1) {

      /* "psycopg_c/types/array.pyx":194
 *         while src < end:
 *             if src[0] == b'\\':
 *                 src += 1             # <<<<<<<<<<<<<<
 *             tgt[0] = src[0]
 *             src += 1
*/
      __pyx_v_src = (__pyx_v_src + 1);

      /* "psycopg_c/types/array.pyx":193
 *         tgt = scratch[0]
 *         while src < end:
 *             if src[0] == b'\\':             # <<<<<<<<<<<<<<
 *                 src += 1
 *             tgt[0] = src[0]
*/
    }

    /* "psycopg_c/types/array.pyx":195
 *             if src[0] == b'\\':
 *                 src += 1
 *             tgt[0] = src[0]             # <<<<<<<<<<<<<<
 *             src += 1
 *             tgt += 1
*/
    (__pyx_v_tgt[0]) = (__pyx_v_src[0]);

    /* "psycopg_c/types/array.pyx":196
 *                 src += 1
 *             tgt[0] = src[0]
 *             src += 1             # <<<<<<<<<<<<<<
 *             tgt += 1
 * 
*/
    __pyx_v_src = (__pyx_v_src + 1);

    /* "psycopg_c/types/array.pyx":197
 *             tgt[0] = src[0]
 *             src += 1
 *             tgt += 1             # <<<<<<<<<<<<<<
 * 
 *         tgt[0] = b'\x00'
*/
    __pyx_v_tgt = (__pyx_v_tgt + 1);
  }

  /* "psycopg_c/types/array.pyx":199
 *             tgt += 1
 * 
 *         tgt[0] = b'\x00'             # <<<<<<<<<<<<<<
 * 
 *         if cloader is not None:
*/
  (__pyx_v_tgt[0]) = '\x00';

  /* "psycopg_c/types/array.pyx":201
 *         tgt[0] = b'\x00'
 * 
 *         if cloader is not None:             # <<<<<<<<<<<<<<
 *             return cloader.cload(scratch[0], length - num_escapes)
 *         else:
*/
  __pyx_t_1 = (((PyObject *)__pyx_v_cloader) != Py_None);
  if (__pyx_t_1) {

    /* "psycopg_c/types/array.pyx":202
 * 
 *         if cloader is not None:
 *             return cloader.cload(scratch[0], length - num_escapes)             # <<<<<<<<<<<<<<
 *         else:
 *             b = scratch[0][:length - num_escapes]
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_3 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)__pyx_v_cloader->__pyx_vtab)->cload(__pyx_v_cloader, (__pyx_v_scratch[0]), (__pyx_v_length - __pyx_v_num_escapes)); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 202, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "psycopg_c/types/array.pyx":201
 *         tgt[0] = b'\x00'
 * 
 *         if cloader is not None:             # <<<<<<<<<<<<<<
 *             return cloader.cload(scratch[0], length - num_escapes)
 *         else:
*/
  }

  /* "psycopg_c/types/array.pyx":204
 *             return cloader.cload(scratch[0], length - num_escapes)
 *         else:
 *             b = scratch[0][:length - num_escapes]             # <<<<<<<<<<<<<<
 *             return load(b)
 * 
*/
  /*else*/ {
    __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize((__pyx_v_scratch[0]) + 0, (__pyx_v_length - __pyx_v_num_escapes) - 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 204, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_b = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "psycopg_c/types/array.pyx":205
 *         else:
 *             b = scratch[0][:length - num_escapes]
 *             return load(b)             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = NULL;
    __Pyx_INCREF(__pyx_v_load);
    __pyx_t_6 = __pyx_v_load; 
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_b};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(11, 205, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }
}

/* "psycopg_c/types/array.pyx":133
 * 
 * 
 * cdef object _parse_token(             # <<<<<<<<<<<<<<
 *     const char **bufptr, const char *bufend, char cdelim,
 *     char **scratch, size_t *sclen, CLoader cloader, object load
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_AddTraceback("psycopg_c._psycopg._parse_token", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_b);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/array.pyx":208
 * 
 * 
 * @cython.cdivision(True)             # <<<<<<<<<<<<<<
 * cdef object _array_load_binary(
 *     const char *buf, size_t length, Transformer tx, PyObject **row_loader_ptr
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__array_load_binary(char const *__pyx_v_buf, CYTHON_UNUSED size_t __pyx_v_length, struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *__pyx_v_tx, PyObject **__pyx_v_row_loader_ptr) {
uint32_t __pyx_v_buf32;
int __pyx_v_ndims;
PyObject *__pyx_v_oid = 0;
uint32_t __pyx_v_beoid;
Py_ssize_t __pyx_v_dims[MAXDIM];
int __pyx_v_i;
uint32_t __pyx_v_bedata;
char const *__pyx_v_dimptr;
PyObject *__pyx_v_out = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8[4];
size_t __pyx_t_9;
PyObject *__pyx_t_10;
int __pyx_t_11;
int __pyx_t_12;
int __pyx_t_13;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_array_load_binary", 0);

/* "psycopg_c/types/array.pyx":214
 *     # head is ndims, hasnull, elem oid
 *     cdef uint32_t buf32
 *     memcpy(&buf32, buf, sizeof(buf32))             # <<<<<<<<<<<<<<
 *     cdef int ndims = endian.be32toh(buf32)
 * 
*/
(void)(memcpy((&__pyx_v_buf32), __pyx_v_buf, (sizeof(__pyx_v_buf32))));

/* "psycopg_c/types/array.pyx":215
 *     cdef uint32_t buf32
 *     memcpy(&buf32, buf, sizeof(buf32))
 *     cdef int ndims = endian.be32toh(buf32)             # <<<<<<<<<<<<<<
 * 
 *     if ndims <= 0:
*/
__pyx_v_ndims = be32toh(__pyx_v_buf32);

/* "psycopg_c/types/array.pyx":217
 *     cdef int ndims = endian.be32toh(buf32)
 * 
 *     if ndims <= 0:             # <<<<<<<<<<<<<<
 *         return []
 *     elif ndims > MAXDIM:
*/
__pyx_t_1 = (__pyx_v_ndims <= 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/array.pyx":218
 * 
 *     if ndims <= 0:
 *         return []             # <<<<<<<<<<<<<<
 *     elif ndims > MAXDIM:
 *         raise e.DataError(
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/array.pyx":217
 *     cdef int ndims = endian.be32toh(buf32)
 * 
 *     if ndims <= 0:             # <<<<<<<<<<<<<<
 *         return []
 *     elif ndims > MAXDIM:
*/
}

/* "psycopg_c/types/array.pyx":219
 *     if ndims <= 0:
 *         return []
 *     elif ndims > MAXDIM:             # <<<<<<<<<<<<<<
 *         raise e.DataError(
 *             r"unexpected number of dimensions %s exceeding the maximum allowed %s"
*/
__pyx_t_1 = (__pyx_v_ndims > MAXDIM);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/array.pyx":220
 *         return []
 *     elif ndims > MAXDIM:
 *         raise e.DataError(             # <<<<<<<<<<<<<<
 *             r"unexpected number of dimensions %s exceeding the maximum allowed %s"
 *             % (ndims, MAXDIM)
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_5)) __PYX_ERR(11, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/array.pyx":222
 *         raise e.DataError(
 *             r"unexpected number of dimensions %s exceeding the maximum allowed %s"
 *             % (ndims, MAXDIM)             # <<<<<<<<<<<<<<
 *         )
 * 
*/
  __pyx_t_4 = __Pyx_PyUnicode_From_int(__pyx_v_ndims, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyLong_From_int(MAXDIM); if (unlikely(!__pyx_t_6)) __PYX_ERR(11, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Str(__pyx_t_6), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(11, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_unexpected_number_of_dimensions;
  __pyx_t_8[1] = __pyx_t_4;
  __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u_exceeding_the_maximum_allowed;
  __pyx_t_8[3] = __pyx_t_7;

  /* "psycopg_c/types/array.pyx":221
 *     elif ndims > MAXDIM:
 *         raise e.DataError(
 *             r"unexpected number of dimensions %s exceeding the maximum allowed %s"             # <<<<<<<<<<<<<<
 *             % (ndims, MAXDIM)
 *         )
*/
  __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_8, 4, 32 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 31 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
  if (unlikely(!__pyx_t_6)) __PYX_ERR(11, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_9 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_9 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_6};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(11, 220, __pyx_L1_error)

  /* "psycopg_c/types/array.pyx":219
 *     if ndims <= 0:
 *         return []
 *     elif ndims > MAXDIM:             # <<<<<<<<<<<<<<
 *         raise e.DataError(
 *             r"unexpected number of dimensions %s exceeding the maximum allowed %s"
*/
}

/* "psycopg_c/types/array.pyx":227
 *     cdef object oid
 *     cdef uint32_t beoid
 *     if row_loader_ptr[0] == NULL:             # <<<<<<<<<<<<<<
 *         memcpy(&beoid, buf + 2 * sizeof(uint32_t), sizeof(beoid))
 *         oid = <Oid>endian.be32toh(beoid)
*/
__pyx_t_1 = ((__pyx_v_row_loader_ptr[0]) == NULL);
if (__pyx_t_1) {

  /* "psycopg_c/types/array.pyx":228
 *     cdef uint32_t beoid
 *     if row_loader_ptr[0] == NULL:
 *         memcpy(&beoid, buf + 2 * sizeof(uint32_t), sizeof(beoid))             # <<<<<<<<<<<<<<
 *         oid = <Oid>endian.be32toh(beoid)
 *         row_loader_ptr[0] = tx._c_get_loader(<PyObject *>oid, <PyObject *>PQ_BINARY)
*/
  (void)(memcpy((&__pyx_v_beoid), (__pyx_v_buf + (2 * (sizeof(uint32_t)))), (sizeof(__pyx_v_beoid))));

  /* "psycopg_c/types/array.pyx":229
 *     if row_loader_ptr[0] == NULL:
 *         memcpy(&beoid, buf + 2 * sizeof(uint32_t), sizeof(beoid))
 *         oid = <Oid>endian.be32toh(beoid)             # <<<<<<<<<<<<<<
 *         row_loader_ptr[0] = tx._c_get_loader(<PyObject *>oid, <PyObject *>PQ_BINARY)
 * 
*/
  __pyx_t_2 = __Pyx_PyLong_From_Oid(((Oid)be32toh(__pyx_v_beoid))); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_oid = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/types/array.pyx":230
 *         memcpy(&beoid, buf + 2 * sizeof(uint32_t), sizeof(beoid))
 *         oid = <Oid>endian.be32toh(beoid)
 *         row_loader_ptr[0] = tx._c_get_loader(<PyObject *>oid, <PyObject *>PQ_BINARY)             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t[MAXDIM] dims
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_10 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer *)__pyx_v_tx->__pyx_vtab)->_c_get_loader(__pyx_v_tx, ((PyObject *)__pyx_v_oid), ((PyObject *)__pyx_t_2)); if (unlikely(__pyx_t_10 == ((void *)NULL))) __PYX_ERR(11, 230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  (__pyx_v_row_loader_ptr[0]) = __pyx_t_10;

  /* "psycopg_c/types/array.pyx":227
 *     cdef object oid
 *     cdef uint32_t beoid
 *     if row_loader_ptr[0] == NULL:             # <<<<<<<<<<<<<<
 *         memcpy(&beoid, buf + 2 * sizeof(uint32_t), sizeof(beoid))
 *         oid = <Oid>endian.be32toh(beoid)
*/
}

/* "psycopg_c/types/array.pyx":235
 *     cdef int i
 *     cdef uint32_t bedata
 *     cdef const char *dimptr = buf + 3 * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *     for i in range(ndims):
 *         # Every dimension is dim, lower bound
*/
__pyx_v_dimptr = (__pyx_v_buf + (3 * (sizeof(uint32_t))));

/* "psycopg_c/types/array.pyx":236
 *     cdef uint32_t bedata
 *     cdef const char *dimptr = buf + 3 * sizeof(uint32_t)
 *     for i in range(ndims):             # <<<<<<<<<<<<<<
 *         # Every dimension is dim, lower bound
 *         memcpy(&bedata, dimptr, sizeof(bedata))
*/
__pyx_t_11 = __pyx_v_ndims;
__pyx_t_12 = __pyx_t_11;
for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
  __pyx_v_i = __pyx_t_13;

  /* "psycopg_c/types/array.pyx":238
 *     for i in range(ndims):
 *         # Every dimension is dim, lower bound
 *         memcpy(&bedata, dimptr, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         dimptr += 2 * sizeof(uint32_t)
 *         dims[i] = endian.be32toh(bedata)
*/
  (void)(memcpy((&__pyx_v_bedata), __pyx_v_dimptr, (sizeof(__pyx_v_bedata))));

  /* "psycopg_c/types/array.pyx":239
 *         # Every dimension is dim, lower bound
 *         memcpy(&bedata, dimptr, sizeof(bedata))
 *         dimptr += 2 * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         dims[i] = endian.be32toh(bedata)
 * 
*/
  __pyx_v_dimptr = (__pyx_v_dimptr + (2 * (sizeof(uint32_t))));

  /* "psycopg_c/types/array.pyx":240
 *         memcpy(&bedata, dimptr, sizeof(bedata))
 *         dimptr += 2 * sizeof(uint32_t)
 *         dims[i] = endian.be32toh(bedata)             # <<<<<<<<<<<<<<
 * 
 *     buf += (3 + 2 * ndims) * sizeof(bedata)
*/
  (__pyx_v_dims[__pyx_v_i]) = be32toh(__pyx_v_bedata);
}

/* "psycopg_c/types/array.pyx":242
 *         dims[i] = endian.be32toh(bedata)
 * 
 *     buf += (3 + 2 * ndims) * sizeof(bedata)             # <<<<<<<<<<<<<<
 *     out = _array_load_binary_rec(ndims, dims, &buf, row_loader_ptr[0])
 *     return out
*/
__pyx_v_buf = (__pyx_v_buf + ((3 + (2 * __pyx_v_ndims)) * (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/array.pyx":243
 * 
 *     buf += (3 + 2 * ndims) * sizeof(bedata)
 *     out = _array_load_binary_rec(ndims, dims, &buf, row_loader_ptr[0])             # <<<<<<<<<<<<<<
 *     return out
 * 
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__array_load_binary_rec(__pyx_v_ndims, __pyx_v_dims, (&__pyx_v_buf), (__pyx_v_row_loader_ptr[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(11, 243, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_v_out = __pyx_t_2;
__pyx_t_2 = 0;

/* "psycopg_c/types/array.pyx":244
 *     buf += (3 + 2 * ndims) * sizeof(bedata)
 *     out = _array_load_binary_rec(ndims, dims, &buf, row_loader_ptr[0])
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_out);
__pyx_r = __pyx_v_out;
goto __pyx_L0;

/* "psycopg_c/types/array.pyx":208
 * 
 * 
 * @cython.cdivision(True)             # <<<<<<<<<<<<<<
 * cdef object _array_load_binary(
 *     const char *buf, size_t length, Transformer tx, PyObject **row_loader_ptr
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_AddTraceback("psycopg_c._psycopg._array_load_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_oid);
__Pyx_XDECREF(__pyx_v_out);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/array.pyx":247
 * 
 * 
 * cdef object _array_load_binary_rec(             # <<<<<<<<<<<<<<
 *     Py_ssize_t ndims, Py_ssize_t *dims, const char **bufptr, PyObject *row_loader
 * ):
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__array_load_binary_rec(Py_ssize_t __pyx_v_ndims, Py_ssize_t *__pyx_v_dims, char const **__pyx_v_bufptr, PyObject *__pyx_v_row_loader) {
char const *__pyx_v_buf;
int __pyx_v_i;
uint32_t __pyx_v_besize;
int32_t __pyx_v_size;
PyObject *__pyx_v_val = 0;
Py_ssize_t __pyx_v_nelems;
PyObject *__pyx_v_out = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
Py_ssize_t __pyx_t_3;
Py_ssize_t __pyx_t_4;
int __pyx_t_5;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
size_t __pyx_t_9;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_array_load_binary_rec", 0);

/* "psycopg_c/types/array.pyx":256
 *     cdef object val
 * 
 *     cdef Py_ssize_t nelems = dims[0]             # <<<<<<<<<<<<<<
 *     cdef list out = PyList_New(nelems)
 * 
*/
__pyx_v_nelems = (__pyx_v_dims[0]);

/* "psycopg_c/types/array.pyx":257
 * 
 *     cdef Py_ssize_t nelems = dims[0]
 *     cdef list out = PyList_New(nelems)             # <<<<<<<<<<<<<<
 * 
 *     if ndims == 1:
*/
__pyx_t_1 = PyList_New(__pyx_v_nelems); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 257, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_out = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/array.pyx":259
 *     cdef list out = PyList_New(nelems)
 * 
 *     if ndims == 1:             # <<<<<<<<<<<<<<
 *         buf = bufptr[0]
 *         for i in range(nelems):
*/
__pyx_t_2 = (__pyx_v_ndims == 1);
if (__pyx_t_2) {

  /* "psycopg_c/types/array.pyx":260
 * 
 *     if ndims == 1:
 *         buf = bufptr[0]             # <<<<<<<<<<<<<<
 *         for i in range(nelems):
 *             memcpy(&besize, buf, sizeof(besize))
*/
  __pyx_v_buf = (__pyx_v_bufptr[0]);

  /* "psycopg_c/types/array.pyx":261
 *     if ndims == 1:
 *         buf = bufptr[0]
 *         for i in range(nelems):             # <<<<<<<<<<<<<<
 *             memcpy(&besize, buf, sizeof(besize))
 *             size = <int32_t>endian.be32toh(besize)
*/
  __pyx_t_3 = __pyx_v_nelems;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "psycopg_c/types/array.pyx":262
 *         buf = bufptr[0]
 *         for i in range(nelems):
 *             memcpy(&besize, buf, sizeof(besize))             # <<<<<<<<<<<<<<
 *             size = <int32_t>endian.be32toh(besize)
 *             buf += sizeof(besize)
*/
    (void)(memcpy((&__pyx_v_besize), __pyx_v_buf, (sizeof(__pyx_v_besize))));

    /* "psycopg_c/types/array.pyx":263
 *         for i in range(nelems):
 *             memcpy(&besize, buf, sizeof(besize))
 *             size = <int32_t>endian.be32toh(besize)             # <<<<<<<<<<<<<<
 *             buf += sizeof(besize)
 *             if size == -1:
*/
    __pyx_v_size = ((int32_t)be32toh(__pyx_v_besize));

    /* "psycopg_c/types/array.pyx":264
 *             memcpy(&besize, buf, sizeof(besize))
 *             size = <int32_t>endian.be32toh(besize)
 *             buf += sizeof(besize)             # <<<<<<<<<<<<<<
 *             if size == -1:
 *                 val = None
*/
    __pyx_v_buf = (__pyx_v_buf + (sizeof(__pyx_v_besize)));

    /* "psycopg_c/types/array.pyx":265
 *             size = <int32_t>endian.be32toh(besize)
 *             buf += sizeof(besize)
 *             if size == -1:             # <<<<<<<<<<<<<<
 *                 val = None
 *             else:
*/
    __pyx_t_2 = (__pyx_v_size == -1L);
    if (__pyx_t_2) {

      /* "psycopg_c/types/array.pyx":266
 *             buf += sizeof(besize)
 *             if size == -1:
 *                 val = None             # <<<<<<<<<<<<<<
 *             else:
 *                 if (<RowLoader>row_loader).cloader is not None:
*/
      __Pyx_INCREF(Py_None);
      __Pyx_XDECREF_SET(__pyx_v_val, Py_None);

      /* "psycopg_c/types/array.pyx":265
 *             size = <int32_t>endian.be32toh(besize)
 *             buf += sizeof(besize)
 *             if size == -1:             # <<<<<<<<<<<<<<
 *                 val = None
 *             else:
*/
      goto __pyx_L6;
    }

    /* "psycopg_c/types/array.pyx":268
 *                 val = None
 *             else:
 *                 if (<RowLoader>row_loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                     val = (<RowLoader>row_loader).cloader.cload(buf, size)
 *                 else:
*/
    /*else*/ {
      __pyx_t_2 = (((PyObject *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->cloader) != Py_None);
      if (__pyx_t_2) {

        /* "psycopg_c/types/array.pyx":269
 *             else:
 *                 if (<RowLoader>row_loader).cloader is not None:
 *                     val = (<RowLoader>row_loader).cloader.cload(buf, size)             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (<RowLoader>row_loader).loadfunc(buf[:size])
*/
        __pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader *)((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->cloader->__pyx_vtab)->cload(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->cloader, __pyx_v_buf, __pyx_v_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 269, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_1);
        __pyx_t_1 = 0;

        /* "psycopg_c/types/array.pyx":268
 *                 val = None
 *             else:
 *                 if (<RowLoader>row_loader).cloader is not None:             # <<<<<<<<<<<<<<
 *                     val = (<RowLoader>row_loader).cloader.cload(buf, size)
 *                 else:
*/
        goto __pyx_L7;
      }

      /* "psycopg_c/types/array.pyx":271
 *                     val = (<RowLoader>row_loader).cloader.cload(buf, size)
 *                 else:
 *                     val = (<RowLoader>row_loader).loadfunc(buf[:size])             # <<<<<<<<<<<<<<
 *                 buf += size
 * 
*/
      /*else*/ {
        __pyx_t_6 = NULL;
        __Pyx_INCREF(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->loadfunc);
        __pyx_t_7 = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v_row_loader)->loadfunc; 
        __pyx_t_8 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_buf + 0, __pyx_v_size - 0); if (unlikely(!__pyx_t_8)) __PYX_ERR(11, 271, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_9 = 1;
        #if CYTHON_UNPACK_METHODS
        if (likely(PyMethod_Check(__pyx_t_7))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
          assert(__pyx_t_6);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
          __pyx_t_9 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
          __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
          __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
          if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 271, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_1);
        }
        __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_1);
        __pyx_t_1 = 0;
      }
      __pyx_L7:;

      /* "psycopg_c/types/array.pyx":272
 *                 else:
 *                     val = (<RowLoader>row_loader).loadfunc(buf[:size])
 *                 buf += size             # <<<<<<<<<<<<<<
 * 
 *             Py_INCREF(val)
*/
      __pyx_v_buf = (__pyx_v_buf + __pyx_v_size);
    }
    __pyx_L6:;

    /* "psycopg_c/types/array.pyx":274
 *                 buf += size
 * 
 *             Py_INCREF(val)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(out, i, val)
 * 
*/
    Py_INCREF(__pyx_v_val);

    /* "psycopg_c/types/array.pyx":275
 * 
 *             Py_INCREF(val)
 *             PyList_SET_ITEM(out, i, val)             # <<<<<<<<<<<<<<
 * 
 *         bufptr[0] = buf
*/
    PyList_SET_ITEM(__pyx_v_out, __pyx_v_i, __pyx_v_val);
  }

  /* "psycopg_c/types/array.pyx":277
 *             PyList_SET_ITEM(out, i, val)
 * 
 *         bufptr[0] = buf             # <<<<<<<<<<<<<<
 * 
 *     else:
*/
  (__pyx_v_bufptr[0]) = __pyx_v_buf;

  /* "psycopg_c/types/array.pyx":259
 *     cdef list out = PyList_New(nelems)
 * 
 *     if ndims == 1:             # <<<<<<<<<<<<<<
 *         buf = bufptr[0]
 *         for i in range(nelems):
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/array.pyx":280
 * 
 *     else:
 *         for i in range(nelems):             # <<<<<<<<<<<<<<
 *             val = _array_load_binary_rec(ndims - 1, dims + 1, bufptr, row_loader)
 *             Py_INCREF(val)
*/
/*else*/ {
  __pyx_t_3 = __pyx_v_nelems;
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
    __pyx_v_i = __pyx_t_5;

    /* "psycopg_c/types/array.pyx":281
 *     else:
 *         for i in range(nelems):
 *             val = _array_load_binary_rec(ndims - 1, dims + 1, bufptr, row_loader)             # <<<<<<<<<<<<<<
 *             Py_INCREF(val)
 *             PyList_SET_ITEM(out, i, val)
*/
    __pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg__array_load_binary_rec((__pyx_v_ndims - 1), (__pyx_v_dims + 1), __pyx_v_bufptr, __pyx_v_row_loader); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 281, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_1);
    __pyx_t_1 = 0;

    /* "psycopg_c/types/array.pyx":282
 *         for i in range(nelems):
 *             val = _array_load_binary_rec(ndims - 1, dims + 1, bufptr, row_loader)
 *             Py_INCREF(val)             # <<<<<<<<<<<<<<
 *             PyList_SET_ITEM(out, i, val)
 * 
*/
    Py_INCREF(__pyx_v_val);

    /* "psycopg_c/types/array.pyx":283
 *             val = _array_load_binary_rec(ndims - 1, dims + 1, bufptr, row_loader)
 *             Py_INCREF(val)
 *             PyList_SET_ITEM(out, i, val)             # <<<<<<<<<<<<<<
 * 
 *     return out
*/
    PyList_SET_ITEM(__pyx_v_out, __pyx_v_i, __pyx_v_val);
  }
}
__pyx_L3:;

/* "psycopg_c/types/array.pyx":285
 *             PyList_SET_ITEM(out, i, val)
 * 
 *     return out             # <<<<<<<<<<<<<<
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_out);
__pyx_r = __pyx_v_out;
goto __pyx_L0;

/* "psycopg_c/types/array.pyx":247
 * 
 * 
 * cdef object _array_load_binary_rec(             # <<<<<<<<<<<<<<
 *     Py_ssize_t ndims, Py_ssize_t *dims, const char **bufptr, PyObject *row_loader
 * ):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("psycopg_c._psycopg._array_load_binary_rec", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_val);
__Pyx_XDECREF(__pyx_v_out);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":74
 *     oid = oids.DATE_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10DateDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_v_size;
char const *__pyx_v_src;
PyObject *__pyx_v_s = 0;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
char *__pyx_t_3;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":80
 *         # NOTE: whatever the PostgreSQL DateStyle input format (DMY, MDY, YMD)
 *         # the YYYY-MM-DD is always understood correctly.
 *         cdef str s = str(obj)             # <<<<<<<<<<<<<<
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
*/
__pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 80, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_s = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":81
 *         # the YYYY-MM-DD is always understood correctly.
 *         cdef str s = str(obj)
 *         src = PyUnicode_AsUTF8AndSize(s, &size)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
*/
__pyx_t_2 = PyUnicode_AsUTF8AndSize(__pyx_v_s, (&__pyx_v_size)); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(1, 81, __pyx_L1_error)
__pyx_v_src = __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":83
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, size)
 *         return size
*/
__pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_size); if (unlikely(__pyx_t_3 == ((void *)NULL))) __PYX_ERR(1, 83, __pyx_L1_error)
__pyx_v_buf = __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":84
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)             # <<<<<<<<<<<<<<
 *         return size
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_size));

/* "psycopg_c/types/datetime.pyx":85
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)
 *         return size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":74
 *     oid = oids.DATE_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.DateDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10DateDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10DateDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10DateDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10DateDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":94
 *     oid = oids.DATE_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int32_t days = PyObject_CallFunctionObjArgs(
 *             date_toordinal, <PyObject *>obj, NULL)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16DateBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int32_t __pyx_v_days;
uint32_t __pyx_v_bedays;
uint32_t *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
int32_t __pyx_t_3;
char *__pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":96
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef int32_t days = PyObject_CallFunctionObjArgs(
 *             date_toordinal, <PyObject *>obj, NULL)             # <<<<<<<<<<<<<<
 *         days -= PG_DATE_EPOCH_DAYS
 *         cdef uint32_t bedays = endian.htobe32(days)
*/
__pyx_t_1 = __pyx_v_9psycopg_c_8_psycopg_date_toordinal;
__Pyx_INCREF(__pyx_t_1);

/* "psycopg_c/types/datetime.pyx":95
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef int32_t days = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *             date_toordinal, <PyObject *>obj, NULL)
 *         days -= PG_DATE_EPOCH_DAYS
*/
__pyx_t_2 = PyObject_CallFunctionObjArgs(__pyx_t_1, ((PyObject *)__pyx_v_obj), NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 95, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_3 = __Pyx_PyLong_As_int32_t(__pyx_t_2); if (unlikely((__pyx_t_3 == ((int32_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 95, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__pyx_v_days = __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":97
 *         cdef int32_t days = PyObject_CallFunctionObjArgs(
 *             date_toordinal, <PyObject *>obj, NULL)
 *         days -= PG_DATE_EPOCH_DAYS             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedays = endian.htobe32(days)
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(rv, offset, sizeof(bedays))
*/
__pyx_v_days = (__pyx_v_days - __pyx_e_9psycopg_c_8_psycopg_PG_DATE_EPOCH_DAYS);

/* "psycopg_c/types/datetime.pyx":98
 *             date_toordinal, <PyObject *>obj, NULL)
 *         days -= PG_DATE_EPOCH_DAYS
 *         cdef uint32_t bedays = endian.htobe32(days)             # <<<<<<<<<<<<<<
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(rv, offset, sizeof(bedays))
 *         memcpy(buf, &bedays, sizeof(bedays))
*/
__pyx_v_bedays = htobe32(__pyx_v_days);

/* "psycopg_c/types/datetime.pyx":99
 *         days -= PG_DATE_EPOCH_DAYS
 *         cdef uint32_t bedays = endian.htobe32(days)
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(rv, offset, sizeof(bedays))             # <<<<<<<<<<<<<<
 *         memcpy(buf, &bedays, sizeof(bedays))
 *         return sizeof(bedays)
*/
__pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_bedays))); if (unlikely(__pyx_t_4 == ((void *)NULL))) __PYX_ERR(1, 99, __pyx_L1_error)
__pyx_v_buf = ((uint32_t *)__pyx_t_4);

/* "psycopg_c/types/datetime.pyx":100
 *         cdef uint32_t bedays = endian.htobe32(days)
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(rv, offset, sizeof(bedays))
 *         memcpy(buf, &bedays, sizeof(bedays))             # <<<<<<<<<<<<<<
 *         return sizeof(bedays)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_bedays), (sizeof(__pyx_v_bedays))));

/* "psycopg_c/types/datetime.pyx":101
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(rv, offset, sizeof(bedays))
 *         memcpy(buf, &bedays, sizeof(bedays))
 *         return sizeof(bedays)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_bedays));
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":94
 *     oid = oids.DATE_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int32_t days = PyObject_CallFunctionObjArgs(
 *             date_toordinal, <PyObject *>obj, NULL)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16DateBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16DateBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":106
 * cdef class _BaseTimeDumper(CDumper):
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         # Use (cls,) to report the need to upgrade to a dumper for timetz (the
 *         # Frankenstein of the data types).
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_t_6;
int __pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("get_key", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (
#if !CYTHON_USE_TYPE_SLOTS
unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper &&
__Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
#else
unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
#endif
) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 106, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 106, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "psycopg_c/types/datetime.pyx":109
 *         # Use (cls,) to report the need to upgrade to a dumper for timetz (the
 *         # Frankenstein of the data types).
 *         if not obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self.cls
 *         else:
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 109, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 109, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_7 = (!__pyx_t_6);
if (__pyx_t_7) {

  /* "psycopg_c/types/datetime.pyx":110
 *         # Frankenstein of the data types).
 *         if not obj.tzinfo:
 *             return self.cls             # <<<<<<<<<<<<<<
 *         else:
 *             return (self.cls,)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.cls);
  __pyx_r = __pyx_v_self->__pyx_base.cls;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":109
 *         # Use (cls,) to report the need to upgrade to a dumper for timetz (the
 *         # Frankenstein of the data types).
 *         if not obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self.cls
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":112
 *             return self.cls
 *         else:
 *             return (self.cls,)             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj: time, format):
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.cls);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.cls);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx_base.cls) != (0)) __PYX_ERR(1, 112, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":106
 * cdef class _BaseTimeDumper(CDumper):
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         # Use (cls,) to report the need to upgrade to a dumper for timetz (the
 *         # Frankenstein of the data types).
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key = {"get_key", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("get_key (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 106, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 106, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 106, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_key", 0) < (0)) __PYX_ERR(1, 106, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, i); __PYX_ERR(1, 106, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 106, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 106, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 106, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("get_key", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 106, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":114
 *             return (self.cls,)
 * 
 *     cpdef upgrade(self, obj: time, format):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_upgrade(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (
#if !CYTHON_USE_TYPE_SLOTS
unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper &&
__Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
#else
unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
#endif
) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_upgrade); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 114, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 114, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "psycopg_c/types/datetime.pyx":115
 * 
 *     cpdef upgrade(self, obj: time, format):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *     cdef object _get_offset(self, obj):
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_NotImplementedError))), 0, 0, 0);
__PYX_ERR(1, 115, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":114
 *             return (self.cls,)
 * 
 *     cpdef upgrade(self, obj: time, format):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 114, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 114, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 114, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(1, 114, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(1, 114, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 114, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 114, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 114, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_2upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_2upgrade(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 114, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":117
 *         raise NotImplementedError
 * 
 *     cdef object _get_offset(self, obj):             # <<<<<<<<<<<<<<
 *         off = PyObject_CallFunctionObjArgs(time_utcoffset, <PyObject *>obj, NULL)
 *         if off is None:
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper__get_offset(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
PyObject *__pyx_v_off = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
int __pyx_t_3;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7[3];
size_t __pyx_t_8;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_get_offset", 0);

/* "psycopg_c/types/datetime.pyx":118
 * 
 *     cdef object _get_offset(self, obj):
 *         off = PyObject_CallFunctionObjArgs(time_utcoffset, <PyObject *>obj, NULL)             # <<<<<<<<<<<<<<
 *         if off is None:
 *             raise e.DataError(
*/
__pyx_t_1 = __pyx_v_9psycopg_c_8_psycopg_time_utcoffset;
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = PyObject_CallFunctionObjArgs(__pyx_t_1, ((PyObject *)__pyx_v_obj), NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 118, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_off = __pyx_t_2;
__pyx_t_2 = 0;

/* "psycopg_c/types/datetime.pyx":119
 *     cdef object _get_offset(self, obj):
 *         off = PyObject_CallFunctionObjArgs(time_utcoffset, <PyObject *>obj, NULL)
 *         if off is None:             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 f"cannot calculate the offset of tzinfo '{obj.tzinfo}' without a date"
*/
__pyx_t_3 = (__pyx_v_off == Py_None);
if (unlikely(__pyx_t_3)) {

  /* "psycopg_c/types/datetime.pyx":120
 *         off = PyObject_CallFunctionObjArgs(time_utcoffset, <PyObject *>obj, NULL)
 *         if off is None:
 *             raise e.DataError(             # <<<<<<<<<<<<<<
 *                 f"cannot calculate the offset of tzinfo '{obj.tzinfo}' without a date"
 *             )
*/
  __pyx_t_1 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":121
 *         if off is None:
 *             raise e.DataError(
 *                 f"cannot calculate the offset of tzinfo '{obj.tzinfo}' without a date"             # <<<<<<<<<<<<<<
 *             )
 *         return off
*/
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_4, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_cannot_calculate_the_offset_of_t;
  __pyx_t_7[1] = __pyx_t_6;
  __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u_without_a_date;
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_7, 3, 39 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 16, 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6));
  if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_5);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_5, __pyx__function);
    __pyx_t_8 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_4};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_5, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(1, 120, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":119
 *     cdef object _get_offset(self, obj):
 *         off = PyObject_CallFunctionObjArgs(time_utcoffset, <PyObject *>obj, NULL)
 *         if off is None:             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 f"cannot calculate the offset of tzinfo '{obj.tzinfo}' without a date"
*/
}

/* "psycopg_c/types/datetime.pyx":123
 *                 f"cannot calculate the offset of tzinfo '{obj.tzinfo}' without a date"
 *             )
 *         return off             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_off);
__pyx_r = __pyx_v_off;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":117
 *         raise NotImplementedError
 * 
 *     cdef object _get_offset(self, obj):             # <<<<<<<<<<<<<<
 *         off = PyObject_CallFunctionObjArgs(time_utcoffset, <PyObject *>obj, NULL)
 *         if off is None:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper._get_offset", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_off);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_5__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_4__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_7__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_6__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15_BaseTimeDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":130
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_v_size;
char const *__pyx_v_src;
PyObject *__pyx_v_s = 0;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
char *__pyx_t_3;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":134
 *         cdef const char *src
 * 
 *         cdef str s = str(obj)             # <<<<<<<<<<<<<<
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
*/
__pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 134, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_s = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":135
 * 
 *         cdef str s = str(obj)
 *         src = PyUnicode_AsUTF8AndSize(s, &size)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
*/
__pyx_t_2 = PyUnicode_AsUTF8AndSize(__pyx_v_s, (&__pyx_v_size)); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(1, 135, __pyx_L1_error)
__pyx_v_src = __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":137
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, size)
 *         return size
*/
__pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_size); if (unlikely(__pyx_t_3 == ((void *)NULL))) __PYX_ERR(1, 137, __pyx_L1_error)
__pyx_v_buf = __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":138
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)             # <<<<<<<<<<<<<<
 *         return size
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_size));

/* "psycopg_c/types/datetime.pyx":139
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)
 *         return size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":130
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeTextDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_BaseTimeTextDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseTimeTextDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeTextDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimeTextDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":147
 *     oid = oids.TIME_OID
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if not obj.tzinfo:
 *             return self
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_10TimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
int __pyx_t_3;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);

/* "psycopg_c/types/datetime.pyx":148
 * 
 *     cpdef upgrade(self, obj, format):
 *         if not obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 148, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 148, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_3 = (!__pyx_t_2);
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":149
 *     cpdef upgrade(self, obj, format):
 *         if not obj.tzinfo:
 *             return self             # <<<<<<<<<<<<<<
 *         else:
 *             return TimeTzDumper(self.cls)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":148
 * 
 *     cpdef upgrade(self, obj, format):
 *         if not obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":151
 *             return self
 *         else:
 *             return TimeTzDumper(self.cls)             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.cls};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 151, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":147
 *     oid = oids.TIME_OID
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if not obj.tzinfo:
 *             return self
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TimeDumper_1upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_1upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 147, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 147, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 147, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(1, 147, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(1, 147, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 147, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 147, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 147, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.TimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_10TimeDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 147, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TimeDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TimeDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":159
 *     oid = oids.TIMETZ_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         self._get_offset(obj)
 *         return _BaseTimeTextDumper.cdump(self, obj, rv, offset)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_12TimeTzDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
Py_ssize_t __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":160
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         self._get_offset(obj)             # <<<<<<<<<<<<<<
 *         return _BaseTimeTextDumper.cdump(self, obj, rv, offset)
 * 
*/
__pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzDumper *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base.__pyx_base._get_offset(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)__pyx_v_self), __pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 160, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":161
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         self._get_offset(obj)
 *         return _BaseTimeTextDumper.cdump(self, obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_cdump(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(1, 161, __pyx_L1_error)
__pyx_r = __pyx_t_2;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":159
 *     oid = oids.TIMETZ_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         self._get_offset(obj)
 *         return _BaseTimeTextDumper.cdump(self, obj, rv, offset)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeTzDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12TimeTzDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12TimeTzDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimeTzDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeTzDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12TimeTzDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12TimeTzDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimeTzDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeTzDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":170
 *     oid = oids.TIME_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int64_t us = cdt.time_microsecond(obj) + 1000000 * (
 *             cdt.time_second(obj)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int64_t __pyx_v_us;
uint64_t __pyx_v_beus;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
char *__pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/datetime.pyx":171
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef int64_t us = cdt.time_microsecond(obj) + 1000000 * (             # <<<<<<<<<<<<<<
 *             cdt.time_second(obj)
 *             + 60 * (cdt.time_minute(obj) + 60 * <int64_t>cdt.time_hour(obj))
*/
__pyx_v_us = (__pyx_f_7cpython_8datetime_time_microsecond(__pyx_v_obj) + (0xF4240 * (__pyx_f_7cpython_8datetime_time_second(__pyx_v_obj) + (60 * (__pyx_f_7cpython_8datetime_time_minute(__pyx_v_obj) + (60 * ((int64_t)__pyx_f_7cpython_8datetime_time_hour(__pyx_v_obj))))))));

/* "psycopg_c/types/datetime.pyx":175
 *             + 60 * (cdt.time_minute(obj) + 60 * <int64_t>cdt.time_hour(obj))
 *         )
 *         cdef uint64_t beus = endian.htobe64(us)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
*/
__pyx_v_beus = htobe64(__pyx_v_us);

/* "psycopg_c/types/datetime.pyx":177
 *         cdef uint64_t beus = endian.htobe64(us)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))             # <<<<<<<<<<<<<<
 *         memcpy(buf, &beus, sizeof(beus))
 *         return sizeof(beus)
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_beus))); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(1, 177, __pyx_L1_error)
__pyx_v_buf = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":178
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
 *         memcpy(buf, &beus, sizeof(beus))             # <<<<<<<<<<<<<<
 *         return sizeof(beus)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beus), (sizeof(__pyx_v_beus))));

/* "psycopg_c/types/datetime.pyx":179
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
 *         memcpy(buf, &beus, sizeof(beus))
 *         return sizeof(beus)             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj, format):
*/
__pyx_r = (sizeof(__pyx_v_beus));
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":170
 *     oid = oids.TIME_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int64_t us = cdt.time_microsecond(obj) + 1000000 * (
 *             cdt.time_second(obj)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":181
 *         return sizeof(beus)
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if not obj.tzinfo:
 *             return self
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
int __pyx_t_3;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);

/* "psycopg_c/types/datetime.pyx":182
 * 
 *     cpdef upgrade(self, obj, format):
 *         if not obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 182, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 182, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_3 = (!__pyx_t_2);
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":183
 *     cpdef upgrade(self, obj, format):
 *         if not obj.tzinfo:
 *             return self             # <<<<<<<<<<<<<<
 *         else:
 *             return TimeTzBinaryDumper(self.cls)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":182
 * 
 *     cpdef upgrade(self, obj, format):
 *         if not obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":185
 *             return self
 *         else:
 *             return TimeTzBinaryDumper(self.cls)             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_self->__pyx_base.__pyx_base.cls};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 185, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":181
 *         return sizeof(beus)
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if not obj.tzinfo:
 *             return self
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryDumper_1upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_1upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 181, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 181, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 181, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(1, 181, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(1, 181, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 181, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 181, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 181, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 181, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":194
 *     oid = oids.TIMETZ_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int64_t us = cdt.time_microsecond(obj) + 1_000_000 * (
 *             cdt.time_second(obj)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int64_t __pyx_v_us;
uint64_t __pyx_v_beus;
PyObject *__pyx_v_off = NULL;
int32_t __pyx_v_offsec;
uint32_t __pyx_v_beoff;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
int32_t __pyx_t_3;
char *__pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":195
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef int64_t us = cdt.time_microsecond(obj) + 1_000_000 * (             # <<<<<<<<<<<<<<
 *             cdt.time_second(obj)
 *             + 60 * (cdt.time_minute(obj) + 60 * <int64_t>cdt.time_hour(obj))
*/
__pyx_v_us = (__pyx_f_7cpython_8datetime_time_microsecond(__pyx_v_obj) + (0xF4240 * (__pyx_f_7cpython_8datetime_time_second(__pyx_v_obj) + (60 * (__pyx_f_7cpython_8datetime_time_minute(__pyx_v_obj) + (60 * ((int64_t)__pyx_f_7cpython_8datetime_time_hour(__pyx_v_obj))))))));

/* "psycopg_c/types/datetime.pyx":199
 *             + 60 * (cdt.time_minute(obj) + 60 * <int64_t>cdt.time_hour(obj))
 *         )
 *         cdef uint64_t beus = endian.htobe64(us)             # <<<<<<<<<<<<<<
 * 
 *         off = self._get_offset(obj)
*/
__pyx_v_beus = htobe64(__pyx_v_us);

/* "psycopg_c/types/datetime.pyx":201
 *         cdef uint64_t beus = endian.htobe64(us)
 * 
 *         off = self._get_offset(obj)             # <<<<<<<<<<<<<<
 *         cdef int32_t offsec = int(PyObject_CallFunctionObjArgs(
 *             timedelta_total_seconds, <PyObject *>off, NULL))
*/
__pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzBinaryDumper *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._get_offset(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)__pyx_v_self), __pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 201, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_off = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":203
 *         off = self._get_offset(obj)
 *         cdef int32_t offsec = int(PyObject_CallFunctionObjArgs(
 *             timedelta_total_seconds, <PyObject *>off, NULL))             # <<<<<<<<<<<<<<
 *         cdef uint32_t beoff = endian.htobe32(-offsec)
 * 
*/
__pyx_t_1 = __pyx_v_9psycopg_c_8_psycopg_timedelta_total_seconds;
__Pyx_INCREF(__pyx_t_1);

/* "psycopg_c/types/datetime.pyx":202
 * 
 *         off = self._get_offset(obj)
 *         cdef int32_t offsec = int(PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *             timedelta_total_seconds, <PyObject *>off, NULL))
 *         cdef uint32_t beoff = endian.htobe32(-offsec)
*/
__pyx_t_2 = PyObject_CallFunctionObjArgs(__pyx_t_1, ((PyObject *)__pyx_v_off), NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 202, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_1 = __Pyx_PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 202, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__pyx_t_3 = __Pyx_PyLong_As_int32_t(__pyx_t_1); if (unlikely((__pyx_t_3 == ((int32_t)-1)) && PyErr_Occurred())) __PYX_ERR(1, 202, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_offsec = __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":204
 *         cdef int32_t offsec = int(PyObject_CallFunctionObjArgs(
 *             timedelta_total_seconds, <PyObject *>off, NULL))
 *         cdef uint32_t beoff = endian.htobe32(-offsec)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus) + sizeof(beoff))
*/
__pyx_v_beoff = htobe32((-__pyx_v_offsec));

/* "psycopg_c/types/datetime.pyx":206
 *         cdef uint32_t beoff = endian.htobe32(-offsec)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus) + sizeof(beoff))             # <<<<<<<<<<<<<<
 *         memcpy(buf, &beus, sizeof(beus))
 *         memcpy(buf + sizeof(beus), &beoff, sizeof(beoff))
*/
__pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, ((sizeof(__pyx_v_beus)) + (sizeof(__pyx_v_beoff)))); if (unlikely(__pyx_t_4 == ((void *)NULL))) __PYX_ERR(1, 206, __pyx_L1_error)
__pyx_v_buf = __pyx_t_4;

/* "psycopg_c/types/datetime.pyx":207
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus) + sizeof(beoff))
 *         memcpy(buf, &beus, sizeof(beus))             # <<<<<<<<<<<<<<
 *         memcpy(buf + sizeof(beus), &beoff, sizeof(beoff))
 *         return sizeof(beus) + sizeof(beoff)
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beus), (sizeof(__pyx_v_beus))));

/* "psycopg_c/types/datetime.pyx":208
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus) + sizeof(beoff))
 *         memcpy(buf, &beus, sizeof(beus))
 *         memcpy(buf + sizeof(beus), &beoff, sizeof(beoff))             # <<<<<<<<<<<<<<
 *         return sizeof(beus) + sizeof(beoff)
 * 
*/
(void)(memcpy((__pyx_v_buf + (sizeof(__pyx_v_beus))), (&__pyx_v_beoff), (sizeof(__pyx_v_beoff))));

/* "psycopg_c/types/datetime.pyx":209
 *         memcpy(buf, &beus, sizeof(beus))
 *         memcpy(buf + sizeof(beus), &beoff, sizeof(beoff))
 *         return sizeof(beus) + sizeof(beoff)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = ((sizeof(__pyx_v_beus)) + (sizeof(__pyx_v_beoff)));
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":194
 *     oid = oids.TIMETZ_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int64_t us = cdt.time_microsecond(obj) + 1_000_000 * (
 *             cdt.time_second(obj)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeTzBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_off);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18TimeTzBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimeTzBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeTzBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeTzBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":214
 * cdef class _BaseDatetimeDumper(CDumper):
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         # Use (cls,) to report the need to upgrade (downgrade, actually) to a
 *         # dumper for naive timestamp.
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_t_6;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("get_key", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (
#if !CYTHON_USE_TYPE_SLOTS
unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper &&
__Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
#else
unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
#endif
) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 214, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 214, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "psycopg_c/types/datetime.pyx":217
 *         # Use (cls,) to report the need to upgrade (downgrade, actually) to a
 *         # dumper for naive timestamp.
 *         if obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self.cls
 *         else:
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 217, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 217, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_6) {

  /* "psycopg_c/types/datetime.pyx":218
 *         # dumper for naive timestamp.
 *         if obj.tzinfo:
 *             return self.cls             # <<<<<<<<<<<<<<
 *         else:
 *             return (self.cls,)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.cls);
  __pyx_r = __pyx_v_self->__pyx_base.cls;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":217
 *         # Use (cls,) to report the need to upgrade (downgrade, actually) to a
 *         # dumper for naive timestamp.
 *         if obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self.cls
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":220
 *             return self.cls
 *         else:
 *             return (self.cls,)             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj: time, format):
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->__pyx_base.cls);
  __Pyx_GIVEREF(__pyx_v_self->__pyx_base.cls);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx_base.cls) != (0)) __PYX_ERR(1, 220, __pyx_L1_error);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":214
 * cdef class _BaseDatetimeDumper(CDumper):
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         # Use (cls,) to report the need to upgrade (downgrade, actually) to a
 *         # dumper for naive timestamp.
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key = {"get_key", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("get_key (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 214, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 214, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 214, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_key", 0) < (0)) __PYX_ERR(1, 214, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, i); __PYX_ERR(1, 214, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 214, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 214, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 214, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("get_key", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 214, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":222
 *             return (self.cls,)
 * 
 *     cpdef upgrade(self, obj: time, format):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_upgrade(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (
#if !CYTHON_USE_TYPE_SLOTS
unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper &&
__Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
#else
unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
#endif
) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_upgrade); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 222, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "psycopg_c/types/datetime.pyx":223
 * 
 *     cpdef upgrade(self, obj: time, format):
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_NotImplementedError))), 0, 0, 0);
__PYX_ERR(1, 223, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":222
 *             return (self.cls,)
 * 
 *     cpdef upgrade(self, obj: time, format):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 222, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 222, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 222, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(1, 222, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(1, 222, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 222, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 222, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 222, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_2upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_2upgrade(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 222, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_5__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_4__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_7__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_6__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":230
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_v_size;
char const *__pyx_v_src;
PyObject *__pyx_v_s = 0;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
char *__pyx_t_3;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":236
 *         # NOTE: whatever the PostgreSQL DateStyle input format (DMY, MDY, YMD)
 *         # the YYYY-MM-DD is always understood correctly.
 *         cdef str s = str(obj)             # <<<<<<<<<<<<<<
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
*/
__pyx_t_1 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 236, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_s = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":237
 *         # the YYYY-MM-DD is always understood correctly.
 *         cdef str s = str(obj)
 *         src = PyUnicode_AsUTF8AndSize(s, &size)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
*/
__pyx_t_2 = PyUnicode_AsUTF8AndSize(__pyx_v_s, (&__pyx_v_size)); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(1, 237, __pyx_L1_error)
__pyx_v_src = __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":239
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, size)
 *         return size
*/
__pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_size); if (unlikely(__pyx_t_3 == ((void *)NULL))) __PYX_ERR(1, 239, __pyx_L1_error)
__pyx_v_buf = __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":240
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)             # <<<<<<<<<<<<<<
 *         return size
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_size));

/* "psycopg_c/types/datetime.pyx":241
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)
 *         return size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":230
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeTextDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeTextDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseDatetimeTextDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":249
 *     oid = oids.TIMESTAMPTZ_OID
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if obj.tzinfo:
 *             return self
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);

/* "psycopg_c/types/datetime.pyx":250
 * 
 *     cpdef upgrade(self, obj, format):
 *         if obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 250, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 250, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":251
 *     cpdef upgrade(self, obj, format):
 *         if obj.tzinfo:
 *             return self             # <<<<<<<<<<<<<<
 *         else:
 *             return DatetimeNoTzDumper(self.cls)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":250
 * 
 *     cpdef upgrade(self, obj, format):
 *         if obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":253
 *             return self
 *         else:
 *             return DatetimeNoTzDumper(self.cls)             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self->__pyx_base.__pyx_base.__pyx_base.cls};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 253, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":249
 *     oid = oids.TIMESTAMPTZ_OID
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if obj.tzinfo:
 *             return self
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14DatetimeDumper_1upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_1upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 249, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 249, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 249, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(1, 249, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(1, 249, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 249, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 249, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 249, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 249, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14DatetimeDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14DatetimeDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14DatetimeDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18DatetimeNoTzDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18DatetimeNoTzDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeNoTzDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeNoTzDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":268
 *     oid = oids.TIMESTAMPTZ_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         delta = obj - pg_datetimetz_epoch
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
PyObject *__pyx_v_delta = NULL;
int64_t __pyx_v_us;
uint64_t __pyx_v_beus;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":269
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         delta = obj - pg_datetimetz_epoch             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t us = cdt.timedelta_microseconds(delta) + 1_000_000 * (
*/
__pyx_t_1 = PyNumber_Subtract(__pyx_v_obj, __pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 269, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_delta = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":271
 *         delta = obj - pg_datetimetz_epoch
 * 
 *         cdef int64_t us = cdt.timedelta_microseconds(delta) + 1_000_000 * (             # <<<<<<<<<<<<<<
 *             86_400 * <int64_t>cdt.timedelta_days(delta)
 *             + <int64_t>cdt.timedelta_seconds(delta))
*/
__pyx_v_us = (__pyx_f_7cpython_8datetime_timedelta_microseconds(__pyx_v_delta) + (0xF4240 * ((0x15180 * ((int64_t)__pyx_f_7cpython_8datetime_timedelta_days(__pyx_v_delta))) + ((int64_t)__pyx_f_7cpython_8datetime_timedelta_seconds(__pyx_v_delta)))));

/* "psycopg_c/types/datetime.pyx":274
 *             86_400 * <int64_t>cdt.timedelta_days(delta)
 *             + <int64_t>cdt.timedelta_seconds(delta))
 *         cdef uint64_t beus = endian.htobe64(us)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
*/
__pyx_v_beus = htobe64(__pyx_v_us);

/* "psycopg_c/types/datetime.pyx":276
 *         cdef uint64_t beus = endian.htobe64(us)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))             # <<<<<<<<<<<<<<
 *         memcpy(buf, &beus, sizeof(beus))
 *         return sizeof(beus)
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_beus))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(1, 276, __pyx_L1_error)
__pyx_v_buf = __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":277
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
 *         memcpy(buf, &beus, sizeof(beus))             # <<<<<<<<<<<<<<
 *         return sizeof(beus)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beus), (sizeof(__pyx_v_beus))));

/* "psycopg_c/types/datetime.pyx":278
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
 *         memcpy(buf, &beus, sizeof(beus))
 *         return sizeof(beus)             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj, format):
*/
__pyx_r = (sizeof(__pyx_v_beus));
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":268
 *     oid = oids.TIMESTAMPTZ_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         delta = obj - pg_datetimetz_epoch
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_delta);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":280
 *         return sizeof(beus)
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if obj.tzinfo:
 *             return self
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, CYTHON_UNUSED int __pyx_skip_dispatch) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);

/* "psycopg_c/types/datetime.pyx":281
 * 
 *     cpdef upgrade(self, obj, format):
 *         if obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_tzinfo); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 281, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 281, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":282
 *     cpdef upgrade(self, obj, format):
 *         if obj.tzinfo:
 *             return self             # <<<<<<<<<<<<<<
 *         else:
 *             return DatetimeNoTzBinaryDumper(self.cls)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __pyx_r = ((PyObject *)__pyx_v_self);
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":281
 * 
 *     cpdef upgrade(self, obj, format):
 *         if obj.tzinfo:             # <<<<<<<<<<<<<<
 *             return self
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":284
 *             return self
 *         else:
 *             return DatetimeNoTzBinaryDumper(self.cls)             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_self->__pyx_base.__pyx_base.cls};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 284, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_1);
  }
  __pyx_r = ((PyObject *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":280
 *         return sizeof(beus)
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if obj.tzinfo:
 *             return self
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeBinaryDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_1upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_1upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_1upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 280, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 280, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 280, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(1, 280, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(1, 280, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 280, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 280, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(1, 280, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeBinaryDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 280, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeBinaryDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":293
 *     oid = oids.TIMESTAMP_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         delta = obj - pg_datetime_epoch
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
PyObject *__pyx_v_delta = NULL;
int64_t __pyx_v_us;
uint64_t __pyx_v_beus;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":294
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         delta = obj - pg_datetime_epoch             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t us = cdt.timedelta_microseconds(delta) + 1_000_000 * (
*/
__pyx_t_1 = PyNumber_Subtract(__pyx_v_obj, __pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 294, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_delta = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":296
 *         delta = obj - pg_datetime_epoch
 * 
 *         cdef int64_t us = cdt.timedelta_microseconds(delta) + 1_000_000 * (             # <<<<<<<<<<<<<<
 *             86_400 * <int64_t>cdt.timedelta_days(delta)
 *             + <int64_t>cdt.timedelta_seconds(delta))
*/
__pyx_v_us = (__pyx_f_7cpython_8datetime_timedelta_microseconds(__pyx_v_delta) + (0xF4240 * ((0x15180 * ((int64_t)__pyx_f_7cpython_8datetime_timedelta_days(__pyx_v_delta))) + ((int64_t)__pyx_f_7cpython_8datetime_timedelta_seconds(__pyx_v_delta)))));

/* "psycopg_c/types/datetime.pyx":299
 *             86_400 * <int64_t>cdt.timedelta_days(delta)
 *             + <int64_t>cdt.timedelta_seconds(delta))
 *         cdef uint64_t beus = endian.htobe64(us)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
*/
__pyx_v_beus = htobe64(__pyx_v_us);

/* "psycopg_c/types/datetime.pyx":301
 *         cdef uint64_t beus = endian.htobe64(us)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))             # <<<<<<<<<<<<<<
 *         memcpy(buf, &beus, sizeof(beus))
 *         return sizeof(beus)
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_beus))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(1, 301, __pyx_L1_error)
__pyx_v_buf = __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":302
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
 *         memcpy(buf, &beus, sizeof(beus))             # <<<<<<<<<<<<<<
 *         return sizeof(beus)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beus), (sizeof(__pyx_v_beus))));

/* "psycopg_c/types/datetime.pyx":303
 *         cdef char *buf = CDumper.ensure_size(rv, offset, sizeof(beus))
 *         memcpy(buf, &beus, sizeof(beus))
 *         return sizeof(beus)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_beus));
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":293
 *     oid = oids.TIMESTAMP_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         delta = obj - pg_datetime_epoch
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeNoTzBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_delta);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeNoTzBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DatetimeNoTzBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":313
 *     cdef int _style
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 313, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 313, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 313, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(1, 313, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(1, 313, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 313, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 313, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  __pyx_v_cls = values[0];
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(1, 313, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *)__pyx_v_self), __pyx_v_cls, __pyx_v_context);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_ds;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
int __pyx_t_3;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/datetime.pyx":315
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)             # <<<<<<<<<<<<<<
 *         if ds[0] == b's':  # sql_standard
 *             self._style = INTERVALSTYLE_SQL_STANDARD
*/
__pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_intervalstyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 315, __pyx_L1_error)
__pyx_v_ds = __pyx_t_2;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":316
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
 *         if ds[0] == b's':  # sql_standard             # <<<<<<<<<<<<<<
 *             self._style = INTERVALSTYLE_SQL_STANDARD
 *         else:  # iso_8601, postgres, postgres_verbose
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 's');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":317
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
 *         if ds[0] == b's':  # sql_standard
 *             self._style = INTERVALSTYLE_SQL_STANDARD             # <<<<<<<<<<<<<<
 *         else:  # iso_8601, postgres, postgres_verbose
 *             self._style = INTERVALSTYLE_OTHERS
*/
  __pyx_v_self->_style = __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_SQL_STANDARD;

  /* "psycopg_c/types/datetime.pyx":316
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
 *         if ds[0] == b's':  # sql_standard             # <<<<<<<<<<<<<<
 *             self._style = INTERVALSTYLE_SQL_STANDARD
 *         else:  # iso_8601, postgres, postgres_verbose
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":319
 *             self._style = INTERVALSTYLE_SQL_STANDARD
 *         else:  # iso_8601, postgres, postgres_verbose
 *             self._style = INTERVALSTYLE_OTHERS             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
/*else*/ {
  __pyx_v_self->_style = __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_OTHERS;
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":313
 *     cdef int _style
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":321
 *             self._style = INTERVALSTYLE_OTHERS
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_15TimedeltaDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_v_size;
char const *__pyx_v_src;
PyObject *__pyx_v_s = 0;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
char const *__pyx_t_6;
char *__pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/datetime.pyx":326
 * 
 *         cdef str s
 *         if self._style == INTERVALSTYLE_OTHERS:             # <<<<<<<<<<<<<<
 *             # The comma is parsed ok by PostgreSQL but it's not documented
 *             # and it seems brittle to rely on it. CRDB doesn't consume it well.
*/
__pyx_t_1 = (__pyx_v_self->_style == __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_OTHERS);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":329
 *             # The comma is parsed ok by PostgreSQL but it's not documented
 *             # and it seems brittle to rely on it. CRDB doesn't consume it well.
 *             s = str(obj).replace(",", "")             # <<<<<<<<<<<<<<
 *         else:
 *             # sql_standard format needs explicit signs
*/
  __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyUnicode_Replace(((PyObject*)__pyx_t_2), __pyx_mstate_global->__pyx_kp_u__6, __pyx_mstate_global->__pyx_kp_u__4, -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_s = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "psycopg_c/types/datetime.pyx":326
 * 
 *         cdef str s
 *         if self._style == INTERVALSTYLE_OTHERS:             # <<<<<<<<<<<<<<
 *             # The comma is parsed ok by PostgreSQL but it's not documented
 *             # and it seems brittle to rely on it. CRDB doesn't consume it well.
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":333
 *             # sql_standard format needs explicit signs
 *             # otherwise -1 day 1 sec will mean -1 sec
 *             s = "%+d day %+d second %+d microsecond" % (             # <<<<<<<<<<<<<<
 *                 obj.days, obj.seconds, obj.microseconds)
 * 
*/
/*else*/ {

  /* "psycopg_c/types/datetime.pyx":334
 *             # otherwise -1 day 1 sec will mean -1 sec
 *             s = "%+d day %+d second %+d microsecond" % (
 *                 obj.days, obj.seconds, obj.microseconds)             # <<<<<<<<<<<<<<
 * 
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
*/
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_days); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_seconds); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_obj, __pyx_mstate_global->__pyx_n_u_microseconds); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 334, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3) != (0)) __PYX_ERR(1, 334, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2) != (0)) __PYX_ERR(1, 334, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4) != (0)) __PYX_ERR(1, 334, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":333
 *             # sql_standard format needs explicit signs
 *             # otherwise -1 day 1 sec will mean -1 sec
 *             s = "%+d day %+d second %+d microsecond" % (             # <<<<<<<<<<<<<<
 *                 obj.days, obj.seconds, obj.microseconds)
 * 
*/
  __pyx_t_4 = PyUnicode_Format(__pyx_mstate_global->__pyx_kp_u_d_day_d_second_d_microsecond, __pyx_t_5); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 333, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_s = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":336
 *                 obj.days, obj.seconds, obj.microseconds)
 * 
 *         src = PyUnicode_AsUTF8AndSize(s, &size)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
*/
__pyx_t_6 = PyUnicode_AsUTF8AndSize(__pyx_v_s, (&__pyx_v_size)); if (unlikely(__pyx_t_6 == ((void *)NULL))) __PYX_ERR(1, 336, __pyx_L1_error)
__pyx_v_src = __pyx_t_6;

/* "psycopg_c/types/datetime.pyx":338
 *         src = PyUnicode_AsUTF8AndSize(s, &size)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, size)
 *         return size
*/
__pyx_t_7 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_size); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(1, 338, __pyx_L1_error)
__pyx_v_buf = __pyx_t_7;

/* "psycopg_c/types/datetime.pyx":339
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)             # <<<<<<<<<<<<<<
 *         return size
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_size));

/* "psycopg_c/types/datetime.pyx":340
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)
 *         return size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":321
 *             self._style = INTERVALSTYLE_OTHERS
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size
 *         cdef const char *src
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15TimedeltaDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15TimedeltaDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimedeltaDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":349
 *     oid = oids.INTERVAL_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int64_t us = (
 *             1_000_000 * <int64_t>cdt.timedelta_seconds(obj)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int64_t __pyx_v_us;
uint64_t __pyx_v_beus;
int32_t __pyx_v_days;
uint32_t __pyx_v_bedays;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
char *__pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/datetime.pyx":352
 *         cdef int64_t us = (
 *             1_000_000 * <int64_t>cdt.timedelta_seconds(obj)
 *             + cdt.timedelta_microseconds(obj))             # <<<<<<<<<<<<<<
 *         cdef uint64_t beus = endian.htobe64(us)
 * 
*/
__pyx_v_us = ((0xF4240 * ((int64_t)__pyx_f_7cpython_8datetime_timedelta_seconds(__pyx_v_obj))) + __pyx_f_7cpython_8datetime_timedelta_microseconds(__pyx_v_obj));

/* "psycopg_c/types/datetime.pyx":353
 *             1_000_000 * <int64_t>cdt.timedelta_seconds(obj)
 *             + cdt.timedelta_microseconds(obj))
 *         cdef uint64_t beus = endian.htobe64(us)             # <<<<<<<<<<<<<<
 * 
 *         cdef int32_t days = cdt.timedelta_days(obj)
*/
__pyx_v_beus = htobe64(__pyx_v_us);

/* "psycopg_c/types/datetime.pyx":355
 *         cdef uint64_t beus = endian.htobe64(us)
 * 
 *         cdef int32_t days = cdt.timedelta_days(obj)             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedays = endian.htobe32(days)
 * 
*/
__pyx_v_days = __pyx_f_7cpython_8datetime_timedelta_days(__pyx_v_obj);

/* "psycopg_c/types/datetime.pyx":356
 * 
 *         cdef int32_t days = cdt.timedelta_days(obj)
 *         cdef uint32_t bedays = endian.htobe32(days)             # <<<<<<<<<<<<<<
 * 
 *         # The third item is months
*/
__pyx_v_bedays = htobe32(__pyx_v_days);

/* "psycopg_c/types/datetime.pyx":359
 * 
 *         # The third item is months
 *         cdef char *buf = CDumper.ensure_size(             # <<<<<<<<<<<<<<
 *             rv, offset, sizeof(beus) + sizeof(bedays) + sizeof(int32_t))
 *         memcpy(buf, &beus, sizeof(beus))
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (((sizeof(__pyx_v_beus)) + (sizeof(__pyx_v_bedays))) + (sizeof(int32_t)))); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(1, 359, __pyx_L1_error)
__pyx_v_buf = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":361
 *         cdef char *buf = CDumper.ensure_size(
 *             rv, offset, sizeof(beus) + sizeof(bedays) + sizeof(int32_t))
 *         memcpy(buf, &beus, sizeof(beus))             # <<<<<<<<<<<<<<
 *         memcpy(buf + sizeof(beus), &bedays, sizeof(bedays))
 *         memset(buf + sizeof(beus) + sizeof(bedays), 0, sizeof(int32_t))
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beus), (sizeof(__pyx_v_beus))));

/* "psycopg_c/types/datetime.pyx":362
 *             rv, offset, sizeof(beus) + sizeof(bedays) + sizeof(int32_t))
 *         memcpy(buf, &beus, sizeof(beus))
 *         memcpy(buf + sizeof(beus), &bedays, sizeof(bedays))             # <<<<<<<<<<<<<<
 *         memset(buf + sizeof(beus) + sizeof(bedays), 0, sizeof(int32_t))
 * 
*/
(void)(memcpy((__pyx_v_buf + (sizeof(__pyx_v_beus))), (&__pyx_v_bedays), (sizeof(__pyx_v_bedays))));

/* "psycopg_c/types/datetime.pyx":363
 *         memcpy(buf, &beus, sizeof(beus))
 *         memcpy(buf + sizeof(beus), &bedays, sizeof(bedays))
 *         memset(buf + sizeof(beus) + sizeof(bedays), 0, sizeof(int32_t))             # <<<<<<<<<<<<<<
 * 
 *         return sizeof(beus) + sizeof(bedays) + sizeof(int32_t)
*/
(void)(memset(((__pyx_v_buf + (sizeof(__pyx_v_beus))) + (sizeof(__pyx_v_bedays))), 0, (sizeof(int32_t))));

/* "psycopg_c/types/datetime.pyx":365
 *         memset(buf + sizeof(beus) + sizeof(bedays), 0, sizeof(int32_t))
 * 
 *         return sizeof(beus) + sizeof(bedays) + sizeof(int32_t)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (((sizeof(__pyx_v_beus)) + (sizeof(__pyx_v_bedays))) + (sizeof(int32_t)));
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":349
 *     oid = oids.INTERVAL_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef int64_t us = (
 *             1_000_000 * <int64_t>cdt.timedelta_seconds(obj)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimedeltaBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":374
 *     cdef int _order
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_10DateLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_10DateLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 374, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 374, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 374, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(1, 374, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(1, 374, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 374, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 374, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(1, 374, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(1, 374, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.DateLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(1, 374, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10DateLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_10DateLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_ds;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
int __pyx_t_3;
int __pyx_t_4;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
Py_ssize_t __pyx_t_8;
PyObject *__pyx_t_9 = NULL;
size_t __pyx_t_10;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/datetime.pyx":376
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)             # <<<<<<<<<<<<<<
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
*/
__pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_datestyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 376, __pyx_L1_error)
__pyx_v_ds = __pyx_t_2;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":377
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO             # <<<<<<<<<<<<<<
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'I');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":378
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD             # <<<<<<<<<<<<<<
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY
*/
  __pyx_v_self->_order = __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD;

  /* "psycopg_c/types/datetime.pyx":377
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO             # <<<<<<<<<<<<<<
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":379
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'G');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":380
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY             # <<<<<<<<<<<<<<
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
*/
  __pyx_v_self->_order = __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY;

  /* "psycopg_c/types/datetime.pyx":379
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":381
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'S');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":382
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY             # <<<<<<<<<<<<<<
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
 *             self._order = ORDER_DMY if ds[10] == b'D' else ORDER_MDY
*/
  __pyx_t_3 = ((__pyx_v_ds[5]) == 'D');
  if (__pyx_t_3) {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY;
  } else {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_MDY;
  }
  __pyx_v_self->_order = __pyx_t_4;

  /* "psycopg_c/types/datetime.pyx":381
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":383
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY if ds[10] == b'D' else ORDER_MDY
 *         else:
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'P');
if (likely(__pyx_t_3)) {

  /* "psycopg_c/types/datetime.pyx":384
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
 *             self._order = ORDER_DMY if ds[10] == b'D' else ORDER_MDY             # <<<<<<<<<<<<<<
 *         else:
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")
*/
  __pyx_t_3 = ((__pyx_v_ds[10]) == 'D');
  if (__pyx_t_3) {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY;
  } else {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_MDY;
  }
  __pyx_v_self->_order = __pyx_t_4;

  /* "psycopg_c/types/datetime.pyx":383
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY if ds[10] == b'D' else ORDER_MDY
 *         else:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":386
 *             self._order = ORDER_DMY if ds[10] == b'D' else ORDER_MDY
 *         else:
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")             # <<<<<<<<<<<<<<
 * 
 *     cdef object _error_date(self, const char *data, str msg):
*/
/*else*/ {
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_ssize_strlen(__pyx_v_ds); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(1, 386, __pyx_L1_error)
  __pyx_t_6 = __Pyx_decode_c_string(__pyx_v_ds, 0, __pyx_t_8, NULL, NULL, PyUnicode_DecodeASCII); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_unexpected_DateStyle, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_10 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_10 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_9};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 386, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 386, __pyx_L1_error)
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":374
 *     cdef int _order
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_AddTraceback("psycopg_c._psycopg.DateLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":388
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")
 * 
 *     cdef object _error_date(self, const char *data, str msg):             # <<<<<<<<<<<<<<
 *         s = bytes(data).decode("utf8", "replace")
 *         if s == "infinity" or len(s.split()[0]) > 10:
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_10DateLoader__error_date(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, char const *__pyx_v_data, PyObject *__pyx_v_msg) {
PyObject *__pyx_v_s = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_t_5;
int __pyx_t_6;
Py_ssize_t __pyx_t_7;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10[4];
PyObject *__pyx_t_11 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_error_date", 0);

/* "psycopg_c/types/datetime.pyx":389
 * 
 *     cdef object _error_date(self, const char *data, str msg):
 *         s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *         if s == "infinity" or len(s.split()[0]) > 10:
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None
*/
__pyx_t_2 = NULL;
__pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 389, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_t_3 = __Pyx_decode_bytes(__pyx_t_1, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 389, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_s = ((PyObject*)__pyx_t_3);
__pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":390
 *     cdef object _error_date(self, const char *data, str msg):
 *         s = bytes(data).decode("utf8", "replace")
 *         if s == "infinity" or len(s.split()[0]) > 10:             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None
 *         elif s == "-infinity" or "BC" in s:
*/
__pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_infinity, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 390, __pyx_L1_error)
if (!__pyx_t_6) {
} else {
  __pyx_t_5 = __pyx_t_6;
  goto __pyx_L4_bool_binop_done;
}
__pyx_t_3 = PyUnicode_Split(__pyx_v_s, ((PyObject *)NULL), -1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 390, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_1 = __Pyx_GetItemInt_List(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 1, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 390, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__pyx_t_7 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(1, 390, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_6 = (__pyx_t_7 > 10);
__pyx_t_5 = __pyx_t_6;
__pyx_L4_bool_binop_done:;
if (unlikely(__pyx_t_5)) {

  /* "psycopg_c/types/datetime.pyx":391
 *         s = bytes(data).decode("utf8", "replace")
 *         if s == "infinity" or len(s.split()[0]) > 10:
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None             # <<<<<<<<<<<<<<
 *         elif s == "-infinity" or "BC" in s:
 *             raise e.DataError(f"date too small (before year 1): {s!r}") from None
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_date_too_large_after_year_10K, __pyx_t_2); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 391, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":390
 *     cdef object _error_date(self, const char *data, str msg):
 *         s = bytes(data).decode("utf8", "replace")
 *         if s == "infinity" or len(s.split()[0]) > 10:             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None
 *         elif s == "-infinity" or "BC" in s:
*/
}

/* "psycopg_c/types/datetime.pyx":392
 *         if s == "infinity" or len(s.split()[0]) > 10:
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None
 *         elif s == "-infinity" or "BC" in s:             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"date too small (before year 1): {s!r}") from None
 *         else:
*/
__pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s, __pyx_mstate_global->__pyx_kp_u_infinity_2, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 392, __pyx_L1_error)
if (!__pyx_t_6) {
} else {
  __pyx_t_5 = __pyx_t_6;
  goto __pyx_L6_bool_binop_done;
}
__pyx_t_6 = (__Pyx_PyUnicode_ContainsTF(__pyx_mstate_global->__pyx_n_u_BC, __pyx_v_s, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 392, __pyx_L1_error)
__pyx_t_5 = __pyx_t_6;
__pyx_L6_bool_binop_done:;
if (unlikely(__pyx_t_5)) {

  /* "psycopg_c/types/datetime.pyx":393
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None
 *         elif s == "-infinity" or "BC" in s:
 *             raise e.DataError(f"date too small (before year 1): {s!r}") from None             # <<<<<<<<<<<<<<
 *         else:
 *             raise e.DataError(f"can't parse date {s!r}: {msg}") from None
*/
  __pyx_t_8 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_date_too_small_before_year_1, __pyx_t_9); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_8);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_8);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_2};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 393, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 393, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":392
 *         if s == "infinity" or len(s.split()[0]) > 10:
 *             raise e.DataError(f"date too large (after year 10K): {s!r}") from None
 *         elif s == "-infinity" or "BC" in s:             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"date too small (before year 1): {s!r}") from None
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":395
 *             raise e.DataError(f"date too small (before year 1): {s!r}") from None
 *         else:
 *             raise e.DataError(f"can't parse date {s!r}: {msg}") from None             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
/*else*/ {
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyUnicode_Unicode(__pyx_v_msg); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_date;
  __pyx_t_10[1] = __pyx_t_2;
  __pyx_t_10[2] = __pyx_mstate_global->__pyx_kp_u__7;
  __pyx_t_10[3] = __pyx_t_9;
  __pyx_t_11 = __Pyx_PyUnicode_Join(__pyx_t_10, 4, 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9));
  if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 395, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_8))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_8);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_11};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 395, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 395, __pyx_L1_error)
}

/* "psycopg_c/types/datetime.pyx":388
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")
 * 
 *     cdef object _error_date(self, const char *data, str msg):             # <<<<<<<<<<<<<<
 *         s = bytes(data).decode("utf8", "replace")
 *         if s == "infinity" or len(s.split()[0]) > 10:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_AddTraceback("psycopg_c._psycopg.DateLoader._error_date", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":397
 *             raise e.DataError(f"can't parse date {s!r}: {msg}") from None
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if length != 10:
 *             self._error_date(data, "unexpected length")
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_10DateLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
int64_t __pyx_v_vals[3];
char const *__pyx_v_ptr;
char const *__pyx_v_end;
PyObject *__pyx_v_s = NULL;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
char const *__pyx_t_3;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
size_t __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
int __pyx_t_12;
int __pyx_t_13;
char const *__pyx_t_14;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17 = NULL;
PyObject *__pyx_t_18 = NULL;
PyObject *__pyx_t_19 = NULL;
PyObject *__pyx_t_20 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":398
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if length != 10:             # <<<<<<<<<<<<<<
 *             self._error_date(data, "unexpected length")
 * 
*/
__pyx_t_1 = (__pyx_v_length != 10);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":399
 *     cdef object cload(self, const char *data, size_t length):
 *         if length != 10:
 *             self._error_date(data, "unexpected length")             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[3]
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_10DateLoader__error_date(__pyx_v_self, __pyx_v_data, __pyx_mstate_global->__pyx_kp_u_unexpected_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/types/datetime.pyx":398
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if length != 10:             # <<<<<<<<<<<<<<
 *             self._error_date(data, "unexpected length")
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":402
 * 
 *         cdef int64_t vals[3]
 *         memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ptr
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":405
 * 
 *         cdef const char *ptr
 *         cdef const char *end = data + length             # <<<<<<<<<<<<<<
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:
*/
__pyx_v_end = (__pyx_v_data + __pyx_v_length);

/* "psycopg_c/types/datetime.pyx":406
 *         cdef const char *ptr
 *         cdef const char *end = data + length
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
*/
__pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_data, __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_3 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 406, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":407
 *         cdef const char *end = data + length
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse date {s!r}")
*/
__pyx_t_1 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/datetime.pyx":408
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse date {s!r}")
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 408, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __pyx_t_5 = __Pyx_decode_bytes(__pyx_t_2, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 408, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_s = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":409
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse date {s!r}")             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_date, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 409, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_2);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(1, 409, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":407
 *         cdef const char *end = data + length
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse date {s!r}")
*/
}

/* "psycopg_c/types/datetime.pyx":411
 *             raise e.DataError(f"can't parse date {s!r}")
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._order == ORDER_YMD:
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
  __Pyx_XGOTREF(__pyx_t_9);
  __Pyx_XGOTREF(__pyx_t_10);
  __Pyx_XGOTREF(__pyx_t_11);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":412
 * 
 *         try:
 *             if self._order == ORDER_YMD:             # <<<<<<<<<<<<<<
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
 *             elif self._order == ORDER_DMY:
*/
    switch (__pyx_v_self->_order) {
      case __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD:

      /* "psycopg_c/types/datetime.pyx":413
 *         try:
 *             if self._order == ORDER_YMD:
 *                 return cdt.date_new(vals[0], vals[1], vals[2])             # <<<<<<<<<<<<<<
 *             elif self._order == ORDER_DMY:
 *                 return cdt.date_new(vals[2], vals[1], vals[0])
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_f_7cpython_8datetime_date_new((__pyx_v_vals[0]), (__pyx_v_vals[1]), (__pyx_v_vals[2]))); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 413, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L9_try_return;

      /* "psycopg_c/types/datetime.pyx":412
 * 
 *         try:
 *             if self._order == ORDER_YMD:             # <<<<<<<<<<<<<<
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
 *             elif self._order == ORDER_DMY:
*/
      break;
      case __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY:

      /* "psycopg_c/types/datetime.pyx":415
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
 *             elif self._order == ORDER_DMY:
 *                 return cdt.date_new(vals[2], vals[1], vals[0])             # <<<<<<<<<<<<<<
 *             else:
 *                 return cdt.date_new(vals[2], vals[0], vals[1])
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_f_7cpython_8datetime_date_new((__pyx_v_vals[2]), (__pyx_v_vals[1]), (__pyx_v_vals[0]))); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 415, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L9_try_return;

      /* "psycopg_c/types/datetime.pyx":414
 *             if self._order == ORDER_YMD:
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
 *             elif self._order == ORDER_DMY:             # <<<<<<<<<<<<<<
 *                 return cdt.date_new(vals[2], vals[1], vals[0])
 *             else:
*/
      break;
      default:

      /* "psycopg_c/types/datetime.pyx":417
 *                 return cdt.date_new(vals[2], vals[1], vals[0])
 *             else:
 *                 return cdt.date_new(vals[2], vals[0], vals[1])             # <<<<<<<<<<<<<<
 *         except ValueError as ex:
 *             self._error_date(data, str(ex))
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_5 = ((PyObject *)__pyx_f_7cpython_8datetime_date_new((__pyx_v_vals[2]), (__pyx_v_vals[0]), (__pyx_v_vals[1]))); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 417, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L9_try_return;
      break;
    }

    /* "psycopg_c/types/datetime.pyx":411
 *             raise e.DataError(f"can't parse date {s!r}")
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._order == ORDER_YMD:
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
*/
  }
  __pyx_L5_error:;
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "psycopg_c/types/datetime.pyx":418
 *             else:
 *                 return cdt.date_new(vals[2], vals[0], vals[1])
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             self._error_date(data, str(ex))
 * 
*/
  __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_12) {
    __Pyx_AddTraceback("psycopg_c._psycopg.DateLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(1, 418, __pyx_L7_except_error)
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_v_ex = __pyx_t_7;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":419
 *                 return cdt.date_new(vals[2], vals[0], vals[1])
 *         except ValueError as ex:
 *             self._error_date(data, str(ex))             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_2 = __Pyx_PyObject_Unicode(__pyx_v_ex); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 419, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg_10DateLoader__error_date(__pyx_v_self, __pyx_v_data, ((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 419, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }

    /* "psycopg_c/types/datetime.pyx":418
 *             else:
 *                 return cdt.date_new(vals[2], vals[0], vals[1])
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             self._error_date(data, str(ex))
 * 
*/
    /*finally:*/ {
      /*normal exit:*/{
        __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        goto __pyx_L17;
      }
      __pyx_L16_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
        if ( unlikely(__Pyx_GetException(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17) < 0)) __Pyx_ErrFetch(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_20);
        __pyx_t_12 = __pyx_lineno; __pyx_t_13 = __pyx_clineno; __pyx_t_14 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_ExceptionReset(__pyx_t_18, __pyx_t_19, __pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ErrRestore(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        __pyx_t_15 = 0; __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0;
        __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_13; __pyx_filename = __pyx_t_14;
        goto __pyx_L7_except_error;
      }
      __pyx_L17:;
    }
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    goto __pyx_L6_exception_handled;
  }
  goto __pyx_L7_except_error;

  /* "psycopg_c/types/datetime.pyx":411
 *             raise e.DataError(f"can't parse date {s!r}")
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self._order == ORDER_YMD:
 *                 return cdt.date_new(vals[0], vals[1], vals[2])
*/
  __pyx_L7_except_error:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
  goto __pyx_L1_error;
  __pyx_L9_try_return:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
  goto __pyx_L0;
  __pyx_L6_exception_handled:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
}

/* "psycopg_c/types/datetime.pyx":397
 *             raise e.DataError(f"can't parse date {s!r}: {msg}") from None
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if length != 10:
 *             self._error_date(data, "unexpected length")
*/

/* function exit code */
__pyx_r = Py_None; __Pyx_INCREF(Py_None);
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("psycopg_c._psycopg.DateLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10DateLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10DateLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10DateLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10DateLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10DateLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":427
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16DateBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint32_t __pyx_v_bedata;
int __pyx_v_days;
PyObject *__pyx_v_pydays = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
int __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
int __pyx_t_8;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
size_t __pyx_t_13;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":429
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         cdef int days = endian.be32toh(bedata)
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/datetime.pyx":430
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         cdef int days = endian.be32toh(bedata)             # <<<<<<<<<<<<<<
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
 *         try:
*/
__pyx_v_days = be32toh(__pyx_v_bedata);

/* "psycopg_c/types/datetime.pyx":431
 *         memcpy(&bedata, data, sizeof(bedata))
 *         cdef int days = endian.be32toh(bedata)
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS             # <<<<<<<<<<<<<<
 *         try:
 *             return PyObject_CallFunctionObjArgs(
*/
__pyx_t_1 = __Pyx_PyLong_From_int((__pyx_v_days + __pyx_e_9psycopg_c_8_psycopg_PG_DATE_EPOCH_DAYS)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 431, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_pydays = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":432
 *         cdef int days = endian.be32toh(bedata)
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
 *         try:             # <<<<<<<<<<<<<<
 *             return PyObject_CallFunctionObjArgs(
 *                 date_fromordinal, <PyObject *>pydays, NULL)
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
  __Pyx_XGOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_t_4);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":433
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
 *         try:
 *             return PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 date_fromordinal, <PyObject *>pydays, NULL)
 *         except ValueError:
*/
    __Pyx_XDECREF(__pyx_r);

    /* "psycopg_c/types/datetime.pyx":434
 *         try:
 *             return PyObject_CallFunctionObjArgs(
 *                 date_fromordinal, <PyObject *>pydays, NULL)             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             if days < PY_DATE_MIN_DAYS:
*/
    __pyx_t_1 = __pyx_v_9psycopg_c_8_psycopg_date_fromordinal;
    __Pyx_INCREF(__pyx_t_1);

    /* "psycopg_c/types/datetime.pyx":433
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
 *         try:
 *             return PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 date_fromordinal, <PyObject *>pydays, NULL)
 *         except ValueError:
*/
    __pyx_t_5 = PyObject_CallFunctionObjArgs(__pyx_t_1, ((PyObject *)__pyx_v_pydays), NULL); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 433, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L7_try_return;

    /* "psycopg_c/types/datetime.pyx":432
 *         cdef int days = endian.be32toh(bedata)
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
 *         try:             # <<<<<<<<<<<<<<
 *             return PyObject_CallFunctionObjArgs(
 *                 date_fromordinal, <PyObject *>pydays, NULL)
*/
  }
  __pyx_L3_error:;
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":435
 *             return PyObject_CallFunctionObjArgs(
 *                 date_fromordinal, <PyObject *>pydays, NULL)
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             if days < PY_DATE_MIN_DAYS:
 *                 raise e.DataError("date too small (before year 1)") from None
*/
  __pyx_t_6 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_6) {
    __Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_1, &__pyx_t_7) < 0) __PYX_ERR(1, 435, __pyx_L5_except_error)
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_7);

    /* "psycopg_c/types/datetime.pyx":436
 *                 date_fromordinal, <PyObject *>pydays, NULL)
 *         except ValueError:
 *             if days < PY_DATE_MIN_DAYS:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("date too small (before year 1)") from None
 *             else:
*/
    __pyx_t_8 = (__pyx_v_days < __pyx_e_9psycopg_c_8_psycopg_PY_DATE_MIN_DAYS);
    if (unlikely(__pyx_t_8)) {

      /* "psycopg_c/types/datetime.pyx":437
 *         except ValueError:
 *             if days < PY_DATE_MIN_DAYS:
 *                 raise e.DataError("date too small (before year 1)") from None             # <<<<<<<<<<<<<<
 *             else:
 *                 raise e.DataError("date too large (after year 10K)") from None
*/
      __pyx_t_10 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 437, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 437, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_13 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
        assert(__pyx_t_10);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);
        __pyx_t_13 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_kp_u_date_too_small_before_year_1_2};
        __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 437, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __Pyx_Raise(__pyx_t_9, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(1, 437, __pyx_L5_except_error)

      /* "psycopg_c/types/datetime.pyx":436
 *                 date_fromordinal, <PyObject *>pydays, NULL)
 *         except ValueError:
 *             if days < PY_DATE_MIN_DAYS:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("date too small (before year 1)") from None
 *             else:
*/
    }

    /* "psycopg_c/types/datetime.pyx":439
 *                 raise e.DataError("date too small (before year 1)") from None
 *             else:
 *                 raise e.DataError("date too large (after year 10K)") from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
    /*else*/ {
      __pyx_t_12 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 439, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 439, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_13 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_11))) {
        __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
        assert(__pyx_t_12);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
        __Pyx_INCREF(__pyx_t_12);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
        __pyx_t_13 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_mstate_global->__pyx_kp_u_date_too_large_after_year_10K_2};
        __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 439, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __Pyx_Raise(__pyx_t_9, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __PYX_ERR(1, 439, __pyx_L5_except_error)
    }
  }
  goto __pyx_L5_except_error;

  /* "psycopg_c/types/datetime.pyx":432
 *         cdef int days = endian.be32toh(bedata)
 *         cdef object pydays = days + PG_DATE_EPOCH_DAYS
 *         try:             # <<<<<<<<<<<<<<
 *             return PyObject_CallFunctionObjArgs(
 *                 date_fromordinal, <PyObject *>pydays, NULL)
*/
  __pyx_L5_except_error:;
  __Pyx_XGIVEREF(__pyx_t_2);
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
  goto __pyx_L1_error;
  __pyx_L7_try_return:;
  __Pyx_XGIVEREF(__pyx_t_2);
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":427
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_pydays);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16DateBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16DateBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16DateBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DateBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":447
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[3]
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_10TimeLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
int64_t __pyx_v_vals[3];
char const *__pyx_v_ptr;
char const *__pyx_v_end;
PyObject *__pyx_v_s = NULL;
int __pyx_v_us;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
char const *__pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
size_t __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
char const *__pyx_t_9;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
int __pyx_t_13;
PyObject *__pyx_t_14 = NULL;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17[4];
PyObject *__pyx_t_18 = NULL;
int __pyx_t_19;
char const *__pyx_t_20;
PyObject *__pyx_t_21 = NULL;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
PyObject *__pyx_t_24 = NULL;
PyObject *__pyx_t_25 = NULL;
PyObject *__pyx_t_26 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":450
 * 
 *         cdef int64_t vals[3]
 *         memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 *         cdef const char *ptr
 *         cdef const char *end = data + length
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":452
 *         memset(vals, 0, sizeof(vals))
 *         cdef const char *ptr
 *         cdef const char *end = data + length             # <<<<<<<<<<<<<<
 * 
 *         # Parse the first 3 groups of digits
*/
__pyx_v_end = (__pyx_v_data + __pyx_v_length);

/* "psycopg_c/types/datetime.pyx":455
 * 
 *         # Parse the first 3 groups of digits
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_data, __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_1 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 455, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":456
 *         # Parse the first 3 groups of digits
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse time {s!r}")
*/
__pyx_t_2 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/datetime.pyx":457
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse time {s!r}")
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = __Pyx_decode_bytes(__pyx_t_3, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_s = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":458
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse time {s!r}")             # <<<<<<<<<<<<<<
 * 
 *         # Parse the microseconds
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_time, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 458, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 458, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(1, 458, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":456
 *         # Parse the first 3 groups of digits
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse time {s!r}")
*/
}

/* "psycopg_c/types/datetime.pyx":461
 * 
 *         # Parse the microseconds
 *         cdef int us = 0             # <<<<<<<<<<<<<<
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)
*/
__pyx_v_us = 0;

/* "psycopg_c/types/datetime.pyx":462
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
__pyx_t_2 = ((__pyx_v_ptr[0]) == '.');
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":463
 *         cdef int us = 0
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
  __pyx_t_9 = __pyx_f_9psycopg_c_8_psycopg__parse_micros((__pyx_v_ptr + 1), (&__pyx_v_us)); if (unlikely(__pyx_t_9 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 463, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_9;

  /* "psycopg_c/types/datetime.pyx":462
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":465
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
  __Pyx_XGOTREF(__pyx_t_10);
  __Pyx_XGOTREF(__pyx_t_11);
  __Pyx_XGOTREF(__pyx_t_12);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":466
 * 
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)             # <<<<<<<<<<<<<<
 *         except ValueError as ex:
 *             s = bytes(data).decode("utf8", "replace")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = ((PyObject *)__pyx_f_7cpython_8datetime_time_new((__pyx_v_vals[0]), (__pyx_v_vals[1]), (__pyx_v_vals[2]), __pyx_v_us, Py_None, NULL)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 466, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L9_try_return;

    /* "psycopg_c/types/datetime.pyx":465
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:
*/
  }
  __pyx_L5_error:;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "psycopg_c/types/datetime.pyx":467
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse time {s!r}: {ex}") from None
*/
  __pyx_t_13 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_13) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimeLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_7, &__pyx_t_8) < 0) __PYX_ERR(1, 467, __pyx_L7_except_error)
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_v_ex = __pyx_t_7;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":468
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse time {s!r}: {ex}") from None
 * 
*/
      __pyx_t_4 = NULL;
      __pyx_t_14 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 468, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_6 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_14};
        __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 468, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_3);
      }
      __pyx_t_14 = __Pyx_decode_bytes(__pyx_t_3, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 468, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_s = ((PyObject*)__pyx_t_14);
      __pyx_t_14 = 0;

      /* "psycopg_c/types/datetime.pyx":469
 *         except ValueError as ex:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse time {s!r}: {ex}") from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_3 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 469, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 469, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 469, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_16 = __Pyx_PyObject_FormatSimple(__pyx_v_ex, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 469, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_time;
      __pyx_t_17[1] = __pyx_t_4;
      __pyx_t_17[2] = __pyx_mstate_global->__pyx_kp_u__7;
      __pyx_t_17[3] = __pyx_t_16;
      __pyx_t_18 = __Pyx_PyUnicode_Join(__pyx_t_17, 4, 17 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_16), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_4) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_16));
      if (unlikely(!__pyx_t_18)) __PYX_ERR(1, 469, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_15))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_15);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_15, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_18};
        __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_15, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 469, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_14);
      }
      __Pyx_Raise(__pyx_t_14, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __PYX_ERR(1, 469, __pyx_L16_error)
    }

    /* "psycopg_c/types/datetime.pyx":467
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse time {s!r}: {ex}") from None
*/
    /*finally:*/ {
      __pyx_L16_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_24, &__pyx_t_25, &__pyx_t_26);
        if ( unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_25);
        __Pyx_XGOTREF(__pyx_t_26);
        __pyx_t_13 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_24);
        __Pyx_XGIVEREF(__pyx_t_25);
        __Pyx_XGIVEREF(__pyx_t_26);
        __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_25, __pyx_t_26);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_ErrRestore(__pyx_t_21, __pyx_t_22, __pyx_t_23);
        __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
        __pyx_lineno = __pyx_t_13; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
        goto __pyx_L7_except_error;
      }
    }
  }
  goto __pyx_L7_except_error;

  /* "psycopg_c/types/datetime.pyx":465
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:
*/
  __pyx_L7_except_error:;
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
  goto __pyx_L1_error;
  __pyx_L9_try_return:;
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":447
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[3]
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_XDECREF(__pyx_t_15);
__Pyx_XDECREF(__pyx_t_16);
__Pyx_XDECREF(__pyx_t_18);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TimeLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TimeLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TimeLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TimeLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TimeLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":477
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint64_t __pyx_v_bedata;
int64_t __pyx_v_val;
int __pyx_v_h;
int __pyx_v_m;
int __pyx_v_s;
int __pyx_v_us;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
int __pyx_t_5;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
size_t __pyx_t_13;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":479
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         cdef int64_t val = endian.be64toh(bedata)
 *         cdef int h, m, s, us
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/datetime.pyx":480
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         cdef int64_t val = endian.be64toh(bedata)             # <<<<<<<<<<<<<<
 *         cdef int h, m, s, us
 * 
*/
__pyx_v_val = be64toh(__pyx_v_bedata);

/* "psycopg_c/types/datetime.pyx":484
 * 
 *         with cython.cdivision(True):
 *             us = val % 1_000_000             # <<<<<<<<<<<<<<
 *             val //= 1_000_000
 * 
*/
__pyx_v_us = (__pyx_v_val % 0xF4240);

/* "psycopg_c/types/datetime.pyx":485
 *         with cython.cdivision(True):
 *             us = val % 1_000_000
 *             val //= 1_000_000             # <<<<<<<<<<<<<<
 * 
 *             s = val % 60
*/
__pyx_v_val = (__pyx_v_val / 0xF4240);

/* "psycopg_c/types/datetime.pyx":487
 *             val //= 1_000_000
 * 
 *             s = val % 60             # <<<<<<<<<<<<<<
 *             val //= 60
 * 
*/
__pyx_v_s = (__pyx_v_val % 60);

/* "psycopg_c/types/datetime.pyx":488
 * 
 *             s = val % 60
 *             val //= 60             # <<<<<<<<<<<<<<
 * 
 *             m = val % 60
*/
__pyx_v_val = (__pyx_v_val / 60);

/* "psycopg_c/types/datetime.pyx":490
 *             val //= 60
 * 
 *             m = val % 60             # <<<<<<<<<<<<<<
 *             h = <int>(val // 60)
 * 
*/
__pyx_v_m = (__pyx_v_val % 60);

/* "psycopg_c/types/datetime.pyx":491
 * 
 *             m = val % 60
 *             h = <int>(val // 60)             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
__pyx_v_h = ((int)(__pyx_v_val / 60));

/* "psycopg_c/types/datetime.pyx":493
 *             h = <int>(val // 60)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(h, m, s, us, None)
 *         except ValueError:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
  __Pyx_XGOTREF(__pyx_t_1);
  __Pyx_XGOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_t_3);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":494
 * 
 *         try:
 *             return cdt.time_new(h, m, s, us, None)             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             raise e.DataError(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = ((PyObject *)__pyx_f_7cpython_8datetime_time_new(__pyx_v_h, __pyx_v_m, __pyx_v_s, __pyx_v_us, Py_None, NULL)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 494, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L7_try_return;

    /* "psycopg_c/types/datetime.pyx":493
 *             h = <int>(val // 60)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(h, m, s, us, None)
 *         except ValueError:
*/
  }
  __pyx_L3_error:;
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":495
 *         try:
 *             return cdt.time_new(h, m, s, us, None)
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 f"time not supported by Python: hour={h}"
*/
  __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_5) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 495, __pyx_L5_except_error)
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);

    /* "psycopg_c/types/datetime.pyx":496
 *             return cdt.time_new(h, m, s, us, None)
 *         except ValueError:
 *             raise e.DataError(             # <<<<<<<<<<<<<<
 *                 f"time not supported by Python: hour={h}"
 *             ) from None
*/
    __pyx_t_9 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 496, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 496, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "psycopg_c/types/datetime.pyx":497
 *         except ValueError:
 *             raise e.DataError(
 *                 f"time not supported by Python: hour={h}"             # <<<<<<<<<<<<<<
 *             ) from None
 * 
*/
    __pyx_t_10 = __Pyx_PyUnicode_From_int(__pyx_v_h, 0, ' ', 'd'); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 497, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_12 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_time_not_supported_by_Python_hou, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 497, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_13 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
      assert(__pyx_t_9);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
      __pyx_t_13 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_12};
      __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 496, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
    }

    /* "psycopg_c/types/datetime.pyx":498
 *             raise e.DataError(
 *                 f"time not supported by Python: hour={h}"
 *             ) from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_Raise(__pyx_t_8, 0, 0, Py_None);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(1, 496, __pyx_L5_except_error)
  }
  goto __pyx_L5_except_error;

  /* "psycopg_c/types/datetime.pyx":493
 *             h = <int>(val // 60)
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(h, m, s, us, None)
 *         except ValueError:
*/
  __pyx_L5_except_error:;
  __Pyx_XGIVEREF(__pyx_t_1);
  __Pyx_XGIVEREF(__pyx_t_2);
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  goto __pyx_L1_error;
  __pyx_L7_try_return:;
  __Pyx_XGIVEREF(__pyx_t_1);
  __Pyx_XGIVEREF(__pyx_t_2);
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":477
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TimeBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimeBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":506
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[3]
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_12TimetzLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
int64_t __pyx_v_vals[3];
char const *__pyx_v_ptr;
char const *__pyx_v_end;
PyObject *__pyx_v_s = NULL;
int __pyx_v_us;
int __pyx_v_offsecs;
PyObject *__pyx_v_tz = NULL;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
char const *__pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
size_t __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
char const *__pyx_t_9;
int __pyx_t_10;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17[4];
PyObject *__pyx_t_18 = NULL;
int __pyx_t_19;
char const *__pyx_t_20;
PyObject *__pyx_t_21 = NULL;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
PyObject *__pyx_t_24 = NULL;
PyObject *__pyx_t_25 = NULL;
PyObject *__pyx_t_26 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":509
 * 
 *         cdef int64_t vals[3]
 *         memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 *         cdef const char *ptr
 *         cdef const char *end = data + length
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":511
 *         memset(vals, 0, sizeof(vals))
 *         cdef const char *ptr
 *         cdef const char *end = data + length             # <<<<<<<<<<<<<<
 * 
 *         # Parse the first 3 groups of digits (time)
*/
__pyx_v_end = (__pyx_v_data + __pyx_v_length);

/* "psycopg_c/types/datetime.pyx":514
 * 
 *         # Parse the first 3 groups of digits (time)
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_data, __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_1 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 514, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":515
 *         # Parse the first 3 groups of digits (time)
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}")
*/
__pyx_t_2 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/datetime.pyx":516
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse timetz {s!r}")
 * 
*/
  __pyx_t_4 = NULL;
  __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = __Pyx_decode_bytes(__pyx_t_3, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 516, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_s = ((PyObject*)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":517
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}")             # <<<<<<<<<<<<<<
 * 
 *         # Parse the microseconds
*/
  __pyx_t_3 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_timetz, __pyx_t_4); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_3);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(1, 517, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":515
 *         # Parse the first 3 groups of digits (time)
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}")
*/
}

/* "psycopg_c/types/datetime.pyx":520
 * 
 *         # Parse the microseconds
 *         cdef int us = 0             # <<<<<<<<<<<<<<
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)
*/
__pyx_v_us = 0;

/* "psycopg_c/types/datetime.pyx":521
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
__pyx_t_2 = ((__pyx_v_ptr[0]) == '.');
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":522
 *         cdef int us = 0
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)             # <<<<<<<<<<<<<<
 * 
 *         # Parse the timezone
*/
  __pyx_t_9 = __pyx_f_9psycopg_c_8_psycopg__parse_micros((__pyx_v_ptr + 1), (&__pyx_v_us)); if (unlikely(__pyx_t_9 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 522, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_9;

  /* "psycopg_c/types/datetime.pyx":521
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":525
 * 
 *         # Parse the timezone
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
*/
__pyx_t_10 = __pyx_f_9psycopg_c_8_psycopg__parse_timezone_to_seconds((&__pyx_v_ptr), __pyx_v_end); if (unlikely(__pyx_t_10 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(1, 525, __pyx_L1_error)
__pyx_v_offsecs = __pyx_t_10;

/* "psycopg_c/types/datetime.pyx":526
 *         # Parse the timezone
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}")
*/
__pyx_t_2 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/datetime.pyx":527
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse timetz {s!r}")
 * 
*/
  __pyx_t_7 = NULL;
  __pyx_t_8 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_6 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_8};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 527, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_8 = __Pyx_decode_bytes(__pyx_t_5, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_s = ((PyObject*)__pyx_t_8);
  __pyx_t_8 = 0;

  /* "psycopg_c/types/datetime.pyx":528
 *         if ptr == NULL:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}")             # <<<<<<<<<<<<<<
 * 
 *         tz = _timezone_from_seconds(offsecs)
*/
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_timetz, __pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 528, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_6 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
    __pyx_t_6 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_4};
    __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 528, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
  }
  __Pyx_Raise(__pyx_t_8, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __PYX_ERR(1, 528, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":526
 *         # Parse the timezone
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}")
*/
}

/* "psycopg_c/types/datetime.pyx":530
 *             raise e.DataError(f"can't parse timetz {s!r}")
 * 
 *         tz = _timezone_from_seconds(offsecs)             # <<<<<<<<<<<<<<
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
*/
__pyx_t_8 = __pyx_f_9psycopg_c_8_psycopg__timezone_from_seconds(__pyx_v_offsecs, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 530, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_8);
__pyx_v_tz = __pyx_t_8;
__pyx_t_8 = 0;

/* "psycopg_c/types/datetime.pyx":531
 * 
 *         tz = _timezone_from_seconds(offsecs)
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
 *         except ValueError as ex:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
  __Pyx_XGOTREF(__pyx_t_11);
  __Pyx_XGOTREF(__pyx_t_12);
  __Pyx_XGOTREF(__pyx_t_13);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":532
 *         tz = _timezone_from_seconds(offsecs)
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)             # <<<<<<<<<<<<<<
 *         except ValueError as ex:
 *             s = bytes(data).decode("utf8", "replace")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_8 = ((PyObject *)__pyx_f_7cpython_8datetime_time_new((__pyx_v_vals[0]), (__pyx_v_vals[1]), (__pyx_v_vals[2]), __pyx_v_us, __pyx_v_tz, NULL)); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 532, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_r = __pyx_t_8;
    __pyx_t_8 = 0;
    goto __pyx_L10_try_return;

    /* "psycopg_c/types/datetime.pyx":531
 * 
 *         tz = _timezone_from_seconds(offsecs)
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
 *         except ValueError as ex:
*/
  }
  __pyx_L6_error:;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "psycopg_c/types/datetime.pyx":533
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}: {ex}") from None
*/
  __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_10) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimetzLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_8, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(1, 533, __pyx_L8_except_error)
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_ex = __pyx_t_3;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":534
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
 *         except ValueError as ex:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse timetz {s!r}: {ex}") from None
 * 
*/
      __pyx_t_7 = NULL;
      __pyx_t_14 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 534, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_14);
      __pyx_t_6 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_14};
        __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 534, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_5);
      }
      __pyx_t_14 = __Pyx_decode_bytes(__pyx_t_5, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 534, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_v_s = ((PyObject*)__pyx_t_14);
      __pyx_t_14 = 0;

      /* "psycopg_c/types/datetime.pyx":535
 *         except ValueError as ex:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}: {ex}") from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_5 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 535, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_15 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 535, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 535, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_16 = __Pyx_PyObject_FormatSimple(__pyx_v_ex, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 535, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_timetz;
      __pyx_t_17[1] = __pyx_t_7;
      __pyx_t_17[2] = __pyx_mstate_global->__pyx_kp_u__7;
      __pyx_t_17[3] = __pyx_t_16;
      __pyx_t_18 = __Pyx_PyUnicode_Join(__pyx_t_17, 4, 19 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_16), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_16));
      if (unlikely(!__pyx_t_18)) __PYX_ERR(1, 535, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_18);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __pyx_t_6 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_15))) {
        __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_15);
        assert(__pyx_t_5);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_15);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_15, __pyx__function);
        __pyx_t_6 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_18};
        __pyx_t_14 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_15, __pyx_callargs+__pyx_t_6, (2-__pyx_t_6) | (__pyx_t_6*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 535, __pyx_L17_error)
        __Pyx_GOTREF(__pyx_t_14);
      }
      __Pyx_Raise(__pyx_t_14, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __PYX_ERR(1, 535, __pyx_L17_error)
    }

    /* "psycopg_c/types/datetime.pyx":533
 *         try:
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse timetz {s!r}: {ex}") from None
*/
    /*finally:*/ {
      __pyx_L17_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_24, &__pyx_t_25, &__pyx_t_26);
        if ( unlikely(__Pyx_GetException(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23) < 0)) __Pyx_ErrFetch(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_25);
        __Pyx_XGOTREF(__pyx_t_26);
        __pyx_t_10 = __pyx_lineno; __pyx_t_19 = __pyx_clineno; __pyx_t_20 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_24);
        __Pyx_XGIVEREF(__pyx_t_25);
        __Pyx_XGIVEREF(__pyx_t_26);
        __Pyx_ExceptionReset(__pyx_t_24, __pyx_t_25, __pyx_t_26);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_ErrRestore(__pyx_t_21, __pyx_t_22, __pyx_t_23);
        __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0;
        __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_19; __pyx_filename = __pyx_t_20;
        goto __pyx_L8_except_error;
      }
    }
  }
  goto __pyx_L8_except_error;

  /* "psycopg_c/types/datetime.pyx":531
 * 
 *         tz = _timezone_from_seconds(offsecs)
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(vals[0], vals[1], vals[2], us, tz)
 *         except ValueError as ex:
*/
  __pyx_L8_except_error:;
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_XGIVEREF(__pyx_t_13);
  __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
  goto __pyx_L1_error;
  __pyx_L10_try_return:;
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_XGIVEREF(__pyx_t_13);
  __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":506
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[3]
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_XDECREF(__pyx_t_15);
__Pyx_XDECREF(__pyx_t_16);
__Pyx_XDECREF(__pyx_t_18);
__Pyx_AddTraceback("psycopg_c._psycopg.TimetzLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_tz);
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12TimetzLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12TimetzLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimetzLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimetzLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12TimetzLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12TimetzLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12TimetzLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimetzLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":543
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_18TimetzBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint64_t __pyx_v_beval;
int64_t __pyx_v_val;
uint32_t __pyx_v_beoff;
int32_t __pyx_v_off;
int __pyx_v_h;
int __pyx_v_m;
int __pyx_v_s;
int __pyx_v_us;
PyObject *__pyx_v_tz = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
int __pyx_t_5;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
size_t __pyx_t_13;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":545
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))             # <<<<<<<<<<<<<<
 *         cdef int64_t val = endian.be64toh(beval)
 * 
*/
(void)(memcpy((&__pyx_v_beval), __pyx_v_data, (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/datetime.pyx":546
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))
 *         cdef int64_t val = endian.be64toh(beval)             # <<<<<<<<<<<<<<
 * 
 *         cdef uint32_t beoff
*/
__pyx_v_val = be64toh(__pyx_v_beval);

/* "psycopg_c/types/datetime.pyx":549
 * 
 *         cdef uint32_t beoff
 *         memcpy(&beoff, data + sizeof(beval), sizeof(beoff))             # <<<<<<<<<<<<<<
 *         cdef int32_t off = endian.be32toh(beoff)
 * 
*/
(void)(memcpy((&__pyx_v_beoff), (__pyx_v_data + (sizeof(__pyx_v_beval))), (sizeof(__pyx_v_beoff))));

/* "psycopg_c/types/datetime.pyx":550
 *         cdef uint32_t beoff
 *         memcpy(&beoff, data + sizeof(beval), sizeof(beoff))
 *         cdef int32_t off = endian.be32toh(beoff)             # <<<<<<<<<<<<<<
 * 
 *         cdef int h, m, s, us
*/
__pyx_v_off = be32toh(__pyx_v_beoff);

/* "psycopg_c/types/datetime.pyx":555
 * 
 *         with cython.cdivision(True):
 *             us = val % 1_000_000             # <<<<<<<<<<<<<<
 *             val //= 1_000_000
 * 
*/
__pyx_v_us = (__pyx_v_val % 0xF4240);

/* "psycopg_c/types/datetime.pyx":556
 *         with cython.cdivision(True):
 *             us = val % 1_000_000
 *             val //= 1_000_000             # <<<<<<<<<<<<<<
 * 
 *             s = val % 60
*/
__pyx_v_val = (__pyx_v_val / 0xF4240);

/* "psycopg_c/types/datetime.pyx":558
 *             val //= 1_000_000
 * 
 *             s = val % 60             # <<<<<<<<<<<<<<
 *             val //= 60
 * 
*/
__pyx_v_s = (__pyx_v_val % 60);

/* "psycopg_c/types/datetime.pyx":559
 * 
 *             s = val % 60
 *             val //= 60             # <<<<<<<<<<<<<<
 * 
 *             m = val % 60
*/
__pyx_v_val = (__pyx_v_val / 60);

/* "psycopg_c/types/datetime.pyx":561
 *             val //= 60
 * 
 *             m = val % 60             # <<<<<<<<<<<<<<
 *             h = <int>(val // 60)
 * 
*/
__pyx_v_m = (__pyx_v_val % 60);

/* "psycopg_c/types/datetime.pyx":562
 * 
 *             m = val % 60
 *             h = <int>(val // 60)             # <<<<<<<<<<<<<<
 * 
 *         tz = _timezone_from_seconds(-off)
*/
__pyx_v_h = ((int)(__pyx_v_val / 60));

/* "psycopg_c/types/datetime.pyx":564
 *             h = <int>(val // 60)
 * 
 *         tz = _timezone_from_seconds(-off)             # <<<<<<<<<<<<<<
 *         try:
 *             return cdt.time_new(h, m, s, us, tz)
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg__timezone_from_seconds((-__pyx_v_off), NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 564, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_tz = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":565
 * 
 *         tz = _timezone_from_seconds(-off)
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(h, m, s, us, tz)
 *         except ValueError:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
  __Pyx_XGOTREF(__pyx_t_2);
  __Pyx_XGOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_t_4);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":566
 *         tz = _timezone_from_seconds(-off)
 *         try:
 *             return cdt.time_new(h, m, s, us, tz)             # <<<<<<<<<<<<<<
 *         except ValueError:
 *             raise e.DataError(
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = ((PyObject *)__pyx_f_7cpython_8datetime_time_new(__pyx_v_h, __pyx_v_m, __pyx_v_s, __pyx_v_us, __pyx_v_tz, NULL)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 566, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L7_try_return;

    /* "psycopg_c/types/datetime.pyx":565
 * 
 *         tz = _timezone_from_seconds(-off)
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(h, m, s, us, tz)
 *         except ValueError:
*/
  }
  __pyx_L3_error:;
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "psycopg_c/types/datetime.pyx":567
 *         try:
 *             return cdt.time_new(h, m, s, us, tz)
 *         except ValueError:             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 f"time not supported by Python: hour={h}"
*/
  __pyx_t_5 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_5) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimetzBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_1, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(1, 567, __pyx_L5_except_error)
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_7);

    /* "psycopg_c/types/datetime.pyx":568
 *             return cdt.time_new(h, m, s, us, tz)
 *         except ValueError:
 *             raise e.DataError(             # <<<<<<<<<<<<<<
 *                 f"time not supported by Python: hour={h}"
 *             ) from None
*/
    __pyx_t_9 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 568, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 568, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "psycopg_c/types/datetime.pyx":569
 *         except ValueError:
 *             raise e.DataError(
 *                 f"time not supported by Python: hour={h}"             # <<<<<<<<<<<<<<
 *             ) from None
 * 
*/
    __pyx_t_10 = __Pyx_PyUnicode_From_int(__pyx_v_h, 0, ' ', 'd'); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 569, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_10);
    __pyx_t_12 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_time_not_supported_by_Python_hou, __pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 569, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    __pyx_t_13 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_11))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_11);
      assert(__pyx_t_9);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
      __pyx_t_13 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_12};
      __pyx_t_8 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_13, (2-__pyx_t_13) | (__pyx_t_13*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 568, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
    }

    /* "psycopg_c/types/datetime.pyx":570
 *             raise e.DataError(
 *                 f"time not supported by Python: hour={h}"
 *             ) from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_Raise(__pyx_t_8, 0, 0, Py_None);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __PYX_ERR(1, 568, __pyx_L5_except_error)
  }
  goto __pyx_L5_except_error;

  /* "psycopg_c/types/datetime.pyx":565
 * 
 *         tz = _timezone_from_seconds(-off)
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.time_new(h, m, s, us, tz)
 *         except ValueError:
*/
  __pyx_L5_except_error:;
  __Pyx_XGIVEREF(__pyx_t_2);
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
  goto __pyx_L1_error;
  __pyx_L7_try_return:;
  __Pyx_XGIVEREF(__pyx_t_2);
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":543
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_AddTraceback("psycopg_c._psycopg.TimetzBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_tz);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18TimetzBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18TimetzBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimetzBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimetzBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18TimetzBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18TimetzBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18TimetzBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimetzBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":579
 *     cdef int _order
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 579, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 579, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 579, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(1, 579, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(1, 579, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 579, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 579, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(1, 579, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(1, 579, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(1, 579, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_ds;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
int __pyx_t_3;
int __pyx_t_4;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
Py_ssize_t __pyx_t_8;
PyObject *__pyx_t_9 = NULL;
size_t __pyx_t_10;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/datetime.pyx":581
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)             # <<<<<<<<<<<<<<
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
*/
__pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_datestyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 581, __pyx_L1_error)
__pyx_v_ds = __pyx_t_2;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":582
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO             # <<<<<<<<<<<<<<
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'I');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":583
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD             # <<<<<<<<<<<<<<
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY
*/
  __pyx_v_self->_order = __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD;

  /* "psycopg_c/types/datetime.pyx":582
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO             # <<<<<<<<<<<<<<
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":584
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'G');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":585
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY             # <<<<<<<<<<<<<<
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
*/
  __pyx_v_self->_order = __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY;

  /* "psycopg_c/types/datetime.pyx":584
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
 *         elif ds[0] == b'G':  # German             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":586
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'S');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":587
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY             # <<<<<<<<<<<<<<
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
 *             self._order = ORDER_PGDM if ds[10] == b'D' else ORDER_PGMD
*/
  __pyx_t_3 = ((__pyx_v_ds[5]) == 'D');
  if (__pyx_t_3) {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY;
  } else {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_MDY;
  }
  __pyx_v_self->_order = __pyx_t_4;

  /* "psycopg_c/types/datetime.pyx":586
 *         elif ds[0] == b'G':  # German
 *             self._order = ORDER_DMY
 *         elif ds[0] == b'S':  # SQL, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":588
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_PGDM if ds[10] == b'D' else ORDER_PGMD
 *         else:
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'P');
if (likely(__pyx_t_3)) {

  /* "psycopg_c/types/datetime.pyx":589
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY
 *             self._order = ORDER_PGDM if ds[10] == b'D' else ORDER_PGMD             # <<<<<<<<<<<<<<
 *         else:
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")
*/
  __pyx_t_3 = ((__pyx_v_ds[10]) == 'D');
  if (__pyx_t_3) {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_PGDM;
  } else {
    __pyx_t_4 = __pyx_e_9psycopg_c_8_psycopg_ORDER_PGMD;
  }
  __pyx_v_self->_order = __pyx_t_4;

  /* "psycopg_c/types/datetime.pyx":588
 *         elif ds[0] == b'S':  # SQL, DMY / MDY
 *             self._order = ORDER_DMY if ds[5] == b'D' else ORDER_MDY
 *         elif ds[0] == b'P':  # Postgres, DMY / MDY             # <<<<<<<<<<<<<<
 *             self._order = ORDER_PGDM if ds[10] == b'D' else ORDER_PGMD
 *         else:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":591
 *             self._order = ORDER_PGDM if ds[10] == b'D' else ORDER_PGMD
 *         else:
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
/*else*/ {
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_InterfaceError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_ssize_strlen(__pyx_v_ds); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(1, 591, __pyx_L1_error)
  __pyx_t_6 = __Pyx_decode_c_string(__pyx_v_ds, 0, __pyx_t_8, NULL, NULL, PyUnicode_DecodeASCII); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_unexpected_DateStyle, __pyx_t_6); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_10 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_10 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_9};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_10, (2-__pyx_t_10) | (__pyx_t_10*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 591, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __Pyx_Raise(__pyx_t_1, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __PYX_ERR(1, 591, __pyx_L1_error)
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":579
 *     cdef int _order
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":593
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
char const *__pyx_v_end;
int64_t __pyx_v_vals[6];
char const *__pyx_v_ptr;
int __pyx_v_us;
int __pyx_v_y;
int __pyx_v_m;
int __pyx_v_d;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
char const *__pyx_t_4;
char const *__pyx_t_5;
int64_t __pyx_t_6;
int64_t __pyx_t_7;
int64_t __pyx_t_8;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
int __pyx_t_12;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error __pyx_t_17;
int __pyx_t_18;
char const *__pyx_t_19;
PyObject *__pyx_t_20 = NULL;
PyObject *__pyx_t_21 = NULL;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
PyObject *__pyx_t_24 = NULL;
PyObject *__pyx_t_25 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":594
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef const char *end = data + length             # <<<<<<<<<<<<<<
 *         if end[-1] == b'C':  # ends with BC
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_v_end = (__pyx_v_data + __pyx_v_length);

/* "psycopg_c/types/datetime.pyx":595
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_1 = ((__pyx_v_end[-1L]) == 'C');
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/datetime.pyx":596
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         if self._order == ORDER_PGDM or self._order == ORDER_PGMD:
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_2), __pyx_v_data, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(1, 596, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":595
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":598
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
 *         if self._order == ORDER_PGDM or self._order == ORDER_PGMD:             # <<<<<<<<<<<<<<
 *             return self._cload_pg(data, end)
 * 
*/
switch (__pyx_v_self->_order) {
  case __pyx_e_9psycopg_c_8_psycopg_ORDER_PGDM:
  case __pyx_e_9psycopg_c_8_psycopg_ORDER_PGMD:

  /* "psycopg_c/types/datetime.pyx":599
 * 
 *         if self._order == ORDER_PGDM or self._order == ORDER_PGMD:
 *             return self._cload_pg(data, end)             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[6]
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg_15TimestampLoader__cload_pg(__pyx_v_self, __pyx_v_data, __pyx_v_end); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 599, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":598
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
 *         if self._order == ORDER_PGDM or self._order == ORDER_PGMD:             # <<<<<<<<<<<<<<
 *             return self._cload_pg(data, end)
 * 
*/
  break;
  default: break;
}

/* "psycopg_c/types/datetime.pyx":602
 * 
 *         cdef int64_t vals[6]
 *         memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 *         cdef const char *ptr
 * 
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":606
 * 
 *         # Parse the first 6 groups of digits (date and time)
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_data, __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_4 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 606, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_4;

/* "psycopg_c/types/datetime.pyx":607
 *         # Parse the first 6 groups of digits (date and time)
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_1 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/datetime.pyx":608
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         # Parse the microseconds
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3), __pyx_v_data, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 608, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(1, 608, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":607
 *         # Parse the first 6 groups of digits (date and time)
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":611
 * 
 *         # Parse the microseconds
 *         cdef int us = 0             # <<<<<<<<<<<<<<
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)
*/
__pyx_v_us = 0;

/* "psycopg_c/types/datetime.pyx":612
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
__pyx_t_1 = ((__pyx_v_ptr[0]) == '.');
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":613
 *         cdef int us = 0
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)             # <<<<<<<<<<<<<<
 * 
 *         # Resolve the YMD order
*/
  __pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__parse_micros((__pyx_v_ptr + 1), (&__pyx_v_us)); if (unlikely(__pyx_t_5 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 613, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_5;

  /* "psycopg_c/types/datetime.pyx":612
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":617
 *         # Resolve the YMD order
 *         cdef int y, m, d
 *         if self._order == ORDER_YMD:             # <<<<<<<<<<<<<<
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:
*/
switch (__pyx_v_self->_order) {
  case __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD:

  /* "psycopg_c/types/datetime.pyx":618
 *         cdef int y, m, d
 *         if self._order == ORDER_YMD:
 *             y, m, d = vals[0], vals[1], vals[2]             # <<<<<<<<<<<<<<
 *         elif self._order == ORDER_DMY:
 *             d, m, y = vals[0], vals[1], vals[2]
*/
  __pyx_t_6 = (__pyx_v_vals[0]);
  __pyx_t_7 = (__pyx_v_vals[1]);
  __pyx_t_8 = (__pyx_v_vals[2]);
  __pyx_v_y = __pyx_t_6;
  __pyx_v_m = __pyx_t_7;
  __pyx_v_d = __pyx_t_8;

  /* "psycopg_c/types/datetime.pyx":617
 *         # Resolve the YMD order
 *         cdef int y, m, d
 *         if self._order == ORDER_YMD:             # <<<<<<<<<<<<<<
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:
*/
  break;
  case __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY:

  /* "psycopg_c/types/datetime.pyx":620
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:
 *             d, m, y = vals[0], vals[1], vals[2]             # <<<<<<<<<<<<<<
 *         else:  # self._order == ORDER_MDY
 *             m, d, y = vals[0], vals[1], vals[2]
*/
  __pyx_t_8 = (__pyx_v_vals[0]);
  __pyx_t_7 = (__pyx_v_vals[1]);
  __pyx_t_6 = (__pyx_v_vals[2]);
  __pyx_v_d = __pyx_t_8;
  __pyx_v_m = __pyx_t_7;
  __pyx_v_y = __pyx_t_6;

  /* "psycopg_c/types/datetime.pyx":619
 *         if self._order == ORDER_YMD:
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:             # <<<<<<<<<<<<<<
 *             d, m, y = vals[0], vals[1], vals[2]
 *         else:  # self._order == ORDER_MDY
*/
  break;
  default:

  /* "psycopg_c/types/datetime.pyx":622
 *             d, m, y = vals[0], vals[1], vals[2]
 *         else:  # self._order == ORDER_MDY
 *             m, d, y = vals[0], vals[1], vals[2]             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
  __pyx_t_6 = (__pyx_v_vals[0]);
  __pyx_t_7 = (__pyx_v_vals[1]);
  __pyx_t_8 = (__pyx_v_vals[2]);
  __pyx_v_m = __pyx_t_6;
  __pyx_v_d = __pyx_t_7;
  __pyx_v_y = __pyx_t_8;
  break;
}

/* "psycopg_c/types/datetime.pyx":624
 *             m, d, y = vals[0], vals[1], vals[2]
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
  __Pyx_XGOTREF(__pyx_t_9);
  __Pyx_XGOTREF(__pyx_t_10);
  __Pyx_XGOTREF(__pyx_t_11);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":625
 * 
 *         try:
 *             return cdt.datetime_new(             # <<<<<<<<<<<<<<
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
 *         except ValueError as ex:
*/
    __Pyx_XDECREF(__pyx_r);

    /* "psycopg_c/types/datetime.pyx":626
 *         try:
 *             return cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)             # <<<<<<<<<<<<<<
 *         except ValueError as ex:
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_7cpython_8datetime_datetime_new(__pyx_v_y, __pyx_v_m, __pyx_v_d, (__pyx_v_vals[3]), (__pyx_v_vals[4]), (__pyx_v_vals[5]), __pyx_v_us, Py_None, NULL)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 625, __pyx_L6_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L10_try_return;

    /* "psycopg_c/types/datetime.pyx":624
 *             m, d, y = vals[0], vals[1], vals[2]
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
*/
  }
  __pyx_L6_error:;
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "psycopg_c/types/datetime.pyx":627
 *             return cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
*/
  __pyx_t_12 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_12) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_3, &__pyx_t_13) < 0) __PYX_ERR(1, 627, __pyx_L8_except_error)
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_ex = __pyx_t_3;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":628
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
 *         except ValueError as ex:
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None             # <<<<<<<<<<<<<<
 * 
 *     cdef object _cload_pg(self, const char *data, const char *end):
*/
      __pyx_t_14 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
      __Pyx_INCREF(__pyx_t_14);
      __pyx_t_15 = __pyx_v_ex;
      __Pyx_INCREF(__pyx_t_15);
      if (!(likely(__Pyx_PyException_Check(__pyx_t_15))||((__pyx_t_15) == Py_None) || __Pyx_RaiseUnexpectedTypeError("Exception", __pyx_t_15))) __PYX_ERR(1, 628, __pyx_L17_error)
      __pyx_t_17.__pyx_n = 1;
      __pyx_t_17.ex = ((PyObject*)__pyx_t_15);
      __pyx_t_16 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_14), __pyx_v_data, &__pyx_t_17); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 628, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __Pyx_Raise(__pyx_t_16, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      __PYX_ERR(1, 628, __pyx_L17_error)
    }

    /* "psycopg_c/types/datetime.pyx":627
 *             return cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
*/
    /*finally:*/ {
      __pyx_L17_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_23, &__pyx_t_24, &__pyx_t_25);
        if ( unlikely(__Pyx_GetException(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22) < 0)) __Pyx_ErrFetch(&__pyx_t_20, &__pyx_t_21, &__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_25);
        __pyx_t_12 = __pyx_lineno; __pyx_t_18 = __pyx_clineno; __pyx_t_19 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_XGIVEREF(__pyx_t_24);
        __Pyx_XGIVEREF(__pyx_t_25);
        __Pyx_ExceptionReset(__pyx_t_23, __pyx_t_24, __pyx_t_25);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_ErrRestore(__pyx_t_20, __pyx_t_21, __pyx_t_22);
        __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0;
        __pyx_lineno = __pyx_t_12; __pyx_clineno = __pyx_t_18; __pyx_filename = __pyx_t_19;
        goto __pyx_L8_except_error;
      }
    }
  }
  goto __pyx_L8_except_error;

  /* "psycopg_c/types/datetime.pyx":624
 *             m, d, y = vals[0], vals[1], vals[2]
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, None)
*/
  __pyx_L8_except_error:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
  goto __pyx_L1_error;
  __pyx_L10_try_return:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_10, __pyx_t_11);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":593
 *             raise e.InterfaceError(f"unexpected DateStyle: {ds.decode('ascii')}")
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_XDECREF(__pyx_t_15);
__Pyx_XDECREF(__pyx_t_16);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":630
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
 *     cdef object _cload_pg(self, const char *data, const char *end):             # <<<<<<<<<<<<<<
 *         cdef int64_t vals[4]
 *         memset(vals, 0, sizeof(vals))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader__cload_pg(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, char const *__pyx_v_data, char const *__pyx_v_end) {
int64_t __pyx_v_vals[4];
char const *__pyx_v_ptr;
char *__pyx_v_seps[3];
int __pyx_v_us;
int __pyx_v_m;
int __pyx_v_d;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
char *__pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
char const *__pyx_t_5;
char const *__pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
int __pyx_t_10;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error __pyx_t_15;
int __pyx_t_16;
char const *__pyx_t_17;
PyObject *__pyx_t_18 = NULL;
PyObject *__pyx_t_19 = NULL;
PyObject *__pyx_t_20 = NULL;
PyObject *__pyx_t_21 = NULL;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
char const *__pyx_t_24;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_cload_pg", 0);

/* "psycopg_c/types/datetime.pyx":632
 *     cdef object _cload_pg(self, const char *data, const char *end):
 *         cdef int64_t vals[4]
 *         memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 *         cdef const char *ptr
 * 
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":637
 *         # Find Wed Jun 02 or Wed 02 Jun
 *         cdef char *seps[3]
 *         seps[0] = strchr(data, b' ')             # <<<<<<<<<<<<<<
 *         seps[1] = strchr(seps[0] + 1, b' ') if seps[0] != NULL else NULL
 *         seps[2] = strchr(seps[1] + 1, b' ') if seps[1] != NULL else NULL
*/
(__pyx_v_seps[0]) = strchr(__pyx_v_data, ' ');

/* "psycopg_c/types/datetime.pyx":638
 *         cdef char *seps[3]
 *         seps[0] = strchr(data, b' ')
 *         seps[1] = strchr(seps[0] + 1, b' ') if seps[0] != NULL else NULL             # <<<<<<<<<<<<<<
 *         seps[2] = strchr(seps[1] + 1, b' ') if seps[1] != NULL else NULL
 *         if seps[2] == NULL:
*/
__pyx_t_2 = ((__pyx_v_seps[0]) != NULL);
if (__pyx_t_2) {
  __pyx_t_1 = strchr(((__pyx_v_seps[0]) + 1), ' ');
} else {
  __pyx_t_1 = NULL;
}
(__pyx_v_seps[1]) = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":639
 *         seps[0] = strchr(data, b' ')
 *         seps[1] = strchr(seps[0] + 1, b' ') if seps[0] != NULL else NULL
 *         seps[2] = strchr(seps[1] + 1, b' ') if seps[1] != NULL else NULL             # <<<<<<<<<<<<<<
 *         if seps[2] == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_t_2 = ((__pyx_v_seps[1]) != NULL);
if (__pyx_t_2) {
  __pyx_t_1 = strchr(((__pyx_v_seps[1]) + 1), ' ');
} else {
  __pyx_t_1 = NULL;
}
(__pyx_v_seps[2]) = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":640
 *         seps[1] = strchr(seps[0] + 1, b' ') if seps[0] != NULL else NULL
 *         seps[2] = strchr(seps[1] + 1, b' ') if seps[1] != NULL else NULL
 *         if seps[2] == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_2 = ((__pyx_v_seps[2]) == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/datetime.pyx":641
 *         seps[2] = strchr(seps[1] + 1, b' ') if seps[1] != NULL else NULL
 *         if seps[2] == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         # Parse the following 3 groups of digits (time)
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3), __pyx_v_data, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_Raise(__pyx_t_4, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(1, 641, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":640
 *         seps[1] = strchr(seps[0] + 1, b' ') if seps[0] != NULL else NULL
 *         seps[2] = strchr(seps[1] + 1, b' ') if seps[1] != NULL else NULL
 *         if seps[2] == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":644
 * 
 *         # Parse the following 3 groups of digits (time)
 *         ptr = _parse_date_values(seps[2] + 1, end, vals, 3)             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(((__pyx_v_seps[2]) + 1), __pyx_v_end, __pyx_v_vals, 3); if (unlikely(__pyx_t_5 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 644, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_5;

/* "psycopg_c/types/datetime.pyx":645
 *         # Parse the following 3 groups of digits (time)
 *         ptr = _parse_date_values(seps[2] + 1, end, vals, 3)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_2 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/datetime.pyx":646
 *         ptr = _parse_date_values(seps[2] + 1, end, vals, 3)
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         # Parse the microseconds
*/
  __pyx_t_4 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_4), __pyx_v_data, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(1, 646, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":645
 *         # Parse the following 3 groups of digits (time)
 *         ptr = _parse_date_values(seps[2] + 1, end, vals, 3)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":649
 * 
 *         # Parse the microseconds
 *         cdef int us = 0             # <<<<<<<<<<<<<<
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)
*/
__pyx_v_us = 0;

/* "psycopg_c/types/datetime.pyx":650
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
__pyx_t_2 = ((__pyx_v_ptr[0]) == '.');
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":651
 *         cdef int us = 0
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)             # <<<<<<<<<<<<<<
 * 
 *         # Parse the year
*/
  __pyx_t_6 = __pyx_f_9psycopg_c_8_psycopg__parse_micros((__pyx_v_ptr + 1), (&__pyx_v_us)); if (unlikely(__pyx_t_6 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 651, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_6;

  /* "psycopg_c/types/datetime.pyx":650
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":654
 * 
 *         # Parse the year
 *         ptr = _parse_date_values(ptr + 1, end, vals + 3, 1)             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values((__pyx_v_ptr + 1), __pyx_v_end, (__pyx_v_vals + 3), 1); if (unlikely(__pyx_t_5 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 654, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_5;

/* "psycopg_c/types/datetime.pyx":655
 *         # Parse the year
 *         ptr = _parse_date_values(ptr + 1, end, vals + 3, 1)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_2 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/datetime.pyx":656
 *         ptr = _parse_date_values(ptr + 1, end, vals + 3, 1)
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         # Resolve the MD order
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3), __pyx_v_data, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_Raise(__pyx_t_4, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(1, 656, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":655
 *         # Parse the year
 *         ptr = _parse_date_values(ptr + 1, end, vals + 3, 1)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":660
 *         # Resolve the MD order
 *         cdef int m, d
 *         try:             # <<<<<<<<<<<<<<
 *             if self._order == ORDER_PGDM:
 *                 d = int(seps[0][1 : seps[1] - seps[0]])
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
  __Pyx_XGOTREF(__pyx_t_7);
  __Pyx_XGOTREF(__pyx_t_8);
  __Pyx_XGOTREF(__pyx_t_9);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":661
 *         cdef int m, d
 *         try:
 *             if self._order == ORDER_PGDM:             # <<<<<<<<<<<<<<
 *                 d = int(seps[0][1 : seps[1] - seps[0]])
 *                 m = _month_abbr[seps[1][1 : seps[2] - seps[1]]]
*/
    __pyx_t_2 = (__pyx_v_self->_order == __pyx_e_9psycopg_c_8_psycopg_ORDER_PGDM);
    if (__pyx_t_2) {

      /* "psycopg_c/types/datetime.pyx":662
 *         try:
 *             if self._order == ORDER_PGDM:
 *                 d = int(seps[0][1 : seps[1] - seps[0]])             # <<<<<<<<<<<<<<
 *                 m = _month_abbr[seps[1][1 : seps[2] - seps[1]]]
 *             else:  # self._order == ORDER_PGMD
*/
      __pyx_t_4 = __Pyx_PyBytes_FromStringAndSize((__pyx_v_seps[0]) + 1, ((__pyx_v_seps[1]) - (__pyx_v_seps[0])) - 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 662, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 662, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = __Pyx_PyLong_As_int(__pyx_t_3); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 662, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_d = __pyx_t_10;

      /* "psycopg_c/types/datetime.pyx":663
 *             if self._order == ORDER_PGDM:
 *                 d = int(seps[0][1 : seps[1] - seps[0]])
 *                 m = _month_abbr[seps[1][1 : seps[2] - seps[1]]]             # <<<<<<<<<<<<<<
 *             else:  # self._order == ORDER_PGMD
 *                 m = _month_abbr[seps[0][1 : seps[1] - seps[0]]]
*/
      __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize((__pyx_v_seps[1]) + 1, ((__pyx_v_seps[2]) - (__pyx_v_seps[1])) - 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 663, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyObject_GetItem(__pyx_v_9psycopg_c_8_psycopg__month_abbr, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 663, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_10 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 663, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_m = __pyx_t_10;

      /* "psycopg_c/types/datetime.pyx":661
 *         cdef int m, d
 *         try:
 *             if self._order == ORDER_PGDM:             # <<<<<<<<<<<<<<
 *                 d = int(seps[0][1 : seps[1] - seps[0]])
 *                 m = _month_abbr[seps[1][1 : seps[2] - seps[1]]]
*/
      goto __pyx_L13;
    }

    /* "psycopg_c/types/datetime.pyx":665
 *                 m = _month_abbr[seps[1][1 : seps[2] - seps[1]]]
 *             else:  # self._order == ORDER_PGMD
 *                 m = _month_abbr[seps[0][1 : seps[1] - seps[0]]]             # <<<<<<<<<<<<<<
 *                 d = int(seps[1][1 : seps[2] - seps[1]])
 *         except (KeyError, ValueError) as ex:
*/
    /*else*/ {
      __pyx_t_4 = __Pyx_PyBytes_FromStringAndSize((__pyx_v_seps[0]) + 1, ((__pyx_v_seps[1]) - (__pyx_v_seps[0])) - 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 665, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_v_9psycopg_c_8_psycopg__month_abbr, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 665, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_10 = __Pyx_PyLong_As_int(__pyx_t_3); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 665, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_v_m = __pyx_t_10;

      /* "psycopg_c/types/datetime.pyx":666
 *             else:  # self._order == ORDER_PGMD
 *                 m = _month_abbr[seps[0][1 : seps[1] - seps[0]]]
 *                 d = int(seps[1][1 : seps[2] - seps[1]])             # <<<<<<<<<<<<<<
 *         except (KeyError, ValueError) as ex:
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
*/
      __pyx_t_3 = __Pyx_PyBytes_FromStringAndSize((__pyx_v_seps[1]) + 1, ((__pyx_v_seps[2]) - (__pyx_v_seps[1])) - 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 666, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = __Pyx_PyNumber_Int(__pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 666, __pyx_L7_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_10 = __Pyx_PyLong_As_int(__pyx_t_4); if (unlikely((__pyx_t_10 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 666, __pyx_L7_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_d = __pyx_t_10;
    }
    __pyx_L13:;

    /* "psycopg_c/types/datetime.pyx":660
 *         # Resolve the MD order
 *         cdef int m, d
 *         try:             # <<<<<<<<<<<<<<
 *             if self._order == ORDER_PGDM:
 *                 d = int(seps[0][1 : seps[1] - seps[0]])
*/
  }
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
  goto __pyx_L12_try_end;
  __pyx_L7_error:;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":667
 *                 m = _month_abbr[seps[0][1 : seps[1] - seps[0]]]
 *                 d = int(seps[1][1 : seps[2] - seps[1]])
 *         except (KeyError, ValueError) as ex:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
*/
  __pyx_t_10 = __Pyx_PyErr_ExceptionMatches2(((PyObject *)(((PyTypeObject*)PyExc_KeyError))), ((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_10) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader._cload_pg", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_4, &__pyx_t_3, &__pyx_t_11) < 0) __PYX_ERR(1, 667, __pyx_L9_except_error)
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_ex = __pyx_t_3;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":668
 *                 d = int(seps[1][1 : seps[2] - seps[1]])
 *         except (KeyError, ValueError) as ex:
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
      __pyx_t_12 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
      __Pyx_INCREF(__pyx_t_12);
      __pyx_t_13 = __pyx_v_ex;
      __Pyx_INCREF(__pyx_t_13);
      if (!(likely(__Pyx_PyException_Check(__pyx_t_13))||((__pyx_t_13) == Py_None) || __Pyx_RaiseUnexpectedTypeError("Exception", __pyx_t_13))) __PYX_ERR(1, 668, __pyx_L19_error)
      __pyx_t_15.__pyx_n = 1;
      __pyx_t_15.ex = ((PyObject*)__pyx_t_13);
      __pyx_t_14 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_12), __pyx_v_data, &__pyx_t_15); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 668, __pyx_L19_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_Raise(__pyx_t_14, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __PYX_ERR(1, 668, __pyx_L19_error)
    }

    /* "psycopg_c/types/datetime.pyx":667
 *                 m = _month_abbr[seps[0][1 : seps[1] - seps[0]]]
 *                 d = int(seps[1][1 : seps[2] - seps[1]])
 *         except (KeyError, ValueError) as ex:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
*/
    /*finally:*/ {
      __pyx_L19_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
        if ( unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __pyx_t_10 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
        __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
        __pyx_lineno = __pyx_t_10; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
        goto __pyx_L9_except_error;
      }
    }
  }
  goto __pyx_L9_except_error;

  /* "psycopg_c/types/datetime.pyx":660
 *         # Resolve the MD order
 *         cdef int m, d
 *         try:             # <<<<<<<<<<<<<<
 *             if self._order == ORDER_PGDM:
 *                 d = int(seps[0][1 : seps[1] - seps[0]])
*/
  __pyx_L9_except_error:;
  __Pyx_XGIVEREF(__pyx_t_7);
  __Pyx_XGIVEREF(__pyx_t_8);
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_ExceptionReset(__pyx_t_7, __pyx_t_8, __pyx_t_9);
  goto __pyx_L1_error;
  __pyx_L12_try_end:;
}

/* "psycopg_c/types/datetime.pyx":670
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.datetime_new(
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_9, &__pyx_t_8, &__pyx_t_7);
  __Pyx_XGOTREF(__pyx_t_9);
  __Pyx_XGOTREF(__pyx_t_8);
  __Pyx_XGOTREF(__pyx_t_7);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":671
 * 
 *         try:
 *             return cdt.datetime_new(             # <<<<<<<<<<<<<<
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:
*/
    __Pyx_XDECREF(__pyx_r);

    /* "psycopg_c/types/datetime.pyx":672
 *         try:
 *             return cdt.datetime_new(
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)             # <<<<<<<<<<<<<<
 *         except ValueError as ex:
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
*/
    __pyx_t_11 = ((PyObject *)__pyx_f_7cpython_8datetime_datetime_new((__pyx_v_vals[3]), __pyx_v_m, __pyx_v_d, (__pyx_v_vals[0]), (__pyx_v_vals[1]), (__pyx_v_vals[2]), __pyx_v_us, Py_None, NULL)); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 671, __pyx_L25_error)
    __Pyx_GOTREF(__pyx_t_11);
    __pyx_r = __pyx_t_11;
    __pyx_t_11 = 0;
    goto __pyx_L29_try_return;

    /* "psycopg_c/types/datetime.pyx":670
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.datetime_new(
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
*/
  }
  __pyx_L25_error:;
  __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
  __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":673
 *             return cdt.datetime_new(
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
*/
  __pyx_t_16 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_16) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader._cload_pg", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_11, &__pyx_t_3, &__pyx_t_4) < 0) __PYX_ERR(1, 673, __pyx_L27_except_error)
    __Pyx_XGOTREF(__pyx_t_11);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_t_3);
    __pyx_v_ex = __pyx_t_3;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":674
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_14 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
      __Pyx_INCREF(__pyx_t_14);
      __pyx_t_13 = __pyx_v_ex;
      __Pyx_INCREF(__pyx_t_13);
      if (!(likely(__Pyx_PyException_Check(__pyx_t_13))||((__pyx_t_13) == Py_None) || __Pyx_RaiseUnexpectedTypeError("Exception", __pyx_t_13))) __PYX_ERR(1, 674, __pyx_L36_error)
      __pyx_t_15.__pyx_n = 1;
      __pyx_t_15.ex = ((PyObject*)__pyx_t_13);
      __pyx_t_12 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_14), __pyx_v_data, &__pyx_t_15); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 674, __pyx_L36_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __Pyx_Raise(__pyx_t_12, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __PYX_ERR(1, 674, __pyx_L36_error)
    }

    /* "psycopg_c/types/datetime.pyx":673
 *             return cdt.datetime_new(
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
*/
    /*finally:*/ {
      __pyx_L36_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_20, &__pyx_t_19, &__pyx_t_18);
        if ( unlikely(__Pyx_GetException(&__pyx_t_23, &__pyx_t_22, &__pyx_t_21) < 0)) __Pyx_ErrFetch(&__pyx_t_23, &__pyx_t_22, &__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_18);
        __pyx_t_16 = __pyx_lineno; __pyx_t_10 = __pyx_clineno; __pyx_t_24 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ExceptionReset(__pyx_t_20, __pyx_t_19, __pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ErrRestore(__pyx_t_23, __pyx_t_22, __pyx_t_21);
        __pyx_t_23 = 0; __pyx_t_22 = 0; __pyx_t_21 = 0; __pyx_t_20 = 0; __pyx_t_19 = 0; __pyx_t_18 = 0;
        __pyx_lineno = __pyx_t_16; __pyx_clineno = __pyx_t_10; __pyx_filename = __pyx_t_24;
        goto __pyx_L27_except_error;
      }
    }
  }
  goto __pyx_L27_except_error;

  /* "psycopg_c/types/datetime.pyx":670
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.datetime_new(
 *                 vals[3], m, d, vals[0], vals[1], vals[2], us, None)
*/
  __pyx_L27_except_error:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_8);
  __Pyx_XGIVEREF(__pyx_t_7);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
  goto __pyx_L1_error;
  __pyx_L29_try_return:;
  __Pyx_XGIVEREF(__pyx_t_9);
  __Pyx_XGIVEREF(__pyx_t_8);
  __Pyx_XGIVEREF(__pyx_t_7);
  __Pyx_ExceptionReset(__pyx_t_9, __pyx_t_8, __pyx_t_7);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":630
 *             raise _get_timestamp_load_error(self._pgconn, data, ex) from None
 * 
 *     cdef object _cload_pg(self, const char *data, const char *end):             # <<<<<<<<<<<<<<
 *         cdef int64_t vals[4]
 *         memset(vals, 0, sizeof(vals))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader._cload_pg", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15TimestampLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15TimestampLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15TimestampLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":682
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_21TimestampBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint64_t __pyx_v_beval;
int64_t __pyx_v_val;
int64_t __pyx_v_micros;
int64_t __pyx_v_secs;
int64_t __pyx_v_days;
int64_t __pyx_v_aval;
PyDateTime_Delta *__pyx_v_delta = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int64_t __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
int __pyx_t_7;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
size_t __pyx_t_14;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":684
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))             # <<<<<<<<<<<<<<
 *         cdef int64_t val = endian.be64toh(beval)
 *         cdef int64_t micros, secs, days
*/
(void)(memcpy((&__pyx_v_beval), __pyx_v_data, (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/datetime.pyx":685
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))
 *         cdef int64_t val = endian.be64toh(beval)             # <<<<<<<<<<<<<<
 *         cdef int64_t micros, secs, days
 * 
*/
__pyx_v_val = be64toh(__pyx_v_beval);

/* "psycopg_c/types/datetime.pyx":690
 *         # Work only with positive values as the cdivision behaves differently
 *         # with negative values, and cdivision=False adds overhead.
 *         cdef int64_t aval = val if val >= 0 else -val             # <<<<<<<<<<<<<<
 * 
 *         # Group the micros in biggers stuff or timedelta_new might overflow
*/
__pyx_t_2 = (__pyx_v_val >= 0);
if (__pyx_t_2) {
  __pyx_t_1 = __pyx_v_val;
} else {
  __pyx_t_1 = (-__pyx_v_val);
}
__pyx_v_aval = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":694
 *         # Group the micros in biggers stuff or timedelta_new might overflow
 *         with cython.cdivision(True):
 *             secs = aval // 1_000_000             # <<<<<<<<<<<<<<
 *             micros = aval % 1_000_000
 * 
*/
__pyx_v_secs = (__pyx_v_aval / 0xF4240);

/* "psycopg_c/types/datetime.pyx":695
 *         with cython.cdivision(True):
 *             secs = aval // 1_000_000
 *             micros = aval % 1_000_000             # <<<<<<<<<<<<<<
 * 
 *             days = secs // 86_400
*/
__pyx_v_micros = (__pyx_v_aval % 0xF4240);

/* "psycopg_c/types/datetime.pyx":697
 *             micros = aval % 1_000_000
 * 
 *             days = secs // 86_400             # <<<<<<<<<<<<<<
 *             secs %= 86_400
 * 
*/
__pyx_v_days = (__pyx_v_secs / 0x15180);

/* "psycopg_c/types/datetime.pyx":698
 * 
 *             days = secs // 86_400
 *             secs %= 86_400             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
__pyx_v_secs = __Pyx_mod_int64_t(__pyx_v_secs, 0x15180, 1);

/* "psycopg_c/types/datetime.pyx":700
 *             secs %= 86_400
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
  __Pyx_XGOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_t_5);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":701
 * 
 *         try:
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)             # <<<<<<<<<<<<<<
 *             if val > 0:
 *                 return pg_datetime_epoch + delta
*/
    __pyx_t_6 = ((PyObject *)__pyx_f_7cpython_8datetime_timedelta_new(((int)__pyx_v_days), ((int)__pyx_v_secs), ((int)__pyx_v_micros))); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 701, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_delta = ((PyDateTime_Delta *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "psycopg_c/types/datetime.pyx":702
 *         try:
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:             # <<<<<<<<<<<<<<
 *                 return pg_datetime_epoch + delta
 *             else:
*/
    __pyx_t_2 = (__pyx_v_val > 0);
    if (__pyx_t_2) {

      /* "psycopg_c/types/datetime.pyx":703
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
 *                 return pg_datetime_epoch + delta             # <<<<<<<<<<<<<<
 *             else:
 *                 return pg_datetime_epoch - delta
*/
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = PyNumber_Add(__pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch, ((PyObject *)__pyx_v_delta)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 703, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;

      /* "psycopg_c/types/datetime.pyx":702
 *         try:
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:             # <<<<<<<<<<<<<<
 *                 return pg_datetime_epoch + delta
 *             else:
*/
    }

    /* "psycopg_c/types/datetime.pyx":705
 *                 return pg_datetime_epoch + delta
 *             else:
 *                 return pg_datetime_epoch - delta             # <<<<<<<<<<<<<<
 * 
 *         except OverflowError:
*/
    /*else*/ {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_6 = PyNumber_Subtract(__pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch, ((PyObject *)__pyx_v_delta)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 705, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_r = __pyx_t_6;
      __pyx_t_6 = 0;
      goto __pyx_L7_try_return;
    }

    /* "psycopg_c/types/datetime.pyx":700
 *             secs %= 86_400
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
*/
  }
  __pyx_L3_error:;
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":707
 *                 return pg_datetime_epoch - delta
 * 
 *         except OverflowError:             # <<<<<<<<<<<<<<
 *             if val <= 0:
 *                 raise e.DataError("timestamp too small (before year 1)") from None
*/
  __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));
  if (__pyx_t_7) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestampBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(1, 707, __pyx_L5_except_error)
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);

    /* "psycopg_c/types/datetime.pyx":708
 * 
 *         except OverflowError:
 *             if val <= 0:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("timestamp too small (before year 1)") from None
 *             else:
*/
    __pyx_t_2 = (__pyx_v_val <= 0);
    if (unlikely(__pyx_t_2)) {

      /* "psycopg_c/types/datetime.pyx":709
 *         except OverflowError:
 *             if val <= 0:
 *                 raise e.DataError("timestamp too small (before year 1)") from None             # <<<<<<<<<<<<<<
 *             else:
 *                 raise e.DataError("timestamp too large (after year 10K)") from None
*/
      __pyx_t_11 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 709, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 709, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_14 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
        assert(__pyx_t_11);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
        __pyx_t_14 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_timestamp_too_small_before_year};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 709, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_Raise(__pyx_t_10, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(1, 709, __pyx_L5_except_error)

      /* "psycopg_c/types/datetime.pyx":708
 * 
 *         except OverflowError:
 *             if val <= 0:             # <<<<<<<<<<<<<<
 *                 raise e.DataError("timestamp too small (before year 1)") from None
 *             else:
*/
    }

    /* "psycopg_c/types/datetime.pyx":711
 *                 raise e.DataError("timestamp too small (before year 1)") from None
 *             else:
 *                 raise e.DataError("timestamp too large (after year 10K)") from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
    /*else*/ {
      __pyx_t_13 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 711, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 711, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __pyx_t_14 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
        assert(__pyx_t_13);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);
        __pyx_t_14 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_mstate_global->__pyx_kp_u_timestamp_too_large_after_year_1};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_14, (2-__pyx_t_14) | (__pyx_t_14*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 711, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_Raise(__pyx_t_10, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(1, 711, __pyx_L5_except_error)
    }
  }
  goto __pyx_L5_except_error;

  /* "psycopg_c/types/datetime.pyx":700
 *             secs %= 86_400
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
*/
  __pyx_L5_except_error:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L1_error;
  __pyx_L7_try_return:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":682
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t beval
 *         memcpy(&beval, data, sizeof(beval))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF((PyObject *)__pyx_v_delta);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21TimestampBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_21TimestampBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimestampBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21TimestampBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_21TimestampBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21TimestampBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestampBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":717
 *     cdef object _time_zone
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self._time_zone = _timezone_from_connection(self._pgconn)
 * 
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 717, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 717, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 717, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(1, 717, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(1, 717, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 717, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 717, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(1, 717, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(1, 717, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimestamptzLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(1, 717, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/datetime.pyx":718
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 *         self._time_zone = _timezone_from_connection(self._pgconn)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__timezone_from_connection(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 718, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__Pyx_GIVEREF(__pyx_t_2);
__Pyx_GOTREF(__pyx_v_self->_time_zone);
__Pyx_DECREF(__pyx_v_self->_time_zone);
__pyx_v_self->_time_zone = __pyx_t_2;
__pyx_t_2 = 0;

/* "psycopg_c/types/datetime.pyx":717
 *     cdef object _time_zone
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         self._time_zone = _timezone_from_connection(self._pgconn)
 * 
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimestamptzLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimestamptzLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseTimestamptzLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":727
 *     cdef int _order
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 727, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 727, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 727, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(1, 727, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(1, 727, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 727, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 727, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(1, 727, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(1, 727, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(1, 727, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_ds;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
int __pyx_t_3;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/datetime.pyx":729
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)             # <<<<<<<<<<<<<<
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD
*/
__pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_datestyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 729, __pyx_L1_error)
__pyx_v_ds = __pyx_t_2;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":730
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO             # <<<<<<<<<<<<<<
 *             self._order = ORDER_YMD
 *         else:  # Not true, but any non-YMD will do.
*/
__pyx_t_3 = ((__pyx_v_ds[0]) == 'I');
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":731
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO
 *             self._order = ORDER_YMD             # <<<<<<<<<<<<<<
 *         else:  # Not true, but any non-YMD will do.
 *             self._order = ORDER_DMY
*/
  __pyx_v_self->_order = __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD;

  /* "psycopg_c/types/datetime.pyx":730
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
 *         if ds[0] == b'I':  # ISO             # <<<<<<<<<<<<<<
 *             self._order = ORDER_YMD
 *         else:  # Not true, but any non-YMD will do.
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":733
 *             self._order = ORDER_YMD
 *         else:  # Not true, but any non-YMD will do.
 *             self._order = ORDER_DMY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
/*else*/ {
  __pyx_v_self->_order = __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY;
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":727
 *     cdef int _order
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_datestyle(self._pgconn)
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":735
 *             self._order = ORDER_DMY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self._order != ORDER_YMD:
 *             return self._cload_notimpl(data, length)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
char const *__pyx_v_end;
int64_t __pyx_v_vals[6];
char const *__pyx_v_ptr;
int __pyx_v_us;
int __pyx_v_y;
int __pyx_v_m;
int __pyx_v_d;
int __pyx_v_offsecs;
PyDateTime_Delta *__pyx_v_tzoff = NULL;
PyObject *__pyx_v_dt = NULL;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_v_ex1 = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
char const *__pyx_t_4;
char const *__pyx_t_5;
int64_t __pyx_t_6;
int64_t __pyx_t_7;
int64_t __pyx_t_8;
int __pyx_t_9;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17 = NULL;
PyObject *__pyx_t_18 = NULL;
size_t __pyx_t_19;
int __pyx_t_20;
char const *__pyx_t_21;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
PyObject *__pyx_t_24 = NULL;
PyObject *__pyx_t_25 = NULL;
PyObject *__pyx_t_26 = NULL;
PyObject *__pyx_t_27 = NULL;
struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error __pyx_t_28;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":736
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self._order != ORDER_YMD:             # <<<<<<<<<<<<<<
 *             return self._cload_notimpl(data, length)
 * 
*/
__pyx_t_1 = (__pyx_v_self->_order != __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":737
 *     cdef object cload(self, const char *data, size_t length):
 *         if self._order != ORDER_YMD:
 *             return self._cload_notimpl(data, length)             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *end = data + length
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader__cload_notimpl(__pyx_v_self, __pyx_v_data, __pyx_v_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":736
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self._order != ORDER_YMD:             # <<<<<<<<<<<<<<
 *             return self._cload_notimpl(data, length)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":739
 *             return self._cload_notimpl(data, length)
 * 
 *         cdef const char *end = data + length             # <<<<<<<<<<<<<<
 *         if end[-1] == b'C':  # ends with BC
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_v_end = (__pyx_v_data + __pyx_v_length);

/* "psycopg_c/types/datetime.pyx":740
 * 
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_1 = ((__pyx_v_end[-1L]) == 'C');
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/datetime.pyx":741
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         cdef int64_t vals[6]
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_2), __pyx_v_data, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 741, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(1, 741, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":740
 * 
 *         cdef const char *end = data + length
 *         if end[-1] == b'C':  # ends with BC             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":744
 * 
 *         cdef int64_t vals[6]
 *         memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 * 
 *         # Parse the first 6 groups of digits (date and time)
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":748
 *         # Parse the first 6 groups of digits (date and time)
 *         cdef const char *ptr
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_data, __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_4 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 748, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_4;

/* "psycopg_c/types/datetime.pyx":749
 *         cdef const char *ptr
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_1 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/datetime.pyx":750
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         # Parse the microseconds
*/
  __pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3), __pyx_v_data, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_Raise(__pyx_t_2, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(1, 750, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":749
 *         cdef const char *ptr
 *         ptr = _parse_date_values(data, end, vals, ARRAYSIZE(vals))
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":753
 * 
 *         # Parse the microseconds
 *         cdef int us = 0             # <<<<<<<<<<<<<<
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)
*/
__pyx_v_us = 0;

/* "psycopg_c/types/datetime.pyx":754
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
__pyx_t_1 = ((__pyx_v_ptr[0]) == '.');
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":755
 *         cdef int us = 0
 *         if ptr[0] == b".":
 *             ptr = _parse_micros(ptr + 1, &us)             # <<<<<<<<<<<<<<
 * 
 *         # Resolve the YMD order
*/
  __pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__parse_micros((__pyx_v_ptr + 1), (&__pyx_v_us)); if (unlikely(__pyx_t_5 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 755, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_5;

  /* "psycopg_c/types/datetime.pyx":754
 *         # Parse the microseconds
 *         cdef int us = 0
 *         if ptr[0] == b".":             # <<<<<<<<<<<<<<
 *             ptr = _parse_micros(ptr + 1, &us)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":759
 *         # Resolve the YMD order
 *         cdef int y, m, d
 *         if self._order == ORDER_YMD:             # <<<<<<<<<<<<<<
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:
*/
switch (__pyx_v_self->_order) {
  case __pyx_e_9psycopg_c_8_psycopg_ORDER_YMD:

  /* "psycopg_c/types/datetime.pyx":760
 *         cdef int y, m, d
 *         if self._order == ORDER_YMD:
 *             y, m, d = vals[0], vals[1], vals[2]             # <<<<<<<<<<<<<<
 *         elif self._order == ORDER_DMY:
 *             d, m, y = vals[0], vals[1], vals[2]
*/
  __pyx_t_6 = (__pyx_v_vals[0]);
  __pyx_t_7 = (__pyx_v_vals[1]);
  __pyx_t_8 = (__pyx_v_vals[2]);
  __pyx_v_y = __pyx_t_6;
  __pyx_v_m = __pyx_t_7;
  __pyx_v_d = __pyx_t_8;

  /* "psycopg_c/types/datetime.pyx":759
 *         # Resolve the YMD order
 *         cdef int y, m, d
 *         if self._order == ORDER_YMD:             # <<<<<<<<<<<<<<
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:
*/
  break;
  case __pyx_e_9psycopg_c_8_psycopg_ORDER_DMY:

  /* "psycopg_c/types/datetime.pyx":762
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:
 *             d, m, y = vals[0], vals[1], vals[2]             # <<<<<<<<<<<<<<
 *         else:  # self._order == ORDER_MDY
 *             m, d, y = vals[0], vals[1], vals[2]
*/
  __pyx_t_8 = (__pyx_v_vals[0]);
  __pyx_t_7 = (__pyx_v_vals[1]);
  __pyx_t_6 = (__pyx_v_vals[2]);
  __pyx_v_d = __pyx_t_8;
  __pyx_v_m = __pyx_t_7;
  __pyx_v_y = __pyx_t_6;

  /* "psycopg_c/types/datetime.pyx":761
 *         if self._order == ORDER_YMD:
 *             y, m, d = vals[0], vals[1], vals[2]
 *         elif self._order == ORDER_DMY:             # <<<<<<<<<<<<<<
 *             d, m, y = vals[0], vals[1], vals[2]
 *         else:  # self._order == ORDER_MDY
*/
  break;
  default:

  /* "psycopg_c/types/datetime.pyx":764
 *             d, m, y = vals[0], vals[1], vals[2]
 *         else:  # self._order == ORDER_MDY
 *             m, d, y = vals[0], vals[1], vals[2]             # <<<<<<<<<<<<<<
 * 
 *         # Parse the timezone
*/
  __pyx_t_6 = (__pyx_v_vals[0]);
  __pyx_t_7 = (__pyx_v_vals[1]);
  __pyx_t_8 = (__pyx_v_vals[2]);
  __pyx_v_m = __pyx_t_6;
  __pyx_v_d = __pyx_t_7;
  __pyx_v_y = __pyx_t_8;
  break;
}

/* "psycopg_c/types/datetime.pyx":767
 * 
 *         # Parse the timezone
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)             # <<<<<<<<<<<<<<
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
*/
__pyx_t_9 = __pyx_f_9psycopg_c_8_psycopg__parse_timezone_to_seconds((&__pyx_v_ptr), __pyx_v_end); if (unlikely(__pyx_t_9 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(1, 767, __pyx_L1_error)
__pyx_v_offsecs = __pyx_t_9;

/* "psycopg_c/types/datetime.pyx":768
 *         # Parse the timezone
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
__pyx_t_1 = (__pyx_v_ptr == NULL);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/datetime.pyx":769
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)
 *         if ptr == NULL:
 *             raise _get_timestamp_load_error(self._pgconn, data) from None             # <<<<<<<<<<<<<<
 * 
 *         tzoff = cdt.timedelta_new(0, offsecs, 0)
*/
  __pyx_t_2 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._pgconn);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_2), __pyx_v_data, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, Py_None);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(1, 769, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":768
 *         # Parse the timezone
 *         cdef int offsecs = _parse_timezone_to_seconds(&ptr, end)
 *         if ptr == NULL:             # <<<<<<<<<<<<<<
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":771
 *             raise _get_timestamp_load_error(self._pgconn, data) from None
 * 
 *         tzoff = cdt.timedelta_new(0, offsecs, 0)             # <<<<<<<<<<<<<<
 * 
 *         # The return value is a datetime with the timezone of the connection
*/
__pyx_t_3 = ((PyObject *)__pyx_f_7cpython_8datetime_timedelta_new(0, __pyx_v_offsecs, 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 771, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_v_tzoff = ((PyDateTime_Delta *)__pyx_t_3);
__pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":778
 *         # shift it by the offset parsed from the timestamp, and then move it to
 *         # the connection timezone.
 *         dt = None             # <<<<<<<<<<<<<<
 *         try:
 *             dt = cdt.datetime_new(
*/
__Pyx_INCREF(Py_None);
__pyx_v_dt = Py_None;

/* "psycopg_c/types/datetime.pyx":779
 *         # the connection timezone.
 *         dt = None
 *         try:             # <<<<<<<<<<<<<<
 *             dt = cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
  __Pyx_XGOTREF(__pyx_t_10);
  __Pyx_XGOTREF(__pyx_t_11);
  __Pyx_XGOTREF(__pyx_t_12);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":781
 *         try:
 *             dt = cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)             # <<<<<<<<<<<<<<
 *             dt -= tzoff
 *             return PyObject_CallFunctionObjArgs(
*/
    __pyx_t_3 = __pyx_v_9psycopg_c_8_psycopg_timezone_utc;
    __Pyx_INCREF(__pyx_t_3);

    /* "psycopg_c/types/datetime.pyx":780
 *         dt = None
 *         try:
 *             dt = cdt.datetime_new(             # <<<<<<<<<<<<<<
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
 *             dt -= tzoff
*/
    __pyx_t_2 = ((PyObject *)__pyx_f_7cpython_8datetime_datetime_new(__pyx_v_y, __pyx_v_m, __pyx_v_d, (__pyx_v_vals[3]), (__pyx_v_vals[4]), (__pyx_v_vals[5]), __pyx_v_us, __pyx_t_3, NULL)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 780, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "psycopg_c/types/datetime.pyx":782
 *             dt = cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
 *             dt -= tzoff             # <<<<<<<<<<<<<<
 *             return PyObject_CallFunctionObjArgs(
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
*/
    __pyx_t_2 = PyNumber_InPlaceSubtract(__pyx_v_dt, ((PyObject *)__pyx_v_tzoff)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 782, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF_SET(__pyx_v_dt, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "psycopg_c/types/datetime.pyx":783
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
 *             dt -= tzoff
 *             return PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 *         except OverflowError as ex:
*/
    __Pyx_XDECREF(__pyx_r);

    /* "psycopg_c/types/datetime.pyx":784
 *             dt -= tzoff
 *             return PyObject_CallFunctionObjArgs(
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)             # <<<<<<<<<<<<<<
 *         except OverflowError as ex:
 *             # If we have created the temporary 'dt' it means that we have a
*/
    __pyx_t_2 = __pyx_v_9psycopg_c_8_psycopg_datetime_astimezone;
    __Pyx_INCREF(__pyx_t_2);

    /* "psycopg_c/types/datetime.pyx":783
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
 *             dt -= tzoff
 *             return PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 *         except OverflowError as ex:
*/
    __pyx_t_3 = PyObject_CallFunctionObjArgs(__pyx_t_2, ((PyObject *)__pyx_v_dt), ((PyObject *)__pyx_v_self->__pyx_base._time_zone), NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 783, __pyx_L8_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L12_try_return;

    /* "psycopg_c/types/datetime.pyx":779
 *         # the connection timezone.
 *         dt = None
 *         try:             # <<<<<<<<<<<<<<
 *             dt = cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
*/
  }
  __pyx_L8_error:;
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "psycopg_c/types/datetime.pyx":785
 *             return PyObject_CallFunctionObjArgs(
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 *         except OverflowError as ex:             # <<<<<<<<<<<<<<
 *             # If we have created the temporary 'dt' it means that we have a
 *             # datetime close to max, the shift pushed it past max, overflowing.
*/
  __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));
  if (__pyx_t_9) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_2, &__pyx_t_13) < 0) __PYX_ERR(1, 785, __pyx_L10_except_error)
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_ex = __pyx_t_2;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":789
 *             # datetime close to max, the shift pushed it past max, overflowing.
 *             # In this case return the datetime in a fixed offset timezone.
 *             if dt is not None:             # <<<<<<<<<<<<<<
 *                 return dt.replace(tzinfo=timezone(tzoff))
 *             else:
*/
      __pyx_t_1 = (__pyx_v_dt != Py_None);
      if (__pyx_t_1) {

        /* "psycopg_c/types/datetime.pyx":790
 *             # In this case return the datetime in a fixed offset timezone.
 *             if dt is not None:
 *                 return dt.replace(tzinfo=timezone(tzoff))             # <<<<<<<<<<<<<<
 *             else:
 *                 ex1 = ex
*/
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_15 = __pyx_v_dt;
        __Pyx_INCREF(__pyx_t_15);
        __pyx_t_17 = NULL;
        __Pyx_GetModuleGlobalName(__pyx_t_18, __pyx_mstate_global->__pyx_n_u_timezone); if (unlikely(!__pyx_t_18)) __PYX_ERR(1, 790, __pyx_L19_error)
        __Pyx_GOTREF(__pyx_t_18);
        __pyx_t_19 = 1;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_18))) {
          __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_18);
          assert(__pyx_t_17);
          PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_18);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(__pyx__function);
          __Pyx_DECREF_SET(__pyx_t_18, __pyx__function);
          __pyx_t_19 = 0;
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_17, ((PyObject *)__pyx_v_tzoff)};
          __pyx_t_16 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_18, __pyx_callargs+__pyx_t_19, (2-__pyx_t_19) | (__pyx_t_19*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 790, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_16);
        }
        __pyx_t_19 = 0;
        {
          PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_15, NULL};
          __pyx_t_18 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_18)) __PYX_ERR(1, 790, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_18);
          if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_tzinfo, __pyx_t_16, __pyx_t_18, __pyx_callargs+1, 0) < (0)) __PYX_ERR(1, 790, __pyx_L19_error)
          __pyx_t_14 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_replace, __pyx_callargs+__pyx_t_19, (1-__pyx_t_19) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_18);
          __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
          __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
          __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
          if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 790, __pyx_L19_error)
          __Pyx_GOTREF(__pyx_t_14);
        }
        __pyx_r = __pyx_t_14;
        __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L18_return;

        /* "psycopg_c/types/datetime.pyx":789
 *             # datetime close to max, the shift pushed it past max, overflowing.
 *             # In this case return the datetime in a fixed offset timezone.
 *             if dt is not None:             # <<<<<<<<<<<<<<
 *                 return dt.replace(tzinfo=timezone(tzoff))
 *             else:
*/
      }

      /* "psycopg_c/types/datetime.pyx":792
 *                 return dt.replace(tzinfo=timezone(tzoff))
 *             else:
 *                 ex1 = ex             # <<<<<<<<<<<<<<
 *         except ValueError as ex:
 *             ex1 = ex
*/
      /*else*/ {
        __Pyx_INCREF(__pyx_v_ex);
        __pyx_v_ex1 = __pyx_v_ex;
      }
    }

    /* "psycopg_c/types/datetime.pyx":785
 *             return PyObject_CallFunctionObjArgs(
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 *         except OverflowError as ex:             # <<<<<<<<<<<<<<
 *             # If we have created the temporary 'dt' it means that we have a
 *             # datetime close to max, the shift pushed it past max, overflowing.
*/
    /*finally:*/ {
      /*normal exit:*/{
        __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        goto __pyx_L20;
      }
      __pyx_L19_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_18); __pyx_t_18 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
        if ( unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_25);
        __Pyx_XGOTREF(__pyx_t_26);
        __Pyx_XGOTREF(__pyx_t_27);
        __pyx_t_9 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_25);
        __Pyx_XGIVEREF(__pyx_t_26);
        __Pyx_XGIVEREF(__pyx_t_27);
        __Pyx_ExceptionReset(__pyx_t_25, __pyx_t_26, __pyx_t_27);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_XGIVEREF(__pyx_t_24);
        __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
        __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
        __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_21;
        goto __pyx_L10_except_error;
      }
      __pyx_L18_return: {
        __pyx_t_27 = __pyx_r;
        __pyx_r = 0;
        __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        __pyx_r = __pyx_t_27;
        __pyx_t_27 = 0;
        goto __pyx_L11_except_return;
      }
      __pyx_L20:;
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    goto __pyx_L9_exception_handled;
  }

  /* "psycopg_c/types/datetime.pyx":793
 *             else:
 *                 ex1 = ex
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             ex1 = ex
 * 
*/
  __pyx_t_20 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_ValueError))));
  if (__pyx_t_20) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_13, &__pyx_t_2, &__pyx_t_3) < 0) __PYX_ERR(1, 793, __pyx_L10_except_error)
    __Pyx_XGOTREF(__pyx_t_13);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_ex = __pyx_t_2;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":794
 *                 ex1 = ex
 *         except ValueError as ex:
 *             ex1 = ex             # <<<<<<<<<<<<<<
 * 
 *         raise _get_timestamp_load_error(self._pgconn, data, ex1) from None
*/
      __Pyx_INCREF(__pyx_v_ex);
      __pyx_v_ex1 = __pyx_v_ex;
    }

    /* "psycopg_c/types/datetime.pyx":793
 *             else:
 *                 ex1 = ex
 *         except ValueError as ex:             # <<<<<<<<<<<<<<
 *             ex1 = ex
 * 
*/
    /*finally:*/ {
      /*normal exit:*/{
        __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        goto __pyx_L32;
      }
      __pyx_L32:;
    }
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L9_exception_handled;
  }
  goto __pyx_L10_except_error;

  /* "psycopg_c/types/datetime.pyx":779
 *         # the connection timezone.
 *         dt = None
 *         try:             # <<<<<<<<<<<<<<
 *             dt = cdt.datetime_new(
 *                 y, m, d, vals[3], vals[4], vals[5], us, timezone_utc)
*/
  __pyx_L10_except_error:;
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
  goto __pyx_L1_error;
  __pyx_L12_try_return:;
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
  goto __pyx_L0;
  __pyx_L11_except_return:;
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
  goto __pyx_L0;
  __pyx_L9_exception_handled:;
  __Pyx_XGIVEREF(__pyx_t_10);
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
}

/* "psycopg_c/types/datetime.pyx":796
 *             ex1 = ex
 * 
 *         raise _get_timestamp_load_error(self._pgconn, data, ex1) from None             # <<<<<<<<<<<<<<
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):
*/
__pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_3);
if (unlikely(!__pyx_v_ex1)) { __Pyx_RaiseUnboundLocalError("ex1"); __PYX_ERR(1, 796, __pyx_L1_error) }
__pyx_t_2 = __pyx_v_ex1;
__Pyx_INCREF(__pyx_t_2);
if (!(likely(__Pyx_PyException_Check(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("Exception", __pyx_t_2))) __PYX_ERR(1, 796, __pyx_L1_error)
__pyx_t_28.__pyx_n = 1;
__pyx_t_28.ex = ((PyObject*)__pyx_t_2);
__pyx_t_13 = __pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3), __pyx_v_data, &__pyx_t_28); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 796, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_13);
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__Pyx_Raise(__pyx_t_13, 0, 0, Py_None);
__Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
__PYX_ERR(1, 796, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":735
 *             self._order = ORDER_DMY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self._order != ORDER_YMD:
 *             return self._cload_notimpl(data, length)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_XDECREF(__pyx_t_15);
__Pyx_XDECREF(__pyx_t_16);
__Pyx_XDECREF(__pyx_t_17);
__Pyx_XDECREF(__pyx_t_18);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF((PyObject *)__pyx_v_tzoff);
__Pyx_XDECREF(__pyx_v_dt);
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XDECREF(__pyx_v_ex1);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":798
 *         raise _get_timestamp_load_error(self._pgconn, data, ex1) from None
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         s = bytes(data)[:length].decode("utf8", "replace")
 *         ds = _get_datestyle(self._pgconn).decode()
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader__cload_notimpl(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
PyObject *__pyx_v_s = NULL;
PyObject *__pyx_v_ds = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
char const *__pyx_t_5;
Py_ssize_t __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8[4];
PyObject *__pyx_t_9 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_cload_notimpl", 0);

/* "psycopg_c/types/datetime.pyx":799
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):
 *         s = bytes(data)[:length].decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *         ds = _get_datestyle(self._pgconn).decode()
 *         raise NotImplementedError(
*/
__pyx_t_2 = NULL;
__pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 799, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 799, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_t_3 = __Pyx_decode_bytes(__pyx_t_1, 0, __pyx_v_length, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 799, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_s = ((PyObject*)__pyx_t_3);
__pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":800
 *     cdef object _cload_notimpl(self, const char *data, size_t length):
 *         s = bytes(data)[:length].decode("utf8", "replace")
 *         ds = _get_datestyle(self._pgconn).decode()             # <<<<<<<<<<<<<<
 *         raise NotImplementedError(
 *             f"can't parse timestamptz with DateStyle {ds!r}: {s!r}"
*/
__pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base.__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_3);
__pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__get_datestyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3)); if (unlikely(__pyx_t_5 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 800, __pyx_L1_error)
__pyx_t_6 = __Pyx_ssize_strlen(__pyx_t_5); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(1, 800, __pyx_L1_error)
__pyx_t_1 = __Pyx_decode_c_string(__pyx_t_5, 0, __pyx_t_6, NULL, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 800, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__Pyx_INCREF(__pyx_t_1);
__pyx_v_ds = __pyx_t_1;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":801
 *         s = bytes(data)[:length].decode("utf8", "replace")
 *         ds = _get_datestyle(self._pgconn).decode()
 *         raise NotImplementedError(             # <<<<<<<<<<<<<<
 *             f"can't parse timestamptz with DateStyle {ds!r}: {s!r}"
 *         )
*/
__pyx_t_3 = NULL;

/* "psycopg_c/types/datetime.pyx":802
 *         ds = _get_datestyle(self._pgconn).decode()
 *         raise NotImplementedError(
 *             f"can't parse timestamptz with DateStyle {ds!r}: {s!r}"             # <<<<<<<<<<<<<<
 *         )
 * 
*/
__pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_ds), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 802, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 802, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_7);
__pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_timestamptz_with_Dat;
__pyx_t_8[1] = __pyx_t_2;
__pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u__7;
__pyx_t_8[3] = __pyx_t_7;
__pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_8, 4, 39 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 802, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_9);
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_NotImplementedError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__Pyx_Raise(__pyx_t_1, 0, 0, 0);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__PYX_ERR(1, 801, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":798
 *         raise _get_timestamp_load_error(self._pgconn, data, ex1) from None
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         s = bytes(data)[:length].decode("utf8", "replace")
 *         ds = _get_datestyle(self._pgconn).decode()
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader._cload_notimpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_ds);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17TimestamptzLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17TimestamptzLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17TimestamptzLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":811
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint64_t __pyx_v_bedata;
int64_t __pyx_v_val;
int64_t __pyx_v_micros;
int64_t __pyx_v_secs;
int64_t __pyx_v_days;
int64_t __pyx_v_aval;
PyDateTime_Delta *__pyx_v_delta = NULL;
PyObject *__pyx_v_dt = NULL;
PyObject *__pyx_v_utcoff = NULL;
PyObject *__pyx_v_usoff = NULL;
PyObject *__pyx_v_ts = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int64_t __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
int __pyx_t_8;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
size_t __pyx_t_15;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17 = NULL;
PyObject *__pyx_t_18 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":813
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         cdef int64_t val = endian.be64toh(bedata)
 *         cdef int64_t micros, secs, days
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/datetime.pyx":814
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         cdef int64_t val = endian.be64toh(bedata)             # <<<<<<<<<<<<<<
 *         cdef int64_t micros, secs, days
 * 
*/
__pyx_v_val = be64toh(__pyx_v_bedata);

/* "psycopg_c/types/datetime.pyx":819
 *         # Work only with positive values as the cdivision behaves differently
 *         # with negative values, and cdivision=False adds overhead.
 *         cdef int64_t aval = val if val >= 0 else -val             # <<<<<<<<<<<<<<
 * 
 *         # Group the micros in biggers stuff or timedelta_new might overflow
*/
__pyx_t_2 = (__pyx_v_val >= 0);
if (__pyx_t_2) {
  __pyx_t_1 = __pyx_v_val;
} else {
  __pyx_t_1 = (-__pyx_v_val);
}
__pyx_v_aval = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":823
 *         # Group the micros in biggers stuff or timedelta_new might overflow
 *         with cython.cdivision(True):
 *             secs = aval // 1_000_000             # <<<<<<<<<<<<<<
 *             micros = aval % 1_000_000
 * 
*/
__pyx_v_secs = (__pyx_v_aval / 0xF4240);

/* "psycopg_c/types/datetime.pyx":824
 *         with cython.cdivision(True):
 *             secs = aval // 1_000_000
 *             micros = aval % 1_000_000             # <<<<<<<<<<<<<<
 * 
 *             days = secs // 86_400
*/
__pyx_v_micros = (__pyx_v_aval % 0xF4240);

/* "psycopg_c/types/datetime.pyx":826
 *             micros = aval % 1_000_000
 * 
 *             days = secs // 86_400             # <<<<<<<<<<<<<<
 *             secs %= 86_400
 * 
*/
__pyx_v_days = (__pyx_v_secs / 0x15180);

/* "psycopg_c/types/datetime.pyx":827
 * 
 *             days = secs // 86_400
 *             secs %= 86_400             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
__pyx_v_secs = __Pyx_mod_int64_t(__pyx_v_secs, 0x15180, 1);

/* "psycopg_c/types/datetime.pyx":829
 *             secs %= 86_400
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
  __Pyx_XGOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_t_5);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":830
 * 
 *         try:
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)             # <<<<<<<<<<<<<<
 *             if val > 0:
 *                 dt = pg_datetimetz_epoch + delta
*/
    __pyx_t_6 = ((PyObject *)__pyx_f_7cpython_8datetime_timedelta_new(((int)__pyx_v_days), ((int)__pyx_v_secs), ((int)__pyx_v_micros))); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 830, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_v_delta = ((PyDateTime_Delta *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "psycopg_c/types/datetime.pyx":831
 *         try:
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:             # <<<<<<<<<<<<<<
 *                 dt = pg_datetimetz_epoch + delta
 *             else:
*/
    __pyx_t_2 = (__pyx_v_val > 0);
    if (__pyx_t_2) {

      /* "psycopg_c/types/datetime.pyx":832
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
 *                 dt = pg_datetimetz_epoch + delta             # <<<<<<<<<<<<<<
 *             else:
 *                 dt = pg_datetimetz_epoch - delta
*/
      __pyx_t_6 = PyNumber_Add(__pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch, ((PyObject *)__pyx_v_delta)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 832, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_dt = __pyx_t_6;
      __pyx_t_6 = 0;

      /* "psycopg_c/types/datetime.pyx":831
 *         try:
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:             # <<<<<<<<<<<<<<
 *                 dt = pg_datetimetz_epoch + delta
 *             else:
*/
      goto __pyx_L9;
    }

    /* "psycopg_c/types/datetime.pyx":834
 *                 dt = pg_datetimetz_epoch + delta
 *             else:
 *                 dt = pg_datetimetz_epoch - delta             # <<<<<<<<<<<<<<
 *             return PyObject_CallFunctionObjArgs(
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
*/
    /*else*/ {
      __pyx_t_6 = PyNumber_Subtract(__pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch, ((PyObject *)__pyx_v_delta)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 834, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_v_dt = __pyx_t_6;
      __pyx_t_6 = 0;
    }
    __pyx_L9:;

    /* "psycopg_c/types/datetime.pyx":835
 *             else:
 *                 dt = pg_datetimetz_epoch - delta
 *             return PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 * 
*/
    __Pyx_XDECREF(__pyx_r);

    /* "psycopg_c/types/datetime.pyx":836
 *                 dt = pg_datetimetz_epoch - delta
 *             return PyObject_CallFunctionObjArgs(
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)             # <<<<<<<<<<<<<<
 * 
 *         except OverflowError:
*/
    __pyx_t_6 = __pyx_v_9psycopg_c_8_psycopg_datetime_astimezone;
    __Pyx_INCREF(__pyx_t_6);

    /* "psycopg_c/types/datetime.pyx":835
 *             else:
 *                 dt = pg_datetimetz_epoch - delta
 *             return PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 * 
*/
    __pyx_t_7 = PyObject_CallFunctionObjArgs(__pyx_t_6, ((PyObject *)__pyx_v_dt), ((PyObject *)__pyx_v_self->__pyx_base._time_zone), NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 835, __pyx_L3_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L7_try_return;

    /* "psycopg_c/types/datetime.pyx":829
 *             secs %= 86_400
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
*/
  }
  __pyx_L3_error:;
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "psycopg_c/types/datetime.pyx":838
 *                 datetime_astimezone, <PyObject *>dt, <PyObject *>self._time_zone, NULL)
 * 
 *         except OverflowError:             # <<<<<<<<<<<<<<
 *             # If we were asked about a timestamp which would overflow in UTC,
 *             # but not in the desired timezone (e.g. datetime.max at Chicago
*/
  __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));
  if (__pyx_t_8) {
    __Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_6, &__pyx_t_9) < 0) __PYX_ERR(1, 838, __pyx_L5_except_error)
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_9);

    /* "psycopg_c/types/datetime.pyx":843
 *             # timezone) we can still save the day by shifting the value by the
 *             # timezone offset and then replacing the timezone.
 *             if self._time_zone is not None:             # <<<<<<<<<<<<<<
 *                 utcoff = self._time_zone.utcoffset(
 *                     datetime.min if val < 0 else datetime.max
*/
    __pyx_t_2 = (__pyx_v_self->__pyx_base._time_zone != Py_None);
    if (__pyx_t_2) {

      /* "psycopg_c/types/datetime.pyx":844
 *             # timezone offset and then replacing the timezone.
 *             if self._time_zone is not None:
 *                 utcoff = self._time_zone.utcoffset(             # <<<<<<<<<<<<<<
 *                     datetime.min if val < 0 else datetime.max
 *                 )
*/
      __pyx_t_11 = __pyx_v_self->__pyx_base._time_zone;
      __Pyx_INCREF(__pyx_t_11);

      /* "psycopg_c/types/datetime.pyx":845
 *             if self._time_zone is not None:
 *                 utcoff = self._time_zone.utcoffset(
 *                     datetime.min if val < 0 else datetime.max             # <<<<<<<<<<<<<<
 *                 )
 *                 if utcoff:
*/
      __pyx_t_2 = (__pyx_v_val < 0);
      if (__pyx_t_2) {
        __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_datetime); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 845, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_min); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 845, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_12 = __pyx_t_14;
        __pyx_t_14 = 0;
      } else {
        __Pyx_GetModuleGlobalName(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_datetime); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 845, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_14);
        __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_14, __pyx_mstate_global->__pyx_n_u_max); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 845, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_12 = __pyx_t_13;
        __pyx_t_13 = 0;
      }
      __pyx_t_15 = 0;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_12};
        __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_utcoffset, __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 844, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __pyx_v_utcoff = __pyx_t_10;
      __pyx_t_10 = 0;

      /* "psycopg_c/types/datetime.pyx":847
 *                     datetime.min if val < 0 else datetime.max
 *                 )
 *                 if utcoff:             # <<<<<<<<<<<<<<
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:
*/
      __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_utcoff); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 847, __pyx_L5_except_error)
      if (__pyx_t_2) {

        /* "psycopg_c/types/datetime.pyx":848
 *                 )
 *                 if utcoff:
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())             # <<<<<<<<<<<<<<
 *                     try:
 *                         ts = pg_datetime_epoch + timedelta(
*/
        __pyx_t_12 = __pyx_v_utcoff;
        __Pyx_INCREF(__pyx_t_12);
        __pyx_t_15 = 0;
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_12, NULL};
          __pyx_t_10 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_total_seconds, __pyx_callargs+__pyx_t_15, (1-__pyx_t_15) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 848, __pyx_L5_except_error)
          __Pyx_GOTREF(__pyx_t_10);
        }
        __pyx_t_12 = __Pyx_PyNumber_Int(__pyx_t_10); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 848, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __pyx_t_10 = __Pyx_PyLong_MultiplyCObj(__pyx_mstate_global->__pyx_int_1000000, __pyx_t_12, 0xF4240, 0, 0); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 848, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __pyx_v_usoff = ((PyObject*)__pyx_t_10);
        __pyx_t_10 = 0;

        /* "psycopg_c/types/datetime.pyx":849
 *                 if utcoff:
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:             # <<<<<<<<<<<<<<
 *                         ts = pg_datetime_epoch + timedelta(
 *                             microseconds=val + usoff
*/
        {
          __Pyx_PyThreadState_declare
          __Pyx_PyThreadState_assign
          __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
          __Pyx_XGOTREF(__pyx_t_16);
          __Pyx_XGOTREF(__pyx_t_17);
          __Pyx_XGOTREF(__pyx_t_18);
          /*try:*/ {

            /* "psycopg_c/types/datetime.pyx":850
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:
 *                         ts = pg_datetime_epoch + timedelta(             # <<<<<<<<<<<<<<
 *                             microseconds=val + usoff
 *                         )
*/
            __pyx_t_12 = NULL;
            __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_timedelta); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 850, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_11);

            /* "psycopg_c/types/datetime.pyx":851
 *                     try:
 *                         ts = pg_datetime_epoch + timedelta(
 *                             microseconds=val + usoff             # <<<<<<<<<<<<<<
 *                         )
 *                     except OverflowError:
*/
            __pyx_t_13 = __Pyx_PyLong_From_int64_t(__pyx_v_val); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 851, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_13);
            __pyx_t_14 = PyNumber_Add(__pyx_t_13, __pyx_v_usoff); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 851, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_14);
            __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
            __pyx_t_15 = 1;
            #if CYTHON_UNPACK_METHODS
            if (unlikely(PyMethod_Check(__pyx_t_11))) {
              __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_11);
              assert(__pyx_t_12);
              PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_11);
              __Pyx_INCREF(__pyx_t_12);
              __Pyx_INCREF(__pyx__function);
              __Pyx_DECREF_SET(__pyx_t_11, __pyx__function);
              __pyx_t_15 = 0;
            }
            #endif
            {
              PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_12, NULL};
              __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 850, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_13);
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_microseconds, __pyx_t_14, __pyx_t_13, __pyx_callargs+1, 0) < (0)) __PYX_ERR(1, 850, __pyx_L14_error)
              __pyx_t_10 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_11, __pyx_callargs+__pyx_t_15, (1-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
              __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
              __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
              if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 850, __pyx_L14_error)
              __Pyx_GOTREF(__pyx_t_10);
            }

            /* "psycopg_c/types/datetime.pyx":850
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:
 *                         ts = pg_datetime_epoch + timedelta(             # <<<<<<<<<<<<<<
 *                             microseconds=val + usoff
 *                         )
*/
            __pyx_t_11 = PyNumber_Add(__pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch, __pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 850, __pyx_L14_error)
            __Pyx_GOTREF(__pyx_t_11);
            __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
            __pyx_v_ts = __pyx_t_11;
            __pyx_t_11 = 0;

            /* "psycopg_c/types/datetime.pyx":849
 *                 if utcoff:
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:             # <<<<<<<<<<<<<<
 *                         ts = pg_datetime_epoch + timedelta(
 *                             microseconds=val + usoff
*/
          }

          /* "psycopg_c/types/datetime.pyx":856
 *                         pass  # will raise downstream
 *                     else:
 *                         return ts.replace(tzinfo=self._time_zone)             # <<<<<<<<<<<<<<
 * 
 *             if val <= 0:
*/
          /*else:*/ {
            __Pyx_XDECREF(__pyx_r);
            __pyx_t_10 = __pyx_v_ts;
            __Pyx_INCREF(__pyx_t_10);
            __pyx_t_15 = 0;
            {
              PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_10, NULL};
              __pyx_t_13 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 856, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_13);
              if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_tzinfo, __pyx_v_self->__pyx_base._time_zone, __pyx_t_13, __pyx_callargs+1, 0) < (0)) __PYX_ERR(1, 856, __pyx_L16_except_error)
              __pyx_t_11 = __Pyx_Object_VectorcallMethod_CallFromBuilder((PyObject*)__pyx_mstate_global->__pyx_n_u_replace, __pyx_callargs+__pyx_t_15, (1-__pyx_t_15) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_13);
              __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 856, __pyx_L16_except_error)
              __Pyx_GOTREF(__pyx_t_11);
            }
            __pyx_r = __pyx_t_11;
            __pyx_t_11 = 0;
            __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
            __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
            __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
            goto __pyx_L17_except_return;
          }
          __pyx_L14_error:;
          __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
          __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
          __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
          __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
          __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;

          /* "psycopg_c/types/datetime.pyx":853
 *                             microseconds=val + usoff
 *                         )
 *                     except OverflowError:             # <<<<<<<<<<<<<<
 *                         pass  # will raise downstream
 *                     else:
*/
          __pyx_t_8 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));
          if (__pyx_t_8) {
            __Pyx_ErrRestore(0,0,0);
            goto __pyx_L15_exception_handled;
          }
          goto __pyx_L16_except_error;

          /* "psycopg_c/types/datetime.pyx":849
 *                 if utcoff:
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:             # <<<<<<<<<<<<<<
 *                         ts = pg_datetime_epoch + timedelta(
 *                             microseconds=val + usoff
*/
          __pyx_L16_except_error:;
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          goto __pyx_L5_except_error;
          __pyx_L17_except_return:;
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
          goto __pyx_L6_except_return;
          __pyx_L15_exception_handled:;
          __Pyx_XGIVEREF(__pyx_t_16);
          __Pyx_XGIVEREF(__pyx_t_17);
          __Pyx_XGIVEREF(__pyx_t_18);
          __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
        }

        /* "psycopg_c/types/datetime.pyx":847
 *                     datetime.min if val < 0 else datetime.max
 *                 )
 *                 if utcoff:             # <<<<<<<<<<<<<<
 *                     usoff = 1_000_000 * int(utcoff.total_seconds())
 *                     try:
*/
      }

      /* "psycopg_c/types/datetime.pyx":843
 *             # timezone) we can still save the day by shifting the value by the
 *             # timezone offset and then replacing the timezone.
 *             if self._time_zone is not None:             # <<<<<<<<<<<<<<
 *                 utcoff = self._time_zone.utcoffset(
 *                     datetime.min if val < 0 else datetime.max
*/
    }

    /* "psycopg_c/types/datetime.pyx":858
 *                         return ts.replace(tzinfo=self._time_zone)
 * 
 *             if val <= 0:             # <<<<<<<<<<<<<<
 *                 raise e.DataError(
 *                     "timestamp too small (before year 1)"
*/
    __pyx_t_2 = (__pyx_v_val <= 0);
    if (unlikely(__pyx_t_2)) {

      /* "psycopg_c/types/datetime.pyx":859
 * 
 *             if val <= 0:
 *                 raise e.DataError(             # <<<<<<<<<<<<<<
 *                     "timestamp too small (before year 1)"
 *                 ) from None
*/
      __pyx_t_13 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 859, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 859, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __pyx_t_15 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
        assert(__pyx_t_13);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
        __pyx_t_15 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_mstate_global->__pyx_kp_u_timestamp_too_small_before_year};
        __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 859, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_11);
      }

      /* "psycopg_c/types/datetime.pyx":861
 *                 raise e.DataError(
 *                     "timestamp too small (before year 1)"
 *                 ) from None             # <<<<<<<<<<<<<<
 *             else:
 *                 raise e.DataError(
*/
      __Pyx_Raise(__pyx_t_11, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __PYX_ERR(1, 859, __pyx_L5_except_error)

      /* "psycopg_c/types/datetime.pyx":858
 *                         return ts.replace(tzinfo=self._time_zone)
 * 
 *             if val <= 0:             # <<<<<<<<<<<<<<
 *                 raise e.DataError(
 *                     "timestamp too small (before year 1)"
*/
    }

    /* "psycopg_c/types/datetime.pyx":863
 *                 ) from None
 *             else:
 *                 raise e.DataError(             # <<<<<<<<<<<<<<
 *                     "timestamp too large (after year 10K)"
 *                 ) from None
*/
    /*else*/ {
      __pyx_t_14 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 863, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 863, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_10);
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      __pyx_t_15 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_10))) {
        __pyx_t_14 = PyMethod_GET_SELF(__pyx_t_10);
        assert(__pyx_t_14);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
        __Pyx_INCREF(__pyx_t_14);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
        __pyx_t_15 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_14, __pyx_mstate_global->__pyx_kp_u_timestamp_too_large_after_year_1};
        __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 863, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_11);
      }

      /* "psycopg_c/types/datetime.pyx":865
 *                 raise e.DataError(
 *                     "timestamp too large (after year 10K)"
 *                 ) from None             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __Pyx_Raise(__pyx_t_11, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __PYX_ERR(1, 863, __pyx_L5_except_error)
    }
  }
  goto __pyx_L5_except_error;

  /* "psycopg_c/types/datetime.pyx":829
 *             secs %= 86_400
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             delta = cdt.timedelta_new(<int>days, <int>secs, <int>micros)
 *             if val > 0:
*/
  __pyx_L5_except_error:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L1_error;
  __pyx_L7_try_return:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L0;
  __pyx_L6_except_return:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":811
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF((PyObject *)__pyx_v_delta);
__Pyx_XDECREF(__pyx_v_dt);
__Pyx_XDECREF(__pyx_v_utcoff);
__Pyx_XDECREF(__pyx_v_usoff);
__Pyx_XDECREF(__pyx_v_ts);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TimestamptzBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":874
 *     cdef int _style
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(1, 874, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 874, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 874, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(1, 874, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(1, 874, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(1, 874, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(1, 874, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(1, 874, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(1, 874, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(1, 874, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_ds;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
char const *__pyx_t_2;
int __pyx_t_3;
int __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/datetime.pyx":876
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)             # <<<<<<<<<<<<<<
 *         if ds[0] == b'p' and ds[8] == 0:  # postgres
 *             self._style = INTERVALSTYLE_POSTGRES
*/
__pyx_t_1 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg__get_intervalstyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_1)); if (unlikely(__pyx_t_2 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 876, __pyx_L1_error)
__pyx_v_ds = __pyx_t_2;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":877
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
 *         if ds[0] == b'p' and ds[8] == 0:  # postgres             # <<<<<<<<<<<<<<
 *             self._style = INTERVALSTYLE_POSTGRES
 *         else:  # iso_8601, sql_standard, postgres_verbose
*/
__pyx_t_4 = ((__pyx_v_ds[0]) == 'p');
if (__pyx_t_4) {
} else {
  __pyx_t_3 = __pyx_t_4;
  goto __pyx_L4_bool_binop_done;
}
__pyx_t_4 = ((__pyx_v_ds[8]) == 0);
__pyx_t_3 = __pyx_t_4;
__pyx_L4_bool_binop_done:;
if (__pyx_t_3) {

  /* "psycopg_c/types/datetime.pyx":878
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
 *         if ds[0] == b'p' and ds[8] == 0:  # postgres
 *             self._style = INTERVALSTYLE_POSTGRES             # <<<<<<<<<<<<<<
 *         else:  # iso_8601, sql_standard, postgres_verbose
 *             self._style = INTERVALSTYLE_OTHERS
*/
  __pyx_v_self->_style = __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_POSTGRES;

  /* "psycopg_c/types/datetime.pyx":877
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
 *         if ds[0] == b'p' and ds[8] == 0:  # postgres             # <<<<<<<<<<<<<<
 *             self._style = INTERVALSTYLE_POSTGRES
 *         else:  # iso_8601, sql_standard, postgres_verbose
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":880
 *             self._style = INTERVALSTYLE_POSTGRES
 *         else:  # iso_8601, sql_standard, postgres_verbose
 *             self._style = INTERVALSTYLE_OTHERS             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
/*else*/ {
  __pyx_v_self->_style = __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_OTHERS;
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":874
 *     cdef int _style
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         cdef const char *ds = _get_intervalstyle(self._pgconn)
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":882
 *             self._style = INTERVALSTYLE_OTHERS
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self._style == INTERVALSTYLE_OTHERS:
 *             return self._cload_notimpl(data, length)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
int __pyx_v_days;
int __pyx_v_us;
int64_t __pyx_v_secs;
char __pyx_v_sign;
int64_t __pyx_v_val;
char const *__pyx_v_ptr;
char const *__pyx_v_sep;
char const *__pyx_v_end;
PyObject *__pyx_v_s = NULL;
int64_t __pyx_v_vals[3];
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
int __pyx_t_3;
char const *__pyx_t_4;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
size_t __pyx_t_7;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
char const *__pyx_t_10;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
int __pyx_t_14;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17 = NULL;
PyObject *__pyx_t_18[4];
PyObject *__pyx_t_19 = NULL;
int __pyx_t_20;
char const *__pyx_t_21;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
PyObject *__pyx_t_24 = NULL;
PyObject *__pyx_t_25 = NULL;
PyObject *__pyx_t_26 = NULL;
PyObject *__pyx_t_27 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":883
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self._style == INTERVALSTYLE_OTHERS:             # <<<<<<<<<<<<<<
 *             return self._cload_notimpl(data, length)
 * 
*/
__pyx_t_1 = (__pyx_v_self->_style == __pyx_e_9psycopg_c_8_psycopg_INTERVALSTYLE_OTHERS);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":884
 *     cdef object cload(self, const char *data, size_t length):
 *         if self._style == INTERVALSTYLE_OTHERS:
 *             return self._cload_notimpl(data, length)             # <<<<<<<<<<<<<<
 * 
 *         cdef int days = 0, us = 0
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_14IntervalLoader__cload_notimpl(__pyx_v_self, __pyx_v_data, __pyx_v_length); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":883
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self._style == INTERVALSTYLE_OTHERS:             # <<<<<<<<<<<<<<
 *             return self._cload_notimpl(data, length)
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":886
 *             return self._cload_notimpl(data, length)
 * 
 *         cdef int days = 0, us = 0             # <<<<<<<<<<<<<<
 *         cdef int64_t secs = 0
 *         cdef char sign
*/
__pyx_v_days = 0;
__pyx_v_us = 0;

/* "psycopg_c/types/datetime.pyx":887
 * 
 *         cdef int days = 0, us = 0
 *         cdef int64_t secs = 0             # <<<<<<<<<<<<<<
 *         cdef char sign
 *         cdef int64_t val
*/
__pyx_v_secs = 0;

/* "psycopg_c/types/datetime.pyx":890
 *         cdef char sign
 *         cdef int64_t val
 *         cdef const char *ptr = data             # <<<<<<<<<<<<<<
 *         cdef const char *sep
 *         cdef const char *end = ptr + length
*/
__pyx_v_ptr = __pyx_v_data;

/* "psycopg_c/types/datetime.pyx":892
 *         cdef const char *ptr = data
 *         cdef const char *sep
 *         cdef const char *end = ptr + length             # <<<<<<<<<<<<<<
 * 
 *         while True:
*/
__pyx_v_end = (__pyx_v_ptr + __pyx_v_length);

/* "psycopg_c/types/datetime.pyx":894
 *         cdef const char *end = ptr + length
 * 
 *         while True:             # <<<<<<<<<<<<<<
 *             # If there are spaces, there is a [+|-]n [days|months|years]
 *             sep = strchr(ptr, b' ')
*/
while (1) {

  /* "psycopg_c/types/datetime.pyx":896
 *         while True:
 *             # If there are spaces, there is a [+|-]n [days|months|years]
 *             sep = strchr(ptr, b' ')             # <<<<<<<<<<<<<<
 *             if sep == NULL or sep > end:
 *                 break
*/
  __pyx_v_sep = strchr(__pyx_v_ptr, ' ');

  /* "psycopg_c/types/datetime.pyx":897
 *             # If there are spaces, there is a [+|-]n [days|months|years]
 *             sep = strchr(ptr, b' ')
 *             if sep == NULL or sep > end:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
  __pyx_t_3 = (__pyx_v_sep == NULL);
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_sep > __pyx_v_end);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":898
 *             sep = strchr(ptr, b' ')
 *             if sep == NULL or sep > end:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *             if ptr[0] == b'-' or ptr[0] == b'+':
*/
    goto __pyx_L5_break;

    /* "psycopg_c/types/datetime.pyx":897
 *             # If there are spaces, there is a [+|-]n [days|months|years]
 *             sep = strchr(ptr, b' ')
 *             if sep == NULL or sep > end:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
  }

  /* "psycopg_c/types/datetime.pyx":900
 *                 break
 * 
 *             if ptr[0] == b'-' or ptr[0] == b'+':             # <<<<<<<<<<<<<<
 *                 sign = ptr[0]
 *                 ptr += 1
*/
  __pyx_t_3 = ((__pyx_v_ptr[0]) == '-');
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L10_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_ptr[0]) == '+');
  __pyx_t_1 = __pyx_t_3;
  __pyx_L10_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":901
 * 
 *             if ptr[0] == b'-' or ptr[0] == b'+':
 *                 sign = ptr[0]             # <<<<<<<<<<<<<<
 *                 ptr += 1
 *             else:
*/
    __pyx_v_sign = (__pyx_v_ptr[0]);

    /* "psycopg_c/types/datetime.pyx":902
 *             if ptr[0] == b'-' or ptr[0] == b'+':
 *                 sign = ptr[0]
 *                 ptr += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 sign = 0
*/
    __pyx_v_ptr = (__pyx_v_ptr + 1);

    /* "psycopg_c/types/datetime.pyx":900
 *                 break
 * 
 *             if ptr[0] == b'-' or ptr[0] == b'+':             # <<<<<<<<<<<<<<
 *                 sign = ptr[0]
 *                 ptr += 1
*/
    goto __pyx_L9;
  }

  /* "psycopg_c/types/datetime.pyx":904
 *                 ptr += 1
 *             else:
 *                 sign = 0             # <<<<<<<<<<<<<<
 * 
 *             val = 0
*/
  /*else*/ {
    __pyx_v_sign = 0;
  }
  __pyx_L9:;

  /* "psycopg_c/types/datetime.pyx":906
 *                 sign = 0
 * 
 *             val = 0             # <<<<<<<<<<<<<<
 *             ptr = _parse_date_values(ptr, end, &val, 1)
 *             if ptr == NULL:
*/
  __pyx_v_val = 0;

  /* "psycopg_c/types/datetime.pyx":907
 * 
 *             val = 0
 *             ptr = _parse_date_values(ptr, end, &val, 1)             # <<<<<<<<<<<<<<
 *             if ptr == NULL:
 *                 s = bytes(data).decode("utf8", "replace")
*/
  __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_ptr, __pyx_v_end, (&__pyx_v_val), 1); if (unlikely(__pyx_t_4 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 907, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_4;

  /* "psycopg_c/types/datetime.pyx":908
 *             val = 0
 *             ptr = _parse_date_values(ptr, end, &val, 1)
 *             if ptr == NULL:             # <<<<<<<<<<<<<<
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")
*/
  __pyx_t_1 = (__pyx_v_ptr == NULL);
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/types/datetime.pyx":909
 *             ptr = _parse_date_values(ptr, end, &val, 1)
 *             if ptr == NULL:
 *                 s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *                 raise e.DataError(f"can't parse interval {s!r}")
 * 
*/
    __pyx_t_5 = NULL;
    __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 909, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_t_6 = __Pyx_decode_bytes(__pyx_t_2, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 909, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_s = ((PyObject*)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "psycopg_c/types/datetime.pyx":910
 *             if ptr == NULL:
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")             # <<<<<<<<<<<<<<
 * 
 *             if sign == b'-':
*/
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_9 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_interval, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_8);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_8);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_8, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_9};
      __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_8, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 910, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(1, 910, __pyx_L1_error)

    /* "psycopg_c/types/datetime.pyx":908
 *             val = 0
 *             ptr = _parse_date_values(ptr, end, &val, 1)
 *             if ptr == NULL:             # <<<<<<<<<<<<<<
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")
*/
  }

  /* "psycopg_c/types/datetime.pyx":912
 *                 raise e.DataError(f"can't parse interval {s!r}")
 * 
 *             if sign == b'-':             # <<<<<<<<<<<<<<
 *                 val = -val
 * 
*/
  __pyx_t_1 = (__pyx_v_sign == '-');
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":913
 * 
 *             if sign == b'-':
 *                 val = -val             # <<<<<<<<<<<<<<
 * 
 *             if ptr[1] == b'y':
*/
    __pyx_v_val = (-__pyx_v_val);

    /* "psycopg_c/types/datetime.pyx":912
 *                 raise e.DataError(f"can't parse interval {s!r}")
 * 
 *             if sign == b'-':             # <<<<<<<<<<<<<<
 *                 val = -val
 * 
*/
  }

  /* "psycopg_c/types/datetime.pyx":915
 *                 val = -val
 * 
 *             if ptr[1] == b'y':             # <<<<<<<<<<<<<<
 *                 days += 365 * val
 *             elif ptr[1] == b'm':
*/
  __pyx_t_1 = ((__pyx_v_ptr[1]) == 'y');
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":916
 * 
 *             if ptr[1] == b'y':
 *                 days += 365 * val             # <<<<<<<<<<<<<<
 *             elif ptr[1] == b'm':
 *                 days += 30 * val
*/
    __pyx_v_days = (__pyx_v_days + (0x16D * __pyx_v_val));

    /* "psycopg_c/types/datetime.pyx":915
 *                 val = -val
 * 
 *             if ptr[1] == b'y':             # <<<<<<<<<<<<<<
 *                 days += 365 * val
 *             elif ptr[1] == b'm':
*/
    goto __pyx_L14;
  }

  /* "psycopg_c/types/datetime.pyx":917
 *             if ptr[1] == b'y':
 *                 days += 365 * val
 *             elif ptr[1] == b'm':             # <<<<<<<<<<<<<<
 *                 days += 30 * val
 *             elif ptr[1] == b'd':
*/
  __pyx_t_1 = ((__pyx_v_ptr[1]) == 'm');
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":918
 *                 days += 365 * val
 *             elif ptr[1] == b'm':
 *                 days += 30 * val             # <<<<<<<<<<<<<<
 *             elif ptr[1] == b'd':
 *                 days += val
*/
    __pyx_v_days = (__pyx_v_days + (30 * __pyx_v_val));

    /* "psycopg_c/types/datetime.pyx":917
 *             if ptr[1] == b'y':
 *                 days += 365 * val
 *             elif ptr[1] == b'm':             # <<<<<<<<<<<<<<
 *                 days += 30 * val
 *             elif ptr[1] == b'd':
*/
    goto __pyx_L14;
  }

  /* "psycopg_c/types/datetime.pyx":919
 *             elif ptr[1] == b'm':
 *                 days += 30 * val
 *             elif ptr[1] == b'd':             # <<<<<<<<<<<<<<
 *                 days += val
 *             else:
*/
  __pyx_t_1 = ((__pyx_v_ptr[1]) == 'd');
  if (likely(__pyx_t_1)) {

    /* "psycopg_c/types/datetime.pyx":920
 *                 days += 30 * val
 *             elif ptr[1] == b'd':
 *                 days += val             # <<<<<<<<<<<<<<
 *             else:
 *                 s = bytes(data).decode("utf8", "replace")
*/
    __pyx_v_days = (__pyx_v_days + __pyx_v_val);

    /* "psycopg_c/types/datetime.pyx":919
 *             elif ptr[1] == b'm':
 *                 days += 30 * val
 *             elif ptr[1] == b'd':             # <<<<<<<<<<<<<<
 *                 days += val
 *             else:
*/
    goto __pyx_L14;
  }

  /* "psycopg_c/types/datetime.pyx":922
 *                 days += val
 *             else:
 *                 s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *                 raise e.DataError(f"can't parse interval {s!r}")
 * 
*/
  /*else*/ {
    __pyx_t_8 = NULL;
    __pyx_t_9 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_9};
      __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 922, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_t_9 = __Pyx_decode_bytes(__pyx_t_6, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 922, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_s = ((PyObject*)__pyx_t_9);
    __pyx_t_9 = 0;

    /* "psycopg_c/types/datetime.pyx":923
 *             else:
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")             # <<<<<<<<<<<<<<
 * 
 *             # Skip the date part word.
*/
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_5 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_interval, __pyx_t_8); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 923, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_2, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_5};
      __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 923, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    }
    __Pyx_Raise(__pyx_t_9, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __PYX_ERR(1, 923, __pyx_L1_error)
  }
  __pyx_L14:;

  /* "psycopg_c/types/datetime.pyx":926
 * 
 *             # Skip the date part word.
 *             ptr = strchr(ptr + 1, b' ')             # <<<<<<<<<<<<<<
 *             if ptr != NULL and ptr < end:
 *                 ptr += 1
*/
  __pyx_v_ptr = strchr((__pyx_v_ptr + 1), ' ');

  /* "psycopg_c/types/datetime.pyx":927
 *             # Skip the date part word.
 *             ptr = strchr(ptr + 1, b' ')
 *             if ptr != NULL and ptr < end:             # <<<<<<<<<<<<<<
 *                 ptr += 1
 *             else:
*/
  __pyx_t_3 = (__pyx_v_ptr != NULL);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L16_bool_binop_done;
  }
  __pyx_t_3 = (__pyx_v_ptr < __pyx_v_end);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L16_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":928
 *             ptr = strchr(ptr + 1, b' ')
 *             if ptr != NULL and ptr < end:
 *                 ptr += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 break
*/
    __pyx_v_ptr = (__pyx_v_ptr + 1);

    /* "psycopg_c/types/datetime.pyx":927
 *             # Skip the date part word.
 *             ptr = strchr(ptr + 1, b' ')
 *             if ptr != NULL and ptr < end:             # <<<<<<<<<<<<<<
 *                 ptr += 1
 *             else:
*/
    goto __pyx_L15;
  }

  /* "psycopg_c/types/datetime.pyx":930
 *                 ptr += 1
 *             else:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         # Parse the time part if present
*/
  /*else*/ {
    goto __pyx_L5_break;
  }
  __pyx_L15:;
}
__pyx_L5_break:;

/* "psycopg_c/types/datetime.pyx":934
 *         # Parse the time part if present
 *         cdef int64_t vals[3]
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             memset(vals, 0, sizeof(vals))
 * 
*/
__pyx_t_1 = (__pyx_v_ptr != NULL);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":935
 *         cdef int64_t vals[3]
 *         if ptr != NULL:
 *             memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 * 
 *             # Parse the sign of the time part.
*/
  (void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

  /* "psycopg_c/types/datetime.pyx":938
 * 
 *             # Parse the sign of the time part.
 *             if ptr[0] == b'-' or ptr[0] == b'+':             # <<<<<<<<<<<<<<
 *                 sign = ptr[0]
 *                 ptr += 1
*/
  __pyx_t_3 = ((__pyx_v_ptr[0]) == '-');
  if (!__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L20_bool_binop_done;
  }
  __pyx_t_3 = ((__pyx_v_ptr[0]) == '+');
  __pyx_t_1 = __pyx_t_3;
  __pyx_L20_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":939
 *             # Parse the sign of the time part.
 *             if ptr[0] == b'-' or ptr[0] == b'+':
 *                 sign = ptr[0]             # <<<<<<<<<<<<<<
 *                 ptr += 1
 *             else:
*/
    __pyx_v_sign = (__pyx_v_ptr[0]);

    /* "psycopg_c/types/datetime.pyx":940
 *             if ptr[0] == b'-' or ptr[0] == b'+':
 *                 sign = ptr[0]
 *                 ptr += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 sign = 0
*/
    __pyx_v_ptr = (__pyx_v_ptr + 1);

    /* "psycopg_c/types/datetime.pyx":938
 * 
 *             # Parse the sign of the time part.
 *             if ptr[0] == b'-' or ptr[0] == b'+':             # <<<<<<<<<<<<<<
 *                 sign = ptr[0]
 *                 ptr += 1
*/
    goto __pyx_L19;
  }

  /* "psycopg_c/types/datetime.pyx":942
 *                 ptr += 1
 *             else:
 *                 sign = 0             # <<<<<<<<<<<<<<
 * 
 *             ptr = _parse_date_values(ptr, end, vals, ARRAYSIZE(vals))
*/
  /*else*/ {
    __pyx_v_sign = 0;
  }
  __pyx_L19:;

  /* "psycopg_c/types/datetime.pyx":944
 *                 sign = 0
 * 
 *             ptr = _parse_date_values(ptr, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *             if ptr == NULL:
 *                 s = bytes(data).decode("utf8", "replace")
*/
  __pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values(__pyx_v_ptr, __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_4 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 944, __pyx_L1_error)
  __pyx_v_ptr = __pyx_t_4;

  /* "psycopg_c/types/datetime.pyx":945
 * 
 *             ptr = _parse_date_values(ptr, end, vals, ARRAYSIZE(vals))
 *             if ptr == NULL:             # <<<<<<<<<<<<<<
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")
*/
  __pyx_t_1 = (__pyx_v_ptr == NULL);
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/types/datetime.pyx":946
 *             ptr = _parse_date_values(ptr, end, vals, ARRAYSIZE(vals))
 *             if ptr == NULL:
 *                 s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *                 raise e.DataError(f"can't parse interval {s!r}")
 * 
*/
    __pyx_t_2 = NULL;
    __pyx_t_5 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = 1;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_5};
      __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 946, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_9);
    }
    __pyx_t_5 = __Pyx_decode_bytes(__pyx_t_9, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 946, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_v_s = ((PyObject*)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "psycopg_c/types/datetime.pyx":947
 *             if ptr == NULL:
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")             # <<<<<<<<<<<<<<
 * 
 *             secs = vals[2] + 60 * (vals[1] + 60 * vals[0])
*/
    __pyx_t_9 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_interval, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 947, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_9);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 947, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __PYX_ERR(1, 947, __pyx_L1_error)

    /* "psycopg_c/types/datetime.pyx":945
 * 
 *             ptr = _parse_date_values(ptr, end, vals, ARRAYSIZE(vals))
 *             if ptr == NULL:             # <<<<<<<<<<<<<<
 *                 s = bytes(data).decode("utf8", "replace")
 *                 raise e.DataError(f"can't parse interval {s!r}")
*/
  }

  /* "psycopg_c/types/datetime.pyx":949
 *                 raise e.DataError(f"can't parse interval {s!r}")
 * 
 *             secs = vals[2] + 60 * (vals[1] + 60 * vals[0])             # <<<<<<<<<<<<<<
 * 
 *             if secs > 86_400:
*/
  __pyx_v_secs = ((__pyx_v_vals[2]) + (60 * ((__pyx_v_vals[1]) + (60 * (__pyx_v_vals[0])))));

  /* "psycopg_c/types/datetime.pyx":951
 *             secs = vals[2] + 60 * (vals[1] + 60 * vals[0])
 * 
 *             if secs > 86_400:             # <<<<<<<<<<<<<<
 *                 if sign == b'-':
 *                     days -= secs // 86_400
*/
  __pyx_t_1 = (__pyx_v_secs > 0x15180);
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":952
 * 
 *             if secs > 86_400:
 *                 if sign == b'-':             # <<<<<<<<<<<<<<
 *                     days -= secs // 86_400
 *                 else:
*/
    __pyx_t_1 = (__pyx_v_sign == '-');
    if (__pyx_t_1) {

      /* "psycopg_c/types/datetime.pyx":953
 *             if secs > 86_400:
 *                 if sign == b'-':
 *                     days -= secs // 86_400             # <<<<<<<<<<<<<<
 *                 else:
 *                     days += secs // 86_400
*/
      __pyx_v_days = (__pyx_v_days - __Pyx_div_int64_t(__pyx_v_secs, 0x15180, 1));

      /* "psycopg_c/types/datetime.pyx":952
 * 
 *             if secs > 86_400:
 *                 if sign == b'-':             # <<<<<<<<<<<<<<
 *                     days -= secs // 86_400
 *                 else:
*/
      goto __pyx_L24;
    }

    /* "psycopg_c/types/datetime.pyx":955
 *                     days -= secs // 86_400
 *                 else:
 *                     days += secs // 86_400             # <<<<<<<<<<<<<<
 *                 secs %= 86_400
 * 
*/
    /*else*/ {
      __pyx_v_days = (__pyx_v_days + __Pyx_div_int64_t(__pyx_v_secs, 0x15180, 1));
    }
    __pyx_L24:;

    /* "psycopg_c/types/datetime.pyx":956
 *                 else:
 *                     days += secs // 86_400
 *                 secs %= 86_400             # <<<<<<<<<<<<<<
 * 
 *             if ptr[0] == b'.':
*/
    __pyx_v_secs = __Pyx_mod_int64_t(__pyx_v_secs, 0x15180, 1);

    /* "psycopg_c/types/datetime.pyx":951
 *             secs = vals[2] + 60 * (vals[1] + 60 * vals[0])
 * 
 *             if secs > 86_400:             # <<<<<<<<<<<<<<
 *                 if sign == b'-':
 *                     days -= secs // 86_400
*/
  }

  /* "psycopg_c/types/datetime.pyx":958
 *                 secs %= 86_400
 * 
 *             if ptr[0] == b'.':             # <<<<<<<<<<<<<<
 *                 ptr = _parse_micros(ptr + 1, &us)
 * 
*/
  __pyx_t_1 = ((__pyx_v_ptr[0]) == '.');
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":959
 * 
 *             if ptr[0] == b'.':
 *                 ptr = _parse_micros(ptr + 1, &us)             # <<<<<<<<<<<<<<
 * 
 *             if sign == b'-':
*/
    __pyx_t_10 = __pyx_f_9psycopg_c_8_psycopg__parse_micros((__pyx_v_ptr + 1), (&__pyx_v_us)); if (unlikely(__pyx_t_10 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 959, __pyx_L1_error)
    __pyx_v_ptr = __pyx_t_10;

    /* "psycopg_c/types/datetime.pyx":958
 *                 secs %= 86_400
 * 
 *             if ptr[0] == b'.':             # <<<<<<<<<<<<<<
 *                 ptr = _parse_micros(ptr + 1, &us)
 * 
*/
  }

  /* "psycopg_c/types/datetime.pyx":961
 *                 ptr = _parse_micros(ptr + 1, &us)
 * 
 *             if sign == b'-':             # <<<<<<<<<<<<<<
 *                 secs = -secs
 *                 us = -us
*/
  __pyx_t_1 = (__pyx_v_sign == '-');
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":962
 * 
 *             if sign == b'-':
 *                 secs = -secs             # <<<<<<<<<<<<<<
 *                 us = -us
 * 
*/
    __pyx_v_secs = (-__pyx_v_secs);

    /* "psycopg_c/types/datetime.pyx":963
 *             if sign == b'-':
 *                 secs = -secs
 *                 us = -us             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
    __pyx_v_us = (-__pyx_v_us);

    /* "psycopg_c/types/datetime.pyx":961
 *                 ptr = _parse_micros(ptr + 1, &us)
 * 
 *             if sign == b'-':             # <<<<<<<<<<<<<<
 *                 secs = -secs
 *                 us = -us
*/
  }

  /* "psycopg_c/types/datetime.pyx":934
 *         # Parse the time part if present
 *         cdef int64_t vals[3]
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             memset(vals, 0, sizeof(vals))
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":965
 *                 us = -us
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.timedelta_new(days, secs, us)
 *         except OverflowError as ex:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_11, &__pyx_t_12, &__pyx_t_13);
  __Pyx_XGOTREF(__pyx_t_11);
  __Pyx_XGOTREF(__pyx_t_12);
  __Pyx_XGOTREF(__pyx_t_13);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":966
 * 
 *         try:
 *             return cdt.timedelta_new(days, secs, us)             # <<<<<<<<<<<<<<
 *         except OverflowError as ex:
 *             s = bytes(data).decode("utf8", "replace")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_5 = ((PyObject *)__pyx_f_7cpython_8datetime_timedelta_new(__pyx_v_days, __pyx_v_secs, __pyx_v_us)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 966, __pyx_L27_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_r = __pyx_t_5;
    __pyx_t_5 = 0;
    goto __pyx_L31_try_return;

    /* "psycopg_c/types/datetime.pyx":965
 *                 us = -us
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.timedelta_new(days, secs, us)
 *         except OverflowError as ex:
*/
  }
  __pyx_L27_error:;
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;

  /* "psycopg_c/types/datetime.pyx":967
 *         try:
 *             return cdt.timedelta_new(days, secs, us)
 *         except OverflowError as ex:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse interval {s!r}: {ex}") from None
*/
  __pyx_t_14 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));
  if (__pyx_t_14) {
    __Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_8) < 0) __PYX_ERR(1, 967, __pyx_L29_except_error)
    __Pyx_XGOTREF(__pyx_t_5);
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_INCREF(__pyx_t_6);
    __pyx_v_ex = __pyx_t_6;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":968
 *             return cdt.timedelta_new(days, secs, us)
 *         except OverflowError as ex:
 *             s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse interval {s!r}: {ex}") from None
 * 
*/
      __pyx_t_2 = NULL;
      __pyx_t_15 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 968, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_15);
      __pyx_t_7 = 1;
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_15};
        __pyx_t_9 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
        if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 968, __pyx_L38_error)
        __Pyx_GOTREF(__pyx_t_9);
      }
      __pyx_t_15 = __Pyx_decode_bytes(__pyx_t_9, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 968, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
      __pyx_v_s = ((PyObject*)__pyx_t_15);
      __pyx_t_15 = 0;

      /* "psycopg_c/types/datetime.pyx":969
 *         except OverflowError as ex:
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse interval {s!r}: {ex}") from None             # <<<<<<<<<<<<<<
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):
*/
      __pyx_t_9 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 969, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_16)) __PYX_ERR(1, 969, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 969, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_17 = __Pyx_PyObject_FormatSimple(__pyx_v_ex, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_17)) __PYX_ERR(1, 969, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_17);
      __pyx_t_18[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_interval;
      __pyx_t_18[1] = __pyx_t_2;
      __pyx_t_18[2] = __pyx_mstate_global->__pyx_kp_u__7;
      __pyx_t_18[3] = __pyx_t_17;
      __pyx_t_19 = __Pyx_PyUnicode_Join(__pyx_t_18, 4, 21 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_17), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_17));
      if (unlikely(!__pyx_t_19)) __PYX_ERR(1, 969, __pyx_L38_error)
      __Pyx_GOTREF(__pyx_t_19);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_17); __pyx_t_17 = 0;
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_9 = PyMethod_GET_SELF(__pyx_t_16);
        assert(__pyx_t_9);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_16);
        __Pyx_INCREF(__pyx_t_9);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_16, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_9, __pyx_t_19};
        __pyx_t_15 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_16, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
        if (unlikely(!__pyx_t_15)) __PYX_ERR(1, 969, __pyx_L38_error)
        __Pyx_GOTREF(__pyx_t_15);
      }
      __Pyx_Raise(__pyx_t_15, 0, 0, Py_None);
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __PYX_ERR(1, 969, __pyx_L38_error)
    }

    /* "psycopg_c/types/datetime.pyx":967
 *         try:
 *             return cdt.timedelta_new(days, secs, us)
 *         except OverflowError as ex:             # <<<<<<<<<<<<<<
 *             s = bytes(data).decode("utf8", "replace")
 *             raise e.DataError(f"can't parse interval {s!r}: {ex}") from None
*/
    /*finally:*/ {
      __pyx_L38_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        __Pyx_XDECREF(__pyx_t_19); __pyx_t_19 = 0;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_25, &__pyx_t_26, &__pyx_t_27);
        if ( unlikely(__Pyx_GetException(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24) < 0)) __Pyx_ErrFetch(&__pyx_t_22, &__pyx_t_23, &__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __Pyx_XGOTREF(__pyx_t_24);
        __Pyx_XGOTREF(__pyx_t_25);
        __Pyx_XGOTREF(__pyx_t_26);
        __Pyx_XGOTREF(__pyx_t_27);
        __pyx_t_14 = __pyx_lineno; __pyx_t_20 = __pyx_clineno; __pyx_t_21 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_25);
        __Pyx_XGIVEREF(__pyx_t_26);
        __Pyx_XGIVEREF(__pyx_t_27);
        __Pyx_ExceptionReset(__pyx_t_25, __pyx_t_26, __pyx_t_27);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_XGIVEREF(__pyx_t_24);
        __Pyx_ErrRestore(__pyx_t_22, __pyx_t_23, __pyx_t_24);
        __pyx_t_22 = 0; __pyx_t_23 = 0; __pyx_t_24 = 0; __pyx_t_25 = 0; __pyx_t_26 = 0; __pyx_t_27 = 0;
        __pyx_lineno = __pyx_t_14; __pyx_clineno = __pyx_t_20; __pyx_filename = __pyx_t_21;
        goto __pyx_L29_except_error;
      }
    }
  }
  goto __pyx_L29_except_error;

  /* "psycopg_c/types/datetime.pyx":965
 *                 us = -us
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.timedelta_new(days, secs, us)
 *         except OverflowError as ex:
*/
  __pyx_L29_except_error:;
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_XGIVEREF(__pyx_t_13);
  __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
  goto __pyx_L1_error;
  __pyx_L31_try_return:;
  __Pyx_XGIVEREF(__pyx_t_11);
  __Pyx_XGIVEREF(__pyx_t_12);
  __Pyx_XGIVEREF(__pyx_t_13);
  __Pyx_ExceptionReset(__pyx_t_11, __pyx_t_12, __pyx_t_13);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":882
 *             self._style = INTERVALSTYLE_OTHERS
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self._style == INTERVALSTYLE_OTHERS:
 *             return self._cload_notimpl(data, length)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_15);
__Pyx_XDECREF(__pyx_t_16);
__Pyx_XDECREF(__pyx_t_17);
__Pyx_XDECREF(__pyx_t_19);
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":971
 *             raise e.DataError(f"can't parse interval {s!r}: {ex}") from None
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         s = bytes(data).decode("utf8", "replace")
 *         style = _get_intervalstyle(self._pgconn).decode()
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader__cload_notimpl(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
PyObject *__pyx_v_s = NULL;
PyObject *__pyx_v_style = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
char const *__pyx_t_5;
Py_ssize_t __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8[4];
PyObject *__pyx_t_9 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_cload_notimpl", 0);

/* "psycopg_c/types/datetime.pyx":972
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):
 *         s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 *         style = _get_intervalstyle(self._pgconn).decode()
 *         raise NotImplementedError(
*/
__pyx_t_2 = NULL;
__pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 972, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 972, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_t_3 = __Pyx_decode_bytes(__pyx_t_1, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 972, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_s = ((PyObject*)__pyx_t_3);
__pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":973
 *     cdef object _cload_notimpl(self, const char *data, size_t length):
 *         s = bytes(data).decode("utf8", "replace")
 *         style = _get_intervalstyle(self._pgconn).decode()             # <<<<<<<<<<<<<<
 *         raise NotImplementedError(
 *             f"can't parse interval with IntervalStyle {style!r}: {s!r}"
*/
__pyx_t_3 = ((PyObject *)__pyx_v_self->__pyx_base._pgconn);
__Pyx_INCREF(__pyx_t_3);
__pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg__get_intervalstyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3)); if (unlikely(__pyx_t_5 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 973, __pyx_L1_error)
__pyx_t_6 = __Pyx_ssize_strlen(__pyx_t_5); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(1, 973, __pyx_L1_error)
__pyx_t_1 = __Pyx_decode_c_string(__pyx_t_5, 0, __pyx_t_6, NULL, NULL, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 973, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__Pyx_INCREF(__pyx_t_1);
__pyx_v_style = __pyx_t_1;
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":974
 *         s = bytes(data).decode("utf8", "replace")
 *         style = _get_intervalstyle(self._pgconn).decode()
 *         raise NotImplementedError(             # <<<<<<<<<<<<<<
 *             f"can't parse interval with IntervalStyle {style!r}: {s!r}"
 *         )
*/
__pyx_t_3 = NULL;

/* "psycopg_c/types/datetime.pyx":975
 *         style = _get_intervalstyle(self._pgconn).decode()
 *         raise NotImplementedError(
 *             f"can't parse interval with IntervalStyle {style!r}: {s!r}"             # <<<<<<<<<<<<<<
 *         )
 * 
*/
__pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_style), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 975, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_t_7 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 975, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_7);
__pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_interval_with_Interv;
__pyx_t_8[1] = __pyx_t_2;
__pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u__7;
__pyx_t_8[3] = __pyx_t_7;
__pyx_t_9 = __Pyx_PyUnicode_Join(__pyx_t_8, 4, 40 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 975, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_9);
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_9};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_NotImplementedError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 974, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__Pyx_Raise(__pyx_t_1, 0, 0, 0);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__PYX_ERR(1, 974, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":971
 *             raise e.DataError(f"can't parse interval {s!r}: {ex}") from None
 * 
 *     cdef object _cload_notimpl(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         s = bytes(data).decode("utf8", "replace")
 *         style = _get_intervalstyle(self._pgconn).decode()
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader._cload_notimpl", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_style);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14IntervalLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14IntervalLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14IntervalLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":984
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int64_t beval
 *         cdef int32_t bedm[2]
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_20IntervalBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
int64_t __pyx_v_beval;
int32_t __pyx_v_bedm[2];
int64_t __pyx_v_val;
int32_t __pyx_v_days;
int32_t __pyx_v_months;
int __pyx_v_years;
int64_t __pyx_v_aval;
int64_t __pyx_v_us;
int64_t __pyx_v_ussecs;
int64_t __pyx_v_usdays;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int64_t __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
int __pyx_t_7;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
size_t __pyx_t_15;
int __pyx_t_16;
char const *__pyx_t_17;
PyObject *__pyx_t_18 = NULL;
PyObject *__pyx_t_19 = NULL;
PyObject *__pyx_t_20 = NULL;
PyObject *__pyx_t_21 = NULL;
PyObject *__pyx_t_22 = NULL;
PyObject *__pyx_t_23 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/datetime.pyx":987
 *         cdef int64_t beval
 *         cdef int32_t bedm[2]
 *         memcpy(&beval, data, sizeof(beval))             # <<<<<<<<<<<<<<
 *         memcpy(bedm, data + sizeof(beval), sizeof(bedm))
 *         cdef int64_t val = endian.be64toh(beval)
*/
(void)(memcpy((&__pyx_v_beval), __pyx_v_data, (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/datetime.pyx":988
 *         cdef int32_t bedm[2]
 *         memcpy(&beval, data, sizeof(beval))
 *         memcpy(bedm, data + sizeof(beval), sizeof(bedm))             # <<<<<<<<<<<<<<
 *         cdef int64_t val = endian.be64toh(beval)
 *         cdef int32_t days = endian.be32toh(bedm[0])
*/
(void)(memcpy(__pyx_v_bedm, (__pyx_v_data + (sizeof(__pyx_v_beval))), (sizeof(__pyx_v_bedm))));

/* "psycopg_c/types/datetime.pyx":989
 *         memcpy(&beval, data, sizeof(beval))
 *         memcpy(bedm, data + sizeof(beval), sizeof(bedm))
 *         cdef int64_t val = endian.be64toh(beval)             # <<<<<<<<<<<<<<
 *         cdef int32_t days = endian.be32toh(bedm[0])
 *         cdef int32_t months = endian.be32toh(bedm[1])
*/
__pyx_v_val = be64toh(__pyx_v_beval);

/* "psycopg_c/types/datetime.pyx":990
 *         memcpy(bedm, data + sizeof(beval), sizeof(bedm))
 *         cdef int64_t val = endian.be64toh(beval)
 *         cdef int32_t days = endian.be32toh(bedm[0])             # <<<<<<<<<<<<<<
 *         cdef int32_t months = endian.be32toh(bedm[1])
 * 
*/
__pyx_v_days = be32toh((__pyx_v_bedm[0]));

/* "psycopg_c/types/datetime.pyx":991
 *         cdef int64_t val = endian.be64toh(beval)
 *         cdef int32_t days = endian.be32toh(bedm[0])
 *         cdef int32_t months = endian.be32toh(bedm[1])             # <<<<<<<<<<<<<<
 * 
 *         cdef int years
*/
__pyx_v_months = be32toh((__pyx_v_bedm[1]));

/* "psycopg_c/types/datetime.pyx":995
 *         cdef int years
 *         with cython.cdivision(True):
 *             if months > 0:             # <<<<<<<<<<<<<<
 *                 years = months // 12
 *                 months %= 12
*/
__pyx_t_1 = (__pyx_v_months > 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":996
 *         with cython.cdivision(True):
 *             if months > 0:
 *                 years = months // 12             # <<<<<<<<<<<<<<
 *                 months %= 12
 *                 days += 30 * months + 365 * years
*/
  __pyx_v_years = (__pyx_v_months / 12);

  /* "psycopg_c/types/datetime.pyx":997
 *             if months > 0:
 *                 years = months // 12
 *                 months %= 12             # <<<<<<<<<<<<<<
 *                 days += 30 * months + 365 * years
 *             elif months < 0:
*/
  __pyx_v_months = __Pyx_mod_long(__pyx_v_months, 12, 1);

  /* "psycopg_c/types/datetime.pyx":998
 *                 years = months // 12
 *                 months %= 12
 *                 days += 30 * months + 365 * years             # <<<<<<<<<<<<<<
 *             elif months < 0:
 *                 months = -months
*/
  __pyx_v_days = (__pyx_v_days + ((30 * __pyx_v_months) + (0x16D * __pyx_v_years)));

  /* "psycopg_c/types/datetime.pyx":995
 *         cdef int years
 *         with cython.cdivision(True):
 *             if months > 0:             # <<<<<<<<<<<<<<
 *                 years = months // 12
 *                 months %= 12
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/datetime.pyx":999
 *                 months %= 12
 *                 days += 30 * months + 365 * years
 *             elif months < 0:             # <<<<<<<<<<<<<<
 *                 months = -months
 *                 years = months // 12
*/
__pyx_t_1 = (__pyx_v_months < 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1000
 *                 days += 30 * months + 365 * years
 *             elif months < 0:
 *                 months = -months             # <<<<<<<<<<<<<<
 *                 years = months // 12
 *                 months %= 12
*/
  __pyx_v_months = (-__pyx_v_months);

  /* "psycopg_c/types/datetime.pyx":1001
 *             elif months < 0:
 *                 months = -months
 *                 years = months // 12             # <<<<<<<<<<<<<<
 *                 months %= 12
 *                 days -= 30 * months + 365 * years
*/
  __pyx_v_years = (__pyx_v_months / 12);

  /* "psycopg_c/types/datetime.pyx":1002
 *                 months = -months
 *                 years = months // 12
 *                 months %= 12             # <<<<<<<<<<<<<<
 *                 days -= 30 * months + 365 * years
 * 
*/
  __pyx_v_months = __Pyx_mod_long(__pyx_v_months, 12, 1);

  /* "psycopg_c/types/datetime.pyx":1003
 *                 years = months // 12
 *                 months %= 12
 *                 days -= 30 * months + 365 * years             # <<<<<<<<<<<<<<
 * 
 *         # Work only with positive values as the cdivision behaves differently
*/
  __pyx_v_days = (__pyx_v_days - ((30 * __pyx_v_months) + (0x16D * __pyx_v_years)));

  /* "psycopg_c/types/datetime.pyx":999
 *                 months %= 12
 *                 days += 30 * months + 365 * years
 *             elif months < 0:             # <<<<<<<<<<<<<<
 *                 months = -months
 *                 years = months // 12
*/
}
__pyx_L3:;

/* "psycopg_c/types/datetime.pyx":1007
 *         # Work only with positive values as the cdivision behaves differently
 *         # with negative values, and cdivision=False adds overhead.
 *         cdef int64_t aval = val if val >= 0 else -val             # <<<<<<<<<<<<<<
 *         cdef int64_t us, ussecs, usdays
 * 
*/
__pyx_t_1 = (__pyx_v_val >= 0);
if (__pyx_t_1) {
  __pyx_t_2 = __pyx_v_val;
} else {
  __pyx_t_2 = (-__pyx_v_val);
}
__pyx_v_aval = __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":1012
 *         # Group the micros in bigger stuff or timedelta_new might overflow
 *         with cython.cdivision(True):
 *             ussecs = <int64_t>(aval // 1_000_000)             # <<<<<<<<<<<<<<
 *             us = aval % 1_000_000
 * 
*/
__pyx_v_ussecs = ((int64_t)(__pyx_v_aval / 0xF4240));

/* "psycopg_c/types/datetime.pyx":1013
 *         with cython.cdivision(True):
 *             ussecs = <int64_t>(aval // 1_000_000)
 *             us = aval % 1_000_000             # <<<<<<<<<<<<<<
 * 
 *             usdays = ussecs // 86_400
*/
__pyx_v_us = (__pyx_v_aval % 0xF4240);

/* "psycopg_c/types/datetime.pyx":1015
 *             us = aval % 1_000_000
 * 
 *             usdays = ussecs // 86_400             # <<<<<<<<<<<<<<
 *             ussecs %= 86_400
 * 
*/
__pyx_v_usdays = (__pyx_v_ussecs / 0x15180);

/* "psycopg_c/types/datetime.pyx":1016
 * 
 *             usdays = ussecs // 86_400
 *             ussecs %= 86_400             # <<<<<<<<<<<<<<
 * 
 *         if val < 0:
*/
__pyx_v_ussecs = __Pyx_mod_int64_t(__pyx_v_ussecs, 0x15180, 1);

/* "psycopg_c/types/datetime.pyx":1018
 *             ussecs %= 86_400
 * 
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             ussecs = -ussecs
 *             usdays = -usdays
*/
__pyx_t_1 = (__pyx_v_val < 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1019
 * 
 *         if val < 0:
 *             ussecs = -ussecs             # <<<<<<<<<<<<<<
 *             usdays = -usdays
 *             us = -us
*/
  __pyx_v_ussecs = (-__pyx_v_ussecs);

  /* "psycopg_c/types/datetime.pyx":1020
 *         if val < 0:
 *             ussecs = -ussecs
 *             usdays = -usdays             # <<<<<<<<<<<<<<
 *             us = -us
 * 
*/
  __pyx_v_usdays = (-__pyx_v_usdays);

  /* "psycopg_c/types/datetime.pyx":1021
 *             ussecs = -ussecs
 *             usdays = -usdays
 *             us = -us             # <<<<<<<<<<<<<<
 * 
 *         try:
*/
  __pyx_v_us = (-__pyx_v_us);

  /* "psycopg_c/types/datetime.pyx":1018
 *             ussecs %= 86_400
 * 
 *         if val < 0:             # <<<<<<<<<<<<<<
 *             ussecs = -ussecs
 *             usdays = -usdays
*/
}

/* "psycopg_c/types/datetime.pyx":1023
 *             us = -us
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.timedelta_new(days + usdays, ussecs, us)
 *         except OverflowError as ex:
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
  __Pyx_XGOTREF(__pyx_t_3);
  __Pyx_XGOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_t_5);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":1024
 * 
 *         try:
 *             return cdt.timedelta_new(days + usdays, ussecs, us)             # <<<<<<<<<<<<<<
 *         except OverflowError as ex:
 *             raise e.DataError(f"can't parse interval: {ex}")
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)__pyx_f_7cpython_8datetime_timedelta_new((__pyx_v_days + __pyx_v_usdays), __pyx_v_ussecs, __pyx_v_us)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 1024, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L9_try_return;

    /* "psycopg_c/types/datetime.pyx":1023
 *             us = -us
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.timedelta_new(days + usdays, ussecs, us)
 *         except OverflowError as ex:
*/
  }
  __pyx_L5_error:;
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":1025
 *         try:
 *             return cdt.timedelta_new(days + usdays, ussecs, us)
 *         except OverflowError as ex:             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse interval: {ex}")
 * 
*/
  __pyx_t_7 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_OverflowError))));
  if (__pyx_t_7) {
    __Pyx_AddTraceback("psycopg_c._psycopg.IntervalBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_8, &__pyx_t_9) < 0) __PYX_ERR(1, 1025, __pyx_L7_except_error)
    __Pyx_XGOTREF(__pyx_t_6);
    __Pyx_XGOTREF(__pyx_t_8);
    __Pyx_XGOTREF(__pyx_t_9);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_v_ex = __pyx_t_8;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":1026
 *             return cdt.timedelta_new(days + usdays, ussecs, us)
 *         except OverflowError as ex:
 *             raise e.DataError(f"can't parse interval: {ex}")             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_11 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 1026, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 1026, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_13);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_12 = __Pyx_PyObject_FormatSimple(__pyx_v_ex, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 1026, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_14 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_can_t_parse_interval_2, __pyx_t_12); if (unlikely(!__pyx_t_14)) __PYX_ERR(1, 1026, __pyx_L16_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      __pyx_t_15 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_13))) {
        __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
        assert(__pyx_t_11);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
        __Pyx_INCREF(__pyx_t_11);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
        __pyx_t_15 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_11, __pyx_t_14};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_15, (2-__pyx_t_15) | (__pyx_t_15*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 1026, __pyx_L16_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_Raise(__pyx_t_10, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __PYX_ERR(1, 1026, __pyx_L16_error)
    }

    /* "psycopg_c/types/datetime.pyx":1025
 *         try:
 *             return cdt.timedelta_new(days + usdays, ussecs, us)
 *         except OverflowError as ex:             # <<<<<<<<<<<<<<
 *             raise e.DataError(f"can't parse interval: {ex}")
 * 
*/
    /*finally:*/ {
      __pyx_L16_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_21, &__pyx_t_22, &__pyx_t_23);
        if ( unlikely(__Pyx_GetException(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20) < 0)) __Pyx_ErrFetch(&__pyx_t_18, &__pyx_t_19, &__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_21);
        __Pyx_XGOTREF(__pyx_t_22);
        __Pyx_XGOTREF(__pyx_t_23);
        __pyx_t_7 = __pyx_lineno; __pyx_t_16 = __pyx_clineno; __pyx_t_17 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_22);
        __Pyx_XGIVEREF(__pyx_t_23);
        __Pyx_ExceptionReset(__pyx_t_21, __pyx_t_22, __pyx_t_23);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_ErrRestore(__pyx_t_18, __pyx_t_19, __pyx_t_20);
        __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0; __pyx_t_22 = 0; __pyx_t_23 = 0;
        __pyx_lineno = __pyx_t_7; __pyx_clineno = __pyx_t_16; __pyx_filename = __pyx_t_17;
        goto __pyx_L7_except_error;
      }
    }
  }
  goto __pyx_L7_except_error;

  /* "psycopg_c/types/datetime.pyx":1023
 *             us = -us
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             return cdt.timedelta_new(days + usdays, ussecs, us)
 *         except OverflowError as ex:
*/
  __pyx_L7_except_error:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L1_error;
  __pyx_L9_try_return:;
  __Pyx_XGIVEREF(__pyx_t_3);
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":984
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int64_t beval
 *         cdef int32_t bedm[2]
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20IntervalBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20IntervalBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20IntervalBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20IntervalBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20IntervalBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20IntervalBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntervalBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1029
 * 
 * 
 * cdef const char *_parse_date_values(             # <<<<<<<<<<<<<<
 *     const char *ptr, const char *end, int64_t *vals, int nvals
 * ):
*/

static char const *__pyx_f_9psycopg_c_8_psycopg__parse_date_values(char const *__pyx_v_ptr, char const *__pyx_v_end, int64_t *__pyx_v_vals, int __pyx_v_nvals) {
int __pyx_v_ival;
char const *__pyx_r;
int __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":1039
 *     Return the pointer at the separator after the final digit.
 *     """
 *     cdef int ival = 0             # <<<<<<<<<<<<<<
 *     while ptr < end:
 *         if b'0' <= ptr[0] <= b'9':
*/
__pyx_v_ival = 0;

/* "psycopg_c/types/datetime.pyx":1040
 *     """
 *     cdef int ival = 0
 *     while ptr < end:             # <<<<<<<<<<<<<<
 *         if b'0' <= ptr[0] <= b'9':
 *             vals[ival] = vals[ival] * 10 + (ptr[0] - <char>b'0')
*/
while (1) {
  __pyx_t_1 = (__pyx_v_ptr < __pyx_v_end);
  if (!__pyx_t_1) break;

  /* "psycopg_c/types/datetime.pyx":1041
 *     cdef int ival = 0
 *     while ptr < end:
 *         if b'0' <= ptr[0] <= b'9':             # <<<<<<<<<<<<<<
 *             vals[ival] = vals[ival] * 10 + (ptr[0] - <char>b'0')
 *         else:
*/
  __pyx_t_1 = ('0' <= (__pyx_v_ptr[0]));
  if (__pyx_t_1) {
    __pyx_t_1 = ((__pyx_v_ptr[0]) <= '9');
  }
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":1042
 *     while ptr < end:
 *         if b'0' <= ptr[0] <= b'9':
 *             vals[ival] = vals[ival] * 10 + (ptr[0] - <char>b'0')             # <<<<<<<<<<<<<<
 *         else:
 *             ival += 1
*/
    (__pyx_v_vals[__pyx_v_ival]) = (((__pyx_v_vals[__pyx_v_ival]) * 10) + ((__pyx_v_ptr[0]) - ((char)'0')));

    /* "psycopg_c/types/datetime.pyx":1041
 *     cdef int ival = 0
 *     while ptr < end:
 *         if b'0' <= ptr[0] <= b'9':             # <<<<<<<<<<<<<<
 *             vals[ival] = vals[ival] * 10 + (ptr[0] - <char>b'0')
 *         else:
*/
    goto __pyx_L5;
  }

  /* "psycopg_c/types/datetime.pyx":1044
 *             vals[ival] = vals[ival] * 10 + (ptr[0] - <char>b'0')
 *         else:
 *             ival += 1             # <<<<<<<<<<<<<<
 *             if ival >= nvals:
 *                 break
*/
  /*else*/ {
    __pyx_v_ival = (__pyx_v_ival + 1);

    /* "psycopg_c/types/datetime.pyx":1045
 *         else:
 *             ival += 1
 *             if ival >= nvals:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
    __pyx_t_1 = (__pyx_v_ival >= __pyx_v_nvals);
    if (__pyx_t_1) {

      /* "psycopg_c/types/datetime.pyx":1046
 *             ival += 1
 *             if ival >= nvals:
 *                 break             # <<<<<<<<<<<<<<
 * 
 *         ptr += 1
*/
      goto __pyx_L4_break;

      /* "psycopg_c/types/datetime.pyx":1045
 *         else:
 *             ival += 1
 *             if ival >= nvals:             # <<<<<<<<<<<<<<
 *                 break
 * 
*/
    }
  }
  __pyx_L5:;

  /* "psycopg_c/types/datetime.pyx":1048
 *                 break
 * 
 *         ptr += 1             # <<<<<<<<<<<<<<
 * 
 *     return ptr
*/
  __pyx_v_ptr = (__pyx_v_ptr + 1);
}
__pyx_L4_break:;

/* "psycopg_c/types/datetime.pyx":1050
 *         ptr += 1
 * 
 *     return ptr             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_ptr;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1029
 * 
 * 
 * cdef const char *_parse_date_values(             # <<<<<<<<<<<<<<
 *     const char *ptr, const char *end, int64_t *vals, int nvals
 * ):
*/

/* function exit code */
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1053
 * 
 * 
 * cdef const char *_parse_micros(const char *start, int *us):             # <<<<<<<<<<<<<<
 *     """
 *     Parse microseconds from a string.
*/

static char const *__pyx_f_9psycopg_c_8_psycopg__parse_micros(char const *__pyx_v_start, int *__pyx_v_us) {
char const *__pyx_v_ptr;
char const *__pyx_r;
int __pyx_t_1;
int __pyx_t_2;
long __pyx_t_3;

/* "psycopg_c/types/datetime.pyx":1061
 *     Return the pointer at the separator after the final digit.
 *     """
 *     cdef const char *ptr = start             # <<<<<<<<<<<<<<
 *     while ptr[0]:
 *         if b'0' <= ptr[0] <= b'9':
*/
__pyx_v_ptr = __pyx_v_start;

/* "psycopg_c/types/datetime.pyx":1062
 *     """
 *     cdef const char *ptr = start
 *     while ptr[0]:             # <<<<<<<<<<<<<<
 *         if b'0' <= ptr[0] <= b'9':
 *             us[0] = us[0] * 10 + (ptr[0] - <char>b'0')
*/
while (1) {
  __pyx_t_1 = ((__pyx_v_ptr[0]) != 0);
  if (!__pyx_t_1) break;

  /* "psycopg_c/types/datetime.pyx":1063
 *     cdef const char *ptr = start
 *     while ptr[0]:
 *         if b'0' <= ptr[0] <= b'9':             # <<<<<<<<<<<<<<
 *             us[0] = us[0] * 10 + (ptr[0] - <char>b'0')
 *         else:
*/
  __pyx_t_1 = ('0' <= (__pyx_v_ptr[0]));
  if (__pyx_t_1) {
    __pyx_t_1 = ((__pyx_v_ptr[0]) <= '9');
  }
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":1064
 *     while ptr[0]:
 *         if b'0' <= ptr[0] <= b'9':
 *             us[0] = us[0] * 10 + (ptr[0] - <char>b'0')             # <<<<<<<<<<<<<<
 *         else:
 *             break
*/
    (__pyx_v_us[0]) = (((__pyx_v_us[0]) * 10) + ((__pyx_v_ptr[0]) - ((char)'0')));

    /* "psycopg_c/types/datetime.pyx":1063
 *     cdef const char *ptr = start
 *     while ptr[0]:
 *         if b'0' <= ptr[0] <= b'9':             # <<<<<<<<<<<<<<
 *             us[0] = us[0] * 10 + (ptr[0] - <char>b'0')
 *         else:
*/
    goto __pyx_L5;
  }

  /* "psycopg_c/types/datetime.pyx":1066
 *             us[0] = us[0] * 10 + (ptr[0] - <char>b'0')
 *         else:
 *             break             # <<<<<<<<<<<<<<
 * 
 *         ptr += 1
*/
  /*else*/ {
    goto __pyx_L4_break;
  }
  __pyx_L5:;

  /* "psycopg_c/types/datetime.pyx":1068
 *             break
 * 
 *         ptr += 1             # <<<<<<<<<<<<<<
 * 
 *     # Pad the fraction of second to get millis
*/
  __pyx_v_ptr = (__pyx_v_ptr + 1);
}
__pyx_L4_break:;

/* "psycopg_c/types/datetime.pyx":1071
 * 
 *     # Pad the fraction of second to get millis
 *     if us[0] and ptr - start < 6:             # <<<<<<<<<<<<<<
 *         us[0] *= _uspad[ptr - start]
 * 
*/
__pyx_t_2 = ((__pyx_v_us[0]) != 0);
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L7_bool_binop_done;
}
__pyx_t_2 = ((__pyx_v_ptr - __pyx_v_start) < 6);
__pyx_t_1 = __pyx_t_2;
__pyx_L7_bool_binop_done:;
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1072
 *     # Pad the fraction of second to get millis
 *     if us[0] and ptr - start < 6:
 *         us[0] *= _uspad[ptr - start]             # <<<<<<<<<<<<<<
 * 
 *     return ptr
*/
  __pyx_t_3 = 0;
  (__pyx_v_us[__pyx_t_3]) = ((__pyx_v_us[__pyx_t_3]) * (_uspad[(__pyx_v_ptr - __pyx_v_start)]));

  /* "psycopg_c/types/datetime.pyx":1071
 * 
 *     # Pad the fraction of second to get millis
 *     if us[0] and ptr - start < 6:             # <<<<<<<<<<<<<<
 *         us[0] *= _uspad[ptr - start]
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":1074
 *         us[0] *= _uspad[ptr - start]
 * 
 *     return ptr             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_ptr;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1053
 * 
 * 
 * cdef const char *_parse_micros(const char *start, int *us):             # <<<<<<<<<<<<<<
 *     """
 *     Parse microseconds from a string.
*/

/* function exit code */
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1077
 * 
 * 
 * cdef int _parse_timezone_to_seconds(const char **bufptr, const char *end):             # <<<<<<<<<<<<<<
 *     """
 *     Parse a timezone from a string, return Python timezone object.
*/

static int __pyx_f_9psycopg_c_8_psycopg__parse_timezone_to_seconds(char const **__pyx_v_bufptr, char const *__pyx_v_end) {
char const *__pyx_v_ptr;
char __pyx_v_sgn;
int64_t __pyx_v_vals[3];
int __pyx_v_off;
int __pyx_r;
char const *__pyx_t_1;
int __pyx_t_2;
int __pyx_t_3;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/datetime.pyx":1084
 *     timezone parsed. In case of parse error make it NULL.
 *     """
 *     cdef const char *ptr = bufptr[0]             # <<<<<<<<<<<<<<
 *     cdef char sgn = ptr[0]
 * 
*/
__pyx_v_ptr = (__pyx_v_bufptr[0]);

/* "psycopg_c/types/datetime.pyx":1085
 *     """
 *     cdef const char *ptr = bufptr[0]
 *     cdef char sgn = ptr[0]             # <<<<<<<<<<<<<<
 * 
 *     # Parse at most three groups of digits
*/
__pyx_v_sgn = (__pyx_v_ptr[0]);

/* "psycopg_c/types/datetime.pyx":1089
 *     # Parse at most three groups of digits
 *     cdef int64_t vals[3]
 *     memset(vals, 0, sizeof(vals))             # <<<<<<<<<<<<<<
 * 
 *     ptr = _parse_date_values(ptr + 1, end, vals, ARRAYSIZE(vals))
*/
(void)(memset(__pyx_v_vals, 0, (sizeof(__pyx_v_vals))));

/* "psycopg_c/types/datetime.pyx":1091
 *     memset(vals, 0, sizeof(vals))
 * 
 *     ptr = _parse_date_values(ptr + 1, end, vals, ARRAYSIZE(vals))             # <<<<<<<<<<<<<<
 *     if ptr == NULL:
 *         return 0
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg__parse_date_values((__pyx_v_ptr + 1), __pyx_v_end, __pyx_v_vals, ARRAYSIZE(__pyx_v_vals)); if (unlikely(__pyx_t_1 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 1091, __pyx_L1_error)
__pyx_v_ptr = __pyx_t_1;

/* "psycopg_c/types/datetime.pyx":1092
 * 
 *     ptr = _parse_date_values(ptr + 1, end, vals, ARRAYSIZE(vals))
 *     if ptr == NULL:             # <<<<<<<<<<<<<<
 *         return 0
 * 
*/
__pyx_t_2 = (__pyx_v_ptr == NULL);
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":1093
 *     ptr = _parse_date_values(ptr + 1, end, vals, ARRAYSIZE(vals))
 *     if ptr == NULL:
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int off = 60 * (60 * vals[0] + vals[1]) + vals[2]
*/
  __pyx_r = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1092
 * 
 *     ptr = _parse_date_values(ptr + 1, end, vals, ARRAYSIZE(vals))
 *     if ptr == NULL:             # <<<<<<<<<<<<<<
 *         return 0
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":1095
 *         return 0
 * 
 *     cdef int off = 60 * (60 * vals[0] + vals[1]) + vals[2]             # <<<<<<<<<<<<<<
 *     return -off if sgn == b"-" else off
 * 
*/
__pyx_v_off = ((60 * ((60 * (__pyx_v_vals[0])) + (__pyx_v_vals[1]))) + (__pyx_v_vals[2]));

/* "psycopg_c/types/datetime.pyx":1096
 * 
 *     cdef int off = 60 * (60 * vals[0] + vals[1]) + vals[2]
 *     return -off if sgn == b"-" else off             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_2 = (__pyx_v_sgn == '-');
if (__pyx_t_2) {
  __pyx_t_3 = (-__pyx_v_off);
} else {
  __pyx_t_3 = __pyx_v_off;
}
__pyx_r = __pyx_t_3;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1077
 * 
 * 
 * cdef int _parse_timezone_to_seconds(const char **bufptr, const char *end):             # <<<<<<<<<<<<<<
 *     """
 *     Parse a timezone from a string, return Python timezone object.
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._parse_timezone_to_seconds", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1099
 * 
 * 
 * cdef object _timezone_from_seconds(int sec, __cache={}):  # no-cython-lint             # <<<<<<<<<<<<<<
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__timezone_from_seconds(int __pyx_v_sec, struct __pyx_opt_args_9psycopg_c_8_psycopg__timezone_from_seconds *__pyx_optional_args) {
PyObject *__pyx_v___cache = __pyx_mstate_global->__pyx_k__8;
PyObject *__pyx_v_pysec = 0;
PyObject *__pyx_v_ptr;
PyDateTime_Delta *__pyx_v_delta = NULL;
PyObject *__pyx_v_tz = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_timezone_from_seconds", 0);
if (__pyx_optional_args) {
  if (__pyx_optional_args->__pyx_n > 0) {
    __pyx_v___cache = __pyx_optional_args->__pyx___cache;
  }
}

/* "psycopg_c/types/datetime.pyx":1100
 * 
 * cdef object _timezone_from_seconds(int sec, __cache={}):  # no-cython-lint
 *     cdef object pysec = sec             # <<<<<<<<<<<<<<
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
 *     if ptr != NULL:
*/
__pyx_t_1 = __Pyx_PyLong_From_int(__pyx_v_sec); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1100, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_pysec = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":1101
 * cdef object _timezone_from_seconds(int sec, __cache={}):  # no-cython-lint
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)             # <<<<<<<<<<<<<<
 *     if ptr != NULL:
 *         return <object>ptr
*/
__pyx_v_ptr = PyDict_GetItem(__pyx_v___cache, __pyx_v_pysec);

/* "psycopg_c/types/datetime.pyx":1102
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
 *     if ptr != NULL:             # <<<<<<<<<<<<<<
 *         return <object>ptr
 * 
*/
__pyx_t_2 = (__pyx_v_ptr != NULL);
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":1103
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
 *     if ptr != NULL:
 *         return <object>ptr             # <<<<<<<<<<<<<<
 * 
 *     delta = cdt.timedelta_new(0, sec, 0)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_ptr));
  __pyx_r = ((PyObject *)__pyx_v_ptr);
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1102
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
 *     if ptr != NULL:             # <<<<<<<<<<<<<<
 *         return <object>ptr
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":1105
 *         return <object>ptr
 * 
 *     delta = cdt.timedelta_new(0, sec, 0)             # <<<<<<<<<<<<<<
 *     tz = timezone(delta)
 *     __cache[pysec] = tz
*/
__pyx_t_1 = ((PyObject *)__pyx_f_7cpython_8datetime_timedelta_new(0, __pyx_v_sec, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1105, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_delta = ((PyDateTime_Delta *)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":1106
 * 
 *     delta = cdt.timedelta_new(0, sec, 0)
 *     tz = timezone(delta)             # <<<<<<<<<<<<<<
 *     __cache[pysec] = tz
 *     return tz
*/
__pyx_t_3 = NULL;
__Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_timezone); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1106, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_4);
__pyx_t_5 = 1;
#if CYTHON_UNPACK_METHODS
if (unlikely(PyMethod_Check(__pyx_t_4))) {
  __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
  assert(__pyx_t_3);
  PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
  __Pyx_INCREF(__pyx_t_3);
  __Pyx_INCREF(__pyx__function);
  __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
  __pyx_t_5 = 0;
}
#endif
{
  PyObject *__pyx_callargs[2] = {__pyx_t_3, ((PyObject *)__pyx_v_delta)};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_v_tz = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/datetime.pyx":1107
 *     delta = cdt.timedelta_new(0, sec, 0)
 *     tz = timezone(delta)
 *     __cache[pysec] = tz             # <<<<<<<<<<<<<<
 *     return tz
 * 
*/
if (unlikely((PyObject_SetItem(__pyx_v___cache, __pyx_v_pysec, __pyx_v_tz) < 0))) __PYX_ERR(1, 1107, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":1108
 *     tz = timezone(delta)
 *     __cache[pysec] = tz
 *     return tz             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_tz);
__pyx_r = __pyx_v_tz;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1099
 * 
 * 
 * cdef object _timezone_from_seconds(int sec, __cache={}):  # no-cython-lint             # <<<<<<<<<<<<<<
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._timezone_from_seconds", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_pysec);
__Pyx_XDECREF((PyObject *)__pyx_v_delta);
__Pyx_XDECREF(__pyx_v_tz);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1116
 *     s = bytes(data).decode("utf8", "replace")
 * 
 *     def is_overflow(s):             # <<<<<<<<<<<<<<
 *         if not s:
 *             return False
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_25_get_timestamp_load_error_1is_overflow(PyObject *__pyx_self, PyObject *__pyx_v_s); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_25_get_timestamp_load_error_1is_overflow = {"is_overflow", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_25_get_timestamp_load_error_1is_overflow, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_25_get_timestamp_load_error_1is_overflow(PyObject *__pyx_self, PyObject *__pyx_v_s) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("is_overflow (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_25_get_timestamp_load_error_is_overflow(__pyx_self, ((PyObject *)__pyx_v_s));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_25_get_timestamp_load_error_is_overflow(PyObject *__pyx_self, PyObject *__pyx_v_s) {
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *__pyx_cur_scope;
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *__pyx_outer_scope;
char const *__pyx_v_ds;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
char const *__pyx_t_4;
PyObject *__pyx_t_5 = NULL;
size_t __pyx_t_6;
Py_ssize_t __pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("is_overflow", 0);
__pyx_outer_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *) __Pyx_CyFunction_GetClosure(__pyx_self);
__pyx_cur_scope = __pyx_outer_scope;

/* "psycopg_c/types/datetime.pyx":1117
 * 
 *     def is_overflow(s):
 *         if not s:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
__pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_s); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 1117, __pyx_L1_error)
__pyx_t_2 = (!__pyx_t_1);
if (__pyx_t_2) {

  /* "psycopg_c/types/datetime.pyx":1118
 *     def is_overflow(s):
 *         if not s:
 *             return False             # <<<<<<<<<<<<<<
 * 
 *         ds = _get_datestyle(pgconn)
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_False);
  __pyx_r = Py_False;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1117
 * 
 *     def is_overflow(s):
 *         if not s:             # <<<<<<<<<<<<<<
 *             return False
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":1120
 *             return False
 * 
 *         ds = _get_datestyle(pgconn)             # <<<<<<<<<<<<<<
 *         if not ds.startswith(b"P"):  # Postgres
 *             return len(s.split()[0]) > 10  # date is first token
*/
if (unlikely(!__pyx_cur_scope->__pyx_v_pgconn)) { __Pyx_RaiseClosureNameError("pgconn"); __PYX_ERR(1, 1120, __pyx_L1_error) }
__pyx_t_3 = ((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
__Pyx_INCREF(__pyx_t_3);
__pyx_t_4 = __pyx_f_9psycopg_c_8_psycopg__get_datestyle(((struct __pyx_obj_9psycopg_c_2pq_PGconn *)__pyx_t_3)); if (unlikely(__pyx_t_4 == ((void *)NULL) && PyErr_Occurred())) __PYX_ERR(1, 1120, __pyx_L1_error)
__pyx_v_ds = __pyx_t_4;
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":1121
 * 
 *         ds = _get_datestyle(pgconn)
 *         if not ds.startswith(b"P"):  # Postgres             # <<<<<<<<<<<<<<
 *             return len(s.split()[0]) > 10  # date is first token
 *         else:
*/
__pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_ds); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1121, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_2 = __Pyx_PyBytes_Tailmatch(__pyx_t_3, __pyx_mstate_global->__pyx_n_b_P, 0, PY_SSIZE_T_MAX, -1); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(1, 1121, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__pyx_t_1 = (!__pyx_t_2);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1122
 *         ds = _get_datestyle(pgconn)
 *         if not ds.startswith(b"P"):  # Postgres
 *             return len(s.split()[0]) > 10  # date is first token             # <<<<<<<<<<<<<<
 *         else:
 *             return len(s.split()[-1]) > 4  # year is last token
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __pyx_v_s;
  __Pyx_INCREF(__pyx_t_5);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, NULL};
    __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_t_5 = __Pyx_GetItemInt(__pyx_t_3, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_7 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(1, 1122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyBool_FromLong((__pyx_t_7 > 10)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1121
 * 
 *         ds = _get_datestyle(pgconn)
 *         if not ds.startswith(b"P"):  # Postgres             # <<<<<<<<<<<<<<
 *             return len(s.split()[0]) > 10  # date is first token
 *         else:
*/
}

/* "psycopg_c/types/datetime.pyx":1124
 *             return len(s.split()[0]) > 10  # date is first token
 *         else:
 *             return len(s.split()[-1]) > 4  # year is last token             # <<<<<<<<<<<<<<
 * 
 *     if s == "-infinity" or s.endswith("BC"):
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __pyx_v_s;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_6 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_6, (1-__pyx_t_6) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1124, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_5, -1L, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(1, 1124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyBool_FromLong((__pyx_t_7 > 4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":1116
 *     s = bytes(data).decode("utf8", "replace")
 * 
 *     def is_overflow(s):             # <<<<<<<<<<<<<<
 *         if not s:
 *             return False
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_AddTraceback("psycopg_c._psycopg._get_timestamp_load_error.is_overflow", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1111
 * 
 * 
 * cdef object _get_timestamp_load_error(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, const char *data, ex: Exception | None = None
 * ):
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn, char const *__pyx_v_data, struct __pyx_opt_args_9psycopg_c_8_psycopg__get_timestamp_load_error *__pyx_optional_args) {
struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *__pyx_cur_scope;

/* "psycopg_c/types/datetime.pyx":1112
 * 
 * cdef object _get_timestamp_load_error(
 *     pq.PGconn pgconn, const char *data, ex: Exception | None = None             # <<<<<<<<<<<<<<
 * ):
 *     s = bytes(data).decode("utf8", "replace")
*/
PyObject *__pyx_v_ex = ((PyObject*)Py_None);
PyObject *__pyx_v_s = NULL;
PyObject *__pyx_v_is_overflow = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_t_5;
int __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10[4];
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_get_timestamp_load_error", 0);
__pyx_cur_scope = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, __pyx_mstate_global->__pyx_empty_tuple, NULL);
if (unlikely(!__pyx_cur_scope)) {
  __pyx_cur_scope = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *)Py_None);
  __Pyx_INCREF(Py_None);
  __PYX_ERR(1, 1111, __pyx_L1_error)
} else {
  __Pyx_GOTREF((PyObject *)__pyx_cur_scope);
}
if (__pyx_optional_args) {
  if (__pyx_optional_args->__pyx_n > 0) {
    __pyx_v_ex = __pyx_optional_args->ex;
  }
}
__pyx_cur_scope->__pyx_v_pgconn = __pyx_v_pgconn;
__Pyx_INCREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);
__Pyx_GIVEREF((PyObject *)__pyx_cur_scope->__pyx_v_pgconn);

/* "psycopg_c/types/datetime.pyx":1114
 *     pq.PGconn pgconn, const char *data, ex: Exception | None = None
 * ):
 *     s = bytes(data).decode("utf8", "replace")             # <<<<<<<<<<<<<<
 * 
 *     def is_overflow(s):
*/
__pyx_t_2 = NULL;
__pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_data); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1114, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_t_3 = __Pyx_decode_bytes(__pyx_t_1, 0, PY_SSIZE_T_MAX, NULL, __pyx_k_replace, PyUnicode_DecodeUTF8); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1114, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_s = ((PyObject*)__pyx_t_3);
__pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":1116
 *     s = bytes(data).decode("utf8", "replace")
 * 
 *     def is_overflow(s):             # <<<<<<<<<<<<<<
 *         if not s:
 *             return False
*/
__pyx_t_3 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_25_get_timestamp_load_error_1is_overflow, 0, __pyx_mstate_global->__pyx_n_u_get_timestamp_load_error_locals, ((PyObject*)__pyx_cur_scope), __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[8])); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1116, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_v_is_overflow = __pyx_t_3;
__pyx_t_3 = 0;

/* "psycopg_c/types/datetime.pyx":1126
 *             return len(s.split()[-1]) > 4  # year is last token
 * 
 *     if s == "-infinity" or s.endswith("BC"):             # <<<<<<<<<<<<<<
 *         return e.DataError(f"timestamp too small (before year 1): {s!r}")
 *     elif s == "infinity" or is_overflow(s):
*/
__pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s, __pyx_mstate_global->__pyx_kp_u_infinity_2, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 1126, __pyx_L1_error)
if (!__pyx_t_6) {
} else {
  __pyx_t_5 = __pyx_t_6;
  goto __pyx_L4_bool_binop_done;
}
__pyx_t_6 = __Pyx_PyUnicode_Tailmatch(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_BC, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(1, 1126, __pyx_L1_error)
__pyx_t_5 = __pyx_t_6;
__pyx_L4_bool_binop_done:;
if (__pyx_t_5) {

  /* "psycopg_c/types/datetime.pyx":1127
 * 
 *     if s == "-infinity" or s.endswith("BC"):
 *         return e.DataError(f"timestamp too small (before year 1): {s!r}")             # <<<<<<<<<<<<<<
 *     elif s == "infinity" or is_overflow(s):
 *         return e.DataError(f"timestamp too large (after year 10K): {s!r}")
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_timestamp_too_small_before_year_2, __pyx_t_2); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_8};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1127, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1126
 *             return len(s.split()[-1]) > 4  # year is last token
 * 
 *     if s == "-infinity" or s.endswith("BC"):             # <<<<<<<<<<<<<<
 *         return e.DataError(f"timestamp too small (before year 1): {s!r}")
 *     elif s == "infinity" or is_overflow(s):
*/
}

/* "psycopg_c/types/datetime.pyx":1128
 *     if s == "-infinity" or s.endswith("BC"):
 *         return e.DataError(f"timestamp too small (before year 1): {s!r}")
 *     elif s == "infinity" or is_overflow(s):             # <<<<<<<<<<<<<<
 *         return e.DataError(f"timestamp too large (after year 10K): {s!r}")
 *     else:
*/
__pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_v_s, __pyx_mstate_global->__pyx_n_u_infinity, Py_EQ)); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 1128, __pyx_L1_error)
if (!__pyx_t_6) {
} else {
  __pyx_t_5 = __pyx_t_6;
  goto __pyx_L6_bool_binop_done;
}
__pyx_t_3 = __pyx_pf_9psycopg_c_8_psycopg_25_get_timestamp_load_error_is_overflow(__pyx_v_is_overflow, __pyx_v_s); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1128, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 1128, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__pyx_t_5 = __pyx_t_6;
__pyx_L6_bool_binop_done:;
if (__pyx_t_5) {

  /* "psycopg_c/types/datetime.pyx":1129
 *         return e.DataError(f"timestamp too small (before year 1): {s!r}")
 *     elif s == "infinity" or is_overflow(s):
 *         return e.DataError(f"timestamp too large (after year 10K): {s!r}")             # <<<<<<<<<<<<<<
 *     else:
 *         return e.DataError(f"can't parse timestamp {s!r}: {ex or '(unknown)'}")
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_7 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_2 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_timestamp_too_large_after_year_1_2, __pyx_t_8); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    assert(__pyx_t_7);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_7);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_1, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_2};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_1, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1129, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1128
 *     if s == "-infinity" or s.endswith("BC"):
 *         return e.DataError(f"timestamp too small (before year 1): {s!r}")
 *     elif s == "infinity" or is_overflow(s):             # <<<<<<<<<<<<<<
 *         return e.DataError(f"timestamp too large (after year 10K): {s!r}")
 *     else:
*/
}

/* "psycopg_c/types/datetime.pyx":1131
 *         return e.DataError(f"timestamp too large (after year 10K): {s!r}")
 *     else:
 *         return e.DataError(f"can't parse timestamp {s!r}: {ex or '(unknown)'}")             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_v_s), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_ex); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(1, 1131, __pyx_L1_error)
  if (!__pyx_t_5) {
  } else {
    __Pyx_INCREF(__pyx_v_ex);
    __pyx_t_8 = __pyx_v_ex;
    goto __pyx_L8_bool_binop_done;
  }
  __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_u_unknown);
  __pyx_t_8 = __pyx_mstate_global->__pyx_kp_u_unknown;
  __pyx_L8_bool_binop_done:;
  __pyx_t_9 = __Pyx_PyObject_FormatSimple(__pyx_t_8, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(1, 1131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_10[0] = __pyx_mstate_global->__pyx_kp_u_can_t_parse_timestamp;
  __pyx_t_10[1] = __pyx_t_2;
  __pyx_t_10[2] = __pyx_mstate_global->__pyx_kp_u__7;
  __pyx_t_10[3] = __pyx_t_9;
  __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_10, 4, 22 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2) + 2 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_9), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_2) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_9));
  if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 1131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_4 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_1);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_4 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_1, __pyx_t_8};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/datetime.pyx":1111
 * 
 * 
 * cdef object _get_timestamp_load_error(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, const char *data, ex: Exception | None = None
 * ):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_AddTraceback("psycopg_c._psycopg._get_timestamp_load_error", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XDECREF(__pyx_v_is_overflow);
__Pyx_DECREF((PyObject *)__pyx_cur_scope);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1139
 * 
 * 
 * cdef object _timezone_from_connection(pq.PGconn pgconn):             # <<<<<<<<<<<<<<
 *     """Return the Python timezone info of the connection's timezone."""
 *     if pgconn is None:
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg__timezone_from_connection(struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
PyObject *__pyx_v_tzname = 0;
PyObject *__pyx_v_ptr;
PyObject *__pyx_v_sname = NULL;
PyObject *__pyx_v_zi = NULL;
PyObject *__pyx_v_ex = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
size_t __pyx_t_8;
int __pyx_t_9;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
int __pyx_t_14;
char const *__pyx_t_15;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17 = NULL;
PyObject *__pyx_t_18 = NULL;
PyObject *__pyx_t_19 = NULL;
PyObject *__pyx_t_20 = NULL;
PyObject *__pyx_t_21 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_timezone_from_connection", 0);

/* "psycopg_c/types/datetime.pyx":1141
 * cdef object _timezone_from_connection(pq.PGconn pgconn):
 *     """Return the Python timezone info of the connection's timezone."""
 *     if pgconn is None:             # <<<<<<<<<<<<<<
 *         return timezone_utc
 * 
*/
__pyx_t_1 = (((PyObject *)__pyx_v_pgconn) == Py_None);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1142
 *     """Return the Python timezone info of the connection's timezone."""
 *     if pgconn is None:
 *         return timezone_utc             # <<<<<<<<<<<<<<
 * 
 *     cdef bytes tzname = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"TimeZone")
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_timezone_utc);
  __pyx_r = __pyx_v_9psycopg_c_8_psycopg_timezone_utc;
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1141
 * cdef object _timezone_from_connection(pq.PGconn pgconn):
 *     """Return the Python timezone info of the connection's timezone."""
 *     if pgconn is None:             # <<<<<<<<<<<<<<
 *         return timezone_utc
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":1144
 *         return timezone_utc
 * 
 *     cdef bytes tzname = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"TimeZone")             # <<<<<<<<<<<<<<
 *     cdef PyObject *ptr = PyDict_GetItem(_timezones, tzname)
 *     if ptr != NULL:
*/
__pyx_t_2 = __Pyx_PyBytes_FromString(PQparameterStatus(__pyx_v_pgconn->_pgconn_ptr, __pyx_k_TimeZone)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1144, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_v_tzname = ((PyObject*)__pyx_t_2);
__pyx_t_2 = 0;

/* "psycopg_c/types/datetime.pyx":1145
 * 
 *     cdef bytes tzname = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"TimeZone")
 *     cdef PyObject *ptr = PyDict_GetItem(_timezones, tzname)             # <<<<<<<<<<<<<<
 *     if ptr != NULL:
 *         return <object>ptr
*/
__pyx_t_2 = __pyx_v_9psycopg_c_8_psycopg__timezones;
__Pyx_INCREF(__pyx_t_2);
__pyx_v_ptr = PyDict_GetItem(__pyx_t_2, __pyx_v_tzname);
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

/* "psycopg_c/types/datetime.pyx":1146
 *     cdef bytes tzname = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"TimeZone")
 *     cdef PyObject *ptr = PyDict_GetItem(_timezones, tzname)
 *     if ptr != NULL:             # <<<<<<<<<<<<<<
 *         return <object>ptr
 * 
*/
__pyx_t_1 = (__pyx_v_ptr != NULL);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1147
 *     cdef PyObject *ptr = PyDict_GetItem(_timezones, tzname)
 *     if ptr != NULL:
 *         return <object>ptr             # <<<<<<<<<<<<<<
 * 
 *     sname = tzname.decode() if tzname else "UTC"
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_ptr));
  __pyx_r = ((PyObject *)__pyx_v_ptr);
  goto __pyx_L0;

  /* "psycopg_c/types/datetime.pyx":1146
 *     cdef bytes tzname = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"TimeZone")
 *     cdef PyObject *ptr = PyDict_GetItem(_timezones, tzname)
 *     if ptr != NULL:             # <<<<<<<<<<<<<<
 *         return <object>ptr
 * 
*/
}

/* "psycopg_c/types/datetime.pyx":1149
 *         return <object>ptr
 * 
 *     sname = tzname.decode() if tzname else "UTC"             # <<<<<<<<<<<<<<
 *     try:
 *         zi = ZoneInfo(sname)
*/
{
  Py_ssize_t __pyx_temp = __Pyx_PyBytes_GET_SIZE(__pyx_v_tzname);
  if (unlikely(((!CYTHON_ASSUME_SAFE_SIZE) && __pyx_temp < 0))) __PYX_ERR(1, 1149, __pyx_L1_error)
  __pyx_t_1 = (__pyx_temp != 0);
}

if (__pyx_t_1) {
  __pyx_t_3 = __Pyx_decode_bytes(__pyx_v_tzname, 0, PY_SSIZE_T_MAX, NULL, NULL, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_t_3;
  __pyx_t_3 = 0;
} else {
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_u_UTC);
  __pyx_t_2 = __pyx_mstate_global->__pyx_n_u_UTC;
}
__pyx_v_sname = ((PyObject*)__pyx_t_2);
__pyx_t_2 = 0;

/* "psycopg_c/types/datetime.pyx":1150
 * 
 *     sname = tzname.decode() if tzname else "UTC"
 *     try:             # <<<<<<<<<<<<<<
 *         zi = ZoneInfo(sname)
 *     except (KeyError, OSError):
*/
{
  __Pyx_PyThreadState_declare
  __Pyx_PyThreadState_assign
  __Pyx_ExceptionSave(&__pyx_t_4, &__pyx_t_5, &__pyx_t_6);
  __Pyx_XGOTREF(__pyx_t_4);
  __Pyx_XGOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_t_6);
  /*try:*/ {

    /* "psycopg_c/types/datetime.pyx":1151
 *     sname = tzname.decode() if tzname else "UTC"
 *     try:
 *         zi = ZoneInfo(sname)             # <<<<<<<<<<<<<<
 *     except (KeyError, OSError):
 *         logger.warning(
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_ZoneInfo); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1151, __pyx_L5_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v_sname};
      __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1151, __pyx_L5_error)
      __Pyx_GOTREF(__pyx_t_2);
    }
    __pyx_v_zi = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "psycopg_c/types/datetime.pyx":1150
 * 
 *     sname = tzname.decode() if tzname else "UTC"
 *     try:             # <<<<<<<<<<<<<<
 *         zi = ZoneInfo(sname)
 *     except (KeyError, OSError):
*/
  }
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
  goto __pyx_L10_try_end;
  __pyx_L5_error:;
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "psycopg_c/types/datetime.pyx":1152
 *     try:
 *         zi = ZoneInfo(sname)
 *     except (KeyError, OSError):             # <<<<<<<<<<<<<<
 *         logger.warning(
 *             "unknown PostgreSQL timezone: %r; will use UTC", sname
*/
  __pyx_t_9 = __Pyx_PyErr_ExceptionMatches2(((PyObject *)(((PyTypeObject*)PyExc_KeyError))), ((PyObject *)(((PyTypeObject*)PyExc_OSError))));
  if (__pyx_t_9) {
    __Pyx_AddTraceback("psycopg_c._psycopg._timezone_from_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_2, &__pyx_t_7, &__pyx_t_3) < 0) __PYX_ERR(1, 1152, __pyx_L7_except_error)
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_3);

    /* "psycopg_c/types/datetime.pyx":1153
 *         zi = ZoneInfo(sname)
 *     except (KeyError, OSError):
 *         logger.warning(             # <<<<<<<<<<<<<<
 *             "unknown PostgreSQL timezone: %r; will use UTC", sname
 *         )
*/
    __pyx_t_11 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_logger); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 1153, __pyx_L7_except_error)
    __Pyx_GOTREF(__pyx_t_12);
    __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_13)) __PYX_ERR(1, 1153, __pyx_L7_except_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;

    /* "psycopg_c/types/datetime.pyx":1154
 *     except (KeyError, OSError):
 *         logger.warning(
 *             "unknown PostgreSQL timezone: %r; will use UTC", sname             # <<<<<<<<<<<<<<
 *         )
 *         zi = timezone_utc
*/
    __pyx_t_8 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_13))) {
      __pyx_t_11 = PyMethod_GET_SELF(__pyx_t_13);
      assert(__pyx_t_11);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
      __Pyx_INCREF(__pyx_t_11);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
      __pyx_t_8 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_11, __pyx_mstate_global->__pyx_kp_u_unknown_PostgreSQL_timezone_r_wi, __pyx_v_sname};
      __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_8, (3-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
      if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 1153, __pyx_L7_except_error)
      __Pyx_GOTREF(__pyx_t_10);
    }
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

    /* "psycopg_c/types/datetime.pyx":1156
 *             "unknown PostgreSQL timezone: %r; will use UTC", sname
 *         )
 *         zi = timezone_utc             # <<<<<<<<<<<<<<
 *     except Exception as ex:
 *         logger.warning(
*/
    __Pyx_INCREF(__pyx_v_9psycopg_c_8_psycopg_timezone_utc);
    __Pyx_XDECREF_SET(__pyx_v_zi, __pyx_v_9psycopg_c_8_psycopg_timezone_utc);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L6_exception_handled;
  }

  /* "psycopg_c/types/datetime.pyx":1157
 *         )
 *         zi = timezone_utc
 *     except Exception as ex:             # <<<<<<<<<<<<<<
 *         logger.warning(
 *             "error handling PostgreSQL timezone: %r; will use UTC (%s - %s)",
*/
  __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_Exception))));
  if (__pyx_t_9) {
    __Pyx_AddTraceback("psycopg_c._psycopg._timezone_from_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
    if (__Pyx_GetException(&__pyx_t_3, &__pyx_t_7, &__pyx_t_2) < 0) __PYX_ERR(1, 1157, __pyx_L7_except_error)
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_7);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_7);
    __pyx_v_ex = __pyx_t_7;
    /*try:*/ {

      /* "psycopg_c/types/datetime.pyx":1158
 *         zi = timezone_utc
 *     except Exception as ex:
 *         logger.warning(             # <<<<<<<<<<<<<<
 *             "error handling PostgreSQL timezone: %r; will use UTC (%s - %s)",
 *             sname,
*/
      __pyx_t_13 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_logger); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 1158, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_mstate_global->__pyx_n_u_warning); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 1158, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;

      /* "psycopg_c/types/datetime.pyx":1161
 *             "error handling PostgreSQL timezone: %r; will use UTC (%s - %s)",
 *             sname,
 *             type(ex).__name__,             # <<<<<<<<<<<<<<
 *             ex,
 *         )
*/
      __pyx_t_11 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_ex)), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_11)) __PYX_ERR(1, 1161, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_11);

      /* "psycopg_c/types/datetime.pyx":1162
 *             sname,
 *             type(ex).__name__,
 *             ex,             # <<<<<<<<<<<<<<
 *         )
 *         zi = timezone.utc
*/
      __pyx_t_8 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_12))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_12);
        assert(__pyx_t_13);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_12);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_12, __pyx__function);
        __pyx_t_8 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[5] = {__pyx_t_13, __pyx_mstate_global->__pyx_kp_u_error_handling_PostgreSQL_timezo, __pyx_v_sname, __pyx_t_11, __pyx_v_ex};
        __pyx_t_10 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_12, __pyx_callargs+__pyx_t_8, (5-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 1158, __pyx_L18_error)
        __Pyx_GOTREF(__pyx_t_10);
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

      /* "psycopg_c/types/datetime.pyx":1164
 *             ex,
 *         )
 *         zi = timezone.utc             # <<<<<<<<<<<<<<
 * 
 *     _timezones[tzname] = zi
*/
      __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_timezone); if (unlikely(!__pyx_t_10)) __PYX_ERR(1, 1164, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_10);
      __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_utc); if (unlikely(!__pyx_t_12)) __PYX_ERR(1, 1164, __pyx_L18_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      __Pyx_XDECREF_SET(__pyx_v_zi, __pyx_t_12);
      __pyx_t_12 = 0;
    }

    /* "psycopg_c/types/datetime.pyx":1157
 *         )
 *         zi = timezone_utc
 *     except Exception as ex:             # <<<<<<<<<<<<<<
 *         logger.warning(
 *             "error handling PostgreSQL timezone: %r; will use UTC (%s - %s)",
*/
    /*finally:*/ {
      /*normal exit:*/{
        __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        goto __pyx_L19;
      }
      __pyx_L18_error:;
      /*exception exit:*/{
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
        __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
        __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
         __Pyx_ExceptionSwap(&__pyx_t_19, &__pyx_t_20, &__pyx_t_21);
        if ( unlikely(__Pyx_GetException(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18) < 0)) __Pyx_ErrFetch(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_18);
        __Pyx_XGOTREF(__pyx_t_19);
        __Pyx_XGOTREF(__pyx_t_20);
        __Pyx_XGOTREF(__pyx_t_21);
        __pyx_t_9 = __pyx_lineno; __pyx_t_14 = __pyx_clineno; __pyx_t_15 = __pyx_filename;
        {
          __Pyx_DECREF(__pyx_v_ex); __pyx_v_ex = 0;
        }
        __Pyx_XGIVEREF(__pyx_t_19);
        __Pyx_XGIVEREF(__pyx_t_20);
        __Pyx_XGIVEREF(__pyx_t_21);
        __Pyx_ExceptionReset(__pyx_t_19, __pyx_t_20, __pyx_t_21);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_XGIVEREF(__pyx_t_18);
        __Pyx_ErrRestore(__pyx_t_16, __pyx_t_17, __pyx_t_18);
        __pyx_t_16 = 0; __pyx_t_17 = 0; __pyx_t_18 = 0; __pyx_t_19 = 0; __pyx_t_20 = 0; __pyx_t_21 = 0;
        __pyx_lineno = __pyx_t_9; __pyx_clineno = __pyx_t_14; __pyx_filename = __pyx_t_15;
        goto __pyx_L7_except_error;
      }
      __pyx_L19:;
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L6_exception_handled;
  }
  goto __pyx_L7_except_error;

  /* "psycopg_c/types/datetime.pyx":1150
 * 
 *     sname = tzname.decode() if tzname else "UTC"
 *     try:             # <<<<<<<<<<<<<<
 *         zi = ZoneInfo(sname)
 *     except (KeyError, OSError):
*/
  __pyx_L7_except_error:;
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_XGIVEREF(__pyx_t_6);
  __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
  goto __pyx_L1_error;
  __pyx_L6_exception_handled:;
  __Pyx_XGIVEREF(__pyx_t_4);
  __Pyx_XGIVEREF(__pyx_t_5);
  __Pyx_XGIVEREF(__pyx_t_6);
  __Pyx_ExceptionReset(__pyx_t_4, __pyx_t_5, __pyx_t_6);
  __pyx_L10_try_end:;
}

/* "psycopg_c/types/datetime.pyx":1166
 *         zi = timezone.utc
 * 
 *     _timezones[tzname] = zi             # <<<<<<<<<<<<<<
 *     return zi
 * 
*/
if (unlikely((PyObject_SetItem(__pyx_v_9psycopg_c_8_psycopg__timezones, __pyx_v_tzname, __pyx_v_zi) < 0))) __PYX_ERR(1, 1166, __pyx_L1_error)

/* "psycopg_c/types/datetime.pyx":1167
 * 
 *     _timezones[tzname] = zi
 *     return zi             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_zi);
__pyx_r = __pyx_v_zi;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1139
 * 
 * 
 * cdef object _timezone_from_connection(pq.PGconn pgconn):             # <<<<<<<<<<<<<<
 *     """Return the Python timezone info of the connection's timezone."""
 *     if pgconn is None:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_AddTraceback("psycopg_c._psycopg._timezone_from_connection", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_tzname);
__Pyx_XDECREF(__pyx_v_sname);
__Pyx_XDECREF(__pyx_v_zi);
__Pyx_XDECREF(__pyx_v_ex);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1170
 * 
 * 
 * cdef const char *_get_datestyle(pq.PGconn pgconn):             # <<<<<<<<<<<<<<
 *     cdef const char *ds
 *     if pgconn is not None:
*/

static char const *__pyx_f_9psycopg_c_8_psycopg__get_datestyle(struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
char const *__pyx_v_ds;
char const *__pyx_r;
int __pyx_t_1;
int __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":1172
 * cdef const char *_get_datestyle(pq.PGconn pgconn):
 *     cdef const char *ds
 *     if pgconn is not None:             # <<<<<<<<<<<<<<
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"DateStyle")
 *         if ds is not NULL and ds[0]:
*/
__pyx_t_1 = (((PyObject *)__pyx_v_pgconn) != Py_None);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1173
 *     cdef const char *ds
 *     if pgconn is not None:
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"DateStyle")             # <<<<<<<<<<<<<<
 *         if ds is not NULL and ds[0]:
 *             return ds
*/
  __pyx_v_ds = PQparameterStatus(__pyx_v_pgconn->_pgconn_ptr, __pyx_k_DateStyle);

  /* "psycopg_c/types/datetime.pyx":1174
 *     if pgconn is not None:
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"DateStyle")
 *         if ds is not NULL and ds[0]:             # <<<<<<<<<<<<<<
 *             return ds
 * 
*/
  __pyx_t_2 = (__pyx_v_ds != NULL);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_ds[0]) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":1175
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"DateStyle")
 *         if ds is not NULL and ds[0]:
 *             return ds             # <<<<<<<<<<<<<<
 * 
 *     return b"ISO, DMY"
*/
    __pyx_r = __pyx_v_ds;
    goto __pyx_L0;

    /* "psycopg_c/types/datetime.pyx":1174
 *     if pgconn is not None:
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"DateStyle")
 *         if ds is not NULL and ds[0]:             # <<<<<<<<<<<<<<
 *             return ds
 * 
*/
  }

  /* "psycopg_c/types/datetime.pyx":1172
 * cdef const char *_get_datestyle(pq.PGconn pgconn):
 *     cdef const char *ds
 *     if pgconn is not None:             # <<<<<<<<<<<<<<
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"DateStyle")
 *         if ds is not NULL and ds[0]:
*/
}

/* "psycopg_c/types/datetime.pyx":1177
 *             return ds
 * 
 *     return b"ISO, DMY"             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_k_ISO_DMY;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1170
 * 
 * 
 * cdef const char *_get_datestyle(pq.PGconn pgconn):             # <<<<<<<<<<<<<<
 *     cdef const char *ds
 *     if pgconn is not None:
*/

/* function exit code */
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/datetime.pyx":1180
 * 
 * 
 * cdef const char *_get_intervalstyle(pq.PGconn pgconn):             # <<<<<<<<<<<<<<
 *     cdef const char *ds
 *     if pgconn is not None:
*/

static char const *__pyx_f_9psycopg_c_8_psycopg__get_intervalstyle(struct __pyx_obj_9psycopg_c_2pq_PGconn *__pyx_v_pgconn) {
char const *__pyx_v_ds;
char const *__pyx_r;
int __pyx_t_1;
int __pyx_t_2;

/* "psycopg_c/types/datetime.pyx":1182
 * cdef const char *_get_intervalstyle(pq.PGconn pgconn):
 *     cdef const char *ds
 *     if pgconn is not None:             # <<<<<<<<<<<<<<
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"IntervalStyle")
 *         if ds is not NULL and ds[0]:
*/
__pyx_t_1 = (((PyObject *)__pyx_v_pgconn) != Py_None);
if (__pyx_t_1) {

  /* "psycopg_c/types/datetime.pyx":1183
 *     cdef const char *ds
 *     if pgconn is not None:
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"IntervalStyle")             # <<<<<<<<<<<<<<
 *         if ds is not NULL and ds[0]:
 *             return ds
*/
  __pyx_v_ds = PQparameterStatus(__pyx_v_pgconn->_pgconn_ptr, __pyx_k_IntervalStyle);

  /* "psycopg_c/types/datetime.pyx":1184
 *     if pgconn is not None:
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"IntervalStyle")
 *         if ds is not NULL and ds[0]:             # <<<<<<<<<<<<<<
 *             return ds
 * 
*/
  __pyx_t_2 = (__pyx_v_ds != NULL);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_ds[0]) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/datetime.pyx":1185
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"IntervalStyle")
 *         if ds is not NULL and ds[0]:
 *             return ds             # <<<<<<<<<<<<<<
 * 
 *     return b"postgres"
*/
    __pyx_r = __pyx_v_ds;
    goto __pyx_L0;

    /* "psycopg_c/types/datetime.pyx":1184
 *     if pgconn is not None:
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"IntervalStyle")
 *         if ds is not NULL and ds[0]:             # <<<<<<<<<<<<<<
 *             return ds
 * 
*/
  }

  /* "psycopg_c/types/datetime.pyx":1182
 * cdef const char *_get_intervalstyle(pq.PGconn pgconn):
 *     cdef const char *ds
 *     if pgconn is not None:             # <<<<<<<<<<<<<<
 *         ds = libpq.PQparameterStatus(pgconn._pgconn_ptr, b"IntervalStyle")
 *         if ds is not NULL and ds[0]:
*/
}

/* "psycopg_c/types/datetime.pyx":1187
 *             return ds
 * 
 *     return b"postgres"             # <<<<<<<<<<<<<<
*/
__pyx_r = __pyx_k_postgres;
goto __pyx_L0;

/* "psycopg_c/types/datetime.pyx":1180
 * 
 * 
 * cdef const char *_get_intervalstyle(pq.PGconn pgconn):             # <<<<<<<<<<<<<<
 *     cdef const char *ds
 *     if pgconn is not None:
*/

/* function exit code */
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":61
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_text(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10_IntDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":62
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_text(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 *     def quote(self, obj) -> Buffer | None:
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_text(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 62, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":61
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_text(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._IntDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":64
 *         return dump_int_to_text(obj, rv, offset)
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t length
 * 
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10_IntDumper_1quote = {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_1quote, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("quote (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_quote(((struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_quote(struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
Py_ssize_t __pyx_v_length;
PyObject *__pyx_v_rv = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
Py_ssize_t __pyx_t_3;
int __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("quote", 0);

/* "psycopg_c/types/numeric.pyx":67
 *         cdef Py_ssize_t length
 * 
 *         rv = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 *         if obj >= 0:
 *             length = self.cdump(obj, rv, 0)
*/
__pyx_t_1 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 67, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_rv = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":68
 * 
 *         rv = PyByteArray_FromStringAndSize("", 0)
 *         if obj >= 0:             # <<<<<<<<<<<<<<
 *             length = self.cdump(obj, rv, 0)
 *         else:
*/
__pyx_t_1 = PyObject_RichCompare(__pyx_v_obj, __pyx_mstate_global->__pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 68, __pyx_L1_error)
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(12, 68, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_2) {

  /* "psycopg_c/types/numeric.pyx":69
 *         rv = PyByteArray_FromStringAndSize("", 0)
 *         if obj >= 0:
 *             length = self.cdump(obj, rv, 0)             # <<<<<<<<<<<<<<
 *         else:
 *             PyByteArray_Resize(rv, 23)
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_rv, 0); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 69, __pyx_L1_error)
  __pyx_v_length = __pyx_t_3;

  /* "psycopg_c/types/numeric.pyx":68
 * 
 *         rv = PyByteArray_FromStringAndSize("", 0)
 *         if obj >= 0:             # <<<<<<<<<<<<<<
 *             length = self.cdump(obj, rv, 0)
 *         else:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/numeric.pyx":71
 *             length = self.cdump(obj, rv, 0)
 *         else:
 *             PyByteArray_Resize(rv, 23)             # <<<<<<<<<<<<<<
 *             rv[0] = b' '
 *             length = 1 + self.cdump(obj, rv, 1)
*/
/*else*/ {
  __pyx_t_4 = PyByteArray_Resize(__pyx_v_rv, 23); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(12, 71, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":72
 *         else:
 *             PyByteArray_Resize(rv, 23)
 *             rv[0] = b' '             # <<<<<<<<<<<<<<
 *             length = 1 + self.cdump(obj, rv, 1)
 * 
*/
  if (unlikely((__Pyx_SetItemInt_ByteArray(__pyx_v_rv, 0, ' ', long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference) < 0))) __PYX_ERR(12, 72, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":73
 *             PyByteArray_Resize(rv, 23)
 *             rv[0] = b' '
 *             length = 1 + self.cdump(obj, rv, 1)             # <<<<<<<<<<<<<<
 * 
 *         PyByteArray_Resize(rv, length)
*/
  __pyx_t_3 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper *)__pyx_v_self->__pyx_base.__pyx_vtab)->__pyx_base.cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_rv, 1); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 73, __pyx_L1_error)
  __pyx_v_length = (1 + __pyx_t_3);
}
__pyx_L3:;

/* "psycopg_c/types/numeric.pyx":75
 *             length = 1 + self.cdump(obj, rv, 1)
 * 
 *         PyByteArray_Resize(rv, length)             # <<<<<<<<<<<<<<
 *         return rv
 * 
*/
__pyx_t_4 = PyByteArray_Resize(__pyx_v_rv, __pyx_v_length); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(12, 75, __pyx_L1_error)

/* "psycopg_c/types/numeric.pyx":76
 * 
 *         PyByteArray_Resize(rv, length)
 *         return rv             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_rv);
__pyx_r = __pyx_v_rv;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":64
 *         return dump_int_to_text(obj, rv, offset)
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t length
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg._IntDumper.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_rv);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10_IntDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._IntDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10_IntDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_IntDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._IntDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":83
 *     format = PQ_TEXT
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         global _int_classes
 * 
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(12, 83, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 83, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 83, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(12, 83, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(12, 83, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 83, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 83, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  __pyx_v_cls = values[0];
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(12, 83, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._IntOrSubclassDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *)__pyx_v_self), __pyx_v_cls, __pyx_v_context);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper___cinit__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context) {
PyObject *__pyx_v_numpy = NULL;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/numeric.pyx":86
 *         global _int_classes
 * 
 *         if _int_classes is None:             # <<<<<<<<<<<<<<
 *             if "numpy" in sys.modules:
 *                 import numpy
*/
__Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_int_classes); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 86, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = (__pyx_t_1 == Py_None);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_2) {

  /* "psycopg_c/types/numeric.pyx":87
 * 
 *         if _int_classes is None:
 *             if "numpy" in sys.modules:             # <<<<<<<<<<<<<<
 *                 import numpy
 *                 _int_classes = (int, numpy.integer)
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_modules); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_numpy, __pyx_t_3, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(12, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "psycopg_c/types/numeric.pyx":88
 *         if _int_classes is None:
 *             if "numpy" in sys.modules:
 *                 import numpy             # <<<<<<<<<<<<<<
 *                 _int_classes = (int, numpy.integer)
 *             else:
*/
    __pyx_t_4 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_numpy, 0, 0, NULL, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 88, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_numpy = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "psycopg_c/types/numeric.pyx":89
 *             if "numpy" in sys.modules:
 *                 import numpy
 *                 _int_classes = (int, numpy.integer)             # <<<<<<<<<<<<<<
 *             else:
 *                 _int_classes = int
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_numpy, __pyx_mstate_global->__pyx_n_u_integer); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 89, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF((PyObject *)(&PyLong_Type));
    __Pyx_GIVEREF((PyObject *)(&PyLong_Type));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)(&PyLong_Type))) != (0)) __PYX_ERR(12, 89, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3) != (0)) __PYX_ERR(12, 89, __pyx_L1_error);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_int_classes, __pyx_t_1) < (0)) __PYX_ERR(12, 89, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "psycopg_c/types/numeric.pyx":87
 * 
 *         if _int_classes is None:
 *             if "numpy" in sys.modules:             # <<<<<<<<<<<<<<
 *                 import numpy
 *                 _int_classes = (int, numpy.integer)
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/numeric.pyx":91
 *                 _int_classes = (int, numpy.integer)
 *             else:
 *                 _int_classes = int             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  /*else*/ {
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_int_classes, ((PyObject *)(&PyLong_Type))) < (0)) __PYX_ERR(12, 91, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "psycopg_c/types/numeric.pyx":86
 *         global _int_classes
 * 
 *         if _int_classes is None:             # <<<<<<<<<<<<<<
 *             if "numpy" in sys.modules:
 *                 import numpy
*/
}

/* "psycopg_c/types/numeric.pyx":83
 *     format = PQ_TEXT
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         global _int_classes
 * 
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg._IntOrSubclassDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_numpy);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":93
 *                 _int_classes = int
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_or_sub_to_text(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":94
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_or_sub_to_text(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_int_or_sub_to_text(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 94, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":93
 *                 _int_classes = int
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_or_sub_to_text(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._IntOrSubclassDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._IntOrSubclassDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._IntOrSubclassDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10Int2Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10Int2Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int2Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10Int2Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10Int2Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int2Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10Int4Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10Int4Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int4Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10Int4Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10Int4Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int4Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10Int8Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10Int8Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int8Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10Int8Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10Int8Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10Int8Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16IntNumericDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16IntNumericDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16IntNumericDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntNumericDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16IntNumericDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16IntNumericDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16IntNumericDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntNumericDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":127
 *     oid = oids.INT2_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int2_binary(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16Int2BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":128
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_int2_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int2_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 128, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":127
 *     oid = oids.INT2_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int2_binary(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":137
 *     oid = oids.INT4_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int4_binary(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16Int4BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":138
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_int4_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int4_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 138, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":137
 *     oid = oids.INT4_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int4_binary(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":147
 *     oid = oids.INT8_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int8_binary(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16Int8BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":148
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_int8_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int8_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 148, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":147
 *     oid = oids.INT8_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int8_binary(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":182
 *     oid = oids.NUMERIC_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_numeric_binary(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":183
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_numeric_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_numeric_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 183, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":182
 *     oid = oids.NUMERIC_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_numeric_binary(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntNumericBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22IntNumericBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22IntNumericBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntNumericBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntNumericBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":190
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             f"{type(self).__name__} is a dispatcher to other dumpers:"
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_9IntDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_rv, CYTHON_UNUSED Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numeric.pyx":191
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         raise TypeError(             # <<<<<<<<<<<<<<
 *             f"{type(self).__name__} is a dispatcher to other dumpers:"
 *             " dump() is not supposed to be called"
*/
__pyx_t_2 = NULL;

/* "psycopg_c/types/numeric.pyx":192
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         raise TypeError(
 *             f"{type(self).__name__} is a dispatcher to other dumpers:"             # <<<<<<<<<<<<<<
 *             " dump() is not supposed to be called"
 *         )
*/
__pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 192, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_t_3, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 192, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_4);
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__pyx_t_3 = __Pyx_PyUnicode_Concat__Pyx_ReferenceSharing_OwnStrongReferenceInPlace(__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_is_a_dispatcher_to_other_dumper); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 192, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
__pyx_t_5 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__Pyx_Raise(__pyx_t_1, 0, 0, 0);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__PYX_ERR(12, 191, __pyx_L1_error)

/* "psycopg_c/types/numeric.pyx":190
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         raise TypeError(
 *             f"{type(self).__name__} is a dispatcher to other dumpers:"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":196
 *         )
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         cdef long long val
 *         cdef int overflow
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_9IntDumper_get_key(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
PY_LONG_LONG __pyx_v_val;
int __pyx_v_overflow;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
PY_LONG_LONG __pyx_t_6;
int __pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("get_key", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (
#if !CYTHON_USE_TYPE_SLOTS
unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper &&
__Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
#else
unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
#endif
) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_get_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 196, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_9IntDumper_1get_key)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 196, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "psycopg_c/types/numeric.pyx":200
 *         cdef int overflow
 * 
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)             # <<<<<<<<<<<<<<
 *         if overflow:
 *             return IntNumeric
*/
__pyx_t_6 = PyLong_AsLongLongAndOverflow(__pyx_v_obj, (&__pyx_v_overflow)); if (unlikely(__pyx_t_6 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 200, __pyx_L1_error)
__pyx_v_val = __pyx_t_6;

/* "psycopg_c/types/numeric.pyx":201
 * 
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *         if overflow:             # <<<<<<<<<<<<<<
 *             return IntNumeric
 * 
*/
__pyx_t_7 = (__pyx_v_overflow != 0);
if (__pyx_t_7) {

  /* "psycopg_c/types/numeric.pyx":202
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *         if overflow:
 *             return IntNumeric             # <<<<<<<<<<<<<<
 * 
 *         if INT32_MIN <= val <= INT32_MAX:
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_IntNumeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":201
 * 
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *         if overflow:             # <<<<<<<<<<<<<<
 *             return IntNumeric
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":204
 *             return IntNumeric
 * 
 *         if INT32_MIN <= val <= INT32_MAX:             # <<<<<<<<<<<<<<
 *             if INT16_MIN <= val <= INT16_MAX:
 *                 return Int2
*/
__pyx_t_7 = (INT32_MIN <= __pyx_v_val);
if (__pyx_t_7) {
  __pyx_t_7 = (__pyx_v_val <= INT32_MAX);
}
if (__pyx_t_7) {

  /* "psycopg_c/types/numeric.pyx":205
 * 
 *         if INT32_MIN <= val <= INT32_MAX:
 *             if INT16_MIN <= val <= INT16_MAX:             # <<<<<<<<<<<<<<
 *                 return Int2
 *             else:
*/
  __pyx_t_7 = (INT16_MIN <= __pyx_v_val);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_v_val <= INT16_MAX);
  }
  if (__pyx_t_7) {

    /* "psycopg_c/types/numeric.pyx":206
 *         if INT32_MIN <= val <= INT32_MAX:
 *             if INT16_MIN <= val <= INT16_MAX:
 *                 return Int2             # <<<<<<<<<<<<<<
 *             else:
 *                 return Int4
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Int2); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "psycopg_c/types/numeric.pyx":205
 * 
 *         if INT32_MIN <= val <= INT32_MAX:
 *             if INT16_MIN <= val <= INT16_MAX:             # <<<<<<<<<<<<<<
 *                 return Int2
 *             else:
*/
  }

  /* "psycopg_c/types/numeric.pyx":208
 *                 return Int2
 *             else:
 *                 return Int4             # <<<<<<<<<<<<<<
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Int4); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 208, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "psycopg_c/types/numeric.pyx":204
 *             return IntNumeric
 * 
 *         if INT32_MIN <= val <= INT32_MAX:             # <<<<<<<<<<<<<<
 *             if INT16_MIN <= val <= INT16_MAX:
 *                 return Int2
*/
}

/* "psycopg_c/types/numeric.pyx":210
 *                 return Int4
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:             # <<<<<<<<<<<<<<
 *                 return Int8
 *             else:
*/
/*else*/ {
  __pyx_t_7 = (INT64_MIN <= __pyx_v_val);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_v_val <= INT64_MAX);
  }
  if (__pyx_t_7) {

    /* "psycopg_c/types/numeric.pyx":211
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:
 *                 return Int8             # <<<<<<<<<<<<<<
 *             else:
 *                 return IntNumeric
*/
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_Int8); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 211, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "psycopg_c/types/numeric.pyx":210
 *                 return Int4
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:             # <<<<<<<<<<<<<<
 *                 return Int8
 *             else:
*/
  }

  /* "psycopg_c/types/numeric.pyx":213
 *                 return Int8
 *             else:
 *                 return IntNumeric             # <<<<<<<<<<<<<<
 * 
 *     _int2_dumper = Int2Dumper
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_IntNumeric); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 213, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
}

/* "psycopg_c/types/numeric.pyx":196
 *         )
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         cdef long long val
 *         cdef int overflow
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_1get_key = {"get_key", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_1get_key, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_1get_key(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("get_key (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(12, 196, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 196, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 196, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "get_key", 0) < (0)) __PYX_ERR(12, 196, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, i); __PYX_ERR(12, 196, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 196, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 196, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("get_key", 1, 2, 2, __pyx_nargs); __PYX_ERR(12, 196, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9IntDumper_get_key(((struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_get_key(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("get_key", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_9IntDumper_get_key(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 196, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.get_key", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":220
 *     _int_numeric_dumper = IntNumericDumper
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         cdef long long val
 *         cdef int overflow
*/

static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_9psycopg_c_8_psycopg_9IntDumper_upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, CYTHON_UNUSED PyObject *__pyx_v_format, int __pyx_skip_dispatch) {
PY_LONG_LONG __pyx_v_val;
int __pyx_v_overflow;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
PY_LONG_LONG __pyx_t_6;
int __pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (
#if !CYTHON_USE_TYPE_SLOTS
unlikely(Py_TYPE(((PyObject *)__pyx_v_self)) != __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper &&
__Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), Py_TPFLAGS_HAVE_GC))
#else
unlikely(Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0 || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))
#endif
) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_mstate_global->__pyx_n_u_upgrade); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!__Pyx_IsSameCFunction(__pyx_t_1, (void(*)(void)) __pyx_pw_9psycopg_c_8_psycopg_9IntDumper_3upgrade)) {
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_3 = NULL;
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_4 = __pyx_t_1; 
      __pyx_t_5 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_4))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
        assert(__pyx_t_3);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_3);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
        __pyx_t_5 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_v_obj, __pyx_v_format};
        __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_5, (3-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 220, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
      }
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "psycopg_c/types/numeric.pyx":224
 *         cdef int overflow
 * 
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)             # <<<<<<<<<<<<<<
 *         if overflow:
 *             return self._int_numeric_dumper(IntNumeric)
*/
__pyx_t_6 = PyLong_AsLongLongAndOverflow(__pyx_v_obj, (&__pyx_v_overflow)); if (unlikely(__pyx_t_6 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 224, __pyx_L1_error)
__pyx_v_val = __pyx_t_6;

/* "psycopg_c/types/numeric.pyx":225
 * 
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *         if overflow:             # <<<<<<<<<<<<<<
 *             return self._int_numeric_dumper(IntNumeric)
 * 
*/
__pyx_t_7 = (__pyx_v_overflow != 0);
if (__pyx_t_7) {

  /* "psycopg_c/types/numeric.pyx":226
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *         if overflow:
 *             return self._int_numeric_dumper(IntNumeric)             # <<<<<<<<<<<<<<
 * 
 *         if INT32_MIN <= val <= INT32_MAX:
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)__pyx_v_self);
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_IntNumeric); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = 0;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
    __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_int_numeric_dumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 226, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":225
 * 
 *         val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *         if overflow:             # <<<<<<<<<<<<<<
 *             return self._int_numeric_dumper(IntNumeric)
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":228
 *             return self._int_numeric_dumper(IntNumeric)
 * 
 *         if INT32_MIN <= val <= INT32_MAX:             # <<<<<<<<<<<<<<
 *             if INT16_MIN <= val <= INT16_MAX:
 *                 return self._int2_dumper(Int2)
*/
__pyx_t_7 = (INT32_MIN <= __pyx_v_val);
if (__pyx_t_7) {
  __pyx_t_7 = (__pyx_v_val <= INT32_MAX);
}
if (__pyx_t_7) {

  /* "psycopg_c/types/numeric.pyx":229
 * 
 *         if INT32_MIN <= val <= INT32_MAX:
 *             if INT16_MIN <= val <= INT16_MAX:             # <<<<<<<<<<<<<<
 *                 return self._int2_dumper(Int2)
 *             else:
*/
  __pyx_t_7 = (INT16_MIN <= __pyx_v_val);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_v_val <= INT16_MAX);
  }
  if (__pyx_t_7) {

    /* "psycopg_c/types/numeric.pyx":230
 *         if INT32_MIN <= val <= INT32_MAX:
 *             if INT16_MIN <= val <= INT16_MAX:
 *                 return self._int2_dumper(Int2)             # <<<<<<<<<<<<<<
 *             else:
 *                 return self._int4_dumper(Int4)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Int2); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 230, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_int2_dumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 230, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "psycopg_c/types/numeric.pyx":229
 * 
 *         if INT32_MIN <= val <= INT32_MAX:
 *             if INT16_MIN <= val <= INT16_MAX:             # <<<<<<<<<<<<<<
 *                 return self._int2_dumper(Int2)
 *             else:
*/
  }

  /* "psycopg_c/types/numeric.pyx":232
 *                 return self._int2_dumper(Int2)
 *             else:
 *                 return self._int4_dumper(Int4)             # <<<<<<<<<<<<<<
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Int4); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_int4_dumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }

  /* "psycopg_c/types/numeric.pyx":228
 *             return self._int_numeric_dumper(IntNumeric)
 * 
 *         if INT32_MIN <= val <= INT32_MAX:             # <<<<<<<<<<<<<<
 *             if INT16_MIN <= val <= INT16_MAX:
 *                 return self._int2_dumper(Int2)
*/
}

/* "psycopg_c/types/numeric.pyx":234
 *                 return self._int4_dumper(Int4)
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:             # <<<<<<<<<<<<<<
 *                 return self._int8_dumper(Int8)
 *             else:
*/
/*else*/ {
  __pyx_t_7 = (INT64_MIN <= __pyx_v_val);
  if (__pyx_t_7) {
    __pyx_t_7 = (__pyx_v_val <= INT64_MAX);
  }
  if (__pyx_t_7) {

    /* "psycopg_c/types/numeric.pyx":235
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:
 *                 return self._int8_dumper(Int8)             # <<<<<<<<<<<<<<
 *             else:
 *                 return self._int_numeric_dumper(IntNumeric)
*/
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_4 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Int8); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 235, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_2};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_int8_dumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 235, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "psycopg_c/types/numeric.pyx":234
 *                 return self._int4_dumper(Int4)
 *         else:
 *             if INT64_MIN <= val <= INT64_MAX:             # <<<<<<<<<<<<<<
 *                 return self._int8_dumper(Int8)
 *             else:
*/
  }

  /* "psycopg_c/types/numeric.pyx":237
 *                 return self._int8_dumper(Int8)
 *             else:
 *                 return self._int_numeric_dumper(IntNumeric)             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_v_self);
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_IntNumeric); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 237, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_4};
      __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_int_numeric_dumper, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 237, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;
  }
}

/* "psycopg_c/types/numeric.pyx":220
 *     _int_numeric_dumper = IntNumericDumper
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         cdef long long val
 *         cdef int overflow
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_3upgrade = {"upgrade", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_3upgrade, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_3upgrade(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v_obj = 0;
PyObject *__pyx_v_format = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("upgrade (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_obj,&__pyx_mstate_global->__pyx_n_u_format,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(12, 220, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 220, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 220, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "upgrade", 0) < (0)) __PYX_ERR(12, 220, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 2; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, i); __PYX_ERR(12, 220, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 2)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 220, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 220, __pyx_L3_error)
  }
  __pyx_v_obj = values[0];
  __pyx_v_format = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("upgrade", 1, 2, 2, __pyx_nargs); __PYX_ERR(12, 220, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9IntDumper_2upgrade(((struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_format);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_2upgrade(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_format) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("upgrade", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_9IntDumper_upgrade(__pyx_v_self, __pyx_v_obj, __pyx_v_format, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 220, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.upgrade", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_5__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9IntDumper_4__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_7__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9IntDumper_6__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15IntBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15IntBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15IntBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15IntBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15IntBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15IntBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":256
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         # if the number ends with a 0 we don't need a copy
 *         if data[length] == b'\0':
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_9IntLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
char __pyx_v_buf[(MAXINT8LEN + 1)];
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":258
 *     cdef object cload(self, const char *data, size_t length):
 *         # if the number ends with a 0 we don't need a copy
 *         if data[length] == b'\0':             # <<<<<<<<<<<<<<
 *             return PyLong_FromString(data, NULL, 10)
 * 
*/
__pyx_t_1 = ((__pyx_v_data[__pyx_v_length]) == '\x00');
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":259
 *         # if the number ends with a 0 we don't need a copy
 *         if data[length] == b'\0':
 *             return PyLong_FromString(data, NULL, 10)             # <<<<<<<<<<<<<<
 * 
 *         # Otherwise we have to copy it aside
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyLong_FromString(__pyx_v_data, NULL, 10); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":258
 *     cdef object cload(self, const char *data, size_t length):
 *         # if the number ends with a 0 we don't need a copy
 *         if data[length] == b'\0':             # <<<<<<<<<<<<<<
 *             return PyLong_FromString(data, NULL, 10)
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":262
 * 
 *         # Otherwise we have to copy it aside
 *         if length > MAXINT8LEN:             # <<<<<<<<<<<<<<
 *             raise ValueError("string too big for an int")
 * 
*/
__pyx_t_1 = (__pyx_v_length > MAXINT8LEN);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/numeric.pyx":263
 *         # Otherwise we have to copy it aside
 *         if length > MAXINT8LEN:
 *             raise ValueError("string too big for an int")             # <<<<<<<<<<<<<<
 * 
 *         cdef char[MAXINT8LEN + 1] buf
*/
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_string_too_big_for_an_int};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 263, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(12, 263, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":262
 * 
 *         # Otherwise we have to copy it aside
 *         if length > MAXINT8LEN:             # <<<<<<<<<<<<<<
 *             raise ValueError("string too big for an int")
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":266
 * 
 *         cdef char[MAXINT8LEN + 1] buf
 *         memcpy(buf, data, length)             # <<<<<<<<<<<<<<
 *         buf[length] = 0
 *         return PyLong_FromString(buf, NULL, 10)
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_data, __pyx_v_length));

/* "psycopg_c/types/numeric.pyx":267
 *         cdef char[MAXINT8LEN + 1] buf
 *         memcpy(buf, data, length)
 *         buf[length] = 0             # <<<<<<<<<<<<<<
 *         return PyLong_FromString(buf, NULL, 10)
 * 
*/
(__pyx_v_buf[__pyx_v_length]) = 0;

/* "psycopg_c/types/numeric.pyx":268
 *         memcpy(buf, data, length)
 *         buf[length] = 0
 *         return PyLong_FromString(buf, NULL, 10)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_2 = PyLong_FromString(__pyx_v_buf, NULL, 10); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 268, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_r = __pyx_t_2;
__pyx_t_2 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":256
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         # if the number ends with a 0 we don't need a copy
 *         if data[length] == b'\0':
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.IntLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9IntLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9IntLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9IntLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9IntLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9IntLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.IntLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":276
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int16_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16Int2BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
int16_t __pyx_v_bedata;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":278
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef int16_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         return PyLong_FromLong(<int16_t>endian.be16toh(bedata))
 * 
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/numeric.pyx":279
 *         cdef int16_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         return PyLong_FromLong(<int16_t>endian.be16toh(bedata))             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = PyLong_FromLong(((int16_t)be16toh(__pyx_v_bedata))); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 279, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":276
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int16_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.Int2BinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2BinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int2BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int2BinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":287
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16Int4BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
int32_t __pyx_v_bedata;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":289
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef int32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         return PyLong_FromLong(<int32_t>endian.be32toh(bedata))
 * 
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/numeric.pyx":290
 *         cdef int32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         return PyLong_FromLong(<int32_t>endian.be32toh(bedata))             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = PyLong_FromLong(((int32_t)be32toh(__pyx_v_bedata))); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 290, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":287
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.Int4BinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4BinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int4BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int4BinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":298
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16Int8BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
int64_t __pyx_v_bedata;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":300
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef int64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         return PyLong_FromLongLong(<int64_t>endian.be64toh(bedata))
 * 
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/numeric.pyx":301
 *         cdef int64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         return PyLong_FromLongLong(<int64_t>endian.be64toh(bedata))             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = PyLong_FromLongLong(((int64_t)be64toh(__pyx_v_bedata))); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 301, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":298
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef int64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.Int8BinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8BinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16Int8BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Int8BinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":309
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_15OidBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint32_t __pyx_v_bedata;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":311
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         return PyLong_FromUnsignedLong(endian.be32toh(bedata))
 * 
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/numeric.pyx":312
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         return PyLong_FromUnsignedLong(endian.be32toh(bedata))             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = PyLong_FromUnsignedLong(be32toh(__pyx_v_bedata)); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 312, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":309
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.OidBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15OidBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15OidBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15OidBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.OidBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15OidBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15OidBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15OidBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.OidBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":319
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef double d = PyFloat_AsDouble(obj)
 *         cdef char *out = PyOS_double_to_string(
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_12_FloatDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
double __pyx_v_d;
char *__pyx_v_out;
Py_ssize_t __pyx_v_length;
char *__pyx_v_tgt;
Py_ssize_t __pyx_r;
double __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":320
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef double d = PyFloat_AsDouble(obj)             # <<<<<<<<<<<<<<
 *         cdef char *out = PyOS_double_to_string(
 *             d, b'r', 0, Py_DTSF_ADD_DOT_0, NULL)
*/
__pyx_t_1 = PyFloat_AsDouble(__pyx_v_obj); if (unlikely(__pyx_t_1 == ((double)-1.0) && PyErr_Occurred())) __PYX_ERR(12, 320, __pyx_L1_error)
__pyx_v_d = __pyx_t_1;

/* "psycopg_c/types/numeric.pyx":321
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef double d = PyFloat_AsDouble(obj)
 *         cdef char *out = PyOS_double_to_string(             # <<<<<<<<<<<<<<
 *             d, b'r', 0, Py_DTSF_ADD_DOT_0, NULL)
 *         cdef Py_ssize_t length = strlen(out)
*/
__pyx_t_2 = PyOS_double_to_string(__pyx_v_d, 'r', 0, Py_DTSF_ADD_DOT_0, NULL); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 321, __pyx_L1_error)
__pyx_v_out = __pyx_t_2;

/* "psycopg_c/types/numeric.pyx":323
 *         cdef char *out = PyOS_double_to_string(
 *             d, b'r', 0, Py_DTSF_ADD_DOT_0, NULL)
 *         cdef Py_ssize_t length = strlen(out)             # <<<<<<<<<<<<<<
 *         cdef char *tgt = CDumper.ensure_size(rv, offset, length)
 *         memcpy(tgt, out, length)
*/
__pyx_v_length = strlen(__pyx_v_out);

/* "psycopg_c/types/numeric.pyx":324
 *             d, b'r', 0, Py_DTSF_ADD_DOT_0, NULL)
 *         cdef Py_ssize_t length = strlen(out)
 *         cdef char *tgt = CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 *         memcpy(tgt, out, length)
 *         PyMem_Free(out)
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 324, __pyx_L1_error)
__pyx_v_tgt = __pyx_t_2;

/* "psycopg_c/types/numeric.pyx":325
 *         cdef Py_ssize_t length = strlen(out)
 *         cdef char *tgt = CDumper.ensure_size(rv, offset, length)
 *         memcpy(tgt, out, length)             # <<<<<<<<<<<<<<
 *         PyMem_Free(out)
 *         return length
*/
(void)(memcpy(__pyx_v_tgt, __pyx_v_out, __pyx_v_length));

/* "psycopg_c/types/numeric.pyx":326
 *         cdef char *tgt = CDumper.ensure_size(rv, offset, length)
 *         memcpy(tgt, out, length)
 *         PyMem_Free(out)             # <<<<<<<<<<<<<<
 *         return length
 * 
*/
PyMem_Free(__pyx_v_out);

/* "psycopg_c/types/numeric.pyx":327
 *         memcpy(tgt, out, length)
 *         PyMem_Free(out)
 *         return length             # <<<<<<<<<<<<<<
 * 
 *     def quote(self, obj) -> Buffer | None:
*/
__pyx_r = __pyx_v_length;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":319
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef double d = PyFloat_AsDouble(obj)
 *         cdef char *out = PyOS_double_to_string(
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._FloatDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":329
 *         return length
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12_FloatDumper_1quote = {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_1quote, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("quote (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_quote(((struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_quote(struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
PyObject *__pyx_v_value = NULL;
PyObject *__pyx_v_ptr;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_t_6;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("quote", 0);

/* "psycopg_c/types/numeric.pyx":330
 * 
 *     def quote(self, obj) -> Buffer | None:
 *         value = bytes(self.dump(obj))             # <<<<<<<<<<<<<<
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
 *         if ptr != NULL:
*/
__pyx_t_2 = NULL;
__pyx_t_4 = ((PyObject *)__pyx_v_self);
__Pyx_INCREF(__pyx_t_4);
__pyx_t_5 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_obj};
  __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_dump, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
}
__pyx_t_5 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 330, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_v_value = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":331
 *     def quote(self, obj) -> Buffer | None:
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)             # <<<<<<<<<<<<<<
 *         if ptr != NULL:
 *             return <object>ptr
*/
__pyx_t_1 = __pyx_v_9psycopg_c_8_psycopg__special_float;
__Pyx_INCREF(__pyx_t_1);
__pyx_v_ptr = PyDict_GetItem(__pyx_t_1, __pyx_v_value);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":332
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             return <object>ptr
 * 
*/
__pyx_t_6 = (__pyx_v_ptr != NULL);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":333
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
 *         if ptr != NULL:
 *             return <object>ptr             # <<<<<<<<<<<<<<
 * 
 *         return value if obj >= 0 else b" " + value
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_ptr));
  __pyx_r = ((PyObject *)__pyx_v_ptr);
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":332
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             return <object>ptr
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":335
 *             return <object>ptr
 * 
 *         return value if obj >= 0 else b" " + value             # <<<<<<<<<<<<<<
 * 
 * cdef dict _special_float = {
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_3 = PyObject_RichCompare(__pyx_v_obj, __pyx_mstate_global->__pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 335, __pyx_L1_error)
__pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(12, 335, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
if (__pyx_t_6) {
  __Pyx_INCREF(__pyx_v_value);
  __pyx_t_1 = __pyx_v_value;
} else {
  __pyx_t_3 = PyNumber_Add(__pyx_mstate_global->__pyx_kp_b__9, __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 335, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
}
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":329
 *         return length
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._FloatDumper.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_value);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12_FloatDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._FloatDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12_FloatDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12_FloatDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._FloatDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11FloatDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11FloatDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11FloatDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11FloatDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12Float4Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12Float4Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12Float4Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_12Float4Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_12Float4Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_12Float4Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":362
 *     oid = oids.FLOAT8_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef double d = PyFloat_AsDouble(obj)
 *         cdef uint64_t ival
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_17FloatBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
double __pyx_v_d;
uint64_t __pyx_v_ival;
uint64_t __pyx_v_beval;
uint64_t *__pyx_v_buf;
Py_ssize_t __pyx_r;
double __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":363
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef double d = PyFloat_AsDouble(obj)             # <<<<<<<<<<<<<<
 *         cdef uint64_t ival
 *         memcpy(&ival, &d, sizeof(ival))
*/
__pyx_t_1 = PyFloat_AsDouble(__pyx_v_obj); if (unlikely(__pyx_t_1 == ((double)-1.0) && PyErr_Occurred())) __PYX_ERR(12, 363, __pyx_L1_error)
__pyx_v_d = __pyx_t_1;

/* "psycopg_c/types/numeric.pyx":365
 *         cdef double d = PyFloat_AsDouble(obj)
 *         cdef uint64_t ival
 *         memcpy(&ival, &d, sizeof(ival))             # <<<<<<<<<<<<<<
 *         cdef uint64_t beval = endian.htobe64(ival)
 *         cdef uint64_t *buf = <uint64_t *>CDumper.ensure_size(
*/
(void)(memcpy((&__pyx_v_ival), (&__pyx_v_d), (sizeof(__pyx_v_ival))));

/* "psycopg_c/types/numeric.pyx":366
 *         cdef uint64_t ival
 *         memcpy(&ival, &d, sizeof(ival))
 *         cdef uint64_t beval = endian.htobe64(ival)             # <<<<<<<<<<<<<<
 *         cdef uint64_t *buf = <uint64_t *>CDumper.ensure_size(
 *             rv, offset, sizeof(beval))
*/
__pyx_v_beval = htobe64(__pyx_v_ival);

/* "psycopg_c/types/numeric.pyx":367
 *         memcpy(&ival, &d, sizeof(ival))
 *         cdef uint64_t beval = endian.htobe64(ival)
 *         cdef uint64_t *buf = <uint64_t *>CDumper.ensure_size(             # <<<<<<<<<<<<<<
 *             rv, offset, sizeof(beval))
 *         memcpy(buf, &beval, sizeof(beval))
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_beval))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 367, __pyx_L1_error)
__pyx_v_buf = ((uint64_t *)__pyx_t_2);

/* "psycopg_c/types/numeric.pyx":369
 *         cdef uint64_t *buf = <uint64_t *>CDumper.ensure_size(
 *             rv, offset, sizeof(beval))
 *         memcpy(buf, &beval, sizeof(beval))             # <<<<<<<<<<<<<<
 *         return sizeof(beval)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beval), (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/numeric.pyx":370
 *             rv, offset, sizeof(beval))
 *         memcpy(buf, &beval, sizeof(beval))
 *         return sizeof(beval)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_beval));
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":362
 *     oid = oids.FLOAT8_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef double d = PyFloat_AsDouble(obj)
 *         cdef uint64_t ival
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17FloatBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17FloatBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17FloatBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17FloatBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17FloatBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17FloatBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":379
 *     oid = oids.FLOAT4_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef float f = <float>PyFloat_AsDouble(obj)
 *         cdef uint32_t ival
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_18Float4BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
float __pyx_v_f;
uint32_t __pyx_v_ival;
uint32_t __pyx_v_beval;
uint32_t *__pyx_v_buf;
Py_ssize_t __pyx_r;
double __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":380
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef float f = <float>PyFloat_AsDouble(obj)             # <<<<<<<<<<<<<<
 *         cdef uint32_t ival
 *         memcpy(&ival, &f, sizeof(ival))
*/
__pyx_t_1 = PyFloat_AsDouble(__pyx_v_obj); if (unlikely(__pyx_t_1 == ((double)-1.0) && PyErr_Occurred())) __PYX_ERR(12, 380, __pyx_L1_error)
__pyx_v_f = ((float)__pyx_t_1);

/* "psycopg_c/types/numeric.pyx":382
 *         cdef float f = <float>PyFloat_AsDouble(obj)
 *         cdef uint32_t ival
 *         memcpy(&ival, &f, sizeof(ival))             # <<<<<<<<<<<<<<
 *         cdef uint32_t beval = endian.htobe32(ival)
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(
*/
(void)(memcpy((&__pyx_v_ival), (&__pyx_v_f), (sizeof(__pyx_v_ival))));

/* "psycopg_c/types/numeric.pyx":383
 *         cdef uint32_t ival
 *         memcpy(&ival, &f, sizeof(ival))
 *         cdef uint32_t beval = endian.htobe32(ival)             # <<<<<<<<<<<<<<
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(
 *             rv, offset, sizeof(beval))
*/
__pyx_v_beval = htobe32(__pyx_v_ival);

/* "psycopg_c/types/numeric.pyx":384
 *         memcpy(&ival, &f, sizeof(ival))
 *         cdef uint32_t beval = endian.htobe32(ival)
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(             # <<<<<<<<<<<<<<
 *             rv, offset, sizeof(beval))
 *         memcpy(buf, &beval, sizeof(beval))
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_beval))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 384, __pyx_L1_error)
__pyx_v_buf = ((uint32_t *)__pyx_t_2);

/* "psycopg_c/types/numeric.pyx":386
 *         cdef uint32_t *buf = <uint32_t *>CDumper.ensure_size(
 *             rv, offset, sizeof(beval))
 *         memcpy(buf, &beval, sizeof(beval))             # <<<<<<<<<<<<<<
 *         return sizeof(beval)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beval), (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/numeric.pyx":387
 *             rv, offset, sizeof(beval))
 *         memcpy(buf, &beval, sizeof(beval))
 *         return sizeof(beval)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_beval));
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":379
 *     oid = oids.FLOAT4_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef float f = <float>PyFloat_AsDouble(obj)
 *         cdef uint32_t ival
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":395
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef char *endptr
 *         cdef double d = PyOS_string_to_double(
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11FloatLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
char *__pyx_v_endptr;
double __pyx_v_d;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
double __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":397
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef char *endptr
 *         cdef double d = PyOS_string_to_double(             # <<<<<<<<<<<<<<
 *             data, &endptr, <PyObject *>OverflowError)
 *         return PyFloat_FromDouble(d)
*/
__pyx_t_1 = PyOS_string_to_double(__pyx_v_data, (&__pyx_v_endptr), ((PyObject *)(((PyTypeObject*)PyExc_OverflowError)))); if (unlikely(__PYX_CHECK_FLOAT_EXCEPTION(__pyx_t_1, ((double)(-1.0))) && PyErr_Occurred())) __PYX_ERR(12, 397, __pyx_L1_error)
__pyx_v_d = __pyx_t_1;

/* "psycopg_c/types/numeric.pyx":399
 *         cdef double d = PyOS_string_to_double(
 *             data, &endptr, <PyObject *>OverflowError)
 *         return PyFloat_FromDouble(d)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_2 = PyFloat_FromDouble(__pyx_v_d); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 399, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_r = __pyx_t_2;
__pyx_t_2 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":395
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef char *endptr
 *         cdef double d = PyOS_string_to_double(
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg.FloatLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11FloatLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11FloatLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11FloatLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11FloatLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11FloatLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.FloatLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":407
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_18Float4BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint32_t __pyx_v_bedata;
uint32_t __pyx_v_asint;
float __pyx_v_f;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":409
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         cdef uint32_t asint = endian.be32toh(bedata)
 *         cdef float f
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/numeric.pyx":410
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         cdef uint32_t asint = endian.be32toh(bedata)             # <<<<<<<<<<<<<<
 *         cdef float f
 *         memcpy(&f, &asint, sizeof(asint))
*/
__pyx_v_asint = be32toh(__pyx_v_bedata);

/* "psycopg_c/types/numeric.pyx":412
 *         cdef uint32_t asint = endian.be32toh(bedata)
 *         cdef float f
 *         memcpy(&f, &asint, sizeof(asint))             # <<<<<<<<<<<<<<
 *         return PyFloat_FromDouble(f)
 * 
*/
(void)(memcpy((&__pyx_v_f), (&__pyx_v_asint), (sizeof(__pyx_v_asint))));

/* "psycopg_c/types/numeric.pyx":413
 *         cdef float f
 *         memcpy(&f, &asint, sizeof(asint))
 *         return PyFloat_FromDouble(f)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = PyFloat_FromDouble(__pyx_v_f); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 413, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":407
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint32_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.Float4BinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4BinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float4BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float4BinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":421
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_18Float8BinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
uint64_t __pyx_v_bedata;
uint64_t __pyx_v_asint;
double __pyx_v_d;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":423
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))             # <<<<<<<<<<<<<<
 *         cdef uint64_t asint = endian.be64toh(bedata)
 *         cdef double d
*/
(void)(memcpy((&__pyx_v_bedata), __pyx_v_data, (sizeof(__pyx_v_bedata))));

/* "psycopg_c/types/numeric.pyx":424
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
 *         cdef uint64_t asint = endian.be64toh(bedata)             # <<<<<<<<<<<<<<
 *         cdef double d
 *         memcpy(&d, &asint, sizeof(asint))
*/
__pyx_v_asint = be64toh(__pyx_v_bedata);

/* "psycopg_c/types/numeric.pyx":426
 *         cdef uint64_t asint = endian.be64toh(bedata)
 *         cdef double d
 *         memcpy(&d, &asint, sizeof(asint))             # <<<<<<<<<<<<<<
 *         return PyFloat_FromDouble(d)
 * 
*/
(void)(memcpy((&__pyx_v_d), (&__pyx_v_asint), (sizeof(__pyx_v_asint))));

/* "psycopg_c/types/numeric.pyx":427
 *         cdef double d
 *         memcpy(&d, &asint, sizeof(asint))
 *         return PyFloat_FromDouble(d)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = PyFloat_FromDouble(__pyx_v_d); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 427, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":421
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t bedata
 *         memcpy(&bedata, data, sizeof(bedata))
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.Float8BinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18Float8BinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18Float8BinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float8BinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float8BinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_18Float8BinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_18Float8BinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_18Float8BinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.Float8BinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":436
 *     oid = oids.NUMERIC_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_decimal_to_text(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_13DecimalDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":437
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_decimal_to_text(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 *     def quote(self, obj) -> Buffer | None:
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_text(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 437, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":436
 *     oid = oids.NUMERIC_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_decimal_to_text(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":439
 *         return dump_decimal_to_text(obj, rv, offset)
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13DecimalDumper_1quote = {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_1quote, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("quote (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_quote(((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_quote(struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
PyObject *__pyx_v_value = NULL;
PyObject *__pyx_v_ptr;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
size_t __pyx_t_5;
int __pyx_t_6;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("quote", 0);

/* "psycopg_c/types/numeric.pyx":440
 * 
 *     def quote(self, obj) -> Buffer | None:
 *         value = bytes(self.dump(obj))             # <<<<<<<<<<<<<<
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
 *         if ptr != NULL:
*/
__pyx_t_2 = NULL;
__pyx_t_4 = ((PyObject *)__pyx_v_self);
__Pyx_INCREF(__pyx_t_4);
__pyx_t_5 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_obj};
  __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_dump, __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
}
__pyx_t_5 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_3};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_5, (2-__pyx_t_5) | (__pyx_t_5*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_v_value = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":441
 *     def quote(self, obj) -> Buffer | None:
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)             # <<<<<<<<<<<<<<
 *         if ptr != NULL:
 *             return <object>ptr
*/
__pyx_t_1 = __pyx_v_9psycopg_c_8_psycopg__special_decimal;
__Pyx_INCREF(__pyx_t_1);
__pyx_v_ptr = PyDict_GetItem(__pyx_t_1, __pyx_v_value);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":442
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             return <object>ptr
 * 
*/
__pyx_t_6 = (__pyx_v_ptr != NULL);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":443
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
 *         if ptr != NULL:
 *             return <object>ptr             # <<<<<<<<<<<<<<
 * 
 *         return value if obj >= 0 else b" " + value
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_ptr));
  __pyx_r = ((PyObject *)__pyx_v_ptr);
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":442
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
 *         if ptr != NULL:             # <<<<<<<<<<<<<<
 *             return <object>ptr
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":445
 *             return <object>ptr
 * 
 *         return value if obj >= 0 else b" " + value             # <<<<<<<<<<<<<<
 * 
 * cdef dict _special_decimal = {
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_3 = PyObject_RichCompare(__pyx_v_obj, __pyx_mstate_global->__pyx_int_0, Py_GE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 445, __pyx_L1_error)
__pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(12, 445, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
if (__pyx_t_6) {
  __Pyx_INCREF(__pyx_v_value);
  __pyx_t_1 = __pyx_v_value;
} else {
  __pyx_t_3 = PyNumber_Add(__pyx_mstate_global->__pyx_kp_b__9, __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __pyx_t_3;
  __pyx_t_3 = 0;
}
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":439
 *         return dump_decimal_to_text(obj, rv, offset)
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalDumper.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_value);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13DecimalDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13DecimalDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13DecimalDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":459
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         s = PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         return Decimal(s)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_13NumericLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
PyObject *__pyx_v_s = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":460
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         s = PyUnicode_DecodeUTF8(<char *>data, length, NULL)             # <<<<<<<<<<<<<<
 *         return Decimal(s)
 * 
*/
__pyx_t_1 = PyUnicode_DecodeUTF8(((char *)__pyx_v_data), __pyx_v_length, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 460, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_s = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":461
 *     cdef object cload(self, const char *data, size_t length):
 *         s = PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         return Decimal(s)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_2 = NULL;
__Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 461, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = 1;
#if CYTHON_UNPACK_METHODS
if (unlikely(PyMethod_Check(__pyx_t_3))) {
  __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
  assert(__pyx_t_2);
  PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_3);
  __Pyx_INCREF(__pyx_t_2);
  __Pyx_INCREF(__pyx__function);
  __Pyx_DECREF_SET(__pyx_t_3, __pyx__function);
  __pyx_t_4 = 0;
}
#endif
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_s};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_3, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":459
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         s = PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         return Decimal(s)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.NumericLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_s);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NumericLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NumericLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NumericLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NumericLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":480
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 * 
 *         cdef uint16_t behead[4]
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_19NumericBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
uint16_t __pyx_v_behead[4];
uint16_t __pyx_v_ndigits;
int16_t __pyx_v_weight;
uint16_t __pyx_v_sign;
uint16_t __pyx_v_dscale;
int __pyx_v_shift;
CYTHON_UNUSED int __pyx_v_i;
PyObject *__pyx_v_pctx;
PyObject *__pyx_v_key = 0;
char const *__pyx_v_digitptr;
uint16_t __pyx_v_bedigit;
PyObject *__pyx_v_val = NULL;
PyObject *__pyx_v_ctx = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
size_t __pyx_t_7;
uint16_t __pyx_t_8;
uint16_t __pyx_t_9;
int __pyx_t_10;
PyObject *__pyx_t_11 = NULL;
PyObject *__pyx_t_12 = NULL;
PyObject *__pyx_t_13 = NULL;
PyObject *__pyx_t_14 = NULL;
PyObject *__pyx_t_15 = NULL;
PyObject *__pyx_t_16 = NULL;
PyObject *__pyx_t_17 = NULL;
PyObject *__pyx_t_18 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/numeric.pyx":483
 * 
 *         cdef uint16_t behead[4]
 *         memcpy(&behead, data, sizeof(behead))             # <<<<<<<<<<<<<<
 *         cdef uint16_t ndigits = endian.be16toh(behead[0])
 *         cdef int16_t weight = <int16_t>endian.be16toh(behead[1])
*/
(void)(memcpy((&__pyx_v_behead), __pyx_v_data, (sizeof(__pyx_v_behead))));

/* "psycopg_c/types/numeric.pyx":484
 *         cdef uint16_t behead[4]
 *         memcpy(&behead, data, sizeof(behead))
 *         cdef uint16_t ndigits = endian.be16toh(behead[0])             # <<<<<<<<<<<<<<
 *         cdef int16_t weight = <int16_t>endian.be16toh(behead[1])
 *         cdef uint16_t sign = endian.be16toh(behead[2])
*/
__pyx_v_ndigits = be16toh((__pyx_v_behead[0]));

/* "psycopg_c/types/numeric.pyx":485
 *         memcpy(&behead, data, sizeof(behead))
 *         cdef uint16_t ndigits = endian.be16toh(behead[0])
 *         cdef int16_t weight = <int16_t>endian.be16toh(behead[1])             # <<<<<<<<<<<<<<
 *         cdef uint16_t sign = endian.be16toh(behead[2])
 *         cdef uint16_t dscale = endian.be16toh(behead[3])
*/
__pyx_v_weight = ((int16_t)be16toh((__pyx_v_behead[1])));

/* "psycopg_c/types/numeric.pyx":486
 *         cdef uint16_t ndigits = endian.be16toh(behead[0])
 *         cdef int16_t weight = <int16_t>endian.be16toh(behead[1])
 *         cdef uint16_t sign = endian.be16toh(behead[2])             # <<<<<<<<<<<<<<
 *         cdef uint16_t dscale = endian.be16toh(behead[3])
 * 
*/
__pyx_v_sign = be16toh((__pyx_v_behead[2]));

/* "psycopg_c/types/numeric.pyx":487
 *         cdef int16_t weight = <int16_t>endian.be16toh(behead[1])
 *         cdef uint16_t sign = endian.be16toh(behead[2])
 *         cdef uint16_t dscale = endian.be16toh(behead[3])             # <<<<<<<<<<<<<<
 * 
 *         cdef int shift
*/
__pyx_v_dscale = be16toh((__pyx_v_behead[3]));

/* "psycopg_c/types/numeric.pyx":496
 *         cdef uint16_t bedigit
 * 
 *         if sign == NUMERIC_POS or sign == NUMERIC_NEG:             # <<<<<<<<<<<<<<
 *             if length != (4 + ndigits) * sizeof(uint16_t):
 *                 raise e.DataError("bad ndigits in numeric binary representation")
*/
__pyx_t_2 = (__pyx_v_sign == NUMERIC_POS);
if (!__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L4_bool_binop_done;
}
__pyx_t_2 = (__pyx_v_sign == NUMERIC_NEG);
__pyx_t_1 = __pyx_t_2;
__pyx_L4_bool_binop_done:;
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":497
 * 
 *         if sign == NUMERIC_POS or sign == NUMERIC_NEG:
 *             if length != (4 + ndigits) * sizeof(uint16_t):             # <<<<<<<<<<<<<<
 *                 raise e.DataError("bad ndigits in numeric binary representation")
 * 
*/
  __pyx_t_1 = (__pyx_v_length != ((4 + __pyx_v_ndigits) * (sizeof(uint16_t))));
  if (unlikely(__pyx_t_1)) {

    /* "psycopg_c/types/numeric.pyx":498
 *         if sign == NUMERIC_POS or sign == NUMERIC_NEG:
 *             if length != (4 + ndigits) * sizeof(uint16_t):
 *                 raise e.DataError("bad ndigits in numeric binary representation")             # <<<<<<<<<<<<<<
 * 
 *             val = 0
*/
    __pyx_t_4 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 498, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
      assert(__pyx_t_4);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_bad_ndigits_in_numeric_binary_re};
      __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 498, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(12, 498, __pyx_L1_error)

    /* "psycopg_c/types/numeric.pyx":497
 * 
 *         if sign == NUMERIC_POS or sign == NUMERIC_NEG:
 *             if length != (4 + ndigits) * sizeof(uint16_t):             # <<<<<<<<<<<<<<
 *                 raise e.DataError("bad ndigits in numeric binary representation")
 * 
*/
  }

  /* "psycopg_c/types/numeric.pyx":500
 *                 raise e.DataError("bad ndigits in numeric binary representation")
 * 
 *             val = 0             # <<<<<<<<<<<<<<
 *             digitptr = data + sizeof(behead)
 *             for i in range(ndigits):
*/
  __Pyx_INCREF(__pyx_mstate_global->__pyx_int_0);
  __pyx_v_val = __pyx_mstate_global->__pyx_int_0;

  /* "psycopg_c/types/numeric.pyx":501
 * 
 *             val = 0
 *             digitptr = data + sizeof(behead)             # <<<<<<<<<<<<<<
 *             for i in range(ndigits):
 *                 memcpy(&bedigit, digitptr, sizeof(bedigit))
*/
  __pyx_v_digitptr = (__pyx_v_data + (sizeof(__pyx_v_behead)));

  /* "psycopg_c/types/numeric.pyx":502
 *             val = 0
 *             digitptr = data + sizeof(behead)
 *             for i in range(ndigits):             # <<<<<<<<<<<<<<
 *                 memcpy(&bedigit, digitptr, sizeof(bedigit))
 *                 digitptr += sizeof(bedigit)
*/
  __pyx_t_8 = __pyx_v_ndigits;
  __pyx_t_9 = __pyx_t_8;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "psycopg_c/types/numeric.pyx":503
 *             digitptr = data + sizeof(behead)
 *             for i in range(ndigits):
 *                 memcpy(&bedigit, digitptr, sizeof(bedigit))             # <<<<<<<<<<<<<<
 *                 digitptr += sizeof(bedigit)
 *                 val *= 10_000
*/
    (void)(memcpy((&__pyx_v_bedigit), __pyx_v_digitptr, (sizeof(__pyx_v_bedigit))));

    /* "psycopg_c/types/numeric.pyx":504
 *             for i in range(ndigits):
 *                 memcpy(&bedigit, digitptr, sizeof(bedigit))
 *                 digitptr += sizeof(bedigit)             # <<<<<<<<<<<<<<
 *                 val *= 10_000
 *                 val += endian.be16toh(bedigit)
*/
    __pyx_v_digitptr = (__pyx_v_digitptr + (sizeof(__pyx_v_bedigit)));

    /* "psycopg_c/types/numeric.pyx":505
 *                 memcpy(&bedigit, digitptr, sizeof(bedigit))
 *                 digitptr += sizeof(bedigit)
 *                 val *= 10_000             # <<<<<<<<<<<<<<
 *                 val += endian.be16toh(bedigit)
 * 
*/
    __pyx_t_3 = __Pyx_PyLong_MultiplyObjC(__pyx_v_val, __pyx_mstate_global->__pyx_int_10000, 0x2710, 1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 505, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "psycopg_c/types/numeric.pyx":506
 *                 digitptr += sizeof(bedigit)
 *                 val *= 10_000
 *                 val += endian.be16toh(bedigit)             # <<<<<<<<<<<<<<
 * 
 *             shift = dscale - (ndigits - weight - 1) * DEC_DIGITS
*/
    __pyx_t_3 = __Pyx_PyLong_From_uint16_t(be16toh(__pyx_v_bedigit)); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyNumber_InPlaceAdd(__pyx_v_val, __pyx_t_3); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF_SET(__pyx_v_val, __pyx_t_6);
    __pyx_t_6 = 0;
  }

  /* "psycopg_c/types/numeric.pyx":508
 *                 val += endian.be16toh(bedigit)
 * 
 *             shift = dscale - (ndigits - weight - 1) * DEC_DIGITS             # <<<<<<<<<<<<<<
 * 
 *             key = (weight + 2) * DEC_DIGITS + dscale
*/
  __pyx_v_shift = (__pyx_v_dscale - (((__pyx_v_ndigits - __pyx_v_weight) - 1) * DEC_DIGITS));

  /* "psycopg_c/types/numeric.pyx":510
 *             shift = dscale - (ndigits - weight - 1) * DEC_DIGITS
 * 
 *             key = (weight + 2) * DEC_DIGITS + dscale             # <<<<<<<<<<<<<<
 *             pctx = PyDict_GetItem(_contexts, key)
 *             if pctx == NULL:
*/
  __pyx_t_6 = __Pyx_PyLong_From_long((((__pyx_v_weight + 2) * DEC_DIGITS) + __pyx_v_dscale)); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_key = __pyx_t_6;
  __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":511
 * 
 *             key = (weight + 2) * DEC_DIGITS + dscale
 *             pctx = PyDict_GetItem(_contexts, key)             # <<<<<<<<<<<<<<
 *             if pctx == NULL:
 *                 ctx = Context(prec=key)
*/
  __pyx_t_6 = __pyx_v_9psycopg_c_8_psycopg__contexts;
  __Pyx_INCREF(__pyx_t_6);
  __pyx_v_pctx = PyDict_GetItem(__pyx_t_6, __pyx_v_key);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":512
 *             key = (weight + 2) * DEC_DIGITS + dscale
 *             pctx = PyDict_GetItem(_contexts, key)
 *             if pctx == NULL:             # <<<<<<<<<<<<<<
 *                 ctx = Context(prec=key)
 *                 PyDict_SetItem(_contexts, key, ctx)
*/
  __pyx_t_1 = (__pyx_v_pctx == NULL);
  if (__pyx_t_1) {

    /* "psycopg_c/types/numeric.pyx":513
 *             pctx = PyDict_GetItem(_contexts, key)
 *             if pctx == NULL:
 *                 ctx = Context(prec=key)             # <<<<<<<<<<<<<<
 *                 PyDict_SetItem(_contexts, key, ctx)
 *                 pctx = <PyObject *>ctx
*/
    __pyx_t_3 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_Context); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
      assert(__pyx_t_3);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_4, __pyx__function);
      __pyx_t_7 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2 + ((CYTHON_VECTORCALL) ? 1 : 0)] = {__pyx_t_3, NULL};
      __pyx_t_5 = __Pyx_MakeVectorcallBuilderKwds(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (__Pyx_VectorcallBuilder_AddArg(__pyx_mstate_global->__pyx_n_u_prec, __pyx_v_key, __pyx_t_5, __pyx_callargs+1, 0) < (0)) __PYX_ERR(12, 513, __pyx_L1_error)
      __pyx_t_6 = __Pyx_Object_Vectorcall_CallFromBuilder((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET), __pyx_t_5);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 513, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
    }
    __pyx_v_ctx = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "psycopg_c/types/numeric.pyx":514
 *             if pctx == NULL:
 *                 ctx = Context(prec=key)
 *                 PyDict_SetItem(_contexts, key, ctx)             # <<<<<<<<<<<<<<
 *                 pctx = <PyObject *>ctx
 * 
*/
    __pyx_t_6 = __pyx_v_9psycopg_c_8_psycopg__contexts;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_10 = PyDict_SetItem(__pyx_t_6, __pyx_v_key, __pyx_v_ctx); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(12, 514, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "psycopg_c/types/numeric.pyx":515
 *                 ctx = Context(prec=key)
 *                 PyDict_SetItem(_contexts, key, ctx)
 *                 pctx = <PyObject *>ctx             # <<<<<<<<<<<<<<
 * 
 *             return (
*/
    __pyx_v_pctx = ((PyObject *)__pyx_v_ctx);

    /* "psycopg_c/types/numeric.pyx":512
 *             key = (weight + 2) * DEC_DIGITS + dscale
 *             pctx = PyDict_GetItem(_contexts, key)
 *             if pctx == NULL:             # <<<<<<<<<<<<<<
 *                 ctx = Context(prec=key)
 *                 PyDict_SetItem(_contexts, key, ctx)
*/
  }

  /* "psycopg_c/types/numeric.pyx":517
 *                 pctx = <PyObject *>ctx
 * 
 *             return (             # <<<<<<<<<<<<<<
 *                 Decimal(val if sign == NUMERIC_POS else -val)
 *                 .scaleb(-dscale, <object>pctx)
*/
  __Pyx_XDECREF(__pyx_r);

  /* "psycopg_c/types/numeric.pyx":518
 * 
 *             return (
 *                 Decimal(val if sign == NUMERIC_POS else -val)             # <<<<<<<<<<<<<<
 *                 .scaleb(-dscale, <object>pctx)
 *                 .shift(shift, <object>pctx)
*/
  __pyx_t_12 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_13, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_13)) __PYX_ERR(12, 518, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = (__pyx_v_sign == NUMERIC_POS);
  if (__pyx_t_1) {
    __Pyx_INCREF(__pyx_v_val);
    __pyx_t_14 = __pyx_v_val;
  } else {
    __pyx_t_15 = PyNumber_Negative(__pyx_v_val); if (unlikely(!__pyx_t_15)) __PYX_ERR(12, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_15);
    __pyx_t_14 = __pyx_t_15;
    __pyx_t_15 = 0;
  }
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_13))) {
    __pyx_t_12 = PyMethod_GET_SELF(__pyx_t_13);
    assert(__pyx_t_12);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_13);
    __Pyx_INCREF(__pyx_t_12);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_13, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_12, __pyx_t_14};
    __pyx_t_11 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_13, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    if (unlikely(!__pyx_t_11)) __PYX_ERR(12, 518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
  }
  __pyx_t_3 = __pyx_t_11;
  __Pyx_INCREF(__pyx_t_3);

  /* "psycopg_c/types/numeric.pyx":519
 *             return (
 *                 Decimal(val if sign == NUMERIC_POS else -val)
 *                 .scaleb(-dscale, <object>pctx)             # <<<<<<<<<<<<<<
 *                 .shift(shift, <object>pctx)
 *             )
*/
  __pyx_t_13 = __Pyx_PyLong_From_int((-__pyx_v_dscale)); if (unlikely(!__pyx_t_13)) __PYX_ERR(12, 519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_3, __pyx_t_13, ((PyObject *)__pyx_v_pctx)};
    __pyx_t_5 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_scaleb, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __pyx_t_4 = __pyx_t_5;
  __Pyx_INCREF(__pyx_t_4);

  /* "psycopg_c/types/numeric.pyx":520
 *                 Decimal(val if sign == NUMERIC_POS else -val)
 *                 .scaleb(-dscale, <object>pctx)
 *                 .shift(shift, <object>pctx)             # <<<<<<<<<<<<<<
 *             )
 *         else:
*/
  __pyx_t_11 = __Pyx_PyLong_From_int(__pyx_v_shift); if (unlikely(!__pyx_t_11)) __PYX_ERR(12, 520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_7 = 0;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_11, ((PyObject *)__pyx_v_pctx)};
    __pyx_t_6 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_shift, __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 520, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":496
 *         cdef uint16_t bedigit
 * 
 *         if sign == NUMERIC_POS or sign == NUMERIC_NEG:             # <<<<<<<<<<<<<<
 *             if length != (4 + ndigits) * sizeof(uint16_t):
 *                 raise e.DataError("bad ndigits in numeric binary representation")
*/
}

/* "psycopg_c/types/numeric.pyx":523
 *             )
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 return _decimal_special[sign]
 *             except KeyError:
*/
/*else*/ {
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_16, &__pyx_t_17, &__pyx_t_18);
    __Pyx_XGOTREF(__pyx_t_16);
    __Pyx_XGOTREF(__pyx_t_17);
    __Pyx_XGOTREF(__pyx_t_18);
    /*try:*/ {

      /* "psycopg_c/types/numeric.pyx":524
 *         else:
 *             try:
 *                 return _decimal_special[sign]             # <<<<<<<<<<<<<<
 *             except KeyError:
 *                 raise e.DataError(f"bad value for numeric sign: 0x{sign:X}")
*/
      __Pyx_XDECREF(__pyx_r);
      if (unlikely(__pyx_v_9psycopg_c_8_psycopg__decimal_special == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(12, 524, __pyx_L10_error)
      }
      __pyx_t_6 = __Pyx_PyLong_From_uint16_t(__pyx_v_sign); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 524, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_5 = __Pyx_PyDict_GetItem(__pyx_v_9psycopg_c_8_psycopg__decimal_special, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 524, __pyx_L10_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_r = __pyx_t_5;
      __pyx_t_5 = 0;
      goto __pyx_L14_try_return;

      /* "psycopg_c/types/numeric.pyx":523
 *             )
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 return _decimal_special[sign]
 *             except KeyError:
*/
    }
    __pyx_L10_error:;
    __Pyx_XDECREF(__pyx_t_11); __pyx_t_11 = 0;
    __Pyx_XDECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
    __Pyx_XDECREF(__pyx_t_14); __pyx_t_14 = 0;
    __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "psycopg_c/types/numeric.pyx":525
 *             try:
 *                 return _decimal_special[sign]
 *             except KeyError:             # <<<<<<<<<<<<<<
 *                 raise e.DataError(f"bad value for numeric sign: 0x{sign:X}")
 * 
*/
    __pyx_t_10 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(((PyTypeObject*)PyExc_KeyError))));
    if (__pyx_t_10) {
      __Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_11) < 0) __PYX_ERR(12, 525, __pyx_L12_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_11);

      /* "psycopg_c/types/numeric.pyx":526
 *                 return _decimal_special[sign]
 *             except KeyError:
 *                 raise e.DataError(f"bad value for numeric sign: 0x{sign:X}")             # <<<<<<<<<<<<<<
 * 
 * 
*/
      __pyx_t_13 = NULL;
      __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 526, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_14 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_14)) __PYX_ERR(12, 526, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_14);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyUnicode_From_uint16_t(__pyx_v_sign, 0, ' ', 'X'); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 526, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_12 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_bad_value_for_numeric_sign_0x, __pyx_t_3); if (unlikely(!__pyx_t_12)) __PYX_ERR(12, 526, __pyx_L12_except_error)
      __Pyx_GOTREF(__pyx_t_12);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = 1;
      #if CYTHON_UNPACK_METHODS
      if (unlikely(PyMethod_Check(__pyx_t_14))) {
        __pyx_t_13 = PyMethod_GET_SELF(__pyx_t_14);
        assert(__pyx_t_13);
        PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_14);
        __Pyx_INCREF(__pyx_t_13);
        __Pyx_INCREF(__pyx__function);
        __Pyx_DECREF_SET(__pyx_t_14, __pyx__function);
        __pyx_t_7 = 0;
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_13, __pyx_t_12};
        __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_14, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 526, __pyx_L12_except_error)
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __PYX_ERR(12, 526, __pyx_L12_except_error)
    }
    goto __pyx_L12_except_error;

    /* "psycopg_c/types/numeric.pyx":523
 *             )
 *         else:
 *             try:             # <<<<<<<<<<<<<<
 *                 return _decimal_special[sign]
 *             except KeyError:
*/
    __pyx_L12_except_error:;
    __Pyx_XGIVEREF(__pyx_t_16);
    __Pyx_XGIVEREF(__pyx_t_17);
    __Pyx_XGIVEREF(__pyx_t_18);
    __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
    goto __pyx_L1_error;
    __pyx_L14_try_return:;
    __Pyx_XGIVEREF(__pyx_t_16);
    __Pyx_XGIVEREF(__pyx_t_17);
    __Pyx_XGIVEREF(__pyx_t_18);
    __Pyx_ExceptionReset(__pyx_t_16, __pyx_t_17, __pyx_t_18);
    goto __pyx_L0;
  }
}

/* "psycopg_c/types/numeric.pyx":480
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 * 
 *         cdef uint16_t behead[4]
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_XDECREF(__pyx_t_12);
__Pyx_XDECREF(__pyx_t_13);
__Pyx_XDECREF(__pyx_t_14);
__Pyx_XDECREF(__pyx_t_15);
__Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_key);
__Pyx_XDECREF(__pyx_v_val);
__Pyx_XDECREF(__pyx_v_ctx);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":535
 *     oid = oids.NUMERIC_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_decimal_to_numeric_binary(obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19DecimalBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
Py_ssize_t __pyx_t_1;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":536
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_decimal_to_numeric_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_numeric_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 536, __pyx_L1_error)
__pyx_r = __pyx_t_1;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":535
 *     oid = oids.NUMERIC_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_decimal_to_numeric_binary(obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19DecimalBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19DecimalBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19DecimalBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19DecimalBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19DecimalBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19DecimalBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.DecimalBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":543
 *     oid = oids.NUMERIC_OID
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         global _int_classes
 * 
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(12, 543, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 543, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 543, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(12, 543, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(12, 543, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(12, 543, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(12, 543, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  __pyx_v_cls = values[0];
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(12, 543, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._MixedNumericDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *)__pyx_v_self), __pyx_v_cls, __pyx_v_context);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper___cinit__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context) {
PyObject *__pyx_v_numpy = NULL;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/numeric.pyx":546
 *         global _int_classes
 * 
 *         if _int_classes is None:             # <<<<<<<<<<<<<<
 *             if "numpy" in sys.modules:
 *                 import numpy
*/
__Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_int_classes); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 546, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = (__pyx_t_1 == Py_None);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_2) {

  /* "psycopg_c/types/numeric.pyx":547
 * 
 *         if _int_classes is None:
 *             if "numpy" in sys.modules:             # <<<<<<<<<<<<<<
 *                 import numpy
 *                 _int_classes = (int, numpy.integer)
*/
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_sys); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_modules); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 547, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_mstate_global->__pyx_n_u_numpy, __pyx_t_3, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(12, 547, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_2) {

    /* "psycopg_c/types/numeric.pyx":548
 *         if _int_classes is None:
 *             if "numpy" in sys.modules:
 *                 import numpy             # <<<<<<<<<<<<<<
 *                 _int_classes = (int, numpy.integer)
 *             else:
*/
    __pyx_t_4 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_numpy, 0, 0, NULL, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 548, __pyx_L1_error)
    __pyx_t_3 = __pyx_t_4;
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_v_numpy = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "psycopg_c/types/numeric.pyx":549
 *             if "numpy" in sys.modules:
 *                 import numpy
 *                 _int_classes = (int, numpy.integer)             # <<<<<<<<<<<<<<
 *             else:
 *                 _int_classes = int
*/
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_numpy, __pyx_mstate_global->__pyx_n_u_integer); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF((PyObject *)(&PyLong_Type));
    __Pyx_GIVEREF((PyObject *)(&PyLong_Type));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)(&PyLong_Type))) != (0)) __PYX_ERR(12, 549, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3) != (0)) __PYX_ERR(12, 549, __pyx_L1_error);
    __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_int_classes, __pyx_t_1) < (0)) __PYX_ERR(12, 549, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "psycopg_c/types/numeric.pyx":547
 * 
 *         if _int_classes is None:
 *             if "numpy" in sys.modules:             # <<<<<<<<<<<<<<
 *                 import numpy
 *                 _int_classes = (int, numpy.integer)
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/numeric.pyx":551
 *                 _int_classes = (int, numpy.integer)
 *             else:
 *                 _int_classes = int             # <<<<<<<<<<<<<<
 * 
 * 
*/
  /*else*/ {
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_int_classes, ((PyObject *)(&PyLong_Type))) < (0)) __PYX_ERR(12, 551, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "psycopg_c/types/numeric.pyx":546
 *         global _int_classes
 * 
 *         if _int_classes is None:             # <<<<<<<<<<<<<<
 *             if "numpy" in sys.modules:
 *                 import numpy
*/
}

/* "psycopg_c/types/numeric.pyx":543
 *     oid = oids.NUMERIC_OID
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         global _int_classes
 * 
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg._MixedNumericDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_numpy);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_MixedNumericDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._MixedNumericDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19_MixedNumericDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19_MixedNumericDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._MixedNumericDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":559
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         if type(obj) is int:  # fast path
 *             return dump_int_to_text(obj, rv, offset)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_13NumericDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
Py_ssize_t __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8[4];
size_t __pyx_t_9;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numeric.pyx":560
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         if type(obj) is int:  # fast path             # <<<<<<<<<<<<<<
 *             return dump_int_to_text(obj, rv, offset)
 *         elif isinstance(obj, Decimal):
*/
__pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_obj)) == ((PyObject *)(&PyLong_Type)));
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":561
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         if type(obj) is int:  # fast path
 *             return dump_int_to_text(obj, rv, offset)             # <<<<<<<<<<<<<<
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_text(obj, rv, offset)
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_text(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 561, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":560
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         if type(obj) is int:  # fast path             # <<<<<<<<<<<<<<
 *             return dump_int_to_text(obj, rv, offset)
 *         elif isinstance(obj, Decimal):
*/
}

/* "psycopg_c/types/numeric.pyx":562
 *         if type(obj) is int:  # fast path
 *             return dump_int_to_text(obj, rv, offset)
 *         elif isinstance(obj, Decimal):             # <<<<<<<<<<<<<<
 *             return dump_decimal_to_text(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):
*/
__Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 562, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_1 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(12, 562, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":563
 *             return dump_int_to_text(obj, rv, offset)
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_text(obj, rv, offset)             # <<<<<<<<<<<<<<
 *         elif isinstance(obj, _int_classes):
 *             return dump_int_to_text(obj, rv, offset)
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_text(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 563, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":562
 *         if type(obj) is int:  # fast path
 *             return dump_int_to_text(obj, rv, offset)
 *         elif isinstance(obj, Decimal):             # <<<<<<<<<<<<<<
 *             return dump_decimal_to_text(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):
*/
}

/* "psycopg_c/types/numeric.pyx":564
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_text(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):             # <<<<<<<<<<<<<<
 *             return dump_int_to_text(obj, rv, offset)
 *         else:
*/
__Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_int_classes); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 564, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_1 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(12, 564, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
if (likely(__pyx_t_1)) {

  /* "psycopg_c/types/numeric.pyx":565
 *             return dump_decimal_to_text(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):
 *             return dump_int_to_text(obj, rv, offset)             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_text(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 565, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":564
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_text(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):             # <<<<<<<<<<<<<<
 *             return dump_int_to_text(obj, rv, offset)
 *         else:
*/
}

/* "psycopg_c/types/numeric.pyx":567
 *             return dump_int_to_text(obj, rv, offset)
 *         else:
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 f"class {type(self).__name__} cannot dump {type(obj).__name__}"
 *             )
*/
/*else*/ {
  __pyx_t_4 = NULL;

  /* "psycopg_c/types/numeric.pyx":568
 *         else:
 *             raise TypeError(
 *                 f"class {type(self).__name__} cannot dump {type(obj).__name__}"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_obj)), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(12, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_class;
  __pyx_t_8[1] = __pyx_t_6;
  __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u_cannot_dump;
  __pyx_t_8[3] = __pyx_t_7;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_8, 4, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 13 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
  if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_9 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(12, 567, __pyx_L1_error)
}

/* "psycopg_c/types/numeric.pyx":559
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         if type(obj) is int:  # fast path
 *             return dump_int_to_text(obj, rv, offset)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_AddTraceback("psycopg_c._psycopg.NumericDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NumericDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NumericDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NumericDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NumericDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NumericDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":577
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         if type(obj) is int:
 *             return dump_int_to_numeric_binary(obj, rv, offset)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NumericBinaryDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
Py_ssize_t __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8[4];
size_t __pyx_t_9;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numeric.pyx":578
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         if type(obj) is int:             # <<<<<<<<<<<<<<
 *             return dump_int_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, Decimal):
*/
__pyx_t_1 = (((PyObject *)Py_TYPE(__pyx_v_obj)) == ((PyObject *)(&PyLong_Type)));
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":579
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         if type(obj) is int:
 *             return dump_int_to_numeric_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_numeric_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 579, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":578
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         if type(obj) is int:             # <<<<<<<<<<<<<<
 *             return dump_int_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, Decimal):
*/
}

/* "psycopg_c/types/numeric.pyx":580
 *         if type(obj) is int:
 *             return dump_int_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, Decimal):             # <<<<<<<<<<<<<<
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):
*/
__Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 580, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_1 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(12, 580, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":581
 *             return dump_int_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)             # <<<<<<<<<<<<<<
 *         elif isinstance(obj, _int_classes):
 *             return dump_int_to_numeric_binary(int(obj), rv, offset)
*/
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_numeric_binary(__pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 581, __pyx_L1_error)
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":580
 *         if type(obj) is int:
 *             return dump_int_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, Decimal):             # <<<<<<<<<<<<<<
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):
*/
}

/* "psycopg_c/types/numeric.pyx":582
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):             # <<<<<<<<<<<<<<
 *             return dump_int_to_numeric_binary(int(obj), rv, offset)
 *         else:
*/
__Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_int_classes); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 582, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_1 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_3); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(12, 582, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
if (likely(__pyx_t_1)) {

  /* "psycopg_c/types/numeric.pyx":583
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):
 *             return dump_int_to_numeric_binary(int(obj), rv, offset)             # <<<<<<<<<<<<<<
 *         else:
 *             raise TypeError(
*/
  __pyx_t_3 = __Pyx_PyNumber_Int(__pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_numeric_binary(__pyx_t_3, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(12, 583, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":582
 *         elif isinstance(obj, Decimal):
 *             return dump_decimal_to_numeric_binary(obj, rv, offset)
 *         elif isinstance(obj, _int_classes):             # <<<<<<<<<<<<<<
 *             return dump_int_to_numeric_binary(int(obj), rv, offset)
 *         else:
*/
}

/* "psycopg_c/types/numeric.pyx":585
 *             return dump_int_to_numeric_binary(int(obj), rv, offset)
 *         else:
 *             raise TypeError(             # <<<<<<<<<<<<<<
 *                 f"class {type(self).__name__} cannot dump {type(obj).__name__}"
 *             )
*/
/*else*/ {
  __pyx_t_4 = NULL;

  /* "psycopg_c/types/numeric.pyx":586
 *         else:
 *             raise TypeError(
 *                 f"class {type(self).__name__} cannot dump {type(obj).__name__}"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_obj)), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __Pyx_PyObject_FormatSimple(__pyx_t_5, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(12, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8[0] = __pyx_mstate_global->__pyx_kp_u_class;
  __pyx_t_8[1] = __pyx_t_6;
  __pyx_t_8[2] = __pyx_mstate_global->__pyx_kp_u_cannot_dump;
  __pyx_t_8[3] = __pyx_t_7;
  __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_8, 4, 6 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 13 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7), 127 | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_6) | __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7));
  if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_9 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_5};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_TypeError)), __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 585, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(12, 585, __pyx_L1_error)
}

/* "psycopg_c/types/numeric.pyx":577
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         if type(obj) is int:
 *             return dump_int_to_numeric_binary(obj, rv, offset)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NumericBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NumericBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":590
 * 
 * 
 * cdef Py_ssize_t dump_decimal_to_text(obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *     cdef char *src
 *     cdef Py_ssize_t length
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_text(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
char *__pyx_v_src;
Py_ssize_t __pyx_v_length;
char *__pyx_v_buf;
PyObject *__pyx_v_b = NULL;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_t_5;
int __pyx_t_6;
char *__pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("dump_decimal_to_text", 0);

/* "psycopg_c/types/numeric.pyx":595
 *     cdef char *buf
 * 
 *     b = bytes(str(obj), "utf-8")             # <<<<<<<<<<<<<<
 *     PyBytes_AsStringAndSize(b, &src, &length)
 * 
*/
__pyx_t_2 = NULL;
__pyx_t_3 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 595, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_4 = 1;
{
  PyObject *__pyx_callargs[3] = {__pyx_t_2, __pyx_t_3, __pyx_mstate_global->__pyx_kp_u_utf_8};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_4, (3-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_v_b = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":596
 * 
 *     b = bytes(str(obj), "utf-8")
 *     PyBytes_AsStringAndSize(b, &src, &length)             # <<<<<<<<<<<<<<
 * 
 *     if src[0] != b's':
*/
__pyx_t_5 = PyBytes_AsStringAndSize(__pyx_v_b, (&__pyx_v_src), (&__pyx_v_length)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(12, 596, __pyx_L1_error)

/* "psycopg_c/types/numeric.pyx":598
 *     PyBytes_AsStringAndSize(b, &src, &length)
 * 
 *     if src[0] != b's':             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)
*/
__pyx_t_6 = ((__pyx_v_src[0]) != 's');
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":599
 * 
 *     if src[0] != b's':
 *         buf = CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, length)
 * 
*/
  __pyx_t_7 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(12, 599, __pyx_L1_error)
  __pyx_v_buf = __pyx_t_7;

  /* "psycopg_c/types/numeric.pyx":600
 *     if src[0] != b's':
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)             # <<<<<<<<<<<<<<
 * 
 *     else:  # convert sNaN to NaN
*/
  (void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_length));

  /* "psycopg_c/types/numeric.pyx":598
 *     PyBytes_AsStringAndSize(b, &src, &length)
 * 
 *     if src[0] != b's':             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/numeric.pyx":603
 * 
 *     else:  # convert sNaN to NaN
 *         length = 3  # NaN             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, b"NaN", length)
*/
/*else*/ {
  __pyx_v_length = 3;

  /* "psycopg_c/types/numeric.pyx":604
 *     else:  # convert sNaN to NaN
 *         length = 3  # NaN
 *         buf = CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 *         memcpy(buf, b"NaN", length)
 * 
*/
  __pyx_t_7 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(12, 604, __pyx_L1_error)
  __pyx_v_buf = __pyx_t_7;

  /* "psycopg_c/types/numeric.pyx":605
 *         length = 3  # NaN
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, b"NaN", length)             # <<<<<<<<<<<<<<
 * 
 *     return length
*/
  (void)(memcpy(__pyx_v_buf, __pyx_k_NaN, __pyx_v_length));
}
__pyx_L3:;

/* "psycopg_c/types/numeric.pyx":607
 *         memcpy(buf, b"NaN", length)
 * 
 *     return length             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_length;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":590
 * 
 * 
 * cdef Py_ssize_t dump_decimal_to_text(obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *     cdef char *src
 *     cdef Py_ssize_t length
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.dump_decimal_to_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_b);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":618
 * 
 * 
 * @cython.cdivision(True)             # <<<<<<<<<<<<<<
 * cdef Py_ssize_t dump_decimal_to_numeric_binary(
 *     obj, bytearray rv, Py_ssize_t offset
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_decimal_to_numeric_binary(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
PyObject *__pyx_v_t = 0;
int __pyx_v_sign;
PyObject *__pyx_v_digits = 0;
uint16_t *__pyx_v_buf;
uint16_t __pyx_v_behead[4];
Py_ssize_t __pyx_v_length;
PyObject *__pyx_v_pyexp = 0;
char const *__pyx_v_bexp;
int __pyx_v_exp;
uint16_t __pyx_v_ndigits;
int __pyx_v_nzdigits;
uint16_t __pyx_v_dscale;
int __pyx_v_wi;
int __pyx_v_mod;
int __pyx_v_tmp;
int __pyx_v_pgdigits;
uint16_t __pyx_v_pgdigit;
uint16_t __pyx_v_bedigit;
int __pyx_v_i;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
size_t __pyx_t_3;
int __pyx_t_4;
int __pyx_t_5;
int __pyx_t_6;
char *__pyx_t_7;
char const *__pyx_t_8;
PyObject *__pyx_t_9 = NULL;
PyObject *__pyx_t_10 = NULL;
PyObject *__pyx_t_11 = NULL;
Py_ssize_t __pyx_t_12;
long __pyx_t_13;
uint16_t __pyx_t_14;
int __pyx_t_15;
int __pyx_t_16;
int __pyx_t_17;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("dump_decimal_to_numeric_binary", 0);

/* "psycopg_c/types/numeric.pyx":629
 *     # tuple, and then accessing them).
 * 
 *     cdef object t = obj.as_tuple()             # <<<<<<<<<<<<<<
 *     cdef int sign = t[0]
 *     cdef tuple digits = t[1]
*/
__pyx_t_2 = __pyx_v_obj;
__Pyx_INCREF(__pyx_t_2);
__pyx_t_3 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
  __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_as_tuple, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_v_t = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":630
 * 
 *     cdef object t = obj.as_tuple()
 *     cdef int sign = t[0]             # <<<<<<<<<<<<<<
 *     cdef tuple digits = t[1]
 *     cdef uint16_t *buf
*/
__pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 630, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_4 = __Pyx_PyLong_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(12, 630, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_sign = __pyx_t_4;

/* "psycopg_c/types/numeric.pyx":631
 *     cdef object t = obj.as_tuple()
 *     cdef int sign = t[0]
 *     cdef tuple digits = t[1]             # <<<<<<<<<<<<<<
 *     cdef uint16_t *buf
 *     cdef uint16_t behead[4]
*/
__pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 631, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
if (!(likely(PyTuple_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_t_1))) __PYX_ERR(12, 631, __pyx_L1_error)
__pyx_v_digits = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":636
 *     cdef Py_ssize_t length
 * 
 *     cdef object pyexp = t[2]             # <<<<<<<<<<<<<<
 *     cdef const char *bexp
 * 
*/
__pyx_t_1 = __Pyx_GetItemInt(__pyx_v_t, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 636, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_pyexp = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/numeric.pyx":639
 *     cdef const char *bexp
 * 
 *     if not isinstance(pyexp, int):             # <<<<<<<<<<<<<<
 *         # Handle inf, nan
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
*/
__pyx_t_5 = PyLong_Check(__pyx_v_pyexp); 
__pyx_t_6 = (!__pyx_t_5);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":641
 *     if not isinstance(pyexp, int):
 *         # Handle inf, nan
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))             # <<<<<<<<<<<<<<
 *         behead[0] = 0
 *         behead[1] = 0
*/
  __pyx_t_7 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_behead))); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(12, 641, __pyx_L1_error)
  __pyx_v_buf = ((uint16_t *)__pyx_t_7);

  /* "psycopg_c/types/numeric.pyx":642
 *         # Handle inf, nan
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
 *         behead[0] = 0             # <<<<<<<<<<<<<<
 *         behead[1] = 0
 *         behead[3] = 0
*/
  (__pyx_v_behead[0]) = 0;

  /* "psycopg_c/types/numeric.pyx":643
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
 *         behead[0] = 0
 *         behead[1] = 0             # <<<<<<<<<<<<<<
 *         behead[3] = 0
 *         bexp = PyUnicode_AsUTF8(pyexp)
*/
  (__pyx_v_behead[1]) = 0;

  /* "psycopg_c/types/numeric.pyx":644
 *         behead[0] = 0
 *         behead[1] = 0
 *         behead[3] = 0             # <<<<<<<<<<<<<<
 *         bexp = PyUnicode_AsUTF8(pyexp)
 *         if bexp[0] == b'n' or bexp[0] == b'N':
*/
  (__pyx_v_behead[3]) = 0;

  /* "psycopg_c/types/numeric.pyx":645
 *         behead[1] = 0
 *         behead[3] = 0
 *         bexp = PyUnicode_AsUTF8(pyexp)             # <<<<<<<<<<<<<<
 *         if bexp[0] == b'n' or bexp[0] == b'N':
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
*/
  __pyx_t_8 = PyUnicode_AsUTF8(__pyx_v_pyexp); if (unlikely(__pyx_t_8 == ((void *)NULL))) __PYX_ERR(12, 645, __pyx_L1_error)
  __pyx_v_bexp = __pyx_t_8;

  /* "psycopg_c/types/numeric.pyx":646
 *         behead[3] = 0
 *         bexp = PyUnicode_AsUTF8(pyexp)
 *         if bexp[0] == b'n' or bexp[0] == b'N':             # <<<<<<<<<<<<<<
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
 *         elif bexp[0] == b'F':
*/
  __pyx_t_5 = ((__pyx_v_bexp[0]) == 'n');
  if (!__pyx_t_5) {
  } else {
    __pyx_t_6 = __pyx_t_5;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_5 = ((__pyx_v_bexp[0]) == 'N');
  __pyx_t_6 = __pyx_t_5;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_6) {

    /* "psycopg_c/types/numeric.pyx":647
 *         bexp = PyUnicode_AsUTF8(pyexp)
 *         if bexp[0] == b'n' or bexp[0] == b'N':
 *             behead[2] = endian.htobe16(NUMERIC_NAN)             # <<<<<<<<<<<<<<
 *         elif bexp[0] == b'F':
 *             if sign:
*/
    (__pyx_v_behead[2]) = htobe16(NUMERIC_NAN);

    /* "psycopg_c/types/numeric.pyx":646
 *         behead[3] = 0
 *         bexp = PyUnicode_AsUTF8(pyexp)
 *         if bexp[0] == b'n' or bexp[0] == b'N':             # <<<<<<<<<<<<<<
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
 *         elif bexp[0] == b'F':
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/numeric.pyx":648
 *         if bexp[0] == b'n' or bexp[0] == b'N':
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
 *         elif bexp[0] == b'F':             # <<<<<<<<<<<<<<
 *             if sign:
 *                 behead[2] = endian.htobe16(NUMERIC_NINF)
*/
  __pyx_t_6 = ((__pyx_v_bexp[0]) == 'F');
  if (likely(__pyx_t_6)) {

    /* "psycopg_c/types/numeric.pyx":649
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
 *         elif bexp[0] == b'F':
 *             if sign:             # <<<<<<<<<<<<<<
 *                 behead[2] = endian.htobe16(NUMERIC_NINF)
 *             else:
*/
    __pyx_t_6 = (__pyx_v_sign != 0);
    if (__pyx_t_6) {

      /* "psycopg_c/types/numeric.pyx":650
 *         elif bexp[0] == b'F':
 *             if sign:
 *                 behead[2] = endian.htobe16(NUMERIC_NINF)             # <<<<<<<<<<<<<<
 *             else:
 *                 behead[2] = endian.htobe16(NUMERIC_PINF)
*/
      (__pyx_v_behead[2]) = htobe16(NUMERIC_NINF);

      /* "psycopg_c/types/numeric.pyx":649
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
 *         elif bexp[0] == b'F':
 *             if sign:             # <<<<<<<<<<<<<<
 *                 behead[2] = endian.htobe16(NUMERIC_NINF)
 *             else:
*/
      goto __pyx_L7;
    }

    /* "psycopg_c/types/numeric.pyx":652
 *                 behead[2] = endian.htobe16(NUMERIC_NINF)
 *             else:
 *                 behead[2] = endian.htobe16(NUMERIC_PINF)             # <<<<<<<<<<<<<<
 *         else:
 *             raise e.DataError(f"unexpected decimal exponent: {pyexp}")
*/
    /*else*/ {
      (__pyx_v_behead[2]) = htobe16(NUMERIC_PINF);
    }
    __pyx_L7:;

    /* "psycopg_c/types/numeric.pyx":648
 *         if bexp[0] == b'n' or bexp[0] == b'N':
 *             behead[2] = endian.htobe16(NUMERIC_NAN)
 *         elif bexp[0] == b'F':             # <<<<<<<<<<<<<<
 *             if sign:
 *                 behead[2] = endian.htobe16(NUMERIC_NINF)
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/numeric.pyx":654
 *                 behead[2] = endian.htobe16(NUMERIC_PINF)
 *         else:
 *             raise e.DataError(f"unexpected decimal exponent: {pyexp}")             # <<<<<<<<<<<<<<
 *         memcpy(buf, behead, sizeof(behead))
 *         return sizeof(behead)
*/
  /*else*/ {
    __pyx_t_2 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_9)) __PYX_ERR(12, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_9 = __Pyx_PyObject_FormatSimple(__pyx_v_pyexp, __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_9)) __PYX_ERR(12, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __pyx_t_11 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_unexpected_decimal_exponent, __pyx_t_9); if (unlikely(!__pyx_t_11)) __PYX_ERR(12, 654, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_11);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __pyx_t_3 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_10))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_10);
      assert(__pyx_t_2);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_10);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_10, __pyx__function);
      __pyx_t_3 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_t_11};
      __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 654, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
    }
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(12, 654, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "psycopg_c/types/numeric.pyx":655
 *         else:
 *             raise e.DataError(f"unexpected decimal exponent: {pyexp}")
 *         memcpy(buf, behead, sizeof(behead))             # <<<<<<<<<<<<<<
 *         return sizeof(behead)
 * 
*/
  (void)(memcpy(__pyx_v_buf, __pyx_v_behead, (sizeof(__pyx_v_behead))));

  /* "psycopg_c/types/numeric.pyx":656
 *             raise e.DataError(f"unexpected decimal exponent: {pyexp}")
 *         memcpy(buf, behead, sizeof(behead))
 *         return sizeof(behead)             # <<<<<<<<<<<<<<
 * 
 *     cdef int exp = pyexp
*/
  __pyx_r = (sizeof(__pyx_v_behead));
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":639
 *     cdef const char *bexp
 * 
 *     if not isinstance(pyexp, int):             # <<<<<<<<<<<<<<
 *         # Handle inf, nan
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
*/
}

/* "psycopg_c/types/numeric.pyx":658
 *         return sizeof(behead)
 * 
 *     cdef int exp = pyexp             # <<<<<<<<<<<<<<
 *     cdef uint16_t ndigits = <uint16_t>len(digits)
 * 
*/
__pyx_t_4 = __Pyx_PyLong_As_int(__pyx_v_pyexp); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(12, 658, __pyx_L1_error)
__pyx_v_exp = __pyx_t_4;

/* "psycopg_c/types/numeric.pyx":659
 * 
 *     cdef int exp = pyexp
 *     cdef uint16_t ndigits = <uint16_t>len(digits)             # <<<<<<<<<<<<<<
 * 
 *     # Find the last nonzero digit
*/
if (unlikely(__pyx_v_digits == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(12, 659, __pyx_L1_error)
}
__pyx_t_12 = __Pyx_PyTuple_GET_SIZE(__pyx_v_digits); if (unlikely(__pyx_t_12 == ((Py_ssize_t)-1))) __PYX_ERR(12, 659, __pyx_L1_error)
__pyx_v_ndigits = ((uint16_t)__pyx_t_12);

/* "psycopg_c/types/numeric.pyx":662
 * 
 *     # Find the last nonzero digit
 *     cdef int nzdigits = ndigits             # <<<<<<<<<<<<<<
 *     while nzdigits > 0 and digits[nzdigits - 1] == 0:
 *         nzdigits -= 1
*/
__pyx_v_nzdigits = __pyx_v_ndigits;

/* "psycopg_c/types/numeric.pyx":663
 *     # Find the last nonzero digit
 *     cdef int nzdigits = ndigits
 *     while nzdigits > 0 and digits[nzdigits - 1] == 0:             # <<<<<<<<<<<<<<
 *         nzdigits -= 1
 * 
*/
while (1) {
  __pyx_t_5 = (__pyx_v_nzdigits > 0);
  if (__pyx_t_5) {
  } else {
    __pyx_t_6 = __pyx_t_5;
    goto __pyx_L10_bool_binop_done;
  }
  if (unlikely(__pyx_v_digits == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(12, 663, __pyx_L1_error)
  }
  __pyx_t_13 = (__pyx_v_nzdigits - 1);
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_digits, __pyx_t_13, long, 1, __Pyx_PyLong_From_long, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = (__Pyx_PyLong_BoolEqObjC(__pyx_t_1, __pyx_mstate_global->__pyx_int_0, 0, 0)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(12, 663, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_t_5;
  __pyx_L10_bool_binop_done:;
  if (!__pyx_t_6) break;

  /* "psycopg_c/types/numeric.pyx":664
 *     cdef int nzdigits = ndigits
 *     while nzdigits > 0 and digits[nzdigits - 1] == 0:
 *         nzdigits -= 1             # <<<<<<<<<<<<<<
 * 
 *     cdef uint16_t dscale
*/
  __pyx_v_nzdigits = (__pyx_v_nzdigits - 1);
}

/* "psycopg_c/types/numeric.pyx":667
 * 
 *     cdef uint16_t dscale
 *     if exp <= 0:             # <<<<<<<<<<<<<<
 *         dscale = -exp
 *     else:
*/
__pyx_t_6 = (__pyx_v_exp <= 0);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":668
 *     cdef uint16_t dscale
 *     if exp <= 0:
 *         dscale = -exp             # <<<<<<<<<<<<<<
 *     else:
 *         dscale = 0
*/
  __pyx_v_dscale = (-__pyx_v_exp);

  /* "psycopg_c/types/numeric.pyx":667
 * 
 *     cdef uint16_t dscale
 *     if exp <= 0:             # <<<<<<<<<<<<<<
 *         dscale = -exp
 *     else:
*/
  goto __pyx_L12;
}

/* "psycopg_c/types/numeric.pyx":670
 *         dscale = -exp
 *     else:
 *         dscale = 0             # <<<<<<<<<<<<<<
 *         # align the py digits to the pg digits if there's some py exponent
 *         ndigits += exp % DEC_DIGITS
*/
/*else*/ {
  __pyx_v_dscale = 0;

  /* "psycopg_c/types/numeric.pyx":672
 *         dscale = 0
 *         # align the py digits to the pg digits if there's some py exponent
 *         ndigits += exp % DEC_DIGITS             # <<<<<<<<<<<<<<
 * 
 *     if nzdigits == 0:
*/
  __pyx_v_ndigits = (__pyx_v_ndigits + (__pyx_v_exp % DEC_DIGITS));
}
__pyx_L12:;

/* "psycopg_c/types/numeric.pyx":674
 *         ndigits += exp % DEC_DIGITS
 * 
 *     if nzdigits == 0:             # <<<<<<<<<<<<<<
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
 *         behead[0] = 0  # ndigits
*/
__pyx_t_6 = (__pyx_v_nzdigits == 0);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":675
 * 
 *     if nzdigits == 0:
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))             # <<<<<<<<<<<<<<
 *         behead[0] = 0  # ndigits
 *         behead[1] = 0  # weight
*/
  __pyx_t_7 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_behead))); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(12, 675, __pyx_L1_error)
  __pyx_v_buf = ((uint16_t *)__pyx_t_7);

  /* "psycopg_c/types/numeric.pyx":676
 *     if nzdigits == 0:
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
 *         behead[0] = 0  # ndigits             # <<<<<<<<<<<<<<
 *         behead[1] = 0  # weight
 *         behead[2] = endian.htobe16(NUMERIC_POS)  # sign
*/
  (__pyx_v_behead[0]) = 0;

  /* "psycopg_c/types/numeric.pyx":677
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
 *         behead[0] = 0  # ndigits
 *         behead[1] = 0  # weight             # <<<<<<<<<<<<<<
 *         behead[2] = endian.htobe16(NUMERIC_POS)  # sign
 *         behead[3] = endian.htobe16(dscale)
*/
  (__pyx_v_behead[1]) = 0;

  /* "psycopg_c/types/numeric.pyx":678
 *         behead[0] = 0  # ndigits
 *         behead[1] = 0  # weight
 *         behead[2] = endian.htobe16(NUMERIC_POS)  # sign             # <<<<<<<<<<<<<<
 *         behead[3] = endian.htobe16(dscale)
 *         memcpy(buf, behead, sizeof(behead))
*/
  (__pyx_v_behead[2]) = htobe16(NUMERIC_POS);

  /* "psycopg_c/types/numeric.pyx":679
 *         behead[1] = 0  # weight
 *         behead[2] = endian.htobe16(NUMERIC_POS)  # sign
 *         behead[3] = endian.htobe16(dscale)             # <<<<<<<<<<<<<<
 *         memcpy(buf, behead, sizeof(behead))
 *         return sizeof(behead)
*/
  (__pyx_v_behead[3]) = htobe16(__pyx_v_dscale);

  /* "psycopg_c/types/numeric.pyx":680
 *         behead[2] = endian.htobe16(NUMERIC_POS)  # sign
 *         behead[3] = endian.htobe16(dscale)
 *         memcpy(buf, behead, sizeof(behead))             # <<<<<<<<<<<<<<
 *         return sizeof(behead)
 * 
*/
  (void)(memcpy(__pyx_v_buf, __pyx_v_behead, (sizeof(__pyx_v_behead))));

  /* "psycopg_c/types/numeric.pyx":681
 *         behead[3] = endian.htobe16(dscale)
 *         memcpy(buf, behead, sizeof(behead))
 *         return sizeof(behead)             # <<<<<<<<<<<<<<
 * 
 *     # Equivalent of 0-padding left to align the py digits to the pg digits
*/
  __pyx_r = (sizeof(__pyx_v_behead));
  goto __pyx_L0;

  /* "psycopg_c/types/numeric.pyx":674
 *         ndigits += exp % DEC_DIGITS
 * 
 *     if nzdigits == 0:             # <<<<<<<<<<<<<<
 *         buf = <uint16_t *>CDumper.ensure_size(rv, offset, sizeof(behead))
 *         behead[0] = 0  # ndigits
*/
}

/* "psycopg_c/types/numeric.pyx":685
 *     # Equivalent of 0-padding left to align the py digits to the pg digits
 *     # but without changing the digits tuple.
 *     cdef int wi = 0             # <<<<<<<<<<<<<<
 *     cdef int mod = (ndigits - dscale) % DEC_DIGITS
 *     if mod < 0:
*/
__pyx_v_wi = 0;

/* "psycopg_c/types/numeric.pyx":686
 *     # but without changing the digits tuple.
 *     cdef int wi = 0
 *     cdef int mod = (ndigits - dscale) % DEC_DIGITS             # <<<<<<<<<<<<<<
 *     if mod < 0:
 *         # the difference between C and Py % operator
*/
__pyx_v_mod = ((__pyx_v_ndigits - __pyx_v_dscale) % DEC_DIGITS);

/* "psycopg_c/types/numeric.pyx":687
 *     cdef int wi = 0
 *     cdef int mod = (ndigits - dscale) % DEC_DIGITS
 *     if mod < 0:             # <<<<<<<<<<<<<<
 *         # the difference between C and Py % operator
 *         mod += 4
*/
__pyx_t_6 = (__pyx_v_mod < 0);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":689
 *     if mod < 0:
 *         # the difference between C and Py % operator
 *         mod += 4             # <<<<<<<<<<<<<<
 *     if mod:
 *         wi = DEC_DIGITS - mod
*/
  __pyx_v_mod = (__pyx_v_mod + 4);

  /* "psycopg_c/types/numeric.pyx":687
 *     cdef int wi = 0
 *     cdef int mod = (ndigits - dscale) % DEC_DIGITS
 *     if mod < 0:             # <<<<<<<<<<<<<<
 *         # the difference between C and Py % operator
 *         mod += 4
*/
}

/* "psycopg_c/types/numeric.pyx":690
 *         # the difference between C and Py % operator
 *         mod += 4
 *     if mod:             # <<<<<<<<<<<<<<
 *         wi = DEC_DIGITS - mod
 *         ndigits += wi
*/
__pyx_t_6 = (__pyx_v_mod != 0);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":691
 *         mod += 4
 *     if mod:
 *         wi = DEC_DIGITS - mod             # <<<<<<<<<<<<<<
 *         ndigits += wi
 * 
*/
  __pyx_v_wi = (DEC_DIGITS - __pyx_v_mod);

  /* "psycopg_c/types/numeric.pyx":692
 *     if mod:
 *         wi = DEC_DIGITS - mod
 *         ndigits += wi             # <<<<<<<<<<<<<<
 * 
 *     cdef int tmp = nzdigits + wi
*/
  __pyx_v_ndigits = (__pyx_v_ndigits + __pyx_v_wi);

  /* "psycopg_c/types/numeric.pyx":690
 *         # the difference between C and Py % operator
 *         mod += 4
 *     if mod:             # <<<<<<<<<<<<<<
 *         wi = DEC_DIGITS - mod
 *         ndigits += wi
*/
}

/* "psycopg_c/types/numeric.pyx":694
 *         ndigits += wi
 * 
 *     cdef int tmp = nzdigits + wi             # <<<<<<<<<<<<<<
 *     cdef int pgdigits = tmp // DEC_DIGITS + (tmp % DEC_DIGITS and 1)
 *     length = sizeof(behead) + pgdigits * sizeof(uint16_t)
*/
__pyx_v_tmp = (__pyx_v_nzdigits + __pyx_v_wi);

/* "psycopg_c/types/numeric.pyx":695
 * 
 *     cdef int tmp = nzdigits + wi
 *     cdef int pgdigits = tmp // DEC_DIGITS + (tmp % DEC_DIGITS and 1)             # <<<<<<<<<<<<<<
 *     length = sizeof(behead) + pgdigits * sizeof(uint16_t)
 *     buf = <uint16_t*>CDumper.ensure_size(rv, offset, length)
*/
__pyx_t_4 = (__pyx_v_tmp % DEC_DIGITS);
if (__pyx_t_4) {
} else {
  __pyx_t_13 = __pyx_t_4;
  goto __pyx_L16_bool_binop_done;
}
__pyx_t_13 = 1;
__pyx_L16_bool_binop_done:;
__pyx_v_pgdigits = ((__pyx_v_tmp / DEC_DIGITS) + __pyx_t_13);

/* "psycopg_c/types/numeric.pyx":696
 *     cdef int tmp = nzdigits + wi
 *     cdef int pgdigits = tmp // DEC_DIGITS + (tmp % DEC_DIGITS and 1)
 *     length = sizeof(behead) + pgdigits * sizeof(uint16_t)             # <<<<<<<<<<<<<<
 *     buf = <uint16_t*>CDumper.ensure_size(rv, offset, length)
 *     behead[0] = endian.htobe16(pgdigits)
*/
__pyx_v_length = ((sizeof(__pyx_v_behead)) + (__pyx_v_pgdigits * (sizeof(uint16_t))));

/* "psycopg_c/types/numeric.pyx":697
 *     cdef int pgdigits = tmp // DEC_DIGITS + (tmp % DEC_DIGITS and 1)
 *     length = sizeof(behead) + pgdigits * sizeof(uint16_t)
 *     buf = <uint16_t*>CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 *     behead[0] = endian.htobe16(pgdigits)
 *     behead[1] = endian.htobe16(<int16_t>((ndigits + exp) // DEC_DIGITS - 1))
*/
__pyx_t_7 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(12, 697, __pyx_L1_error)
__pyx_v_buf = ((uint16_t *)__pyx_t_7);

/* "psycopg_c/types/numeric.pyx":698
 *     length = sizeof(behead) + pgdigits * sizeof(uint16_t)
 *     buf = <uint16_t*>CDumper.ensure_size(rv, offset, length)
 *     behead[0] = endian.htobe16(pgdigits)             # <<<<<<<<<<<<<<
 *     behead[1] = endian.htobe16(<int16_t>((ndigits + exp) // DEC_DIGITS - 1))
 *     behead[2] = endian.htobe16(NUMERIC_NEG) if sign else endian.htobe16(NUMERIC_POS)
*/
(__pyx_v_behead[0]) = htobe16(__pyx_v_pgdigits);

/* "psycopg_c/types/numeric.pyx":699
 *     buf = <uint16_t*>CDumper.ensure_size(rv, offset, length)
 *     behead[0] = endian.htobe16(pgdigits)
 *     behead[1] = endian.htobe16(<int16_t>((ndigits + exp) // DEC_DIGITS - 1))             # <<<<<<<<<<<<<<
 *     behead[2] = endian.htobe16(NUMERIC_NEG) if sign else endian.htobe16(NUMERIC_POS)
 *     behead[3] = endian.htobe16(dscale)
*/
(__pyx_v_behead[1]) = htobe16(((int16_t)(((__pyx_v_ndigits + __pyx_v_exp) / DEC_DIGITS) - 1)));

/* "psycopg_c/types/numeric.pyx":700
 *     behead[0] = endian.htobe16(pgdigits)
 *     behead[1] = endian.htobe16(<int16_t>((ndigits + exp) // DEC_DIGITS - 1))
 *     behead[2] = endian.htobe16(NUMERIC_NEG) if sign else endian.htobe16(NUMERIC_POS)             # <<<<<<<<<<<<<<
 *     behead[3] = endian.htobe16(dscale)
 *     memcpy(buf, behead, sizeof(behead))
*/
__pyx_t_6 = (__pyx_v_sign != 0);
if (__pyx_t_6) {
  __pyx_t_14 = htobe16(NUMERIC_NEG);
} else {
  __pyx_t_14 = htobe16(NUMERIC_POS);
}
(__pyx_v_behead[2]) = __pyx_t_14;

/* "psycopg_c/types/numeric.pyx":701
 *     behead[1] = endian.htobe16(<int16_t>((ndigits + exp) // DEC_DIGITS - 1))
 *     behead[2] = endian.htobe16(NUMERIC_NEG) if sign else endian.htobe16(NUMERIC_POS)
 *     behead[3] = endian.htobe16(dscale)             # <<<<<<<<<<<<<<
 *     memcpy(buf, behead, sizeof(behead))
 *     buf += 4
*/
(__pyx_v_behead[3]) = htobe16(__pyx_v_dscale);

/* "psycopg_c/types/numeric.pyx":702
 *     behead[2] = endian.htobe16(NUMERIC_NEG) if sign else endian.htobe16(NUMERIC_POS)
 *     behead[3] = endian.htobe16(dscale)
 *     memcpy(buf, behead, sizeof(behead))             # <<<<<<<<<<<<<<
 *     buf += 4
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_behead, (sizeof(__pyx_v_behead))));

/* "psycopg_c/types/numeric.pyx":703
 *     behead[3] = endian.htobe16(dscale)
 *     memcpy(buf, behead, sizeof(behead))
 *     buf += 4             # <<<<<<<<<<<<<<
 * 
 *     cdef uint16_t pgdigit = 0, bedigit
*/
__pyx_v_buf = (__pyx_v_buf + 4);

/* "psycopg_c/types/numeric.pyx":705
 *     buf += 4
 * 
 *     cdef uint16_t pgdigit = 0, bedigit             # <<<<<<<<<<<<<<
 *     for i in range(nzdigits):
 *         pgdigit += pydigit_weights[wi] * <int>(digits[i])
*/
__pyx_v_pgdigit = 0;

/* "psycopg_c/types/numeric.pyx":706
 * 
 *     cdef uint16_t pgdigit = 0, bedigit
 *     for i in range(nzdigits):             # <<<<<<<<<<<<<<
 *         pgdigit += pydigit_weights[wi] * <int>(digits[i])
 *         wi += 1
*/
__pyx_t_4 = __pyx_v_nzdigits;
__pyx_t_15 = __pyx_t_4;
for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
  __pyx_v_i = __pyx_t_16;

  /* "psycopg_c/types/numeric.pyx":707
 *     cdef uint16_t pgdigit = 0, bedigit
 *     for i in range(nzdigits):
 *         pgdigit += pydigit_weights[wi] * <int>(digits[i])             # <<<<<<<<<<<<<<
 *         wi += 1
 *         if wi >= DEC_DIGITS:
*/
  if (unlikely(__pyx_v_digits == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(12, 707, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v_digits, __pyx_v_i, int, 1, __Pyx_PyLong_From_int, 0, 1, 1, 1, __Pyx_ReferenceSharing_OwnStrongReference); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 707, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_17 = __Pyx_PyLong_As_int(__pyx_t_1); if (unlikely((__pyx_t_17 == (int)-1) && PyErr_Occurred())) __PYX_ERR(12, 707, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_pgdigit = (__pyx_v_pgdigit + ((pydigit_weights[__pyx_v_wi]) * ((int)__pyx_t_17)));

  /* "psycopg_c/types/numeric.pyx":708
 *     for i in range(nzdigits):
 *         pgdigit += pydigit_weights[wi] * <int>(digits[i])
 *         wi += 1             # <<<<<<<<<<<<<<
 *         if wi >= DEC_DIGITS:
 *             bedigit = endian.htobe16(pgdigit)
*/
  __pyx_v_wi = (__pyx_v_wi + 1);

  /* "psycopg_c/types/numeric.pyx":709
 *         pgdigit += pydigit_weights[wi] * <int>(digits[i])
 *         wi += 1
 *         if wi >= DEC_DIGITS:             # <<<<<<<<<<<<<<
 *             bedigit = endian.htobe16(pgdigit)
 *             memcpy(buf, &bedigit, sizeof(bedigit))
*/
  __pyx_t_6 = (__pyx_v_wi >= DEC_DIGITS);
  if (__pyx_t_6) {

    /* "psycopg_c/types/numeric.pyx":710
 *         wi += 1
 *         if wi >= DEC_DIGITS:
 *             bedigit = endian.htobe16(pgdigit)             # <<<<<<<<<<<<<<
 *             memcpy(buf, &bedigit, sizeof(bedigit))
 *             buf += 1
*/
    __pyx_v_bedigit = htobe16(__pyx_v_pgdigit);

    /* "psycopg_c/types/numeric.pyx":711
 *         if wi >= DEC_DIGITS:
 *             bedigit = endian.htobe16(pgdigit)
 *             memcpy(buf, &bedigit, sizeof(bedigit))             # <<<<<<<<<<<<<<
 *             buf += 1
 *             pgdigit = wi = 0
*/
    (void)(memcpy(__pyx_v_buf, (&__pyx_v_bedigit), (sizeof(__pyx_v_bedigit))));

    /* "psycopg_c/types/numeric.pyx":712
 *             bedigit = endian.htobe16(pgdigit)
 *             memcpy(buf, &bedigit, sizeof(bedigit))
 *             buf += 1             # <<<<<<<<<<<<<<
 *             pgdigit = wi = 0
 * 
*/
    __pyx_v_buf = (__pyx_v_buf + 1);

    /* "psycopg_c/types/numeric.pyx":713
 *             memcpy(buf, &bedigit, sizeof(bedigit))
 *             buf += 1
 *             pgdigit = wi = 0             # <<<<<<<<<<<<<<
 * 
 *     if pgdigit:
*/
    __pyx_v_pgdigit = 0;
    __pyx_v_wi = 0;

    /* "psycopg_c/types/numeric.pyx":709
 *         pgdigit += pydigit_weights[wi] * <int>(digits[i])
 *         wi += 1
 *         if wi >= DEC_DIGITS:             # <<<<<<<<<<<<<<
 *             bedigit = endian.htobe16(pgdigit)
 *             memcpy(buf, &bedigit, sizeof(bedigit))
*/
  }
}

/* "psycopg_c/types/numeric.pyx":715
 *             pgdigit = wi = 0
 * 
 *     if pgdigit:             # <<<<<<<<<<<<<<
 *         bedigit = endian.htobe16(pgdigit)
 *         memcpy(buf, &bedigit, sizeof(bedigit))
*/
__pyx_t_6 = (__pyx_v_pgdigit != 0);
if (__pyx_t_6) {

  /* "psycopg_c/types/numeric.pyx":716
 * 
 *     if pgdigit:
 *         bedigit = endian.htobe16(pgdigit)             # <<<<<<<<<<<<<<
 *         memcpy(buf, &bedigit, sizeof(bedigit))
 * 
*/
  __pyx_v_bedigit = htobe16(__pyx_v_pgdigit);

  /* "psycopg_c/types/numeric.pyx":717
 *     if pgdigit:
 *         bedigit = endian.htobe16(pgdigit)
 *         memcpy(buf, &bedigit, sizeof(bedigit))             # <<<<<<<<<<<<<<
 * 
 *     return length
*/
  (void)(memcpy(__pyx_v_buf, (&__pyx_v_bedigit), (sizeof(__pyx_v_bedigit))));

  /* "psycopg_c/types/numeric.pyx":715
 *             pgdigit = wi = 0
 * 
 *     if pgdigit:             # <<<<<<<<<<<<<<
 *         bedigit = endian.htobe16(pgdigit)
 *         memcpy(buf, &bedigit, sizeof(bedigit))
*/
}

/* "psycopg_c/types/numeric.pyx":719
 *         memcpy(buf, &bedigit, sizeof(bedigit))
 * 
 *     return length             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_length;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":618
 * 
 * 
 * @cython.cdivision(True)             # <<<<<<<<<<<<<<
 * cdef Py_ssize_t dump_decimal_to_numeric_binary(
 *     obj, bytearray rv, Py_ssize_t offset
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_9);
__Pyx_XDECREF(__pyx_t_10);
__Pyx_XDECREF(__pyx_t_11);
__Pyx_AddTraceback("psycopg_c._psycopg.dump_decimal_to_numeric_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_t);
__Pyx_XDECREF(__pyx_v_digits);
__Pyx_XDECREF(__pyx_v_pyexp);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":722
 * 
 * 
 * cdef Py_ssize_t dump_int_to_text(obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *     cdef long long val
 *     cdef int overflow
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_text(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
PY_LONG_LONG __pyx_v_val;
int __pyx_v_overflow;
char *__pyx_v_buf;
char *__pyx_v_src;
Py_ssize_t __pyx_v_length;
PyObject *__pyx_v_b = NULL;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PY_LONG_LONG __pyx_t_1;
int __pyx_t_2;
char *__pyx_t_3;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
size_t __pyx_t_7;
int __pyx_t_8;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("dump_int_to_text", 0);

/* "psycopg_c/types/numeric.pyx":729
 *     cdef Py_ssize_t length
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)             # <<<<<<<<<<<<<<
 *     if not overflow:
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
*/
__pyx_t_1 = PyLong_AsLongLongAndOverflow(__pyx_v_obj, (&__pyx_v_overflow)); if (unlikely(__pyx_t_1 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 729, __pyx_L1_error)
__pyx_v_val = __pyx_t_1;

/* "psycopg_c/types/numeric.pyx":730
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *     if not overflow:             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
 *         length = pg_lltoa(val, buf)
*/
__pyx_t_2 = (!(__pyx_v_overflow != 0));
if (__pyx_t_2) {

  /* "psycopg_c/types/numeric.pyx":731
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *     if not overflow:
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)             # <<<<<<<<<<<<<<
 *         length = pg_lltoa(val, buf)
 *     else:
*/
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (MAXINT8LEN + 1)); if (unlikely(__pyx_t_3 == ((void *)NULL))) __PYX_ERR(12, 731, __pyx_L1_error)
  __pyx_v_buf = __pyx_t_3;

  /* "psycopg_c/types/numeric.pyx":732
 *     if not overflow:
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
 *         length = pg_lltoa(val, buf)             # <<<<<<<<<<<<<<
 *     else:
 *         b = bytes(str(obj), "utf-8")
*/
  __pyx_v_length = pg_lltoa(__pyx_v_val, __pyx_v_buf);

  /* "psycopg_c/types/numeric.pyx":730
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *     if not overflow:             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
 *         length = pg_lltoa(val, buf)
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/numeric.pyx":734
 *         length = pg_lltoa(val, buf)
 *     else:
 *         b = bytes(str(obj), "utf-8")             # <<<<<<<<<<<<<<
 *         PyBytes_AsStringAndSize(b, &src, &length)
 *         buf = CDumper.ensure_size(rv, offset, length)
*/
/*else*/ {
  __pyx_t_5 = NULL;
  __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_t_6, __pyx_mstate_global->__pyx_kp_u_utf_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_7, (3-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 734, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __pyx_v_b = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "psycopg_c/types/numeric.pyx":735
 *     else:
 *         b = bytes(str(obj), "utf-8")
 *         PyBytes_AsStringAndSize(b, &src, &length)             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)
*/
  __pyx_t_8 = PyBytes_AsStringAndSize(__pyx_v_b, (&__pyx_v_src), (&__pyx_v_length)); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(12, 735, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":736
 *         b = bytes(str(obj), "utf-8")
 *         PyBytes_AsStringAndSize(b, &src, &length)
 *         buf = CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, length)
 * 
*/
  __pyx_t_3 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_3 == ((void *)NULL))) __PYX_ERR(12, 736, __pyx_L1_error)
  __pyx_v_buf = __pyx_t_3;

  /* "psycopg_c/types/numeric.pyx":737
 *         PyBytes_AsStringAndSize(b, &src, &length)
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)             # <<<<<<<<<<<<<<
 * 
 *     return length
*/
  (void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_length));
}
__pyx_L3:;

/* "psycopg_c/types/numeric.pyx":739
 *         memcpy(buf, src, length)
 * 
 *     return length             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_length;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":722
 * 
 * 
 * cdef Py_ssize_t dump_int_to_text(obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *     cdef long long val
 *     cdef int overflow
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_AddTraceback("psycopg_c._psycopg.dump_int_to_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_b);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":742
 * 
 * 
 * cdef Py_ssize_t dump_int_or_sub_to_text(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_or_sub_to_text(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
PY_LONG_LONG __pyx_v_val;
int __pyx_v_overflow;
char *__pyx_v_buf;
char *__pyx_v_src;
Py_ssize_t __pyx_v_length;
PyObject *__pyx_v_b = NULL;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
int __pyx_t_4;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
size_t __pyx_t_9;
PY_LONG_LONG __pyx_t_10;
char *__pyx_t_11;
int __pyx_t_12;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("dump_int_or_sub_to_text", 0);

/* "psycopg_c/types/numeric.pyx":753
 *     # Ensure an int or a subclass. The 'is' type check is fast.
 *     # Passing a float must give an error, but passing an Enum should work.
 *     if type(obj) is not int and not isinstance(obj, _int_classes):             # <<<<<<<<<<<<<<
 *         raise e.DataError(f"integer expected, got {type(obj).__name__!r}")
 * 
*/
__pyx_t_2 = (((PyObject *)Py_TYPE(__pyx_v_obj)) != ((PyObject *)(&PyLong_Type)));
if (__pyx_t_2) {
} else {
  __pyx_t_1 = __pyx_t_2;
  goto __pyx_L4_bool_binop_done;
}
__Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_mstate_global->__pyx_n_u_int_classes); if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 753, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_t_2 = PyObject_IsInstance(__pyx_v_obj, __pyx_t_3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(12, 753, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__pyx_t_4 = (!__pyx_t_2);
__pyx_t_1 = __pyx_t_4;
__pyx_L4_bool_binop_done:;
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/numeric.pyx":754
 *     # Passing a float must give an error, but passing an Enum should work.
 *     if type(obj) is not int and not isinstance(obj, _int_classes):
 *         raise e.DataError(f"integer expected, got {type(obj).__name__!r}")             # <<<<<<<<<<<<<<
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
*/
  __pyx_t_5 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_7)) __PYX_ERR(12, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)Py_TYPE(__pyx_v_obj)), __pyx_mstate_global->__pyx_n_u_name_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __Pyx_PyObject_FormatSimpleAndDecref(PyObject_Repr(__pyx_t_6), __pyx_mstate_global->__pyx_empty_unicode); if (unlikely(!__pyx_t_8)) __PYX_ERR(12, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_mstate_global->__pyx_kp_u_integer_expected_got, __pyx_t_8); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_9 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_7);
    assert(__pyx_t_5);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
    __pyx_t_9 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_6};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 754, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(12, 754, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":753
 *     # Ensure an int or a subclass. The 'is' type check is fast.
 *     # Passing a float must give an error, but passing an Enum should work.
 *     if type(obj) is not int and not isinstance(obj, _int_classes):             # <<<<<<<<<<<<<<
 *         raise e.DataError(f"integer expected, got {type(obj).__name__!r}")
 * 
*/
}

/* "psycopg_c/types/numeric.pyx":756
 *         raise e.DataError(f"integer expected, got {type(obj).__name__!r}")
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)             # <<<<<<<<<<<<<<
 *     if not overflow:
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
*/
__pyx_t_10 = PyLong_AsLongLongAndOverflow(__pyx_v_obj, (&__pyx_v_overflow)); if (unlikely(__pyx_t_10 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 756, __pyx_L1_error)
__pyx_v_val = __pyx_t_10;

/* "psycopg_c/types/numeric.pyx":757
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *     if not overflow:             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
 *         length = pg_lltoa(val, buf)
*/
__pyx_t_1 = (!(__pyx_v_overflow != 0));
if (__pyx_t_1) {

  /* "psycopg_c/types/numeric.pyx":758
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *     if not overflow:
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)             # <<<<<<<<<<<<<<
 *         length = pg_lltoa(val, buf)
 *     else:
*/
  __pyx_t_11 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (MAXINT8LEN + 1)); if (unlikely(__pyx_t_11 == ((void *)NULL))) __PYX_ERR(12, 758, __pyx_L1_error)
  __pyx_v_buf = __pyx_t_11;

  /* "psycopg_c/types/numeric.pyx":759
 *     if not overflow:
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
 *         length = pg_lltoa(val, buf)             # <<<<<<<<<<<<<<
 *     else:
 *         b = bytes(str(obj), "utf-8")
*/
  __pyx_v_length = pg_lltoa(__pyx_v_val, __pyx_v_buf);

  /* "psycopg_c/types/numeric.pyx":757
 * 
 *     val = PyLong_AsLongLongAndOverflow(obj, &overflow)
 *     if not overflow:             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, MAXINT8LEN + 1)
 *         length = pg_lltoa(val, buf)
*/
  goto __pyx_L6;
}

/* "psycopg_c/types/numeric.pyx":761
 *         length = pg_lltoa(val, buf)
 *     else:
 *         b = bytes(str(obj), "utf-8")             # <<<<<<<<<<<<<<
 *         PyBytes_AsStringAndSize(b, &src, &length)
 *         buf = CDumper.ensure_size(rv, offset, length)
*/
/*else*/ {
  __pyx_t_7 = NULL;
  __pyx_t_6 = __Pyx_PyObject_Unicode(__pyx_v_obj); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 761, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_9 = 1;
  {
    PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_6, __pyx_mstate_global->__pyx_kp_u_utf_8};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_9, (3-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(12, 761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __pyx_v_b = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "psycopg_c/types/numeric.pyx":762
 *     else:
 *         b = bytes(str(obj), "utf-8")
 *         PyBytes_AsStringAndSize(b, &src, &length)             # <<<<<<<<<<<<<<
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)
*/
  __pyx_t_12 = PyBytes_AsStringAndSize(__pyx_v_b, (&__pyx_v_src), (&__pyx_v_length)); if (unlikely(__pyx_t_12 == ((int)-1))) __PYX_ERR(12, 762, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":763
 *         b = bytes(str(obj), "utf-8")
 *         PyBytes_AsStringAndSize(b, &src, &length)
 *         buf = CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, length)
 * 
*/
  __pyx_t_11 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_11 == ((void *)NULL))) __PYX_ERR(12, 763, __pyx_L1_error)
  __pyx_v_buf = __pyx_t_11;

  /* "psycopg_c/types/numeric.pyx":764
 *         PyBytes_AsStringAndSize(b, &src, &length)
 *         buf = CDumper.ensure_size(rv, offset, length)
 *         memcpy(buf, src, length)             # <<<<<<<<<<<<<<
 * 
 *     return length
*/
  (void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_length));
}
__pyx_L6:;

/* "psycopg_c/types/numeric.pyx":766
 *         memcpy(buf, src, length)
 * 
 *     return length             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_length;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":742
 * 
 * 
 * cdef Py_ssize_t dump_int_or_sub_to_text(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("psycopg_c._psycopg.dump_int_or_sub_to_text", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_b);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":769
 * 
 * 
 * cdef Py_ssize_t dump_int_to_int2_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int2_binary(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int16_t __pyx_v_val;
int16_t *__pyx_v_buf;
uint16_t __pyx_v_beval;
Py_ssize_t __pyx_r;
PY_LONG_LONG __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":772
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
 *     cdef int16_t val = <int16_t>PyLong_AsLongLong(obj)             # <<<<<<<<<<<<<<
 *     cdef int16_t *buf = <int16_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint16_t beval = endian.htobe16(val)  # swap bytes if needed
*/
__pyx_t_1 = PyLong_AsLongLong(__pyx_v_obj); if (unlikely(__pyx_t_1 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 772, __pyx_L1_error)
__pyx_v_val = ((int16_t)__pyx_t_1);

/* "psycopg_c/types/numeric.pyx":773
 * ) except -1:
 *     cdef int16_t val = <int16_t>PyLong_AsLongLong(obj)
 *     cdef int16_t *buf = <int16_t *>CDumper.ensure_size(rv, offset, sizeof(val))             # <<<<<<<<<<<<<<
 *     cdef uint16_t beval = endian.htobe16(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_val))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 773, __pyx_L1_error)
__pyx_v_buf = ((int16_t *)__pyx_t_2);

/* "psycopg_c/types/numeric.pyx":774
 *     cdef int16_t val = <int16_t>PyLong_AsLongLong(obj)
 *     cdef int16_t *buf = <int16_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint16_t beval = endian.htobe16(val)  # swap bytes if needed             # <<<<<<<<<<<<<<
 *     memcpy(buf, &beval, sizeof(beval))
 *     return sizeof(val)
*/
__pyx_v_beval = htobe16(__pyx_v_val);

/* "psycopg_c/types/numeric.pyx":775
 *     cdef int16_t *buf = <int16_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint16_t beval = endian.htobe16(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))             # <<<<<<<<<<<<<<
 *     return sizeof(val)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beval), (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/numeric.pyx":776
 *     cdef uint16_t beval = endian.htobe16(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))
 *     return sizeof(val)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_val));
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":769
 * 
 * 
 * cdef Py_ssize_t dump_int_to_int2_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.dump_int_to_int2_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":779
 * 
 * 
 * cdef Py_ssize_t dump_int_to_int4_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int4_binary(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int32_t __pyx_v_val;
int32_t *__pyx_v_buf;
uint32_t __pyx_v_beval;
Py_ssize_t __pyx_r;
PY_LONG_LONG __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":782
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
 *     cdef int32_t val = <int32_t>PyLong_AsLongLong(obj)             # <<<<<<<<<<<<<<
 *     cdef int32_t *buf = <int32_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint32_t beval = endian.htobe32(val)  # swap bytes if needed
*/
__pyx_t_1 = PyLong_AsLongLong(__pyx_v_obj); if (unlikely(__pyx_t_1 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 782, __pyx_L1_error)
__pyx_v_val = ((int32_t)__pyx_t_1);

/* "psycopg_c/types/numeric.pyx":783
 * ) except -1:
 *     cdef int32_t val = <int32_t>PyLong_AsLongLong(obj)
 *     cdef int32_t *buf = <int32_t *>CDumper.ensure_size(rv, offset, sizeof(val))             # <<<<<<<<<<<<<<
 *     cdef uint32_t beval = endian.htobe32(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_val))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 783, __pyx_L1_error)
__pyx_v_buf = ((int32_t *)__pyx_t_2);

/* "psycopg_c/types/numeric.pyx":784
 *     cdef int32_t val = <int32_t>PyLong_AsLongLong(obj)
 *     cdef int32_t *buf = <int32_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint32_t beval = endian.htobe32(val)  # swap bytes if needed             # <<<<<<<<<<<<<<
 *     memcpy(buf, &beval, sizeof(beval))
 *     return sizeof(val)
*/
__pyx_v_beval = htobe32(__pyx_v_val);

/* "psycopg_c/types/numeric.pyx":785
 *     cdef int32_t *buf = <int32_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint32_t beval = endian.htobe32(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))             # <<<<<<<<<<<<<<
 *     return sizeof(val)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beval), (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/numeric.pyx":786
 *     cdef uint32_t beval = endian.htobe32(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))
 *     return sizeof(val)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_val));
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":779
 * 
 * 
 * cdef Py_ssize_t dump_int_to_int4_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.dump_int_to_int4_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":789
 * 
 * 
 * cdef Py_ssize_t dump_int_to_int8_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int8_binary(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
int64_t __pyx_v_val;
int64_t *__pyx_v_buf;
uint64_t __pyx_v_beval;
Py_ssize_t __pyx_r;
PY_LONG_LONG __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/numeric.pyx":792
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
 *     cdef int64_t val = PyLong_AsLongLong(obj)             # <<<<<<<<<<<<<<
 *     cdef int64_t *buf = <int64_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint64_t beval = endian.htobe64(val)  # swap bytes if needed
*/
__pyx_t_1 = PyLong_AsLongLong(__pyx_v_obj); if (unlikely(__pyx_t_1 == ((PY_LONG_LONG)-1LL) && PyErr_Occurred())) __PYX_ERR(12, 792, __pyx_L1_error)
__pyx_v_val = __pyx_t_1;

/* "psycopg_c/types/numeric.pyx":793
 * ) except -1:
 *     cdef int64_t val = PyLong_AsLongLong(obj)
 *     cdef int64_t *buf = <int64_t *>CDumper.ensure_size(rv, offset, sizeof(val))             # <<<<<<<<<<<<<<
 *     cdef uint64_t beval = endian.htobe64(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, (sizeof(__pyx_v_val))); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(12, 793, __pyx_L1_error)
__pyx_v_buf = ((int64_t *)__pyx_t_2);

/* "psycopg_c/types/numeric.pyx":794
 *     cdef int64_t val = PyLong_AsLongLong(obj)
 *     cdef int64_t *buf = <int64_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint64_t beval = endian.htobe64(val)  # swap bytes if needed             # <<<<<<<<<<<<<<
 *     memcpy(buf, &beval, sizeof(beval))
 *     return sizeof(val)
*/
__pyx_v_beval = htobe64(__pyx_v_val);

/* "psycopg_c/types/numeric.pyx":795
 *     cdef int64_t *buf = <int64_t *>CDumper.ensure_size(rv, offset, sizeof(val))
 *     cdef uint64_t beval = endian.htobe64(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))             # <<<<<<<<<<<<<<
 *     return sizeof(val)
 * 
*/
(void)(memcpy(__pyx_v_buf, (&__pyx_v_beval), (sizeof(__pyx_v_beval))));

/* "psycopg_c/types/numeric.pyx":796
 *     cdef uint64_t beval = endian.htobe64(val)  # swap bytes if needed
 *     memcpy(buf, &beval, sizeof(beval))
 *     return sizeof(val)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = (sizeof(__pyx_v_val));
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":789
 * 
 * 
 * cdef Py_ssize_t dump_int_to_int8_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.dump_int_to_int8_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/numeric.pyx":799
 * 
 * 
 * cdef Py_ssize_t dump_int_to_numeric_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_dump_int_to_numeric_binary(PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
uint16_t __pyx_v_ndigits;
uint16_t __pyx_v_sign;
Py_ssize_t __pyx_v_length;
uint16_t *__pyx_v_buf;
uint16_t __pyx_v_behead[4];
int __pyx_v_i;
uint16_t __pyx_v_rem;
uint16_t __pyx_v_berem;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
size_t __pyx_t_3;
int __pyx_t_4;
int __pyx_t_5;
char *__pyx_t_6;
uint16_t __pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("dump_int_to_numeric_binary", 0);
__Pyx_INCREF(__pyx_v_obj);

/* "psycopg_c/types/numeric.pyx":804
 *     # Calculate the number of PG digits required to store the number
 *     cdef uint16_t ndigits
 *     ndigits = <uint16_t>((<int>obj.bit_length()) * BIT_PER_PGDIGIT) + 1             # <<<<<<<<<<<<<<
 * 
 *     cdef uint16_t sign = NUMERIC_POS
*/
__pyx_t_2 = __pyx_v_obj;
__Pyx_INCREF(__pyx_t_2);
__pyx_t_3 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
  __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_bit_length, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 804, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_t_4 = __Pyx_PyLong_As_int(__pyx_t_1); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(12, 804, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_ndigits = (((uint16_t)(((int)__pyx_t_4) * BIT_PER_PGDIGIT)) + 1);

/* "psycopg_c/types/numeric.pyx":806
 *     ndigits = <uint16_t>((<int>obj.bit_length()) * BIT_PER_PGDIGIT) + 1
 * 
 *     cdef uint16_t sign = NUMERIC_POS             # <<<<<<<<<<<<<<
 *     if obj < 0:
 *         sign = NUMERIC_NEG
*/
__pyx_v_sign = NUMERIC_POS;

/* "psycopg_c/types/numeric.pyx":807
 * 
 *     cdef uint16_t sign = NUMERIC_POS
 *     if obj < 0:             # <<<<<<<<<<<<<<
 *         sign = NUMERIC_NEG
 *         obj = -obj
*/
__pyx_t_1 = PyObject_RichCompare(__pyx_v_obj, __pyx_mstate_global->__pyx_int_0, Py_LT); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 807, __pyx_L1_error)
__pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(12, 807, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_5) {

  /* "psycopg_c/types/numeric.pyx":808
 *     cdef uint16_t sign = NUMERIC_POS
 *     if obj < 0:
 *         sign = NUMERIC_NEG             # <<<<<<<<<<<<<<
 *         obj = -obj
 * 
*/
  __pyx_v_sign = NUMERIC_NEG;

  /* "psycopg_c/types/numeric.pyx":809
 *     if obj < 0:
 *         sign = NUMERIC_NEG
 *         obj = -obj             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t length = sizeof(uint16_t) * (ndigits + 4)
*/
  __pyx_t_1 = PyNumber_Negative(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/types/numeric.pyx":807
 * 
 *     cdef uint16_t sign = NUMERIC_POS
 *     if obj < 0:             # <<<<<<<<<<<<<<
 *         sign = NUMERIC_NEG
 *         obj = -obj
*/
}

/* "psycopg_c/types/numeric.pyx":811
 *         obj = -obj
 * 
 *     cdef Py_ssize_t length = sizeof(uint16_t) * (ndigits + 4)             # <<<<<<<<<<<<<<
 *     cdef uint16_t *buf
 *     buf = <uint16_t *><void *>CDumper.ensure_size(rv, offset, length)
*/
__pyx_v_length = ((sizeof(uint16_t)) * (__pyx_v_ndigits + 4));

/* "psycopg_c/types/numeric.pyx":813
 *     cdef Py_ssize_t length = sizeof(uint16_t) * (ndigits + 4)
 *     cdef uint16_t *buf
 *     buf = <uint16_t *><void *>CDumper.ensure_size(rv, offset, length)             # <<<<<<<<<<<<<<
 * 
 *     cdef uint16_t behead[4]
*/
__pyx_t_6 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_length); if (unlikely(__pyx_t_6 == ((void *)NULL))) __PYX_ERR(12, 813, __pyx_L1_error)
__pyx_v_buf = ((uint16_t *)((void *)__pyx_t_6));

/* "psycopg_c/types/numeric.pyx":816
 * 
 *     cdef uint16_t behead[4]
 *     behead[0] = endian.htobe16(ndigits)             # <<<<<<<<<<<<<<
 *     behead[1] = endian.htobe16(ndigits - 1)  # weight
 *     behead[2] = endian.htobe16(sign)
*/
(__pyx_v_behead[0]) = htobe16(__pyx_v_ndigits);

/* "psycopg_c/types/numeric.pyx":817
 *     cdef uint16_t behead[4]
 *     behead[0] = endian.htobe16(ndigits)
 *     behead[1] = endian.htobe16(ndigits - 1)  # weight             # <<<<<<<<<<<<<<
 *     behead[2] = endian.htobe16(sign)
 *     behead[3] = 0  # dscale
*/
(__pyx_v_behead[1]) = htobe16((__pyx_v_ndigits - 1));

/* "psycopg_c/types/numeric.pyx":818
 *     behead[0] = endian.htobe16(ndigits)
 *     behead[1] = endian.htobe16(ndigits - 1)  # weight
 *     behead[2] = endian.htobe16(sign)             # <<<<<<<<<<<<<<
 *     behead[3] = 0  # dscale
 *     memcpy(buf, behead, sizeof(behead))
*/
(__pyx_v_behead[2]) = htobe16(__pyx_v_sign);

/* "psycopg_c/types/numeric.pyx":819
 *     behead[1] = endian.htobe16(ndigits - 1)  # weight
 *     behead[2] = endian.htobe16(sign)
 *     behead[3] = 0  # dscale             # <<<<<<<<<<<<<<
 *     memcpy(buf, behead, sizeof(behead))
 * 
*/
(__pyx_v_behead[3]) = 0;

/* "psycopg_c/types/numeric.pyx":820
 *     behead[2] = endian.htobe16(sign)
 *     behead[3] = 0  # dscale
 *     memcpy(buf, behead, sizeof(behead))             # <<<<<<<<<<<<<<
 * 
 *     cdef int i = 4 + ndigits - 1
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_behead, (sizeof(__pyx_v_behead))));

/* "psycopg_c/types/numeric.pyx":822
 *     memcpy(buf, behead, sizeof(behead))
 * 
 *     cdef int i = 4 + ndigits - 1             # <<<<<<<<<<<<<<
 *     cdef uint16_t rem, berem
 *     while obj:
*/
__pyx_v_i = ((4 + __pyx_v_ndigits) - 1);

/* "psycopg_c/types/numeric.pyx":824
 *     cdef int i = 4 + ndigits - 1
 *     cdef uint16_t rem, berem
 *     while obj:             # <<<<<<<<<<<<<<
 *         rem = obj % 10000
 *         obj //= 10000
*/
while (1) {
  __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_v_obj); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(12, 824, __pyx_L1_error)
  if (!__pyx_t_5) break;

  /* "psycopg_c/types/numeric.pyx":825
 *     cdef uint16_t rem, berem
 *     while obj:
 *         rem = obj % 10000             # <<<<<<<<<<<<<<
 *         obj //= 10000
 *         berem = endian.htobe16(rem)
*/
  __pyx_t_1 = __Pyx_PyLong_RemainderObjC(__pyx_v_obj, __pyx_mstate_global->__pyx_int_10000, 0x2710, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = __Pyx_PyLong_As_uint16_t(__pyx_t_1); if (unlikely((__pyx_t_7 == ((uint16_t)-1)) && PyErr_Occurred())) __PYX_ERR(12, 825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_rem = __pyx_t_7;

  /* "psycopg_c/types/numeric.pyx":826
 *     while obj:
 *         rem = obj % 10000
 *         obj //= 10000             # <<<<<<<<<<<<<<
 *         berem = endian.htobe16(rem)
 *         memcpy(buf + i, &berem, sizeof(berem))
*/
  __pyx_t_1 = __Pyx_PyLong_FloorDivideObjC(__pyx_v_obj, __pyx_mstate_global->__pyx_int_10000, 0x2710, 1, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 826, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/types/numeric.pyx":827
 *         rem = obj % 10000
 *         obj //= 10000
 *         berem = endian.htobe16(rem)             # <<<<<<<<<<<<<<
 *         memcpy(buf + i, &berem, sizeof(berem))
 *         i -= 1
*/
  __pyx_v_berem = htobe16(__pyx_v_rem);

  /* "psycopg_c/types/numeric.pyx":828
 *         obj //= 10000
 *         berem = endian.htobe16(rem)
 *         memcpy(buf + i, &berem, sizeof(berem))             # <<<<<<<<<<<<<<
 *         i -= 1
 *     while i > 3:
*/
  (void)(memcpy((__pyx_v_buf + __pyx_v_i), (&__pyx_v_berem), (sizeof(__pyx_v_berem))));

  /* "psycopg_c/types/numeric.pyx":829
 *         berem = endian.htobe16(rem)
 *         memcpy(buf + i, &berem, sizeof(berem))
 *         i -= 1             # <<<<<<<<<<<<<<
 *     while i > 3:
 *         memset(buf + i, 0, sizeof(buf[0]))
*/
  __pyx_v_i = (__pyx_v_i - 1);
}

/* "psycopg_c/types/numeric.pyx":830
 *         memcpy(buf + i, &berem, sizeof(berem))
 *         i -= 1
 *     while i > 3:             # <<<<<<<<<<<<<<
 *         memset(buf + i, 0, sizeof(buf[0]))
 *         i -= 1
*/
while (1) {
  __pyx_t_5 = (__pyx_v_i > 3);
  if (!__pyx_t_5) break;

  /* "psycopg_c/types/numeric.pyx":831
 *         i -= 1
 *     while i > 3:
 *         memset(buf + i, 0, sizeof(buf[0]))             # <<<<<<<<<<<<<<
 *         i -= 1
 * 
*/
  (void)(memset((__pyx_v_buf + __pyx_v_i), 0, (sizeof((__pyx_v_buf[0])))));

  /* "psycopg_c/types/numeric.pyx":832
 *     while i > 3:
 *         memset(buf + i, 0, sizeof(buf[0]))
 *         i -= 1             # <<<<<<<<<<<<<<
 * 
 *     return length
*/
  __pyx_v_i = (__pyx_v_i - 1);
}

/* "psycopg_c/types/numeric.pyx":834
 *         i -= 1
 * 
 *     return length             # <<<<<<<<<<<<<<
*/
__pyx_r = __pyx_v_length;
goto __pyx_L0;

/* "psycopg_c/types/numeric.pyx":799
 * 
 * 
 * cdef Py_ssize_t dump_int_to_numeric_binary(             # <<<<<<<<<<<<<<
 *     obj, bytearray rv, Py_ssize_t offset
 * ) except -1:
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg.dump_int_to_numeric_binary", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_obj);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/bool.pyx":16
 *     oid = oids.BOOL_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef char *buf = CDumper.ensure_size(rv, offset, 1)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10BoolDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
char *__pyx_t_1;
int __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/bool.pyx":17
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef char *buf = CDumper.ensure_size(rv, offset, 1)             # <<<<<<<<<<<<<<
 * 
 *         # Fast paths, just a pointer comparison
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, 1); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(13, 17, __pyx_L1_error)
__pyx_v_buf = __pyx_t_1;

/* "psycopg_c/types/bool.pyx":20
 * 
 *         # Fast paths, just a pointer comparison
 *         if obj is True:             # <<<<<<<<<<<<<<
 *             buf[0] = b"t"
 *         elif obj is False:
*/
__pyx_t_2 = (__pyx_v_obj == Py_True);
if (__pyx_t_2) {

  /* "psycopg_c/types/bool.pyx":21
 *         # Fast paths, just a pointer comparison
 *         if obj is True:
 *             buf[0] = b"t"             # <<<<<<<<<<<<<<
 *         elif obj is False:
 *             buf[0] = b"f"
*/
  (__pyx_v_buf[0]) = 't';

  /* "psycopg_c/types/bool.pyx":20
 * 
 *         # Fast paths, just a pointer comparison
 *         if obj is True:             # <<<<<<<<<<<<<<
 *             buf[0] = b"t"
 *         elif obj is False:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/bool.pyx":22
 *         if obj is True:
 *             buf[0] = b"t"
 *         elif obj is False:             # <<<<<<<<<<<<<<
 *             buf[0] = b"f"
 *         elif obj:
*/
__pyx_t_2 = (__pyx_v_obj == Py_False);
if (__pyx_t_2) {

  /* "psycopg_c/types/bool.pyx":23
 *             buf[0] = b"t"
 *         elif obj is False:
 *             buf[0] = b"f"             # <<<<<<<<<<<<<<
 *         elif obj:
 *             buf[0] = b"t"
*/
  (__pyx_v_buf[0]) = 'f';

  /* "psycopg_c/types/bool.pyx":22
 *         if obj is True:
 *             buf[0] = b"t"
 *         elif obj is False:             # <<<<<<<<<<<<<<
 *             buf[0] = b"f"
 *         elif obj:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/bool.pyx":24
 *         elif obj is False:
 *             buf[0] = b"f"
 *         elif obj:             # <<<<<<<<<<<<<<
 *             buf[0] = b"t"
 *         else:
*/
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_obj); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(13, 24, __pyx_L1_error)
if (__pyx_t_2) {

  /* "psycopg_c/types/bool.pyx":25
 *             buf[0] = b"f"
 *         elif obj:
 *             buf[0] = b"t"             # <<<<<<<<<<<<<<
 *         else:
 *             buf[0] = b"f"
*/
  (__pyx_v_buf[0]) = 't';

  /* "psycopg_c/types/bool.pyx":24
 *         elif obj is False:
 *             buf[0] = b"f"
 *         elif obj:             # <<<<<<<<<<<<<<
 *             buf[0] = b"t"
 *         else:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/bool.pyx":27
 *             buf[0] = b"t"
 *         else:
 *             buf[0] = b"f"             # <<<<<<<<<<<<<<
 * 
 *         return 1
*/
/*else*/ {
  (__pyx_v_buf[0]) = 'f';
}
__pyx_L3:;

/* "psycopg_c/types/bool.pyx":29
 *             buf[0] = b"f"
 * 
 *         return 1             # <<<<<<<<<<<<<<
 * 
 *     def quote(self, obj: bool) -> Buffer | None:
*/
__pyx_r = 1;
goto __pyx_L0;

/* "psycopg_c/types/bool.pyx":16
 *     oid = oids.BOOL_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef char *buf = CDumper.ensure_size(rv, offset, 1)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "psycopg_c/types/bool.pyx":31
 *         return 1
 * 
 *     def quote(self, obj: bool) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         if obj is True:
 *             return b"true"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_arg_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10BoolDumper_1quote = {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_1quote, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_1quote(PyObject *__pyx_v_self, PyObject *__pyx_arg_obj) {
int __pyx_v_obj;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("quote (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
assert(__pyx_arg_obj); {
  __pyx_v_obj = __Pyx_PyObject_IsTrue(__pyx_arg_obj); if (unlikely((__pyx_v_obj == (int)-1) && PyErr_Occurred())) __PYX_ERR(13, 31, __pyx_L3_error)
}
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolDumper.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_quote(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *)__pyx_v_self), ((int)__pyx_v_obj));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_quote(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self, int __pyx_v_obj) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
__Pyx_RefNannySetupContext("quote", 0);

/* "psycopg_c/types/bool.pyx":32
 * 
 *     def quote(self, obj: bool) -> Buffer | None:
 *         if obj is True:             # <<<<<<<<<<<<<<
 *             return b"true"
 *         elif obj is False:
*/
__pyx_t_1 = (__pyx_v_obj == 1);
if (__pyx_t_1) {

  /* "psycopg_c/types/bool.pyx":33
 *     def quote(self, obj: bool) -> Buffer | None:
 *         if obj is True:
 *             return b"true"             # <<<<<<<<<<<<<<
 *         elif obj is False:
 *             return b"false"
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_b_true);
  __pyx_r = __pyx_mstate_global->__pyx_n_b_true;
  goto __pyx_L0;

  /* "psycopg_c/types/bool.pyx":32
 * 
 *     def quote(self, obj: bool) -> Buffer | None:
 *         if obj is True:             # <<<<<<<<<<<<<<
 *             return b"true"
 *         elif obj is False:
*/
}

/* "psycopg_c/types/bool.pyx":34
 *         if obj is True:
 *             return b"true"
 *         elif obj is False:             # <<<<<<<<<<<<<<
 *             return b"false"
 *         else:
*/
__pyx_t_1 = (__pyx_v_obj == 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/bool.pyx":35
 *             return b"true"
 *         elif obj is False:
 *             return b"false"             # <<<<<<<<<<<<<<
 *         else:
 *             return b"true" if obj else b"false"
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_mstate_global->__pyx_n_b_false);
  __pyx_r = __pyx_mstate_global->__pyx_n_b_false;
  goto __pyx_L0;

  /* "psycopg_c/types/bool.pyx":34
 *         if obj is True:
 *             return b"true"
 *         elif obj is False:             # <<<<<<<<<<<<<<
 *             return b"false"
 *         else:
*/
}

/* "psycopg_c/types/bool.pyx":37
 *             return b"false"
 *         else:
 *             return b"true" if obj else b"false"             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  if (__pyx_v_obj) {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_b_true);
    __pyx_t_2 = __pyx_mstate_global->__pyx_n_b_true;
  } else {
    __Pyx_INCREF(__pyx_mstate_global->__pyx_n_b_false);
    __pyx_t_2 = __pyx_mstate_global->__pyx_n_b_false;
  }
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/bool.pyx":31
 *         return 1
 * 
 *     def quote(self, obj: bool) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         if obj is True:
 *             return b"true"
*/

/* function exit code */
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10BoolDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10BoolDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/bool.pyx":46
 *     oid = oids.BOOL_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef char *buf = CDumper.ensure_size(rv, offset, 1)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_16BoolBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
char *__pyx_t_1;
int __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/bool.pyx":47
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef char *buf = CDumper.ensure_size(rv, offset, 1)             # <<<<<<<<<<<<<<
 * 
 *         # Fast paths, just a pointer comparison
*/
__pyx_t_1 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, 1); if (unlikely(__pyx_t_1 == ((void *)NULL))) __PYX_ERR(13, 47, __pyx_L1_error)
__pyx_v_buf = __pyx_t_1;

/* "psycopg_c/types/bool.pyx":50
 * 
 *         # Fast paths, just a pointer comparison
 *         if obj is True:             # <<<<<<<<<<<<<<
 *             buf[0] = b"\x01"
 *         elif obj is False:
*/
__pyx_t_2 = (__pyx_v_obj == Py_True);
if (__pyx_t_2) {

  /* "psycopg_c/types/bool.pyx":51
 *         # Fast paths, just a pointer comparison
 *         if obj is True:
 *             buf[0] = b"\x01"             # <<<<<<<<<<<<<<
 *         elif obj is False:
 *             buf[0] = b"\x00"
*/
  (__pyx_v_buf[0]) = '\x01';

  /* "psycopg_c/types/bool.pyx":50
 * 
 *         # Fast paths, just a pointer comparison
 *         if obj is True:             # <<<<<<<<<<<<<<
 *             buf[0] = b"\x01"
 *         elif obj is False:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/bool.pyx":52
 *         if obj is True:
 *             buf[0] = b"\x01"
 *         elif obj is False:             # <<<<<<<<<<<<<<
 *             buf[0] = b"\x00"
 *         elif obj:
*/
__pyx_t_2 = (__pyx_v_obj == Py_False);
if (__pyx_t_2) {

  /* "psycopg_c/types/bool.pyx":53
 *             buf[0] = b"\x01"
 *         elif obj is False:
 *             buf[0] = b"\x00"             # <<<<<<<<<<<<<<
 *         elif obj:
 *             buf[0] = b"\x01"
*/
  (__pyx_v_buf[0]) = '\x00';

  /* "psycopg_c/types/bool.pyx":52
 *         if obj is True:
 *             buf[0] = b"\x01"
 *         elif obj is False:             # <<<<<<<<<<<<<<
 *             buf[0] = b"\x00"
 *         elif obj:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/bool.pyx":54
 *         elif obj is False:
 *             buf[0] = b"\x00"
 *         elif obj:             # <<<<<<<<<<<<<<
 *             buf[0] = b"\x01"
 *         else:
*/
__pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v_obj); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(13, 54, __pyx_L1_error)
if (__pyx_t_2) {

  /* "psycopg_c/types/bool.pyx":55
 *             buf[0] = b"\x00"
 *         elif obj:
 *             buf[0] = b"\x01"             # <<<<<<<<<<<<<<
 *         else:
 *             buf[0] = b"\x00"
*/
  (__pyx_v_buf[0]) = '\x01';

  /* "psycopg_c/types/bool.pyx":54
 *         elif obj is False:
 *             buf[0] = b"\x00"
 *         elif obj:             # <<<<<<<<<<<<<<
 *             buf[0] = b"\x01"
 *         else:
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/bool.pyx":57
 *             buf[0] = b"\x01"
 *         else:
 *             buf[0] = b"\x00"             # <<<<<<<<<<<<<<
 * 
 *         return 1
*/
/*else*/ {
  (__pyx_v_buf[0]) = '\x00';
}
__pyx_L3:;

/* "psycopg_c/types/bool.pyx":59
 *             buf[0] = b"\x00"
 * 
 *         return 1             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = 1;
goto __pyx_L0;

/* "psycopg_c/types/bool.pyx":46
 *     oid = oids.BOOL_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef char *buf = CDumper.ensure_size(rv, offset, 1)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/bool.pyx":67
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         # this creates better C than `return data[0] == b't'`
 *         return True if data[0] == b't' else False
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_10BoolLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/bool.pyx":69
 *     cdef object cload(self, const char *data, size_t length):
 *         # this creates better C than `return data[0] == b't'`
 *         return True if data[0] == b't' else False             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_2 = ((__pyx_v_data[0]) == 't');
if (__pyx_t_2) {
  __Pyx_INCREF(Py_True);
  __pyx_t_1 = Py_True;
} else {
  __Pyx_INCREF(Py_False);
  __pyx_t_1 = Py_False;
}
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/bool.pyx":67
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         # this creates better C than `return data[0] == b't'`
 *         return True if data[0] == b't' else False
*/

/* function exit code */
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10BoolLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10BoolLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10BoolLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10BoolLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10BoolLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/bool.pyx":77
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         return True if data[0] else False
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16BoolBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/bool.pyx":78
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         return True if data[0] else False             # <<<<<<<<<<<<<<
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_2 = ((__pyx_v_data[0]) != 0);
if (__pyx_t_2) {
  __Pyx_INCREF(Py_True);
  __pyx_t_1 = Py_True;
} else {
  __Pyx_INCREF(Py_False);
  __pyx_t_1 = Py_False;
}
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/bool.pyx":77
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         return True if data[0] else False
*/

/* function exit code */
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16BoolBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BoolBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NPInt16Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NPInt16Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt16Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt16Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NPInt16Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NPInt16Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt16Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt16Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NPInt32Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NPInt32Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt32Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt32Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NPInt32Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NPInt32Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt32Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt32Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NPInt64Dumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NPInt64Dumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt64Dumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt64Dumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13NPInt64Dumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13NPInt64Dumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13NPInt64Dumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt64Dumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15NPNumericDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15NPNumericDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15NPNumericDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPNumericDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15NPNumericDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15NPNumericDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15NPNumericDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPNumericDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numpy.pyx":40
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int2_binary(int(obj), rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
Py_ssize_t __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numpy.pyx":41
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_int2_binary(int(obj), rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 41, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int2_binary(__pyx_t_1, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(14, 41, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_r = __pyx_t_2;
goto __pyx_L0;

/* "psycopg_c/types/numpy.pyx":40
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int2_binary(int(obj), rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt16BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NPInt16BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt16BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt16BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt16BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numpy.pyx":50
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int4_binary(int(obj), rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
Py_ssize_t __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numpy.pyx":51
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_int4_binary(int(obj), rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 51, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int4_binary(__pyx_t_1, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(14, 51, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_r = __pyx_t_2;
goto __pyx_L0;

/* "psycopg_c/types/numpy.pyx":50
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int4_binary(int(obj), rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt32BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NPInt32BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt32BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt32BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt32BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numpy.pyx":60
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int8_binary(int(obj), rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
Py_ssize_t __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numpy.pyx":61
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_int8_binary(int(obj), rv, offset)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 61, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_int8_binary(__pyx_t_1, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(14, 61, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_r = __pyx_t_2;
goto __pyx_L0;

/* "psycopg_c/types/numpy.pyx":60
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_int8_binary(int(obj), rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt64BinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NPInt64BinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt64BinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt64BinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPInt64BinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/numpy.pyx":70
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_numeric_binary(int(obj), rv, offset)
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
Py_ssize_t __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/numpy.pyx":71
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         return dump_int_to_numeric_binary(int(obj), rv, offset)             # <<<<<<<<<<<<<<
*/
__pyx_t_1 = __Pyx_PyNumber_Int(__pyx_v_obj); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 71, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_dump_int_to_numeric_binary(__pyx_t_1, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1L))) __PYX_ERR(14, 71, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_r = __pyx_t_2;
goto __pyx_L0;

/* "psycopg_c/types/numpy.pyx":70
 *     format = PQ_BINARY
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         return dump_int_to_numeric_binary(int(obj), rv, offset)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.NPNumericBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_21NPNumericBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21NPNumericBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPNumericBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.NPNumericBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":29
 *     cdef bytes _bytes_encoding  # needed to keep `encoding` alive
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         self.is_utf8 = 0
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_cls = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_cls,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(15, 29, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(15, 29, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(15, 29, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(15, 29, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(15, 29, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(15, 29, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(15, 29, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  __pyx_v_cls = values[0];
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(15, 29, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._BaseStrDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *)__pyx_v_self), __pyx_v_cls, __pyx_v_context);

/* function exit code */
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_cls, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_pgenc;
int __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
size_t __pyx_t_9;
char *__pyx_t_10;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/string.pyx":31
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
 * 
 *         self.is_utf8 = 0             # <<<<<<<<<<<<<<
 *         self.encoding = "utf-8"
 *         cdef const char *pgenc
*/
__pyx_v_self->is_utf8 = 0;

/* "psycopg_c/types/string.pyx":32
 * 
 *         self.is_utf8 = 0
 *         self.encoding = "utf-8"             # <<<<<<<<<<<<<<
 *         cdef const char *pgenc
 * 
*/
__pyx_v_self->encoding = ((char *)"utf-8");

/* "psycopg_c/types/string.pyx":35
 *         cdef const char *pgenc
 * 
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
*/
__pyx_t_1 = (((PyObject *)__pyx_v_self->__pyx_base._pgconn) != Py_None);
if (__pyx_t_1) {

  /* "psycopg_c/types/string.pyx":36
 * 
 *         if self._pgconn is not None:
 *             pgenc = libpq.PQparameterStatus(             # <<<<<<<<<<<<<<
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":
*/
  __pyx_v_pgenc = PQparameterStatus(__pyx_v_self->__pyx_base._pgconn->_pgconn_ptr, __pyx_k_client_encoding);

  /* "psycopg_c/types/string.pyx":38
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":             # <<<<<<<<<<<<<<
 *                 self._bytes_encoding = b"utf-8"
 *                 self.is_utf8 = 1
*/
  __pyx_t_2 = (__pyx_v_pgenc == NULL);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_pgenc); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__Pyx_PyBytes_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_b_UTF8, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(15, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/string.pyx":39
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":
 *                 self._bytes_encoding = b"utf-8"             # <<<<<<<<<<<<<<
 *                 self.is_utf8 = 1
 *             else:
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_utf_8);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_b_utf_8);
    __Pyx_GOTREF(__pyx_v_self->_bytes_encoding);
    __Pyx_DECREF(__pyx_v_self->_bytes_encoding);
    __pyx_v_self->_bytes_encoding = __pyx_mstate_global->__pyx_kp_b_utf_8;

    /* "psycopg_c/types/string.pyx":40
 *             if pgenc == NULL or pgenc == b"UTF8":
 *                 self._bytes_encoding = b"utf-8"
 *                 self.is_utf8 = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
*/
    __pyx_v_self->is_utf8 = 1;

    /* "psycopg_c/types/string.pyx":38
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":             # <<<<<<<<<<<<<<
 *                 self._bytes_encoding = b"utf-8"
 *                 self.is_utf8 = 1
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/string.pyx":42
 *                 self.is_utf8 = 1
 *             else:
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()             # <<<<<<<<<<<<<<
 *                 if self._bytes_encoding == b"ascii":
 *                     self.is_utf8 = 1
*/
  /*else*/ {
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_pg2pyenc); if (unlikely(!__pyx_t_7)) __PYX_ERR(15, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyBytes_FromString(__pyx_v_pgenc); if (unlikely(!__pyx_t_8)) __PYX_ERR(15, 42, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(15, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __pyx_t_4 = __pyx_t_5;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_9 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 42, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(15, 42, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_bytes_encoding);
    __Pyx_DECREF(__pyx_v_self->_bytes_encoding);
    __pyx_v_self->_bytes_encoding = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "psycopg_c/types/string.pyx":43
 *             else:
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
 *                 if self._bytes_encoding == b"ascii":             # <<<<<<<<<<<<<<
 *                     self.is_utf8 = 1
 *             self.encoding = PyBytes_AsString(self._bytes_encoding)
*/
    __pyx_t_1 = (__Pyx_PyBytes_Equals(__pyx_v_self->_bytes_encoding, __pyx_mstate_global->__pyx_n_b_ascii, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(15, 43, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "psycopg_c/types/string.pyx":44
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
 *                 if self._bytes_encoding == b"ascii":
 *                     self.is_utf8 = 1             # <<<<<<<<<<<<<<
 *             self.encoding = PyBytes_AsString(self._bytes_encoding)
 * 
*/
      __pyx_v_self->is_utf8 = 1;

      /* "psycopg_c/types/string.pyx":43
 *             else:
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
 *                 if self._bytes_encoding == b"ascii":             # <<<<<<<<<<<<<<
 *                     self.is_utf8 = 1
 *             self.encoding = PyBytes_AsString(self._bytes_encoding)
*/
    }
  }
  __pyx_L4:;

  /* "psycopg_c/types/string.pyx":45
 *                 if self._bytes_encoding == b"ascii":
 *                     self.is_utf8 = 1
 *             self.encoding = PyBytes_AsString(self._bytes_encoding)             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_3 = __pyx_v_self->_bytes_encoding;
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_10 = PyBytes_AsString(__pyx_t_3); if (unlikely(__pyx_t_10 == ((void *)NULL))) __PYX_ERR(15, 45, __pyx_L1_error)
  __pyx_v_self->encoding = __pyx_t_10;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "psycopg_c/types/string.pyx":35
 *         cdef const char *pgenc
 * 
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
*/
}

/* "psycopg_c/types/string.pyx":29
 *     cdef bytes _bytes_encoding  # needed to keep `encoding` alive
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         self.is_utf8 = 0
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseStrDumper.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":47
 *             self.encoding = PyBytes_AsString(self._bytes_encoding)
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         # the server will raise DataError subclass if the string contains 0x00
 *         cdef Py_ssize_t size
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_14_BaseStrDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_v_size;
char const *__pyx_v_src;
PyObject *__pyx_v_b = NULL;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
char const *__pyx_t_3;
int __pyx_t_4;
char *__pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/string.pyx":52
 *         cdef const char *src
 * 
 *         if self.is_utf8:             # <<<<<<<<<<<<<<
 *             # Probably the fastest path, but doesn't work with subclasses
 *             if PyUnicode_CheckExact(obj):
*/
__pyx_t_1 = (__pyx_v_self->is_utf8 != 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/string.pyx":54
 *         if self.is_utf8:
 *             # Probably the fastest path, but doesn't work with subclasses
 *             if PyUnicode_CheckExact(obj):             # <<<<<<<<<<<<<<
 *                 src = PyUnicode_AsUTF8AndSize(obj, &size)
 *             else:
*/
  __pyx_t_1 = PyUnicode_CheckExact(__pyx_v_obj);
  if (__pyx_t_1) {

    /* "psycopg_c/types/string.pyx":55
 *             # Probably the fastest path, but doesn't work with subclasses
 *             if PyUnicode_CheckExact(obj):
 *                 src = PyUnicode_AsUTF8AndSize(obj, &size)             # <<<<<<<<<<<<<<
 *             else:
 *                 b = PyUnicode_AsUTF8String(obj)
*/
    __pyx_t_2 = __pyx_v_obj;
    __Pyx_INCREF(__pyx_t_2);
    if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None) || __Pyx_RaiseUnexpectedTypeError("str", __pyx_t_2))) __PYX_ERR(15, 55, __pyx_L1_error)
    __pyx_t_3 = PyUnicode_AsUTF8AndSize(((PyObject*)__pyx_t_2), (&__pyx_v_size)); if (unlikely(__pyx_t_3 == ((void *)NULL))) __PYX_ERR(15, 55, __pyx_L1_error)
    __pyx_v_src = __pyx_t_3;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "psycopg_c/types/string.pyx":54
 *         if self.is_utf8:
 *             # Probably the fastest path, but doesn't work with subclasses
 *             if PyUnicode_CheckExact(obj):             # <<<<<<<<<<<<<<
 *                 src = PyUnicode_AsUTF8AndSize(obj, &size)
 *             else:
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/string.pyx":57
 *                 src = PyUnicode_AsUTF8AndSize(obj, &size)
 *             else:
 *                 b = PyUnicode_AsUTF8String(obj)             # <<<<<<<<<<<<<<
 *                 PyBytes_AsStringAndSize(b, <char **>&src, &size)
 *         else:
*/
  /*else*/ {
    __pyx_t_2 = PyUnicode_AsUTF8String(__pyx_v_obj); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 57, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_b = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "psycopg_c/types/string.pyx":58
 *             else:
 *                 b = PyUnicode_AsUTF8String(obj)
 *                 PyBytes_AsStringAndSize(b, <char **>&src, &size)             # <<<<<<<<<<<<<<
 *         else:
 *             b = PyUnicode_AsEncodedString(obj, self.encoding, NULL)
*/
    __pyx_t_4 = PyBytes_AsStringAndSize(__pyx_v_b, ((char **)(&__pyx_v_src)), (&__pyx_v_size)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(15, 58, __pyx_L1_error)
  }
  __pyx_L4:;

  /* "psycopg_c/types/string.pyx":52
 *         cdef const char *src
 * 
 *         if self.is_utf8:             # <<<<<<<<<<<<<<
 *             # Probably the fastest path, but doesn't work with subclasses
 *             if PyUnicode_CheckExact(obj):
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/string.pyx":60
 *                 PyBytes_AsStringAndSize(b, <char **>&src, &size)
 *         else:
 *             b = PyUnicode_AsEncodedString(obj, self.encoding, NULL)             # <<<<<<<<<<<<<<
 *             PyBytes_AsStringAndSize(b, <char **>&src, &size)
 * 
*/
/*else*/ {
  __pyx_t_2 = PyUnicode_AsEncodedString(__pyx_v_obj, __pyx_v_self->encoding, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_b = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "psycopg_c/types/string.pyx":61
 *         else:
 *             b = PyUnicode_AsEncodedString(obj, self.encoding, NULL)
 *             PyBytes_AsStringAndSize(b, <char **>&src, &size)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
*/
  __pyx_t_4 = PyBytes_AsStringAndSize(__pyx_v_b, ((char **)(&__pyx_v_src)), (&__pyx_v_size)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(15, 61, __pyx_L1_error)
}
__pyx_L3:;

/* "psycopg_c/types/string.pyx":63
 *             PyBytes_AsStringAndSize(b, <char **>&src, &size)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, size)
 *         return size
*/
__pyx_t_5 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_size); if (unlikely(__pyx_t_5 == ((void *)NULL))) __PYX_ERR(15, 63, __pyx_L1_error)
__pyx_v_buf = __pyx_t_5;

/* "psycopg_c/types/string.pyx":64
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)             # <<<<<<<<<<<<<<
 *         return size
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_size));

/* "psycopg_c/types/string.pyx":65
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)
 *         return size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":47
 *             self.encoding = PyBytes_AsString(self._bytes_encoding)
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         # the server will raise DataError subclass if the string contains 0x00
 *         cdef Py_ssize_t size
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg._BaseStrDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_b);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14_BaseStrDumper_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseStrDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_14_BaseStrDumper_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_14_BaseStrDumper_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._BaseStrDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16_StrBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16_StrBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16_StrBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._StrBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16_StrBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16_StrBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16_StrBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._StrBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15StrBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15StrBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15StrBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_15StrBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_15StrBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_15StrBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrBinaryDumperVarchar.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrBinaryDumperVarchar.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19StrBinaryDumperName_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19StrBinaryDumperName___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19StrBinaryDumperName___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrBinaryDumperName.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_19StrBinaryDumperName_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_19StrBinaryDumperName_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_19StrBinaryDumperName_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrBinaryDumperName.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":95
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size = StrBinaryDumper.cdump(self, obj, rv, offset)
 * 
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_10_StrDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
Py_ssize_t __pyx_v_size;
char const *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
Py_ssize_t __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
size_t __pyx_t_7;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/string.pyx":96
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
 *         cdef Py_ssize_t size = StrBinaryDumper.cdump(self, obj, rv, offset)             # <<<<<<<<<<<<<<
 * 
 *         # Like the binary dump, but check for 0, or the string will be truncated
*/
__pyx_t_1 = __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumper->__pyx_base.__pyx_base.__pyx_base.cdump(((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_v_self), __pyx_v_obj, __pyx_v_rv, __pyx_v_offset); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1L))) __PYX_ERR(15, 96, __pyx_L1_error)
__pyx_v_size = __pyx_t_1;

/* "psycopg_c/types/string.pyx":99
 * 
 *         # Like the binary dump, but check for 0, or the string will be truncated
 *         cdef const char *buf = PyByteArray_AS_STRING(rv)             # <<<<<<<<<<<<<<
 *         if NULL != memchr(buf + offset, 0x00, size):
 *             raise e.DataError(
*/
__pyx_v_buf = PyByteArray_AS_STRING(__pyx_v_rv);

/* "psycopg_c/types/string.pyx":100
 *         # Like the binary dump, but check for 0, or the string will be truncated
 *         cdef const char *buf = PyByteArray_AS_STRING(rv)
 *         if NULL != memchr(buf + offset, 0x00, size):             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 "PostgreSQL text fields cannot contain NUL (0x00) bytes"
*/
__pyx_t_2 = (NULL != memchr((__pyx_v_buf + __pyx_v_offset), 0x00, __pyx_v_size));
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/string.pyx":101
 *         cdef const char *buf = PyByteArray_AS_STRING(rv)
 *         if NULL != memchr(buf + offset, 0x00, size):
 *             raise e.DataError(             # <<<<<<<<<<<<<<
 *                 "PostgreSQL text fields cannot contain NUL (0x00) bytes"
 *             )
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_e); if (unlikely(!__pyx_t_5)) __PYX_ERR(15, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_DataError); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_6);
    assert(__pyx_t_4);
    PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_6);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(__pyx__function);
    __Pyx_DECREF_SET(__pyx_t_6, __pyx__function);
    __pyx_t_7 = 0;
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_kp_u_PostgreSQL_text_fields_cannot_co};
    __pyx_t_3 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 101, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
  }
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(15, 101, __pyx_L1_error)

  /* "psycopg_c/types/string.pyx":100
 *         # Like the binary dump, but check for 0, or the string will be truncated
 *         cdef const char *buf = PyByteArray_AS_STRING(rv)
 *         if NULL != memchr(buf + offset, 0x00, size):             # <<<<<<<<<<<<<<
 *             raise e.DataError(
 *                 "PostgreSQL text fields cannot contain NUL (0x00) bytes"
*/
}

/* "psycopg_c/types/string.pyx":104
 *                 "PostgreSQL text fields cannot contain NUL (0x00) bytes"
 *             )
 *         return size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":95
 *     format = PQ_TEXT
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t size = StrBinaryDumper.cdump(self, obj, rv, offset)
 * 
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_AddTraceback("psycopg_c._psycopg._StrDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10_StrDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10_StrDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_StrDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._StrDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10_StrDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10_StrDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10_StrDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._StrDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9StrDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9StrDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9StrDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_9StrDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_9StrDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_9StrDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16StrDumperVarchar_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16StrDumperVarchar___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperVarchar___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumperVarchar.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16StrDumperVarchar_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16StrDumperVarchar_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperVarchar_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumperVarchar.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13StrDumperName_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13StrDumperName___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13StrDumperName___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumperName.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_13StrDumperName_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_13StrDumperName_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_13StrDumperName_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumperName.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16StrDumperUnknown_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16StrDumperUnknown___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperUnknown___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumperUnknown.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16StrDumperUnknown_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16StrDumperUnknown_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16StrDumperUnknown_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.StrDumperUnknown.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":138
 *     cdef bytes _bytes_encoding  # needed to keep `encoding` alive
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         self.is_utf8 = 0
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(15, 138, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(15, 138, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(15, 138, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(15, 138, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(15, 138, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(15, 138, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(15, 138, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(15, 138, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(15, 138, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._TextLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(15, 138, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11_TextLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_11_TextLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
char const *__pyx_v_pgenc;
int __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int __pyx_t_2;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
size_t __pyx_t_9;
char *__pyx_t_10;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/string.pyx":140
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 * 
 *         self.is_utf8 = 0             # <<<<<<<<<<<<<<
 *         self.encoding = "utf-8"
 *         cdef const char *pgenc
*/
__pyx_v_self->is_utf8 = 0;

/* "psycopg_c/types/string.pyx":141
 * 
 *         self.is_utf8 = 0
 *         self.encoding = "utf-8"             # <<<<<<<<<<<<<<
 *         cdef const char *pgenc
 * 
*/
__pyx_v_self->encoding = ((char *)"utf-8");

/* "psycopg_c/types/string.pyx":144
 *         cdef const char *pgenc
 * 
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
*/
__pyx_t_1 = (((PyObject *)__pyx_v_self->__pyx_base._pgconn) != Py_None);
if (__pyx_t_1) {

  /* "psycopg_c/types/string.pyx":145
 * 
 *         if self._pgconn is not None:
 *             pgenc = libpq.PQparameterStatus(             # <<<<<<<<<<<<<<
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":
*/
  __pyx_v_pgenc = PQparameterStatus(__pyx_v_self->__pyx_base._pgconn->_pgconn_ptr, __pyx_k_client_encoding);

  /* "psycopg_c/types/string.pyx":147
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":             # <<<<<<<<<<<<<<
 *                 self._bytes_encoding = b"utf-8"
 *                 self.is_utf8 = 1
*/
  __pyx_t_2 = (__pyx_v_pgenc == NULL);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_pgenc); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = (__Pyx_PyBytes_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_b_UTF8, Py_EQ)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(15, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = __pyx_t_2;
  __pyx_L5_bool_binop_done:;
  if (__pyx_t_1) {

    /* "psycopg_c/types/string.pyx":148
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":
 *                 self._bytes_encoding = b"utf-8"             # <<<<<<<<<<<<<<
 *                 self.is_utf8 = 1
 *             else:
*/
    __Pyx_INCREF(__pyx_mstate_global->__pyx_kp_b_utf_8);
    __Pyx_GIVEREF(__pyx_mstate_global->__pyx_kp_b_utf_8);
    __Pyx_GOTREF(__pyx_v_self->_bytes_encoding);
    __Pyx_DECREF(__pyx_v_self->_bytes_encoding);
    __pyx_v_self->_bytes_encoding = __pyx_mstate_global->__pyx_kp_b_utf_8;

    /* "psycopg_c/types/string.pyx":149
 *             if pgenc == NULL or pgenc == b"UTF8":
 *                 self._bytes_encoding = b"utf-8"
 *                 self.is_utf8 = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
*/
    __pyx_v_self->is_utf8 = 1;

    /* "psycopg_c/types/string.pyx":147
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
 *             if pgenc == NULL or pgenc == b"UTF8":             # <<<<<<<<<<<<<<
 *                 self._bytes_encoding = b"utf-8"
 *                 self.is_utf8 = 1
*/
    goto __pyx_L4;
  }

  /* "psycopg_c/types/string.pyx":151
 *                 self.is_utf8 = 1
 *             else:
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()             # <<<<<<<<<<<<<<
 * 
 *             if pgenc == b"SQL_ASCII":
*/
  /*else*/ {
    __pyx_t_6 = NULL;
    __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_mstate_global->__pyx_n_u_pg2pyenc); if (unlikely(!__pyx_t_7)) __PYX_ERR(15, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyBytes_FromString(__pyx_v_pgenc); if (unlikely(!__pyx_t_8)) __PYX_ERR(15, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = 1;
    #if CYTHON_UNPACK_METHODS
    if (unlikely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_7);
      assert(__pyx_t_6);
      PyObject* __pyx__function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(__pyx__function);
      __Pyx_DECREF_SET(__pyx_t_7, __pyx__function);
      __pyx_t_9 = 0;
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_t_8};
      __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_7, __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(!__pyx_t_5)) __PYX_ERR(15, 151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
    }
    __pyx_t_4 = __pyx_t_5;
    __Pyx_INCREF(__pyx_t_4);
    __pyx_t_9 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
      __pyx_t_3 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_encode, __pyx_callargs+__pyx_t_9, (1-__pyx_t_9) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 151, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
    }
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(15, 151, __pyx_L1_error)
    __Pyx_GIVEREF(__pyx_t_3);
    __Pyx_GOTREF(__pyx_v_self->_bytes_encoding);
    __Pyx_DECREF(__pyx_v_self->_bytes_encoding);
    __pyx_v_self->_bytes_encoding = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L4:;

  /* "psycopg_c/types/string.pyx":153
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
 * 
 *             if pgenc == b"SQL_ASCII":             # <<<<<<<<<<<<<<
 *                 self.encoding = NULL
 *             else:
*/
  __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_pgenc); if (unlikely(!__pyx_t_3)) __PYX_ERR(15, 153, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = (__Pyx_PyBytes_Equals(__pyx_t_3, __pyx_mstate_global->__pyx_n_b_SQL_ASCII, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(15, 153, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_1) {

    /* "psycopg_c/types/string.pyx":154
 * 
 *             if pgenc == b"SQL_ASCII":
 *                 self.encoding = NULL             # <<<<<<<<<<<<<<
 *             else:
 *                 self.encoding = PyBytes_AsString(self._bytes_encoding)
*/
    __pyx_v_self->encoding = NULL;

    /* "psycopg_c/types/string.pyx":153
 *                 self._bytes_encoding = pg2pyenc(pgenc).encode()
 * 
 *             if pgenc == b"SQL_ASCII":             # <<<<<<<<<<<<<<
 *                 self.encoding = NULL
 *             else:
*/
    goto __pyx_L7;
  }

  /* "psycopg_c/types/string.pyx":156
 *                 self.encoding = NULL
 *             else:
 *                 self.encoding = PyBytes_AsString(self._bytes_encoding)             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  /*else*/ {
    __pyx_t_3 = __pyx_v_self->_bytes_encoding;
    __Pyx_INCREF(__pyx_t_3);
    __pyx_t_10 = PyBytes_AsString(__pyx_t_3); if (unlikely(__pyx_t_10 == ((void *)NULL))) __PYX_ERR(15, 156, __pyx_L1_error)
    __pyx_v_self->encoding = __pyx_t_10;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L7:;

  /* "psycopg_c/types/string.pyx":144
 *         cdef const char *pgenc
 * 
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             pgenc = libpq.PQparameterStatus(
 *                 self._pgconn._pgconn_ptr, b"client_encoding")
*/
}

/* "psycopg_c/types/string.pyx":138
 *     cdef bytes _bytes_encoding  # needed to keep `encoding` alive
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 * 
 *         self.is_utf8 = 0
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("psycopg_c._psycopg._TextLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":158
 *                 self.encoding = PyBytes_AsString(self._bytes_encoding)
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self.is_utf8:
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11_TextLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/string.pyx":159
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self.is_utf8:             # <<<<<<<<<<<<<<
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         elif self.encoding:
*/
__pyx_t_1 = (__pyx_v_self->is_utf8 != 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/string.pyx":160
 *     cdef object cload(self, const char *data, size_t length):
 *         if self.is_utf8:
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)             # <<<<<<<<<<<<<<
 *         elif self.encoding:
 *             return PyUnicode_Decode(<char *>data, length, self.encoding, NULL)
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyUnicode_DecodeUTF8(((char *)__pyx_v_data), __pyx_v_length, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 160, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/string.pyx":159
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         if self.is_utf8:             # <<<<<<<<<<<<<<
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         elif self.encoding:
*/
}

/* "psycopg_c/types/string.pyx":161
 *         if self.is_utf8:
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         elif self.encoding:             # <<<<<<<<<<<<<<
 *             return PyUnicode_Decode(<char *>data, length, self.encoding, NULL)
 *         else:
*/
__pyx_t_1 = (__pyx_v_self->encoding != 0);
if (__pyx_t_1) {

  /* "psycopg_c/types/string.pyx":162
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         elif self.encoding:
 *             return PyUnicode_Decode(<char *>data, length, self.encoding, NULL)             # <<<<<<<<<<<<<<
 *         else:
 *             return data[:length]
*/
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyUnicode_Decode(((char *)__pyx_v_data), __pyx_v_length, __pyx_v_self->encoding, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "psycopg_c/types/string.pyx":161
 *         if self.is_utf8:
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
 *         elif self.encoding:             # <<<<<<<<<<<<<<
 *             return PyUnicode_Decode(<char *>data, length, self.encoding, NULL)
 *         else:
*/
}

/* "psycopg_c/types/string.pyx":164
 *             return PyUnicode_Decode(<char *>data, length, self.encoding, NULL)
 *         else:
 *             return data[:length]             # <<<<<<<<<<<<<<
 * 
 * 
*/
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_data + 0, __pyx_v_length - 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;
}

/* "psycopg_c/types/string.pyx":158
 *                 self.encoding = PyBytes_AsString(self._bytes_encoding)
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         if self.is_utf8:
 *             return PyUnicode_DecodeUTF8(<char *>data, length, NULL)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg._TextLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11_TextLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11_TextLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_TextLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._TextLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11_TextLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11_TextLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_TextLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._TextLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TextLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TextLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TextLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TextLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10TextLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10TextLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10TextLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TextLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TextBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TextBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TextBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TextBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16TextBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16TextBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16TextBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.TextBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":188
 *     cdef int _qplen
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._qplen = 0
 * 
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
if (unlikely(__pyx_nargs > 0)) { __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1; }
const Py_ssize_t __pyx_kwds_len = unlikely(__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
if (unlikely(__pyx_kwds_len < 0)) return -1;
if (unlikely(__pyx_kwds_len > 0)) {__Pyx_RejectKeywords("__cinit__", __pyx_kwds); return -1;}
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11BytesDumper___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_11BytesDumper___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self) {
int __pyx_r;

/* "psycopg_c/types/string.pyx":189
 * 
 *     def __cinit__(self):
 *         self._qplen = 0             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
__pyx_v_self->_qplen = 0;

/* "psycopg_c/types/string.pyx":188
 *     cdef int _qplen
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self._qplen = 0
 * 
*/

/* function exit code */
__pyx_r = 0;
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":191
 *         self._qplen = 0
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t len_out
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_11BytesDumper_cdump(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
size_t __pyx_v_len_out;
unsigned char *__pyx_v_out;
char *__pyx_v_ptr;
Py_ssize_t __pyx_v_length;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
int __pyx_t_2;
int __pyx_t_3;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7[3];
PyObject *__pyx_t_8 = NULL;
size_t __pyx_t_9;
char *__pyx_t_10;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cdump", 0);

/* "psycopg_c/types/string.pyx":198
 *         cdef Py_ssize_t length
 * 
 *         _buffer_as_string_and_size(obj, &ptr, &length)             # <<<<<<<<<<<<<<
 * 
 *         if self._pgconn is not None and self._pgconn._pgconn_ptr != NULL:
*/
__pyx_t_1 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_obj, (&__pyx_v_ptr), (&__pyx_v_length)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(15, 198, __pyx_L1_error)

/* "psycopg_c/types/string.pyx":200
 *         _buffer_as_string_and_size(obj, &ptr, &length)
 * 
 *         if self._pgconn is not None and self._pgconn._pgconn_ptr != NULL:             # <<<<<<<<<<<<<<
 *             out = libpq.PQescapeByteaConn(
 *                 self._pgconn._pgconn_ptr, <unsigned char *>ptr, length, &len_out)
*/
__pyx_t_3 = (((PyObject *)__pyx_v_self->__pyx_base._pgconn) != Py_None);
if (__pyx_t_3) {
} else {
  __pyx_t_2 = __pyx_t_3;
  goto __pyx_L4_bool_binop_done;
}
__pyx_t_3 = (__pyx_v_self->__pyx_base._pgconn->_pgconn_ptr != NULL);
__pyx_t_2 = __pyx_t_3;
__pyx_L4_bool_binop_done:;
if (__pyx_t_2) {

  /* "psycopg_c/types/string.pyx":201
 * 
 *         if self._pgconn is not None and self._pgconn._pgconn_ptr != NULL:
 *             out = libpq.PQescapeByteaConn(             # <<<<<<<<<<<<<<
 *                 self._pgconn._pgconn_ptr, <unsigned char *>ptr, length, &len_out)
 *         else:
*/
  __pyx_v_out = PQescapeByteaConn(__pyx_v_self->__pyx_base._pgconn->_pgconn_ptr, ((unsigned char *)__pyx_v_ptr), __pyx_v_length, (&__pyx_v_len_out));

  /* "psycopg_c/types/string.pyx":200
 *         _buffer_as_string_and_size(obj, &ptr, &length)
 * 
 *         if self._pgconn is not None and self._pgconn._pgconn_ptr != NULL:             # <<<<<<<<<<<<<<
 *             out = libpq.PQescapeByteaConn(
 *                 self._pgconn._pgconn_ptr, <unsigned char *>ptr, length, &len_out)
*/
  goto __pyx_L3;
}

/* "psycopg_c/types/string.pyx":204
 *                 self._pgconn._pgconn_ptr, <unsigned char *>ptr, length, &len_out)
 *         else:
 *             out = libpq.PQescapeBytea(<unsigned char *>ptr, length, &len_out)             # <<<<<<<<<<<<<<
 * 
 *         if out is NULL:
*/
/*else*/ {
  __pyx_v_out = PQescapeBytea(((unsigned char *)__pyx_v_ptr), __pyx_v_length, (&__pyx_v_len_out));
}
__pyx_L3:;

/* "psycopg_c/types/string.pyx":206
 *             out = libpq.PQescapeBytea(<unsigned char *>ptr, length, &len_out)
 * 
 *         if out is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError(
 *                 f"couldn't allocate for escape_bytea of {length} bytes"
*/
__pyx_t_2 = (__pyx_v_out == NULL);
if (unlikely(__pyx_t_2)) {

  /* "psycopg_c/types/string.pyx":207
 * 
 *         if out is NULL:
 *             raise MemoryError(             # <<<<<<<<<<<<<<
 *                 f"couldn't allocate for escape_bytea of {length} bytes"
 *             )
*/
  __pyx_t_5 = NULL;

  /* "psycopg_c/types/string.pyx":208
 *         if out is NULL:
 *             raise MemoryError(
 *                 f"couldn't allocate for escape_bytea of {length} bytes"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
  __pyx_t_6 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_length, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7[0] = __pyx_mstate_global->__pyx_kp_u_couldn_t_allocate_for_escape_byt;
  __pyx_t_7[1] = __pyx_t_6;
  __pyx_t_7[2] = __pyx_mstate_global->__pyx_kp_u_bytes;
  __pyx_t_8 = __Pyx_PyUnicode_Join(__pyx_t_7, 3, 38 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6) + 6, 127);
  if (unlikely(!__pyx_t_8)) __PYX_ERR(15, 208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_9 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_8};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_MemoryError)), __pyx_callargs+__pyx_t_9, (2-__pyx_t_9) | (__pyx_t_9*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(15, 207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  __Pyx_Raise(__pyx_t_4, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(15, 207, __pyx_L1_error)

  /* "psycopg_c/types/string.pyx":206
 *             out = libpq.PQescapeBytea(<unsigned char *>ptr, length, &len_out)
 * 
 *         if out is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError(
 *                 f"couldn't allocate for escape_bytea of {length} bytes"
*/
}

/* "psycopg_c/types/string.pyx":211
 *             )
 * 
 *         len_out -= 1  # out includes final 0             # <<<<<<<<<<<<<<
 *         cdef char *buf = CDumper.ensure_size(rv, offset, len_out)
 *         memcpy(buf, out, len_out)
*/
__pyx_v_len_out = (__pyx_v_len_out - 1);

/* "psycopg_c/types/string.pyx":212
 * 
 *         len_out -= 1  # out includes final 0
 *         cdef char *buf = CDumper.ensure_size(rv, offset, len_out)             # <<<<<<<<<<<<<<
 *         memcpy(buf, out, len_out)
 *         libpq.PQfreemem(out)
*/
__pyx_t_10 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_len_out); if (unlikely(__pyx_t_10 == ((void *)NULL))) __PYX_ERR(15, 212, __pyx_L1_error)
__pyx_v_buf = __pyx_t_10;

/* "psycopg_c/types/string.pyx":213
 *         len_out -= 1  # out includes final 0
 *         cdef char *buf = CDumper.ensure_size(rv, offset, len_out)
 *         memcpy(buf, out, len_out)             # <<<<<<<<<<<<<<
 *         libpq.PQfreemem(out)
 *         return len_out
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_out, __pyx_v_len_out));

/* "psycopg_c/types/string.pyx":214
 *         cdef char *buf = CDumper.ensure_size(rv, offset, len_out)
 *         memcpy(buf, out, len_out)
 *         libpq.PQfreemem(out)             # <<<<<<<<<<<<<<
 *         return len_out
 * 
*/
PQfreemem(__pyx_v_out);

/* "psycopg_c/types/string.pyx":215
 *         memcpy(buf, out, len_out)
 *         libpq.PQfreemem(out)
 *         return len_out             # <<<<<<<<<<<<<<
 * 
 *     def quote(self, obj) -> Buffer:
*/
__pyx_r = __pyx_v_len_out;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":191
 *         self._qplen = 0
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 * 
 *         cdef size_t len_out
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("psycopg_c._psycopg.BytesDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":217
 *         return len_out
 * 
 *     def quote(self, obj) -> Buffer:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef Py_ssize_t length
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_3quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11BytesDumper_3quote = {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_3quote, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_3quote(PyObject *__pyx_v_self, PyObject *__pyx_v_obj) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("quote (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_2quote(((struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *)__pyx_v_self), ((PyObject *)__pyx_v_obj));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_2quote(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self, PyObject *__pyx_v_obj) {
char *__pyx_v_ptr;
Py_ssize_t __pyx_v_length;
char const *__pyx_v_scs;
PyObject *__pyx_v_escaped = NULL;
PyObject *__pyx_v_rv = NULL;
char *__pyx_v_ptr_out;
struct __pyx_obj_9psycopg_c_2pq_Escaping *__pyx_v_esc = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
size_t __pyx_t_3;
int __pyx_t_4;
int __pyx_t_5;
int __pyx_t_6;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("quote", 0);

/* "psycopg_c/types/string.pyx":222
 *         cdef const char *scs
 * 
 *         escaped = self.dump(obj)             # <<<<<<<<<<<<<<
 *         _buffer_as_string_and_size(escaped, &ptr, &length)
 * 
*/
__pyx_t_2 = ((PyObject *)__pyx_v_self);
__Pyx_INCREF(__pyx_t_2);
__pyx_t_3 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_obj};
  __pyx_t_1 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_dump, __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
}
__pyx_v_escaped = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/string.pyx":223
 * 
 *         escaped = self.dump(obj)
 *         _buffer_as_string_and_size(escaped, &ptr, &length)             # <<<<<<<<<<<<<<
 * 
 *         rv = PyByteArray_FromStringAndSize("", 0)
*/
__pyx_t_4 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_escaped, (&__pyx_v_ptr), (&__pyx_v_length)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(15, 223, __pyx_L1_error)

/* "psycopg_c/types/string.pyx":225
 *         _buffer_as_string_and_size(escaped, &ptr, &length)
 * 
 *         rv = PyByteArray_FromStringAndSize("", 0)             # <<<<<<<<<<<<<<
 * 
 *         # We cannot use the base quoting because escape_bytea already returns
*/
__pyx_t_1 = PyByteArray_FromStringAndSize(((char *)""), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 225, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_rv = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/string.pyx":231
 *         # the format, otherwise it won't, but it doesn't tell us what quotes to
 *         # use.
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             if not self._qplen:
 *                 scs = libpq.PQparameterStatus(
*/
__pyx_t_5 = (((PyObject *)__pyx_v_self->__pyx_base._pgconn) != Py_None);
if (__pyx_t_5) {

  /* "psycopg_c/types/string.pyx":232
 *         # use.
 *         if self._pgconn is not None:
 *             if not self._qplen:             # <<<<<<<<<<<<<<
 *                 scs = libpq.PQparameterStatus(
 *                     self._pgconn._pgconn_ptr, b"standard_conforming_strings")
*/
  __pyx_t_5 = (!(__pyx_v_self->_qplen != 0));
  if (__pyx_t_5) {

    /* "psycopg_c/types/string.pyx":233
 *         if self._pgconn is not None:
 *             if not self._qplen:
 *                 scs = libpq.PQparameterStatus(             # <<<<<<<<<<<<<<
 *                     self._pgconn._pgconn_ptr, b"standard_conforming_strings")
 *                 if scs and scs[0] == b'o' and scs[1] == b"n":  # == "on"
*/
    __pyx_v_scs = PQparameterStatus(__pyx_v_self->__pyx_base._pgconn->_pgconn_ptr, __pyx_k_standard_conforming_strings);

    /* "psycopg_c/types/string.pyx":235
 *                 scs = libpq.PQparameterStatus(
 *                     self._pgconn._pgconn_ptr, b"standard_conforming_strings")
 *                 if scs and scs[0] == b'o' and scs[1] == b"n":  # == "on"             # <<<<<<<<<<<<<<
 *                     self._qplen = 1
 *                 else:
*/
    __pyx_t_6 = (__pyx_v_scs != 0);
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = ((__pyx_v_scs[0]) == 'o');
    if (__pyx_t_6) {
    } else {
      __pyx_t_5 = __pyx_t_6;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_6 = ((__pyx_v_scs[1]) == 'n');
    __pyx_t_5 = __pyx_t_6;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_5) {

      /* "psycopg_c/types/string.pyx":236
 *                     self._pgconn._pgconn_ptr, b"standard_conforming_strings")
 *                 if scs and scs[0] == b'o' and scs[1] == b"n":  # == "on"
 *                     self._qplen = 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     self._qplen = 3
*/
      __pyx_v_self->_qplen = 1;

      /* "psycopg_c/types/string.pyx":235
 *                 scs = libpq.PQparameterStatus(
 *                     self._pgconn._pgconn_ptr, b"standard_conforming_strings")
 *                 if scs and scs[0] == b'o' and scs[1] == b"n":  # == "on"             # <<<<<<<<<<<<<<
 *                     self._qplen = 1
 *                 else:
*/
      goto __pyx_L5;
    }

    /* "psycopg_c/types/string.pyx":238
 *                     self._qplen = 1
 *                 else:
 *                     self._qplen = 3             # <<<<<<<<<<<<<<
 * 
 *             PyByteArray_Resize(rv, length + self._qplen + 1)  # Include quotes
*/
    /*else*/ {
      __pyx_v_self->_qplen = 3;
    }
    __pyx_L5:;

    /* "psycopg_c/types/string.pyx":232
 *         # use.
 *         if self._pgconn is not None:
 *             if not self._qplen:             # <<<<<<<<<<<<<<
 *                 scs = libpq.PQparameterStatus(
 *                     self._pgconn._pgconn_ptr, b"standard_conforming_strings")
*/
  }

  /* "psycopg_c/types/string.pyx":240
 *                     self._qplen = 3
 * 
 *             PyByteArray_Resize(rv, length + self._qplen + 1)  # Include quotes             # <<<<<<<<<<<<<<
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             if self._qplen == 1:
*/
  __pyx_t_4 = PyByteArray_Resize(__pyx_v_rv, ((__pyx_v_length + __pyx_v_self->_qplen) + 1)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(15, 240, __pyx_L1_error)

  /* "psycopg_c/types/string.pyx":241
 * 
 *             PyByteArray_Resize(rv, length + self._qplen + 1)  # Include quotes
 *             ptr_out = PyByteArray_AS_STRING(rv)             # <<<<<<<<<<<<<<
 *             if self._qplen == 1:
 *                 ptr_out[0] = b"'"
*/
  __pyx_v_ptr_out = PyByteArray_AS_STRING(__pyx_v_rv);

  /* "psycopg_c/types/string.pyx":242
 *             PyByteArray_Resize(rv, length + self._qplen + 1)  # Include quotes
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             if self._qplen == 1:             # <<<<<<<<<<<<<<
 *                 ptr_out[0] = b"'"
 *             else:
*/
  __pyx_t_5 = (__pyx_v_self->_qplen == 1);
  if (__pyx_t_5) {

    /* "psycopg_c/types/string.pyx":243
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             if self._qplen == 1:
 *                 ptr_out[0] = b"'"             # <<<<<<<<<<<<<<
 *             else:
 *                 ptr_out[0] = b" "
*/
    (__pyx_v_ptr_out[0]) = '\'';

    /* "psycopg_c/types/string.pyx":242
 *             PyByteArray_Resize(rv, length + self._qplen + 1)  # Include quotes
 *             ptr_out = PyByteArray_AS_STRING(rv)
 *             if self._qplen == 1:             # <<<<<<<<<<<<<<
 *                 ptr_out[0] = b"'"
 *             else:
*/
    goto __pyx_L9;
  }

  /* "psycopg_c/types/string.pyx":245
 *                 ptr_out[0] = b"'"
 *             else:
 *                 ptr_out[0] = b" "             # <<<<<<<<<<<<<<
 *                 ptr_out[1] = b"E"
 *                 ptr_out[2] = b"'"
*/
  /*else*/ {
    (__pyx_v_ptr_out[0]) = ' ';

    /* "psycopg_c/types/string.pyx":246
 *             else:
 *                 ptr_out[0] = b" "
 *                 ptr_out[1] = b"E"             # <<<<<<<<<<<<<<
 *                 ptr_out[2] = b"'"
 *             memcpy(ptr_out + self._qplen, ptr, length)
*/
    (__pyx_v_ptr_out[1]) = 'E';

    /* "psycopg_c/types/string.pyx":247
 *                 ptr_out[0] = b" "
 *                 ptr_out[1] = b"E"
 *                 ptr_out[2] = b"'"             # <<<<<<<<<<<<<<
 *             memcpy(ptr_out + self._qplen, ptr, length)
 *             ptr_out[length + self._qplen] = b"'"
*/
    (__pyx_v_ptr_out[2]) = '\'';
  }
  __pyx_L9:;

  /* "psycopg_c/types/string.pyx":248
 *                 ptr_out[1] = b"E"
 *                 ptr_out[2] = b"'"
 *             memcpy(ptr_out + self._qplen, ptr, length)             # <<<<<<<<<<<<<<
 *             ptr_out[length + self._qplen] = b"'"
 *             return rv
*/
  (void)(memcpy((__pyx_v_ptr_out + __pyx_v_self->_qplen), __pyx_v_ptr, __pyx_v_length));

  /* "psycopg_c/types/string.pyx":249
 *                 ptr_out[2] = b"'"
 *             memcpy(ptr_out + self._qplen, ptr, length)
 *             ptr_out[length + self._qplen] = b"'"             # <<<<<<<<<<<<<<
 *             return rv
 * 
*/
  (__pyx_v_ptr_out[(__pyx_v_length + __pyx_v_self->_qplen)]) = '\'';

  /* "psycopg_c/types/string.pyx":250
 *             memcpy(ptr_out + self._qplen, ptr, length)
 *             ptr_out[length + self._qplen] = b"'"
 *             return rv             # <<<<<<<<<<<<<<
 * 
 *         # We don't have a connection, so someone is using us to generate a file
*/
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_rv);
  __pyx_r = __pyx_v_rv;
  goto __pyx_L0;

  /* "psycopg_c/types/string.pyx":231
 *         # the format, otherwise it won't, but it doesn't tell us what quotes to
 *         # use.
 *         if self._pgconn is not None:             # <<<<<<<<<<<<<<
 *             if not self._qplen:
 *                 scs = libpq.PQparameterStatus(
*/
}

/* "psycopg_c/types/string.pyx":256
 *         # string counterpart, is not predictable whether it will escape
 *         # backslashes.
 *         PyByteArray_Resize(rv, length + 4)  # Include quotes             # <<<<<<<<<<<<<<
 *         ptr_out = PyByteArray_AS_STRING(rv)
 *         ptr_out[0] = b" "
*/
__pyx_t_4 = PyByteArray_Resize(__pyx_v_rv, (__pyx_v_length + 4)); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(15, 256, __pyx_L1_error)

/* "psycopg_c/types/string.pyx":257
 *         # backslashes.
 *         PyByteArray_Resize(rv, length + 4)  # Include quotes
 *         ptr_out = PyByteArray_AS_STRING(rv)             # <<<<<<<<<<<<<<
 *         ptr_out[0] = b" "
 *         ptr_out[1] = b"E"
*/
__pyx_v_ptr_out = PyByteArray_AS_STRING(__pyx_v_rv);

/* "psycopg_c/types/string.pyx":258
 *         PyByteArray_Resize(rv, length + 4)  # Include quotes
 *         ptr_out = PyByteArray_AS_STRING(rv)
 *         ptr_out[0] = b" "             # <<<<<<<<<<<<<<
 *         ptr_out[1] = b"E"
 *         ptr_out[2] = b"'"
*/
(__pyx_v_ptr_out[0]) = ' ';

/* "psycopg_c/types/string.pyx":259
 *         ptr_out = PyByteArray_AS_STRING(rv)
 *         ptr_out[0] = b" "
 *         ptr_out[1] = b"E"             # <<<<<<<<<<<<<<
 *         ptr_out[2] = b"'"
 *         memcpy(ptr_out + 3, ptr, length)
*/
(__pyx_v_ptr_out[1]) = 'E';

/* "psycopg_c/types/string.pyx":260
 *         ptr_out[0] = b" "
 *         ptr_out[1] = b"E"
 *         ptr_out[2] = b"'"             # <<<<<<<<<<<<<<
 *         memcpy(ptr_out + 3, ptr, length)
 *         ptr_out[length + 3] = b"'"
*/
(__pyx_v_ptr_out[2]) = '\'';

/* "psycopg_c/types/string.pyx":261
 *         ptr_out[1] = b"E"
 *         ptr_out[2] = b"'"
 *         memcpy(ptr_out + 3, ptr, length)             # <<<<<<<<<<<<<<
 *         ptr_out[length + 3] = b"'"
 * 
*/
(void)(memcpy((__pyx_v_ptr_out + 3), __pyx_v_ptr, __pyx_v_length));

/* "psycopg_c/types/string.pyx":262
 *         ptr_out[2] = b"'"
 *         memcpy(ptr_out + 3, ptr, length)
 *         ptr_out[length + 3] = b"'"             # <<<<<<<<<<<<<<
 * 
 *         esc = Escaping()
*/
(__pyx_v_ptr_out[(__pyx_v_length + 3)]) = '\'';

/* "psycopg_c/types/string.pyx":264
 *         ptr_out[length + 3] = b"'"
 * 
 *         esc = Escaping()             # <<<<<<<<<<<<<<
 *         if esc.escape_bytea(b"\x00") == b"\\000":
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
*/
__pyx_t_2 = NULL;
__pyx_t_3 = 1;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_2, NULL};
  __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_2pq_Escaping, __pyx_callargs+__pyx_t_3, (1-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 264, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_1);
}
__pyx_v_esc = ((struct __pyx_obj_9psycopg_c_2pq_Escaping *)__pyx_t_1);
__pyx_t_1 = 0;

/* "psycopg_c/types/string.pyx":265
 * 
 *         esc = Escaping()
 *         if esc.escape_bytea(b"\x00") == b"\\000":             # <<<<<<<<<<<<<<
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
 * 
*/
__pyx_t_1 = ((struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping *)__pyx_v_esc->__pyx_vtab)->escape_bytea(__pyx_v_esc, __pyx_mstate_global->__pyx_kp_b__10, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 265, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_5 = (__Pyx_PyBytes_Equals(__pyx_t_1, __pyx_mstate_global->__pyx_kp_b_000, Py_EQ)); if (unlikely((__pyx_t_5 < 0))) __PYX_ERR(15, 265, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
if (__pyx_t_5) {

  /* "psycopg_c/types/string.pyx":266
 *         esc = Escaping()
 *         if esc.escape_bytea(b"\x00") == b"\\000":
 *             rv = bytes(rv).replace(b"\\", b"\\\\")             # <<<<<<<<<<<<<<
 * 
 *         return rv
*/
  __pyx_t_2 = NULL;
  __pyx_t_3 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_v_rv};
    __pyx_t_1 = __Pyx_PyObject_FastCall((PyObject*)(&PyBytes_Type), __pyx_callargs+__pyx_t_3, (2-__pyx_t_3) | (__pyx_t_3*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
  }
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_mstate_global->__pyx_n_u_replace); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[0], NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_rv, __pyx_t_1);
  __pyx_t_1 = 0;

  /* "psycopg_c/types/string.pyx":265
 * 
 *         esc = Escaping()
 *         if esc.escape_bytea(b"\x00") == b"\\000":             # <<<<<<<<<<<<<<
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
 * 
*/
}

/* "psycopg_c/types/string.pyx":268
 *             rv = bytes(rv).replace(b"\\", b"\\\\")
 * 
 *         return rv             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_rv);
__pyx_r = __pyx_v_rv;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":217
 *         return len_out
 * 
 *     def quote(self, obj) -> Buffer:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef Py_ssize_t length
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg.BytesDumper.quote", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_escaped);
__Pyx_XDECREF(__pyx_v_rv);
__Pyx_XDECREF((PyObject *)__pyx_v_esc);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11BytesDumper_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_5__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_5__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_4__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BytesDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11BytesDumper_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_7__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_7__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_6__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11BytesDumper_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BytesDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":277
 *     oid = oids.BYTEA_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef char *src
 *         cdef Py_ssize_t size
*/

static Py_ssize_t __pyx_f_9psycopg_c_8_psycopg_17BytesBinaryDumper_cdump(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_v_self, PyObject *__pyx_v_obj, PyObject *__pyx_v_rv, Py_ssize_t __pyx_v_offset) {
char *__pyx_v_src;
Py_ssize_t __pyx_v_size;
char *__pyx_v_buf;
Py_ssize_t __pyx_r;
int __pyx_t_1;
char *__pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;

/* "psycopg_c/types/string.pyx":280
 *         cdef char *src
 *         cdef Py_ssize_t size
 *         _buffer_as_string_and_size(obj, &src, &size)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
*/
__pyx_t_1 = __pyx_f_9psycopg_c_2pq__buffer_as_string_and_size(__pyx_v_obj, (&__pyx_v_src), (&__pyx_v_size)); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(15, 280, __pyx_L1_error)

/* "psycopg_c/types/string.pyx":282
 *         _buffer_as_string_and_size(obj, &src, &size)
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)             # <<<<<<<<<<<<<<
 *         memcpy(buf, src, size)
 *         return  size
*/
__pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size(__pyx_v_rv, __pyx_v_offset, __pyx_v_size); if (unlikely(__pyx_t_2 == ((void *)NULL))) __PYX_ERR(15, 282, __pyx_L1_error)
__pyx_v_buf = __pyx_t_2;

/* "psycopg_c/types/string.pyx":283
 * 
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)             # <<<<<<<<<<<<<<
 *         return  size
 * 
*/
(void)(memcpy(__pyx_v_buf, __pyx_v_src, __pyx_v_size));

/* "psycopg_c/types/string.pyx":284
 *         cdef char *buf = CDumper.ensure_size(rv, offset, size)
 *         memcpy(buf, src, size)
 *         return  size             # <<<<<<<<<<<<<<
 * 
 * 
*/
__pyx_r = __pyx_v_size;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":277
 *     oid = oids.BYTEA_OID
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:             # <<<<<<<<<<<<<<
 *         cdef char *src
 *         cdef Py_ssize_t size
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BytesBinaryDumper.cdump", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1L;
__pyx_L0:;
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17BytesBinaryDumper_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17BytesBinaryDumper___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17BytesBinaryDumper___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BytesBinaryDumper.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17BytesBinaryDumper_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17BytesBinaryDumper_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17BytesBinaryDumper_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.BytesBinaryDumper.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":292
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef size_t len_out
 *         cdef unsigned char *out = libpq.PQunescapeBytea(
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11ByteaLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *__pyx_v_self, char const *__pyx_v_data, CYTHON_UNUSED size_t __pyx_v_length) {
size_t __pyx_v_len_out;
unsigned char *__pyx_v_out;
PyObject *__pyx_v_rv = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
Py_ssize_t __pyx_t_4;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6[3];
PyObject *__pyx_t_7 = NULL;
size_t __pyx_t_8;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/string.pyx":294
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef size_t len_out
 *         cdef unsigned char *out = libpq.PQunescapeBytea(             # <<<<<<<<<<<<<<
 *             <const unsigned char *>data, &len_out)
 *         if out is NULL:
*/
__pyx_v_out = PQunescapeBytea(((unsigned char const *)__pyx_v_data), (&__pyx_v_len_out));

/* "psycopg_c/types/string.pyx":296
 *         cdef unsigned char *out = libpq.PQunescapeBytea(
 *             <const unsigned char *>data, &len_out)
 *         if out is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError(
 *                 f"couldn't allocate for unescape_bytea of {len(data)} bytes"
*/
__pyx_t_1 = (__pyx_v_out == NULL);
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/string.pyx":297
 *             <const unsigned char *>data, &len_out)
 *         if out is NULL:
 *             raise MemoryError(             # <<<<<<<<<<<<<<
 *                 f"couldn't allocate for unescape_bytea of {len(data)} bytes"
 *             )
*/
  __pyx_t_3 = NULL;

  /* "psycopg_c/types/string.pyx":298
 *         if out is NULL:
 *             raise MemoryError(
 *                 f"couldn't allocate for unescape_bytea of {len(data)} bytes"             # <<<<<<<<<<<<<<
 *             )
 * 
*/
  __pyx_t_4 = __Pyx_ssize_strlen(__pyx_v_data); if (unlikely(__pyx_t_4 == ((Py_ssize_t)-1))) __PYX_ERR(15, 298, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_t_4, 0, ' ', 'd'); if (unlikely(!__pyx_t_5)) __PYX_ERR(15, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6[0] = __pyx_mstate_global->__pyx_kp_u_couldn_t_allocate_for_unescape_b;
  __pyx_t_6[1] = __pyx_t_5;
  __pyx_t_6[2] = __pyx_mstate_global->__pyx_kp_u_bytes;
  __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_6, 3, 40 + __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5) + 6, 127);
  if (unlikely(!__pyx_t_7)) __PYX_ERR(15, 298, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_MemoryError)), __pyx_callargs+__pyx_t_8, (2-__pyx_t_8) | (__pyx_t_8*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 297, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(15, 297, __pyx_L1_error)

  /* "psycopg_c/types/string.pyx":296
 *         cdef unsigned char *out = libpq.PQunescapeBytea(
 *             <const unsigned char *>data, &len_out)
 *         if out is NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError(
 *                 f"couldn't allocate for unescape_bytea of {len(data)} bytes"
*/
}

/* "psycopg_c/types/string.pyx":301
 *             )
 * 
 *         rv = out[:len_out]             # <<<<<<<<<<<<<<
 *         libpq.PQfreemem(out)
 *         return rv
*/
__pyx_t_2 = __Pyx_PyBytes_FromStringAndSize(((char const *)__pyx_v_out) + 0, __pyx_v_len_out - 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(15, 301, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_v_rv = ((PyObject*)__pyx_t_2);
__pyx_t_2 = 0;

/* "psycopg_c/types/string.pyx":302
 * 
 *         rv = out[:len_out]
 *         libpq.PQfreemem(out)             # <<<<<<<<<<<<<<
 *         return rv
 * 
*/
PQfreemem(__pyx_v_out);

/* "psycopg_c/types/string.pyx":303
 *         rv = out[:len_out]
 *         libpq.PQfreemem(out)
 *         return rv             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_rv);
__pyx_r = __pyx_v_rv;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":292
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef size_t len_out
 *         cdef unsigned char *out = libpq.PQunescapeBytea(
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_AddTraceback("psycopg_c._psycopg.ByteaLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_rv);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11ByteaLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11ByteaLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ByteaLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.ByteaLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11ByteaLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11ByteaLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11ByteaLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.ByteaLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/string.pyx":311
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         return data[:length]
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_17ByteaBinaryLoader_cload(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/string.pyx":312
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         return data[:length]             # <<<<<<<<<<<<<<
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_data + 0, __pyx_v_length - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 312, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* "psycopg_c/types/string.pyx":311
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         return data[:length]
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.ByteaBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17ByteaBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17ByteaBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ByteaBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.ByteaBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_17ByteaBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_17ByteaBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_17ByteaBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.ByteaBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/uuid.pyx":36
 *     cdef object _safeuuid_unknown
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         from psycopg_c import _uuid
 * 
*/

/* Python wrapper */
static int __pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
CYTHON_UNUSED PyObject *__pyx_v_oid = 0;
CYTHON_UNUSED PyObject *__pyx_v_context = 0;
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[2] = {0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
#endif
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_oid,&__pyx_mstate_global->__pyx_n_u_context,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_VARARGS(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(2, 36, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 36, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 36, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__cinit__", 0) < (0)) __PYX_ERR(2, 36, __pyx_L3_error)
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
    for (Py_ssize_t i = __pyx_nargs; i < 1; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, i); __PYX_ERR(2, 36, __pyx_L3_error) }
    }
  } else {
    switch (__pyx_nargs) {
      case  2:
      values[1] = __Pyx_ArgRef_VARARGS(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(2, 36, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_VARARGS(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(2, 36, __pyx_L3_error)
      break;
      default: goto __pyx_L5_argtuple_error;
    }
    if (!values[1]) values[1] = __Pyx_NewRef(((PyObject *)Py_None));
  }
  if (__Pyx_PyInt_FromNumber(&values[0], "oid", 0) < (0)) __PYX_ERR(2, 36, __pyx_L3_error)
  __pyx_v_oid = ((PyObject*)values[0]);
  __pyx_v_context = values[1];
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 36, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg._UUIDLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return -1;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_oid), (&PyLong_Type), 0, "oid", 2))) __PYX_ERR(2, 36, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader___cinit__(((struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)__pyx_v_self), __pyx_v_oid, __pyx_v_context);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = -1;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static int __pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader___cinit__(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_oid, CYTHON_UNUSED PyObject *__pyx_v_context) {
PyObject *__pyx_v__uuid = NULL;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
Py_ssize_t __pyx_t_3;
PyObject *__pyx_t_4 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__cinit__", 0);

/* "psycopg_c/types/uuid.pyx":37
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):
 *         from psycopg_c import _uuid             # <<<<<<<<<<<<<<
 * 
 *         self._object_new = object.__new__
*/
{
  PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_uuid};
  __pyx_t_2 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg_c, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 37, __pyx_L1_error)
}
__pyx_t_1 = __pyx_t_2;
__Pyx_GOTREF(__pyx_t_1);
{
  PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_uuid};
  __pyx_t_3 = 0; {
    __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_1, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 37, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    switch (__pyx_t_3) {
      case 0:
      __Pyx_INCREF(__pyx_t_4);
      __pyx_v__uuid = __pyx_t_4;
      break;
      default:;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
}
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":39
 *         from psycopg_c import _uuid
 * 
 *         self._object_new = object.__new__             # <<<<<<<<<<<<<<
 *         self._uuid_type = _uuid.UUID
 *         self._wuuid_type = <PyObject *>_uuid._WritableUUID
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_builtin_object, __pyx_mstate_global->__pyx_n_u_new); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 39, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v_self->_object_new);
__Pyx_DECREF(__pyx_v_self->_object_new);
__pyx_v_self->_object_new = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":40
 * 
 *         self._object_new = object.__new__
 *         self._uuid_type = _uuid.UUID             # <<<<<<<<<<<<<<
 *         self._wuuid_type = <PyObject *>_uuid._WritableUUID
 *         self._safeuuid_unknown = _uuid.SafeUUID_unknown
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v__uuid, __pyx_mstate_global->__pyx_n_u_UUID); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 40, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v_self->_uuid_type);
__Pyx_DECREF(__pyx_v_self->_uuid_type);
__pyx_v_self->_uuid_type = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":41
 *         self._object_new = object.__new__
 *         self._uuid_type = _uuid.UUID
 *         self._wuuid_type = <PyObject *>_uuid._WritableUUID             # <<<<<<<<<<<<<<
 *         self._safeuuid_unknown = _uuid.SafeUUID_unknown
 * 
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v__uuid, __pyx_mstate_global->__pyx_n_u_WritableUUID); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 41, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_self->_wuuid_type = ((PyObject *)__pyx_t_1);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":42
 *         self._uuid_type = _uuid.UUID
 *         self._wuuid_type = <PyObject *>_uuid._WritableUUID
 *         self._safeuuid_unknown = _uuid.SafeUUID_unknown             # <<<<<<<<<<<<<<
 * 
 *     cdef object _return_uuid(self, uint64_t low, uint64_t high):
*/
__pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v__uuid, __pyx_mstate_global->__pyx_n_u_SafeUUID_unknown); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 42, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v_self->_safeuuid_unknown);
__Pyx_DECREF(__pyx_v_self->_safeuuid_unknown);
__pyx_v_self->_safeuuid_unknown = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":36
 *     cdef object _safeuuid_unknown
 * 
 *     def __cinit__(self, oid: int, context: AdaptContext | None = None):             # <<<<<<<<<<<<<<
 *         from psycopg_c import _uuid
 * 
*/

/* function exit code */
__pyx_r = 0;
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("psycopg_c._psycopg._UUIDLoader.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = -1;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v__uuid);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/uuid.pyx":44
 *         self._safeuuid_unknown = _uuid.SafeUUID_unknown
 * 
 *     cdef object _return_uuid(self, uint64_t low, uint64_t high):             # <<<<<<<<<<<<<<
 *         cdef object py_low = PyLong_FromUnsignedLongLong(low)
 *         cdef object py_high = PyLong_FromUnsignedLongLong(high)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_11_UUIDLoader__return_uuid(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self, uint64_t __pyx_v_low, uint64_t __pyx_v_high) {
PyObject *__pyx_v_py_low = 0;
PyObject *__pyx_v_py_high = 0;
PyObject *__pyx_v_py_value = 0;
PyObject *__pyx_v_u = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("_return_uuid", 0);

/* "psycopg_c/types/uuid.pyx":45
 * 
 *     cdef object _return_uuid(self, uint64_t low, uint64_t high):
 *         cdef object py_low = PyLong_FromUnsignedLongLong(low)             # <<<<<<<<<<<<<<
 *         cdef object py_high = PyLong_FromUnsignedLongLong(high)
 *         cdef object py_value = (py_high << 64) | py_low
*/
__pyx_t_1 = PyLong_FromUnsignedLongLong(__pyx_v_low); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 45, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_py_low = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":46
 *     cdef object _return_uuid(self, uint64_t low, uint64_t high):
 *         cdef object py_low = PyLong_FromUnsignedLongLong(low)
 *         cdef object py_high = PyLong_FromUnsignedLongLong(high)             # <<<<<<<<<<<<<<
 *         cdef object py_value = (py_high << 64) | py_low
 * 
*/
__pyx_t_1 = PyLong_FromUnsignedLongLong(__pyx_v_high); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 46, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_py_high = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":47
 *         cdef object py_low = PyLong_FromUnsignedLongLong(low)
 *         cdef object py_high = PyLong_FromUnsignedLongLong(high)
 *         cdef object py_value = (py_high << 64) | py_low             # <<<<<<<<<<<<<<
 * 
 *         cdef object u = PyObject_CallFunctionObjArgs(
*/
__pyx_t_1 = PyNumber_Lshift(__pyx_v_py_high, __pyx_mstate_global->__pyx_int_64); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 47, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = PyNumber_Or(__pyx_t_1, __pyx_v_py_low); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 47, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_py_value = __pyx_t_2;
__pyx_t_2 = 0;

/* "psycopg_c/types/uuid.pyx":50
 * 
 *         cdef object u = PyObject_CallFunctionObjArgs(
 *             self._object_new, self._wuuid_type, NULL)             # <<<<<<<<<<<<<<
 *         u.int = py_value
 *         u.is_safe = self._safeuuid_unknown
*/
__pyx_t_2 = __pyx_v_self->_object_new;
__Pyx_INCREF(__pyx_t_2);

/* "psycopg_c/types/uuid.pyx":49
 *         cdef object py_value = (py_high << 64) | py_low
 * 
 *         cdef object u = PyObject_CallFunctionObjArgs(             # <<<<<<<<<<<<<<
 *             self._object_new, self._wuuid_type, NULL)
 *         u.int = py_value
*/
__pyx_t_1 = PyObject_CallFunctionObjArgs(__pyx_t_2, __pyx_v_self->_wuuid_type, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 49, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__pyx_v_u = __pyx_t_1;
__pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":51
 *         cdef object u = PyObject_CallFunctionObjArgs(
 *             self._object_new, self._wuuid_type, NULL)
 *         u.int = py_value             # <<<<<<<<<<<<<<
 *         u.is_safe = self._safeuuid_unknown
 *         u.__class__ = self._uuid_type
*/
if (__Pyx_PyObject_SetAttrStr(__pyx_v_u, __pyx_mstate_global->__pyx_n_u_int, __pyx_v_py_value) < (0)) __PYX_ERR(2, 51, __pyx_L1_error)

/* "psycopg_c/types/uuid.pyx":52
 *             self._object_new, self._wuuid_type, NULL)
 *         u.int = py_value
 *         u.is_safe = self._safeuuid_unknown             # <<<<<<<<<<<<<<
 *         u.__class__ = self._uuid_type
 *         return u
*/
__pyx_t_1 = __pyx_v_self->_safeuuid_unknown;
__Pyx_INCREF(__pyx_t_1);
if (__Pyx_PyObject_SetAttrStr(__pyx_v_u, __pyx_mstate_global->__pyx_n_u_is_safe, __pyx_t_1) < (0)) __PYX_ERR(2, 52, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":53
 *         u.int = py_value
 *         u.is_safe = self._safeuuid_unknown
 *         u.__class__ = self._uuid_type             # <<<<<<<<<<<<<<
 *         return u
 * 
*/
__pyx_t_1 = __pyx_v_self->_uuid_type;
__Pyx_INCREF(__pyx_t_1);
if (__Pyx_PyObject_SetAttrStr(__pyx_v_u, __pyx_mstate_global->__pyx_n_u_class_2, __pyx_t_1) < (0)) __PYX_ERR(2, 53, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "psycopg_c/types/uuid.pyx":54
 *         u.is_safe = self._safeuuid_unknown
 *         u.__class__ = self._uuid_type
 *         return u             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_u);
__pyx_r = __pyx_v_u;
goto __pyx_L0;

/* "psycopg_c/types/uuid.pyx":44
 *         self._safeuuid_unknown = _uuid.SafeUUID_unknown
 * 
 *     cdef object _return_uuid(self, uint64_t low, uint64_t high):             # <<<<<<<<<<<<<<
 *         cdef object py_low = PyLong_FromUnsignedLongLong(low)
 *         cdef object py_high = PyLong_FromUnsignedLongLong(high)
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_AddTraceback("psycopg_c._psycopg._UUIDLoader._return_uuid", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_py_low);
__Pyx_XDECREF(__pyx_v_py_high);
__Pyx_XDECREF(__pyx_v_py_value);
__Pyx_XDECREF(__pyx_v_u);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11_UUIDLoader_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_3__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_3__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader_2__reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._UUIDLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_11_UUIDLoader_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_5__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_5__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader_4__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_11_UUIDLoader_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg._UUIDLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/uuid.pyx":61
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t high = 0
 *         cdef uint64_t low = 0
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_10UUIDLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
uint64_t __pyx_v_high;
uint64_t __pyx_v_low;
size_t __pyx_v_i;
int __pyx_v_ndigits;
int8_t __pyx_v_c;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
size_t __pyx_t_1;
size_t __pyx_t_2;
size_t __pyx_t_3;
int __pyx_t_4;
PyObject *__pyx_t_5 = NULL;
PyObject *__pyx_t_6 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/uuid.pyx":62
 * 
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t high = 0             # <<<<<<<<<<<<<<
 *         cdef uint64_t low = 0
 *         cdef size_t i
*/
__pyx_v_high = 0;

/* "psycopg_c/types/uuid.pyx":63
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t high = 0
 *         cdef uint64_t low = 0             # <<<<<<<<<<<<<<
 *         cdef size_t i
 *         cdef int ndigits = 0
*/
__pyx_v_low = 0;

/* "psycopg_c/types/uuid.pyx":65
 *         cdef uint64_t low = 0
 *         cdef size_t i
 *         cdef int ndigits = 0             # <<<<<<<<<<<<<<
 *         cdef int8_t c
 * 
*/
__pyx_v_ndigits = 0;

/* "psycopg_c/types/uuid.pyx":68
 *         cdef int8_t c
 * 
 *         for i in range(length):             # <<<<<<<<<<<<<<
 *             c = data[i]
 *             if hex_to_int_map[c] == -1:
*/
__pyx_t_1 = __pyx_v_length;
__pyx_t_2 = __pyx_t_1;
for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
  __pyx_v_i = __pyx_t_3;

  /* "psycopg_c/types/uuid.pyx":69
 * 
 *         for i in range(length):
 *             c = data[i]             # <<<<<<<<<<<<<<
 *             if hex_to_int_map[c] == -1:
 *                 continue
*/
  __pyx_v_c = (__pyx_v_data[__pyx_v_i]);

  /* "psycopg_c/types/uuid.pyx":70
 *         for i in range(length):
 *             c = data[i]
 *             if hex_to_int_map[c] == -1:             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
  __pyx_t_4 = ((hex_to_int_map[__pyx_v_c]) == -1L);
  if (__pyx_t_4) {

    /* "psycopg_c/types/uuid.pyx":71
 *             c = data[i]
 *             if hex_to_int_map[c] == -1:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             if ndigits < 16:
*/
    goto __pyx_L3_continue;

    /* "psycopg_c/types/uuid.pyx":70
 *         for i in range(length):
 *             c = data[i]
 *             if hex_to_int_map[c] == -1:             # <<<<<<<<<<<<<<
 *                 continue
 * 
*/
  }

  /* "psycopg_c/types/uuid.pyx":73
 *                 continue
 * 
 *             if ndigits < 16:             # <<<<<<<<<<<<<<
 *                 high = (high << 4) | hex_to_int_map[c]
 *             else:
*/
  __pyx_t_4 = (__pyx_v_ndigits < 16);
  if (__pyx_t_4) {

    /* "psycopg_c/types/uuid.pyx":74
 * 
 *             if ndigits < 16:
 *                 high = (high << 4) | hex_to_int_map[c]             # <<<<<<<<<<<<<<
 *             else:
 *                 low = (low << 4) | hex_to_int_map[c]
*/
    __pyx_v_high = ((__pyx_v_high << 4) | (hex_to_int_map[__pyx_v_c]));

    /* "psycopg_c/types/uuid.pyx":73
 *                 continue
 * 
 *             if ndigits < 16:             # <<<<<<<<<<<<<<
 *                 high = (high << 4) | hex_to_int_map[c]
 *             else:
*/
    goto __pyx_L6;
  }

  /* "psycopg_c/types/uuid.pyx":76
 *                 high = (high << 4) | hex_to_int_map[c]
 *             else:
 *                 low = (low << 4) | hex_to_int_map[c]             # <<<<<<<<<<<<<<
 *             ndigits += 1
 * 
*/
  /*else*/ {
    __pyx_v_low = ((__pyx_v_low << 4) | (hex_to_int_map[__pyx_v_c]));
  }
  __pyx_L6:;

  /* "psycopg_c/types/uuid.pyx":77
 *             else:
 *                 low = (low << 4) | hex_to_int_map[c]
 *             ndigits += 1             # <<<<<<<<<<<<<<
 * 
 *         if ndigits != 32:
*/
  __pyx_v_ndigits = (__pyx_v_ndigits + 1);
  __pyx_L3_continue:;
}

/* "psycopg_c/types/uuid.pyx":79
 *             ndigits += 1
 * 
 *         if ndigits != 32:             # <<<<<<<<<<<<<<
 *             raise ValueError("Invalid UUID string")
 * 
*/
__pyx_t_4 = (__pyx_v_ndigits != 32);
if (unlikely(__pyx_t_4)) {

  /* "psycopg_c/types/uuid.pyx":80
 * 
 *         if ndigits != 32:
 *             raise ValueError("Invalid UUID string")             # <<<<<<<<<<<<<<
 * 
 *         return self._return_uuid(low, high)
*/
  __pyx_t_6 = NULL;
  __pyx_t_1 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_mstate_global->__pyx_kp_u_Invalid_UUID_string};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_1, (2-__pyx_t_1) | (__pyx_t_1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 80, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  __Pyx_Raise(__pyx_t_5, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __PYX_ERR(2, 80, __pyx_L1_error)

  /* "psycopg_c/types/uuid.pyx":79
 *             ndigits += 1
 * 
 *         if ndigits != 32:             # <<<<<<<<<<<<<<
 *             raise ValueError("Invalid UUID string")
 * 
*/
}

/* "psycopg_c/types/uuid.pyx":82
 *             raise ValueError("Invalid UUID string")
 * 
 *         return self._return_uuid(low, high)             # <<<<<<<<<<<<<<
 * 
 * 
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_5 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDLoader *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._return_uuid(((struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)__pyx_v_self), __pyx_v_low, __pyx_v_high); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 82, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_5);
__pyx_r = __pyx_t_5;
__pyx_t_5 = 0;
goto __pyx_L0;

/* "psycopg_c/types/uuid.pyx":61
 *     format = PQ_TEXT
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t high = 0
 *         cdef uint64_t low = 0
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_5);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_AddTraceback("psycopg_c._psycopg.UUIDLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10UUIDLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10UUIDLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10UUIDLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.UUIDLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_10UUIDLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_10UUIDLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_10UUIDLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.UUIDLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "psycopg_c/types/uuid.pyx":89
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t be[2]
 *         if length != sizeof(be):
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg_16UUIDBinaryLoader_cload(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_v_self, char const *__pyx_v_data, size_t __pyx_v_length) {
uint64_t __pyx_v_be[2];
uint64_t __pyx_v_high;
uint64_t __pyx_v_low;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("cload", 0);

/* "psycopg_c/types/uuid.pyx":91
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t be[2]
 *         if length != sizeof(be):             # <<<<<<<<<<<<<<
 *             raise ValueError("Invalid UUID data")
 *         memcpy(&be, data, sizeof(be))
*/
__pyx_t_1 = (__pyx_v_length != (sizeof(__pyx_v_be)));
if (unlikely(__pyx_t_1)) {

  /* "psycopg_c/types/uuid.pyx":92
 *         cdef uint64_t be[2]
 *         if length != sizeof(be):
 *             raise ValueError("Invalid UUID data")             # <<<<<<<<<<<<<<
 *         memcpy(&be, data, sizeof(be))
 * 
*/
  __pyx_t_3 = NULL;
  __pyx_t_4 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_mstate_global->__pyx_kp_u_Invalid_UUID_data};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)(((PyTypeObject*)PyExc_ValueError)), __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (__pyx_t_4*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 92, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  __Pyx_Raise(__pyx_t_2, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(2, 92, __pyx_L1_error)

  /* "psycopg_c/types/uuid.pyx":91
 *     cdef object cload(self, const char *data, size_t length):
 *         cdef uint64_t be[2]
 *         if length != sizeof(be):             # <<<<<<<<<<<<<<
 *             raise ValueError("Invalid UUID data")
 *         memcpy(&be, data, sizeof(be))
*/
}

/* "psycopg_c/types/uuid.pyx":93
 *         if length != sizeof(be):
 *             raise ValueError("Invalid UUID data")
 *         memcpy(&be, data, sizeof(be))             # <<<<<<<<<<<<<<
 * 
 *         cdef uint64_t high = endian.be64toh(be[0])
*/
(void)(memcpy((&__pyx_v_be), __pyx_v_data, (sizeof(__pyx_v_be))));

/* "psycopg_c/types/uuid.pyx":95
 *         memcpy(&be, data, sizeof(be))
 * 
 *         cdef uint64_t high = endian.be64toh(be[0])             # <<<<<<<<<<<<<<
 *         cdef uint64_t low = endian.be64toh(be[1])
 *         return self._return_uuid(low, high)
*/
__pyx_v_high = be64toh((__pyx_v_be[0]));

/* "psycopg_c/types/uuid.pyx":96
 * 
 *         cdef uint64_t high = endian.be64toh(be[0])
 *         cdef uint64_t low = endian.be64toh(be[1])             # <<<<<<<<<<<<<<
 *         return self._return_uuid(low, high)
*/
__pyx_v_low = be64toh((__pyx_v_be[1]));

/* "psycopg_c/types/uuid.pyx":97
 *         cdef uint64_t high = endian.be64toh(be[0])
 *         cdef uint64_t low = endian.be64toh(be[1])
 *         return self._return_uuid(low, high)             # <<<<<<<<<<<<<<
*/
__Pyx_XDECREF(__pyx_r);
__pyx_t_2 = ((struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDBinaryLoader *)__pyx_v_self->__pyx_base.__pyx_base.__pyx_vtab)->__pyx_base._return_uuid(((struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)__pyx_v_self), __pyx_v_low, __pyx_v_high); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 97, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_r = __pyx_t_2;
__pyx_t_2 = 0;
goto __pyx_L0;

/* "psycopg_c/types/uuid.pyx":89
 *     format = PQ_BINARY
 * 
 *     cdef object cload(self, const char *data, size_t length):             # <<<<<<<<<<<<<<
 *         cdef uint64_t be[2]
 *         if length != sizeof(be):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.UUIDBinaryLoader.cload", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16UUIDBinaryLoader_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_1__reduce_cython__, METH_NOARGS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_1__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16UUIDBinaryLoader___reduce_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16UUIDBinaryLoader___reduce_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 2, __pyx_L1_error)

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.UUIDBinaryLoader.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_16UUIDBinaryLoader_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_3__setstate_cython__, METH_O, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_3__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_16UUIDBinaryLoader_2__setstate_cython__(((struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_16UUIDBinaryLoader_2__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
*/
__Pyx_Raise(((PyObject *)(((PyTypeObject*)PyExc_TypeError))), __pyx_mstate_global->__pyx_kp_u_no_default___reduce___due_to_non, 0, 0);
__PYX_ERR(6, 4, __pyx_L1_error)

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_AddTraceback("psycopg_c._psycopg.UUIDBinaryLoader.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_RowLoader(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_32__pyx_unpickle_RowLoader(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_32__pyx_unpickle_RowLoader = {"__pyx_unpickle_RowLoader", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_32__pyx_unpickle_RowLoader, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_32__pyx_unpickle_RowLoader(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v___pyx_type = 0;
long __pyx_v___pyx_checksum;
PyObject *__pyx_v___pyx_state = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[3] = {0,0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__pyx_unpickle_RowLoader (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(6, 4, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  3:
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(6, 4, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(6, 4, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(6, 4, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_RowLoader", 0) < (0)) __PYX_ERR(6, 4, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RowLoader", 1, 3, 3, i); __PYX_ERR(6, 4, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 3)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(6, 4, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(6, 4, __pyx_L3_error)
    values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(6, 4, __pyx_L3_error)
  }
  __pyx_v___pyx_type = values[0];
  __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(6, 4, __pyx_L3_error)
  __pyx_v___pyx_state = ((PyObject*)values[2]);
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RowLoader", 1, 3, 3, __pyx_nargs); __PYX_ERR(6, 4, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.__pyx_unpickle_RowLoader", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(6, 4, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_31__pyx_unpickle_RowLoader(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = NULL;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_31__pyx_unpickle_RowLoader(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_v___pyx_result = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__pyx_unpickle_RowLoader", 0);

/* "(tree fragment)":6
 * def __pyx_unpickle_RowLoader(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')             # <<<<<<<<<<<<<<
 *     __pyx_result = RowLoader.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
__pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, __pyx_k_cloader_loadfunc_pyloader); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(6, 6, __pyx_L1_error)

/* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')
 *     __pyx_result = RowLoader.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)
*/
__pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader);
__Pyx_INCREF(__pyx_t_3);
__pyx_t_4 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
  __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
}
__pyx_v___pyx_result = __pyx_t_2;
__pyx_t_2 = 0;

/* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')
 *     __pyx_result = RowLoader.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
__pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
if (__pyx_t_5) {

  /* "(tree fragment)":9
 *     __pyx_result = RowLoader.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_RowLoader__set_state(RowLoader __pyx_result, __pyx_state: tuple):
*/
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(6, 9, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowLoader__set_state(((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')
 *     __pyx_result = RowLoader.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
}

/* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_RowLoader__set_state(RowLoader __pyx_result, __pyx_state: tuple):
 *     __pyx_result.cloader = __pyx_state[0]; __pyx_result.loadfunc = __pyx_state[1]; __pyx_result.pyloader = __pyx_state[2]
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v___pyx_result);
__pyx_r = __pyx_v___pyx_result;
goto __pyx_L0;

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_RowLoader(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.__pyx_unpickle_RowLoader", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v___pyx_result);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_RowLoader__set_state(RowLoader __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.cloader = __pyx_state[0]; __pyx_result.loadfunc = __pyx_state[1]; __pyx_result.pyloader = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowLoader__set_state(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__pyx_unpickle_RowLoader__set_state", 0);

/* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_RowLoader__set_state(RowLoader __pyx_result, __pyx_state: tuple):
 *     __pyx_result.cloader = __pyx_state[0]; __pyx_result.loadfunc = __pyx_state[1]; __pyx_result.pyloader = __pyx_state[2]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader))))) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->cloader);
__Pyx_DECREF((PyObject *)__pyx_v___pyx_result->cloader);
__pyx_v___pyx_result->cloader = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)__pyx_t_1);
__pyx_t_1 = 0;
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->loadfunc);
__Pyx_DECREF(__pyx_v___pyx_result->loadfunc);
__pyx_v___pyx_result->loadfunc = __pyx_t_1;
__pyx_t_1 = 0;
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->pyloader);
__Pyx_DECREF(__pyx_v___pyx_result->pyloader);
__pyx_v___pyx_result->pyloader = __pyx_t_1;
__pyx_t_1 = 0;

/* "(tree fragment)":13
 * cdef __pyx_unpickle_RowLoader__set_state(RowLoader __pyx_result, __pyx_state: tuple):
 *     __pyx_result.cloader = __pyx_state[0]; __pyx_result.loadfunc = __pyx_state[1]; __pyx_result.pyloader = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)             # <<<<<<<<<<<<<<
*/
__pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 3); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(6, 13, __pyx_L1_error)

/* "(tree fragment)":11
 *         __pyx_unpickle_RowLoader__set_state(<RowLoader> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_RowLoader__set_state(RowLoader __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.cloader = __pyx_state[0]; __pyx_result.loadfunc = __pyx_state[1]; __pyx_result.pyloader = __pyx_state[2]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 3)
*/

/* function exit code */
__pyx_r = Py_None; __Pyx_INCREF(Py_None);
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.__pyx_unpickle_RowLoader__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_RowDumper(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, b'cdumper, dumpfunc, format, oid, pydumper')
*/

/* Python wrapper */
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_34__pyx_unpickle_RowDumper(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_9psycopg_c_8_psycopg_34__pyx_unpickle_RowDumper = {"__pyx_unpickle_RowDumper", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_34__pyx_unpickle_RowDumper, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_9psycopg_c_8_psycopg_34__pyx_unpickle_RowDumper(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
PyObject *__pyx_v___pyx_type = 0;
long __pyx_v___pyx_checksum;
PyObject *__pyx_v___pyx_state = 0;
#if !CYTHON_METH_FASTCALL
CYTHON_UNUSED Py_ssize_t __pyx_nargs;
#endif
CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
PyObject* values[3] = {0,0,0};
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__pyx_unpickle_RowDumper (wrapper)", 0);
#if !CYTHON_METH_FASTCALL
#if CYTHON_ASSUME_SAFE_SIZE
__pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
#else
__pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
#endif
#endif
__pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
{
  PyObject ** const __pyx_pyargnames[] = {&__pyx_mstate_global->__pyx_n_u_pyx_type,&__pyx_mstate_global->__pyx_n_u_pyx_checksum,&__pyx_mstate_global->__pyx_n_u_pyx_state,0};
  const Py_ssize_t __pyx_kwds_len = (__pyx_kwds) ? __Pyx_NumKwargs_FASTCALL(__pyx_kwds) : 0;
  if (unlikely(__pyx_kwds_len) < 0) __PYX_ERR(6, 4, __pyx_L3_error)
  if (__pyx_kwds_len > 0) {
    switch (__pyx_nargs) {
      case  3:
      values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(6, 4, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  2:
      values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(6, 4, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  1:
      values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
      if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(6, 4, __pyx_L3_error)
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    const Py_ssize_t kwd_pos_args = __pyx_nargs;
    if (__Pyx_ParseKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values, kwd_pos_args, __pyx_kwds_len, "__pyx_unpickle_RowDumper", 0) < (0)) __PYX_ERR(6, 4, __pyx_L3_error)
    for (Py_ssize_t i = __pyx_nargs; i < 3; i++) {
      if (unlikely(!values[i])) { __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RowDumper", 1, 3, 3, i); __PYX_ERR(6, 4, __pyx_L3_error) }
    }
  } else if (unlikely(__pyx_nargs != 3)) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = __Pyx_ArgRef_FASTCALL(__pyx_args, 0);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[0])) __PYX_ERR(6, 4, __pyx_L3_error)
    values[1] = __Pyx_ArgRef_FASTCALL(__pyx_args, 1);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[1])) __PYX_ERR(6, 4, __pyx_L3_error)
    values[2] = __Pyx_ArgRef_FASTCALL(__pyx_args, 2);
    if (!CYTHON_ASSUME_SAFE_MACROS && unlikely(!values[2])) __PYX_ERR(6, 4, __pyx_L3_error)
  }
  __pyx_v___pyx_type = values[0];
  __pyx_v___pyx_checksum = __Pyx_PyLong_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(6, 4, __pyx_L3_error)
  __pyx_v___pyx_state = ((PyObject*)values[2]);
}
goto __pyx_L6_skip;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__pyx_unpickle_RowDumper", 1, 3, 3, __pyx_nargs); __PYX_ERR(6, 4, __pyx_L3_error)
__pyx_L6_skip:;
goto __pyx_L4_argument_unpacking_done;
__pyx_L3_error:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__Pyx_AddTraceback("psycopg_c._psycopg.__pyx_unpickle_RowDumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v___pyx_state), (&PyTuple_Type), 1, "__pyx_state", 1))) __PYX_ERR(6, 4, __pyx_L1_error)
__pyx_r = __pyx_pf_9psycopg_c_8_psycopg_33__pyx_unpickle_RowDumper(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = NULL;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
goto __pyx_L7_cleaned_up;
__pyx_L0:;
for (Py_ssize_t __pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
  Py_XDECREF(values[__pyx_temp]);
}
__pyx_L7_cleaned_up:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_9psycopg_c_8_psycopg_33__pyx_unpickle_RowDumper(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_v___pyx_result = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
size_t __pyx_t_4;
int __pyx_t_5;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__pyx_unpickle_RowDumper", 0);

/* "(tree fragment)":6
 * def __pyx_unpickle_RowDumper(__pyx_type, long __pyx_checksum, tuple __pyx_state):
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, b'cdumper, dumpfunc, format, oid, pydumper')             # <<<<<<<<<<<<<<
 *     __pyx_result = RowDumper.__new__(__pyx_type)
 *     if __pyx_state is not None:
*/
__pyx_t_1 = __Pyx_CheckUnpickleChecksum(__pyx_v___pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, __pyx_k_cdumper_dumpfunc_format_oid_pydu); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(6, 6, __pyx_L1_error)

/* "(tree fragment)":7
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, b'cdumper, dumpfunc, format, oid, pydumper')
 *     __pyx_result = RowDumper.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)
*/
__pyx_t_3 = ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper);
__Pyx_INCREF(__pyx_t_3);
__pyx_t_4 = 0;
{
  PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_v___pyx_type};
  __pyx_t_2 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_new, __pyx_callargs+__pyx_t_4, (2-__pyx_t_4) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
}
__pyx_v___pyx_result = __pyx_t_2;
__pyx_t_2 = 0;

/* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, b'cdumper, dumpfunc, format, oid, pydumper')
 *     __pyx_result = RowDumper.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
__pyx_t_5 = (__pyx_v___pyx_state != ((PyObject*)Py_None));
if (__pyx_t_5) {

  /* "(tree fragment)":9
 *     __pyx_result = RowDumper.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_RowDumper__set_state(RowDumper __pyx_result, __pyx_state: tuple):
*/
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "cannot pass None into a C function argument that is declared 'not None'");
    __PYX_ERR(6, 9, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowDumper__set_state(((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)__pyx_v___pyx_result), __pyx_v___pyx_state); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":8
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, b'cdumper, dumpfunc, format, oid, pydumper')
 *     __pyx_result = RowDumper.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)
 *     return __pyx_result
*/
}

/* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_RowDumper__set_state(RowDumper __pyx_result, __pyx_state: tuple):
 *     __pyx_result.cdumper = __pyx_state[0]; __pyx_result.dumpfunc = __pyx_state[1]; __pyx_result.format = __pyx_state[2]; __pyx_result.oid = __pyx_state[3]; __pyx_result.pydumper = __pyx_state[4]
*/
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v___pyx_result);
__pyx_r = __pyx_v___pyx_result;
goto __pyx_L0;

/* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_RowDumper(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0x597b60c, 0x1cec925, 0xcb5bd1f, b'cdumper, dumpfunc, format, oid, pydumper')
*/

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_AddTraceback("psycopg_c._psycopg.__pyx_unpickle_RowDumper", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v___pyx_result);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_RowDumper__set_state(RowDumper __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.cdumper = __pyx_state[0]; __pyx_result.dumpfunc = __pyx_state[1]; __pyx_result.format = __pyx_state[2]; __pyx_result.oid = __pyx_state[3]; __pyx_result.pydumper = __pyx_state[4]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 5)
*/

static PyObject *__pyx_f_9psycopg_c_8_psycopg___pyx_unpickle_RowDumper__set_state(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__pyx_unpickle_RowDumper__set_state", 0);

/* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_RowDumper__set_state(RowDumper __pyx_result, __pyx_state: tuple):
 *     __pyx_result.cdumper = __pyx_state[0]; __pyx_result.dumpfunc = __pyx_state[1]; __pyx_result.format = __pyx_state[2]; __pyx_result.oid = __pyx_state[3]; __pyx_result.pydumper = __pyx_state[4]             # <<<<<<<<<<<<<<
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 5)
*/
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper))))) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF((PyObject *)__pyx_v___pyx_result->cdumper);
__Pyx_DECREF((PyObject *)__pyx_v___pyx_result->cdumper);
__pyx_v___pyx_result->cdumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)__pyx_t_1);
__pyx_t_1 = 0;
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->dumpfunc);
__Pyx_DECREF(__pyx_v___pyx_result->dumpfunc);
__pyx_v___pyx_result->dumpfunc = __pyx_t_1;
__pyx_t_1 = 0;
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 2, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->format);
__Pyx_DECREF(__pyx_v___pyx_result->format);
__pyx_v___pyx_result->format = __pyx_t_1;
__pyx_t_1 = 0;
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 3, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->oid);
__Pyx_DECREF(__pyx_v___pyx_result->oid);
__pyx_v___pyx_result->oid = __pyx_t_1;
__pyx_t_1 = 0;
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 4, long, 1, __Pyx_PyLong_From_long, 0, 0, 1, 1, __Pyx_ReferenceSharing_FunctionArgument); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->pydumper);
__Pyx_DECREF(__pyx_v___pyx_result->pydumper);
__pyx_v___pyx_result->pydumper = __pyx_t_1;
__pyx_t_1 = 0;

/* "(tree fragment)":13
 * cdef __pyx_unpickle_RowDumper__set_state(RowDumper __pyx_result, __pyx_state: tuple):
 *     __pyx_result.cdumper = __pyx_state[0]; __pyx_result.dumpfunc = __pyx_state[1]; __pyx_result.format = __pyx_state[2]; __pyx_result.oid = __pyx_state[3]; __pyx_result.pydumper = __pyx_state[4]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 5)             # <<<<<<<<<<<<<<
*/
__pyx_t_2 = __Pyx_UpdateUnpickledDict(((PyObject *)__pyx_v___pyx_result), __pyx_v___pyx_state, 5); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(6, 13, __pyx_L1_error)

/* "(tree fragment)":11
 *         __pyx_unpickle_RowDumper__set_state(<RowDumper> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_RowDumper__set_state(RowDumper __pyx_result, __pyx_state: tuple):             # <<<<<<<<<<<<<<
 *     __pyx_result.cdumper = __pyx_state[0]; __pyx_result.dumpfunc = __pyx_state[1]; __pyx_result.format = __pyx_state[2]; __pyx_result.oid = __pyx_state[3]; __pyx_result.pydumper = __pyx_state[4]
 *     __Pyx_UpdateUnpickledDict(__pyx_result, __pyx_state, 5)
*/

/* function exit code */
__pyx_r = Py_None; __Pyx_INCREF(Py_None);
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("psycopg_c._psycopg.__pyx_unpickle_RowDumper__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}
/* #### Code section: module_exttypes ### */
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper __pyx_vtable_9psycopg_c_8_psycopg_CDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_CDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *p;
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CDumper > 0) & __PYX_CHECK_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_CDumper[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CDumper];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)o);
  p->__pyx_vtab = __pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  p->cls = Py_None; Py_INCREF(Py_None);
  p->_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_7CDumper_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->cls);
  Py_CLEAR(p->_pgconn);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CDumper < 8) & __PYX_CHECK_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_CDumper[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CDumper++] = ((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->cls) {
    e = (*v)(p->cls, a); if (e) return e;
  }
  if (p->_pgconn) {
    e = (*v)(((PyObject *)p->_pgconn), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)o;
  tmp = ((PyObject*)p->cls);
  p->cls = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_pgconn);
  p->_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_7CDumper_cls(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_7CDumper_3cls_1__get__(o);
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_CDumper[] = {
  {"dump", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_3dump, METH_O, __pyx_doc_9psycopg_c_8_psycopg_7CDumper_2dump},
  {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_5quote, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_11__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CDumper_13__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9psycopg_c_8_psycopg_CDumper[] = {
  {"cls", __pyx_getprop_9psycopg_c_8_psycopg_7CDumper_cls, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_CDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_getset, (void *)__pyx_getsets_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_CDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_CDumper_spec = {
  "psycopg_c._psycopg.CDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_CDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_CDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""CDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_CDumper, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9psycopg_c_8_psycopg_CDumper, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_CDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader __pyx_vtable_9psycopg_c_8_psycopg_CLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_CLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *p;
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CLoader > 0) & __PYX_CHECK_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_CLoader[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CLoader];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)o);
  p->__pyx_vtab = __pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  p->_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_7CLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_pgconn);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CLoader < 8) & __PYX_CHECK_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_CLoader[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_CLoader++] = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->_pgconn) {
    e = (*v)(((PyObject *)p->_pgconn), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)o;
  tmp = ((PyObject*)p->_pgconn);
  p->_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_7CLoader_oid(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_7CLoader_3oid_1__get__(o);
}

static int __pyx_setprop_9psycopg_c_8_psycopg_7CLoader_oid(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_9psycopg_c_8_psycopg_7CLoader_3oid_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_CLoader[] = {
  {"load", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CLoader_3load, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CLoader_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_7CLoader_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9psycopg_c_8_psycopg_CLoader[] = {
  {"oid", __pyx_getprop_9psycopg_c_8_psycopg_7CLoader_oid, __pyx_setprop_9psycopg_c_8_psycopg_7CLoader_oid, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_CLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_getset, (void *)__pyx_getsets_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_CLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_CLoader_spec = {
  "psycopg_c._psycopg.CLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_CLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_CLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""CLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_CLoader, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9psycopg_c_8_psycopg_CLoader, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_CLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__CRecursiveLoader __pyx_vtable_9psycopg_c_8_psycopg__CRecursiveLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__CRecursiveLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg__CRecursiveLoader;
  p->_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_tx);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader(o);
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)o;
  e = __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader(o, v, a); if (e) return e;
  if (p->_tx) {
    e = (*v)(((PyObject *)p->_tx), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader *)o;
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader(o);
  tmp = ((PyObject*)p->_tx);
  p->_tx = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__CRecursiveLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17_CRecursiveLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__CRecursiveLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader_spec = {
  "psycopg_c._psycopg._CRecursiveLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_CRecursiveLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__CRecursiveLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_RowLoader(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *p;
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowLoader > 0) & __PYX_CHECK_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_RowLoader[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowLoader];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)o);
  p->cloader = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)Py_None); Py_INCREF(Py_None);
  p->pyloader = Py_None; Py_INCREF(Py_None);
  p->loadfunc = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg_RowLoader(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg_RowLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->cloader);
  Py_CLEAR(p->pyloader);
  Py_CLEAR(p->loadfunc);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowLoader < 16) & __PYX_CHECK_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_RowLoader[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowLoader++] = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg_RowLoader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->cloader) {
    e = (*v)(((PyObject *)p->cloader), a); if (e) return e;
  }
  if (p->pyloader) {
    e = (*v)(p->pyloader, a); if (e) return e;
  }
  if (p->loadfunc) {
    e = (*v)(p->loadfunc, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg_RowLoader(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader *)o;
  tmp = ((PyObject*)p->cloader);
  p->cloader = ((struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->pyloader);
  p->pyloader = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->loadfunc);
  p->loadfunc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_RowLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_RowLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_RowLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_RowLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_RowLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_RowLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_RowLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_RowLoader_spec = {
  "psycopg_c._psycopg.RowLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_RowLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_RowLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""RowLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_RowLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_RowLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_RowLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_RowLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_RowLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_RowDumper(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *p;
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowDumper > 0) & __PYX_CHECK_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_RowDumper[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowDumper];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 0);
    if (unlikely(!o)) return 0;
  }
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)o);
  p->cdumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)Py_None); Py_INCREF(Py_None);
  p->pydumper = Py_None; Py_INCREF(Py_None);
  p->dumpfunc = Py_None; Py_INCREF(Py_None);
  p->oid = Py_None; Py_INCREF(Py_None);
  p->format = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg_RowDumper(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg_RowDumper) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->cdumper);
  Py_CLEAR(p->pydumper);
  Py_CLEAR(p->dumpfunc);
  Py_CLEAR(p->oid);
  Py_CLEAR(p->format);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowDumper < 16) & __PYX_CHECK_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg_RowDumper[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg_RowDumper++] = ((struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg_RowDumper(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->cdumper) {
    e = (*v)(((PyObject *)p->cdumper), a); if (e) return e;
  }
  if (p->pydumper) {
    e = (*v)(p->pydumper, a); if (e) return e;
  }
  if (p->dumpfunc) {
    e = (*v)(p->dumpfunc, a); if (e) return e;
  }
  if (p->oid) {
    e = (*v)(p->oid, a); if (e) return e;
  }
  if (p->format) {
    e = (*v)(p->format, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg_RowDumper(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper *)o;
  tmp = ((PyObject*)p->cdumper);
  p->cdumper = ((struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->pydumper);
  p->pydumper = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->dumpfunc);
  p->dumpfunc = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->oid);
  p->oid = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->format);
  p->format = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_RowDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9RowDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_RowDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_RowDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_RowDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_RowDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_RowDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_RowDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_RowDumper_spec = {
  "psycopg_c._psycopg.RowDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_RowDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_RowDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""RowDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_RowDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_RowDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_RowDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_RowDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_RowDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_RowDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Transformer __pyx_vtable_9psycopg_c_8_psycopg_Transformer;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Transformer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *p;
  PyObject *o;
  o = __Pyx_AllocateExtensionType(t, 0);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)o);
  p->__pyx_vtab = __pyx_vtabptr_9psycopg_c_8_psycopg_Transformer;
  p->connection = Py_None; Py_INCREF(Py_None);
  p->adapters = Py_None; Py_INCREF(Py_None);
  p->types = Py_None; Py_INCREF(Py_None);
  p->formats = Py_None; Py_INCREF(Py_None);
  p->_encoding = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_auto_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_text_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_binary_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_text_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_binary_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_oid_text_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_oid_binary_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_pgresult = ((struct __pyx_obj_9psycopg_c_2pq_PGresult *)Py_None); Py_INCREF(Py_None);
  p->_row_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_row_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_oid_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_11Transformer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg_Transformer(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *p = (struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg_Transformer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->connection);
  Py_CLEAR(p->adapters);
  Py_CLEAR(p->types);
  Py_CLEAR(p->formats);
  Py_CLEAR(p->_encoding);
  Py_CLEAR(p->_auto_dumpers);
  Py_CLEAR(p->_text_dumpers);
  Py_CLEAR(p->_binary_dumpers);
  Py_CLEAR(p->_text_loaders);
  Py_CLEAR(p->_binary_loaders);
  Py_CLEAR(p->_oid_text_dumpers);
  Py_CLEAR(p->_oid_binary_dumpers);
  Py_CLEAR(p->_pgresult);
  Py_CLEAR(p->_row_dumpers);
  Py_CLEAR(p->_row_loaders);
  Py_CLEAR(p->_oid_types);
  PyTypeObject *tp = Py_TYPE(o);
  #if CYTHON_USE_TYPE_SLOTS
  (*tp->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  Py_DECREF(tp);
  #endif
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg_Transformer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *p = (struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->connection) {
    e = (*v)(p->connection, a); if (e) return e;
  }
  if (p->adapters) {
    e = (*v)(p->adapters, a); if (e) return e;
  }
  if (p->types) {
    e = (*v)(p->types, a); if (e) return e;
  }
  if (p->formats) {
    e = (*v)(p->formats, a); if (e) return e;
  }
  if (p->_auto_dumpers) {
    e = (*v)(p->_auto_dumpers, a); if (e) return e;
  }
  if (p->_text_dumpers) {
    e = (*v)(p->_text_dumpers, a); if (e) return e;
  }
  if (p->_binary_dumpers) {
    e = (*v)(p->_binary_dumpers, a); if (e) return e;
  }
  if (p->_text_loaders) {
    e = (*v)(p->_text_loaders, a); if (e) return e;
  }
  if (p->_binary_loaders) {
    e = (*v)(p->_binary_loaders, a); if (e) return e;
  }
  if (p->_oid_text_dumpers) {
    e = (*v)(p->_oid_text_dumpers, a); if (e) return e;
  }
  if (p->_oid_binary_dumpers) {
    e = (*v)(p->_oid_binary_dumpers, a); if (e) return e;
  }
  if (p->_pgresult) {
    e = (*v)(((PyObject *)p->_pgresult), a); if (e) return e;
  }
  if (p->_row_dumpers) {
    e = (*v)(p->_row_dumpers, a); if (e) return e;
  }
  if (p->_row_loaders) {
    e = (*v)(p->_row_loaders, a); if (e) return e;
  }
  if (p->_oid_types) {
    e = (*v)(p->_oid_types, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg_Transformer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *p = (struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *)o;
  tmp = ((PyObject*)p->connection);
  p->connection = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->adapters);
  p->adapters = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->types);
  p->types = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->formats);
  p->formats = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_auto_dumpers);
  p->_auto_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_text_dumpers);
  p->_text_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_binary_dumpers);
  p->_binary_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_text_loaders);
  p->_text_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_binary_loaders);
  p->_binary_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_oid_text_dumpers);
  p->_oid_text_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_oid_binary_dumpers);
  p->_oid_binary_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_pgresult);
  p->_pgresult = ((struct __pyx_obj_9psycopg_c_2pq_PGresult *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_row_dumpers);
  p->_row_dumpers = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_row_loaders);
  p->_row_loaders = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_oid_types);
  p->_oid_types = ((PyObject*)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_11Transformer_encoding(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_11Transformer_8encoding_1__get__(o);
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_11Transformer_pgresult(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_11Transformer_8pgresult_1__get__(o);
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_11Transformer_connection(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_11Transformer_10connection_1__get__(o);
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_11Transformer_adapters(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_11Transformer_8adapters_1__get__(o);
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_11Transformer_types(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_11Transformer_5types_1__get__(o);
}

static PyObject *__pyx_getprop_9psycopg_c_8_psycopg_11Transformer_formats(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_9psycopg_c_8_psycopg_11Transformer_7formats_1__get__(o);
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Transformer[] = {
  {"from_context", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_3from_context, METH_O, __pyx_doc_9psycopg_c_8_psycopg_11Transformer_2from_context},
  {"set_dumper_types", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_7set_dumper_types, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"set_loader_types", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_9set_loader_types, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_dumper", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_13get_dumper, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"load_rows", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_17load_rows, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"load_row", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_19load_row, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_loader", (PyCFunction)(void(*)(void))(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_23get_loader, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_25__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11Transformer_27__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_9psycopg_c_8_psycopg_Transformer[] = {
  {"encoding", __pyx_getprop_9psycopg_c_8_psycopg_11Transformer_encoding, 0, 0, 0},
  {"pgresult", __pyx_getprop_9psycopg_c_8_psycopg_11Transformer_pgresult, 0, 0, 0},
  {"connection", __pyx_getprop_9psycopg_c_8_psycopg_11Transformer_connection, 0, 0, 0},
  {"adapters", __pyx_getprop_9psycopg_c_8_psycopg_11Transformer_adapters, 0, 0, 0},
  {"types", __pyx_getprop_9psycopg_c_8_psycopg_11Transformer_types, 0, 0, 0},
  {"formats", __pyx_getprop_9psycopg_c_8_psycopg_11Transformer_formats, 0, 0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Transformer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_Transformer},
  {Py_tp_doc, (void *)PyDoc_STR("\n    An object that can adapt efficiently between Python and PostgreSQL.\n\n    The life cycle of the object is the query, so it is assumed that attributes\n    such as the server version or the connection encoding will not change. The\n    object have its state so adapting several values of the same type can be\n    optimised.\n\n    ")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_Transformer},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_Transformer},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Transformer},
  {Py_tp_getset, (void *)__pyx_getsets_9psycopg_c_8_psycopg_Transformer},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Transformer},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Transformer_spec = {
  "psycopg_c._psycopg.Transformer",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Transformer_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Transformer = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Transformer", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_Transformer, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  PyDoc_STR("\n    An object that can adapt efficiently between Python and PostgreSQL.\n\n    The life cycle of the object is the query, so it is assumed that attributes\n    such as the server version or the connection encoding will not change. The\n    object have its state so adapting several values of the same type can be\n    optimised.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_Transformer, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_Transformer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Transformer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_9psycopg_c_8_psycopg_Transformer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Transformer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ArrayLoader __pyx_vtable_9psycopg_c_8_psycopg_ArrayLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ArrayLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__CRecursiveLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_ArrayLoader;
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg_ArrayLoader(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg_ArrayLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_1__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader(o);
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_ArrayLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ArrayLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_ArrayLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_ArrayLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_ArrayLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_ArrayLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_ArrayLoader_spec = {
  "psycopg_c._psycopg.ArrayLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_ArrayLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_ArrayLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""ArrayLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_ArrayLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_ArrayLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_ArrayLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ArrayBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_ArrayBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ArrayBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__CRecursiveLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_ArrayBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_ArrayBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ArrayBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_ArrayBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_ArrayBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader_spec = {
  "psycopg_c._psycopg.ArrayBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""ArrayBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ArrayBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__CRecursiveLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_ArrayBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_ArrayBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateDumper __pyx_vtable_9psycopg_c_8_psycopg_DateDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DateDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DateDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DateDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DateDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DateDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DateDumper_spec = {
  "psycopg_c._psycopg.DateDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DateDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DateDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DateDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DateDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DateDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_DateBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DateBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DateBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper_spec = {
  "psycopg_c._psycopg.DateBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DateBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DateBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeDumper __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__BaseTimeDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15_BaseTimeDumper_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__BaseTimeDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper_spec = {
  "psycopg_c._psycopg._BaseTimeDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_BaseTimeDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__BaseTimeDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimeTextDumper __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeTextDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeTextDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__BaseTimeTextDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__BaseTimeTextDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeTextDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper_spec = {
  "psycopg_c._psycopg._BaseTimeTextDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_BaseTimeTextDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeTextDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__BaseTimeTextDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeTextDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeDumper __pyx_vtable_9psycopg_c_8_psycopg_TimeDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeTextDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimeDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimeDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimeDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimeDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimeDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimeDumper_spec = {
  "psycopg_c._psycopg.TimeDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimeDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimeDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimeDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimeDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimeDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzDumper __pyx_vtable_9psycopg_c_8_psycopg_TimeTzDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeTzDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeTextDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimeTzDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimeTzDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimeTzDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimeTzDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimeTzDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimeTzDumper_spec = {
  "psycopg_c._psycopg.TimeTzDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimeTzDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimeTzDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimeTzDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimeTzDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimeTzDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimeBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimeBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper_spec = {
  "psycopg_c._psycopg.TimeBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimeBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimeBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeTzBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_TimeTzBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeTzBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimeDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimeTzBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimeTzBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimeTzBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper_spec = {
  "psycopg_c._psycopg.TimeTzBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimeTzBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeTzBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimeTzBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimeTzBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeDumper __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__BaseDatetimeDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__BaseDatetimeDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper_spec = {
  "psycopg_c._psycopg._BaseDatetimeDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_BaseDatetimeDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__BaseDatetimeDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseDatetimeTextDumper __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeTextDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__BaseDatetimeTextDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__BaseDatetimeTextDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeTextDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper_spec = {
  "psycopg_c._psycopg._BaseDatetimeTextDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_BaseDatetimeTextDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseDatetimeTextDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__BaseDatetimeTextDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeTextDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeDumper __pyx_vtable_9psycopg_c_8_psycopg_DatetimeDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeTextDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DatetimeDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14DatetimeDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DatetimeDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DatetimeDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DatetimeDumper_spec = {
  "psycopg_c._psycopg.DatetimeDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DatetimeDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DatetimeDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DatetimeDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DatetimeDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DatetimeDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeNoTzDumper __pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeTextDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DatetimeNoTzDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DatetimeNoTzDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper_spec = {
  "psycopg_c._psycopg.DatetimeNoTzDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DatetimeNoTzDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DatetimeNoTzDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_DatetimeBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DatetimeBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DatetimeBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper_spec = {
  "psycopg_c._psycopg.DatetimeBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DatetimeBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DatetimeBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DatetimeBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseDatetimeDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper_spec = {
  "psycopg_c._psycopg.DatetimeNoTzBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DatetimeNoTzBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimedeltaDumper __pyx_vtable_9psycopg_c_8_psycopg_TimedeltaDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaDumper;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimedeltaDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimedeltaDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimedeltaDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper_spec = {
  "psycopg_c._psycopg.TimedeltaDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimedeltaDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimedeltaDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimedeltaBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimedeltaBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimedeltaBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper_spec = {
  "psycopg_c._psycopg.TimedeltaBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimedeltaBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimedeltaBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimedeltaBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimedeltaBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateLoader __pyx_vtable_9psycopg_c_8_psycopg_DateLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_DateLoader;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DateLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10DateLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DateLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DateLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DateLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DateLoader_spec = {
  "psycopg_c._psycopg.DateLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DateLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DateLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DateLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DateLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DateLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DateBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_DateBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DateBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16DateBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DateBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader_spec = {
  "psycopg_c._psycopg.DateBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DateBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DateBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DateBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DateBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeLoader __pyx_vtable_9psycopg_c_8_psycopg_TimeLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimeLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimeLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TimeLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimeLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimeLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimeLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimeLoader_spec = {
  "psycopg_c._psycopg.TimeLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimeLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimeLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimeLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimeLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimeLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimeBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimeBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TimeBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimeBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader_spec = {
  "psycopg_c._psycopg.TimeBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimeBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimeBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimeBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimeBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimetzLoader __pyx_vtable_9psycopg_c_8_psycopg_TimetzLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimetzLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimetzLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimetzLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12TimetzLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimetzLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimetzLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimetzLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimetzLoader_spec = {
  "psycopg_c._psycopg.TimetzLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimetzLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimetzLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimetzLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimetzLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimetzLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimetzLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimetzBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_TimetzBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimetzBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimetzBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimetzBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18TimetzBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimetzBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimetzBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader_spec = {
  "psycopg_c._psycopg.TimetzBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimetzBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimetzBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimetzBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimetzBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestampLoader __pyx_vtable_9psycopg_c_8_psycopg_TimestampLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestampLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimestampLoader;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimestampLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15TimestampLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimestampLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimestampLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimestampLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimestampLoader_spec = {
  "psycopg_c._psycopg.TimestampLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimestampLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimestampLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimestampLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimestampLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimestampLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestampBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_TimestampBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestampBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimestampBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimestampBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21TimestampBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimestampBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimestampBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader_spec = {
  "psycopg_c._psycopg.TimestampBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimestampBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimestampBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimestampBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseTimestamptzLoader __pyx_vtable_9psycopg_c_8_psycopg__BaseTimestamptzLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimestamptzLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  p->_time_zone = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_time_zone);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader(o);
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)o;
  e = __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader(o, v, a); if (e) return e;
  if (p->_time_zone) {
    e = (*v)(p->_time_zone, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader *)o;
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader(o);
  tmp = ((PyObject*)p->_time_zone);
  p->_time_zone = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__BaseTimestamptzLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader_spec = {
  "psycopg_c._psycopg._BaseTimestamptzLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_BaseTimestamptzLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimestamptzLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestamptzLoader __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimestamptzLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzLoader;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimestamptzLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17TimestamptzLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimestamptzLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader_spec = {
  "psycopg_c._psycopg.TimestamptzLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimestamptzLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimestamptzLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TimestamptzBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseTimestamptzLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TimestamptzBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TimestamptzBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader_spec = {
  "psycopg_c._psycopg.TimestamptzBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TimestamptzBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__BaseTimestamptzLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TimestamptzBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TimestamptzBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntervalLoader __pyx_vtable_9psycopg_c_8_psycopg_IntervalLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntervalLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntervalLoader;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntervalLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14IntervalLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntervalLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntervalLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntervalLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntervalLoader_spec = {
  "psycopg_c._psycopg.IntervalLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntervalLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntervalLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntervalLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntervalLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntervalLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntervalBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_IntervalBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntervalBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntervalBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntervalBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20IntervalBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntervalBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntervalBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader_spec = {
  "psycopg_c._psycopg.IntervalBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntervalBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntervalBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntervalBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntDumper __pyx_vtable_9psycopg_c_8_psycopg__IntDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__IntDumper[] = {
  {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_1quote, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_IntDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__IntDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__IntDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__IntDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__IntDumper_spec = {
  "psycopg_c._psycopg._IntDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__IntDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__IntDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_IntDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__IntDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__IntDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__IntOrSubclassDumper __pyx_vtable_9psycopg_c_8_psycopg__IntOrSubclassDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__IntOrSubclassDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__IntOrSubclassDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper_spec = {
  "psycopg_c._psycopg._IntOrSubclassDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_IntOrSubclassDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__IntOrSubclassDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__IntOrSubclassDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2Dumper __pyx_vtable_9psycopg_c_8_psycopg_Int2Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int2Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int2Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int2Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int2Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int2Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int2Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int2Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int2Dumper_spec = {
  "psycopg_c._psycopg.Int2Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int2Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int2Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int2Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int2Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int2Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int2Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4Dumper __pyx_vtable_9psycopg_c_8_psycopg_Int4Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int4Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int4Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int4Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int4Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int4Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int4Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int4Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int4Dumper_spec = {
  "psycopg_c._psycopg.Int4Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int4Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int4Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int4Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int4Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int4Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int4Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8Dumper __pyx_vtable_9psycopg_c_8_psycopg_Int8Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int8Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int8Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int8Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10Int8Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int8Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int8Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int8Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int8Dumper_spec = {
  "psycopg_c._psycopg.Int8Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int8Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int8Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int8Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int8Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int8Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int8Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntNumericDumper __pyx_vtable_9psycopg_c_8_psycopg_IntNumericDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntNumericDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntOrSubclassDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntNumericDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16IntNumericDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntNumericDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntNumericDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntNumericDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntNumericDumper_spec = {
  "psycopg_c._psycopg.IntNumericDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntNumericDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntNumericDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntNumericDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntNumericDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntNumericDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int2BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int2BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper_spec = {
  "psycopg_c._psycopg.Int2BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int2BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int2BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int4BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int4BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper_spec = {
  "psycopg_c._psycopg.Int4BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int4BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int4BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int8BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int8BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper_spec = {
  "psycopg_c._psycopg.Int8BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int8BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int8BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntNumericBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_IntNumericBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntNumericBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntNumericBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntNumericBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntNumericBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper_spec = {
  "psycopg_c._psycopg.IntNumericBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntNumericBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntNumericBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntNumericBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntNumericBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntDumper __pyx_vtable_9psycopg_c_8_psycopg_IntDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntDumper_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntDumper_spec = {
  "psycopg_c._psycopg.IntDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_IntBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15IntBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper_spec = {
  "psycopg_c._psycopg.IntBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_IntLoader __pyx_vtable_9psycopg_c_8_psycopg_IntLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_IntLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_IntLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_IntLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9IntLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_IntLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_IntLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_IntLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_IntLoader_spec = {
  "psycopg_c._psycopg.IntLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_IntLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_IntLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""IntLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_IntLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_IntLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_IntLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int2BinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int2BinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int2BinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int2BinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader_spec = {
  "psycopg_c._psycopg.Int2BinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int2BinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int2BinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int2BinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int2BinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int4BinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int4BinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int4BinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int4BinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader_spec = {
  "psycopg_c._psycopg.Int4BinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int4BinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int4BinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int4BinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int4BinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Int8BinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Int8BinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16Int8BinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Int8BinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader_spec = {
  "psycopg_c._psycopg.Int8BinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Int8BinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Int8BinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Int8BinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Int8BinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_OidBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_OidBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_OidBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_OidBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_OidBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15OidBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_OidBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_OidBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader_spec = {
  "psycopg_c._psycopg.OidBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""OidBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_OidBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_OidBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_OidBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__FloatDumper __pyx_vtable_9psycopg_c_8_psycopg__FloatDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__FloatDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__FloatDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__FloatDumper[] = {
  {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_1quote, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12_FloatDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__FloatDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__FloatDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__FloatDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__FloatDumper_spec = {
  "psycopg_c._psycopg._FloatDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__FloatDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__FloatDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_FloatDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__FloatDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__FloatDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__FloatDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatDumper __pyx_vtable_9psycopg_c_8_psycopg_FloatDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_FloatDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__FloatDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_FloatDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_FloatDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_FloatDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_FloatDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_FloatDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_FloatDumper_spec = {
  "psycopg_c._psycopg.FloatDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_FloatDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_FloatDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""FloatDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_FloatDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_FloatDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_FloatDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4Dumper __pyx_vtable_9psycopg_c_8_psycopg_Float4Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float4Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__FloatDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Float4Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Float4Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_12Float4Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Float4Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Float4Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Float4Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Float4Dumper_spec = {
  "psycopg_c._psycopg.Float4Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Float4Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Float4Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Float4Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float4Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Float4Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Float4Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_FloatBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_FloatBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_FloatBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_FloatBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17FloatBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_FloatBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_FloatBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper_spec = {
  "psycopg_c._psycopg.FloatBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""FloatBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_FloatBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_FloatBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_FloatBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Float4BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Float4BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper_spec = {
  "psycopg_c._psycopg.Float4BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Float4BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Float4BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_FloatLoader __pyx_vtable_9psycopg_c_8_psycopg_FloatLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_FloatLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_FloatLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_FloatLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11FloatLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_FloatLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_FloatLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_FloatLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_FloatLoader_spec = {
  "psycopg_c._psycopg.FloatLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_FloatLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_FloatLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""FloatLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_FloatLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_FloatLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_FloatLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float4BinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Float4BinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float4BinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Float4BinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader_spec = {
  "psycopg_c._psycopg.Float4BinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Float4BinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float4BinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Float4BinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Float4BinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_Float8BinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_Float8BinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_Float8BinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_Float8BinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_Float8BinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_18Float8BinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_Float8BinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_Float8BinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader_spec = {
  "psycopg_c._psycopg.Float8BinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""Float8BinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_Float8BinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_Float8BinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_Float8BinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DecimalDumper __pyx_vtable_9psycopg_c_8_psycopg_DecimalDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DecimalDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DecimalDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DecimalDumper[] = {
  {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_1quote, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13DecimalDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DecimalDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DecimalDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DecimalDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DecimalDumper_spec = {
  "psycopg_c._psycopg.DecimalDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DecimalDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DecimalDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DecimalDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DecimalDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DecimalDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DecimalDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericLoader __pyx_vtable_9psycopg_c_8_psycopg_NumericLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_NumericLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NumericLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NumericLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NumericLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NumericLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NumericLoader_spec = {
  "psycopg_c._psycopg.NumericLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NumericLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NumericLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NumericLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NumericLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NumericLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NumericBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NumericBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader_spec = {
  "psycopg_c._psycopg.NumericBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NumericBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NumericBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_DecimalBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_DecimalBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_DecimalBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_DecimalBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_DecimalBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19DecimalBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_DecimalBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_DecimalBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper_spec = {
  "psycopg_c._psycopg.DecimalBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""DecimalBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_DecimalBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_DecimalBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_DecimalBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__MixedNumericDumper __pyx_vtable_9psycopg_c_8_psycopg__MixedNumericDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__MixedNumericDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__MixedNumericDumper;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__MixedNumericDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19_MixedNumericDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__MixedNumericDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__MixedNumericDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper_spec = {
  "psycopg_c._psycopg._MixedNumericDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_MixedNumericDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__MixedNumericDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__MixedNumericDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__MixedNumericDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericDumper __pyx_vtable_9psycopg_c_8_psycopg_NumericDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__MixedNumericDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NumericDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NumericDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NumericDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NumericDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NumericDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NumericDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NumericDumper_spec = {
  "psycopg_c._psycopg.NumericDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NumericDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NumericDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NumericDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NumericDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NumericDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NumericBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__MixedNumericDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NumericBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NumericBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NumericBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper_spec = {
  "psycopg_c._psycopg.NumericBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NumericBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NumericBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NumericBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NumericBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolDumper __pyx_vtable_9psycopg_c_8_psycopg_BoolDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_BoolDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_BoolDumper[] = {
  {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_1quote, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_BoolDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_BoolDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_BoolDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_BoolDumper_spec = {
  "psycopg_c._psycopg.BoolDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_BoolDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_BoolDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""BoolDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_BoolDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_BoolDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_BoolBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_BoolBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper_spec = {
  "psycopg_c._psycopg.BoolBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""BoolBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_BoolBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolLoader __pyx_vtable_9psycopg_c_8_psycopg_BoolLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_BoolLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_BoolLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10BoolLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_BoolLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_BoolLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_BoolLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_BoolLoader_spec = {
  "psycopg_c._psycopg.BoolLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_BoolLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_BoolLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""BoolLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_BoolLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_BoolLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BoolBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_BoolBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16BoolBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_BoolBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader_spec = {
  "psycopg_c._psycopg.BoolBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""BoolBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BoolBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_BoolBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_BoolBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt16Dumper __pyx_vtable_9psycopg_c_8_psycopg_NPInt16Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt16Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPInt16Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt16Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPInt16Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPInt16Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper_spec = {
  "psycopg_c._psycopg.NPInt16Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPInt16Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPInt16Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPInt16Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt32Dumper __pyx_vtable_9psycopg_c_8_psycopg_NPInt32Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt32Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPInt32Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt32Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPInt32Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPInt32Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper_spec = {
  "psycopg_c._psycopg.NPInt32Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPInt32Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPInt32Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPInt32Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt64Dumper __pyx_vtable_9psycopg_c_8_psycopg_NPInt64Dumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt64Dumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64Dumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPInt64Dumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13NPInt64Dumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPInt64Dumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPInt64Dumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper_spec = {
  "psycopg_c._psycopg.NPInt64Dumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPInt64Dumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64Dumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPInt64Dumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPInt64Dumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPNumericDumper __pyx_vtable_9psycopg_c_8_psycopg_NPNumericDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPNumericDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPNumericDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15NPNumericDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPNumericDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPNumericDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPNumericDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPNumericDumper_spec = {
  "psycopg_c._psycopg.NPNumericDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPNumericDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPNumericDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPNumericDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPNumericDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPNumericDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt16BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_NPInt16BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt16BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPInt16BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPInt16BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPInt16BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper_spec = {
  "psycopg_c._psycopg.NPInt16BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPInt16BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt16BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPInt16BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPInt16BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt32BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_NPInt32BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt32BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPInt32BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPInt32BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPInt32BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper_spec = {
  "psycopg_c._psycopg.NPInt32BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPInt32BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt32BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPInt32BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPInt32BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPInt64BinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_NPInt64BinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPInt64BinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64BinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPInt64BinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPInt64BinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPInt64BinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper_spec = {
  "psycopg_c._psycopg.NPInt64BinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPInt64BinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPInt64BinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPInt64BinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPInt64BinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_NPNumericBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_NPNumericBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_NPNumericBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__IntDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_NPNumericBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_NPNumericBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_NPNumericBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper_spec = {
  "psycopg_c._psycopg.NPNumericBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""NPNumericBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_NPNumericBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_NPNumericBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_NPNumericBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__BaseStrDumper __pyx_vtable_9psycopg_c_8_psycopg__BaseStrDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__BaseStrDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__BaseStrDumper;
  p->_bytes_encoding = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *p = (struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_bytes_encoding);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper(o);
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__BaseStrDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_14_BaseStrDumper_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__BaseStrDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__BaseStrDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__BaseStrDumper_spec = {
  "psycopg_c._psycopg._BaseStrDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__BaseStrDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__BaseStrDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_BaseStrDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__BaseStrDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg__StrBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseStrDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__StrBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16_StrBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__StrBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper_spec = {
  "psycopg_c._psycopg._StrBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_StrBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__StrBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__StrBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_15StrBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper_spec = {
  "psycopg_c._psycopg.StrBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumperVarchar __pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperVarchar(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumperVarchar[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumperVarchar},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperVarchar},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar_spec = {
  "psycopg_c._psycopg.StrBinaryDumperVarchar",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrBinaryDumperVarchar", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperVarchar), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumperVarchar, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperVarchar, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrBinaryDumperName __pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumperName;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperName(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrBinaryDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperName;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumperName[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_19StrBinaryDumperName_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumperName},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperName},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName_spec = {
  "psycopg_c._psycopg.StrBinaryDumperName",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrBinaryDumperName", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrBinaryDumperName), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrBinaryDumperName, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrBinaryDumperName, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__StrDumper __pyx_vtable_9psycopg_c_8_psycopg__StrDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__StrDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__BaseStrDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__StrDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10_StrDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__StrDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__StrDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__StrDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__StrDumper_spec = {
  "psycopg_c._psycopg._StrDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__StrDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__StrDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_StrDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__StrDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__StrDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__StrDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumper __pyx_vtable_9psycopg_c_8_psycopg_StrDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_9StrDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrDumper_spec = {
  "psycopg_c._psycopg.StrDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperVarchar __pyx_vtable_9psycopg_c_8_psycopg_StrDumperVarchar;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperVarchar(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperVarchar;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrDumperVarchar[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperVarchar_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrDumperVarchar},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperVarchar},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar_spec = {
  "psycopg_c._psycopg.StrDumperVarchar",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrDumperVarchar", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperVarchar), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrDumperVarchar, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrDumperVarchar, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperName __pyx_vtable_9psycopg_c_8_psycopg_StrDumperName;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperName(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperName;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrDumperName[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_13StrDumperName_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrDumperName_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrDumperName},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperName},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrDumperName_spec = {
  "psycopg_c._psycopg.StrDumperName",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrDumperName_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrDumperName = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrDumperName", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperName), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrDumperName, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrDumperName, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_StrDumperUnknown __pyx_vtable_9psycopg_c_8_psycopg_StrDumperUnknown;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperUnknown(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__StrDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown *)o);
  p->__pyx_base.__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperUnknown;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_StrDumperUnknown[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16StrDumperUnknown_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_StrDumperUnknown},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_StrDumperUnknown},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown_spec = {
  "psycopg_c._psycopg.StrDumperUnknown",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""StrDumperUnknown", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_StrDumperUnknown), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__BaseStrDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_StrDumperUnknown, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_StrDumperUnknown, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__TextLoader __pyx_vtable_9psycopg_c_8_psycopg__TextLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__TextLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg__TextLoader;
  p->_bytes_encoding = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_bytes_encoding);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader(o);
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__TextLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_TextLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__TextLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__TextLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__TextLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__TextLoader_spec = {
  "psycopg_c._psycopg._TextLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__TextLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__TextLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_TextLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__TextLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__TextLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__TextLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TextLoader __pyx_vtable_9psycopg_c_8_psycopg_TextLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TextLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__TextLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TextLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TextLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10TextLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TextLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TextLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TextLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TextLoader_spec = {
  "psycopg_c._psycopg.TextLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TextLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TextLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TextLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TextLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TextLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TextLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_TextBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_TextBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_TextBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__TextLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_TextBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_TextBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16TextBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_TextBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_TextBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader_spec = {
  "psycopg_c._psycopg.TextBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""TextBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_TextBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__TextLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_TextBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_TextBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BytesDumper __pyx_vtable_9psycopg_c_8_psycopg_BytesDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BytesDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_BytesDumper;
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_1__cinit__(o, __pyx_mstate_global->__pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_BytesDumper[] = {
  {"quote", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_3quote, METH_O, 0},
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_5__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11BytesDumper_7__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_BytesDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_BytesDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_BytesDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_BytesDumper_spec = {
  "psycopg_c._psycopg.BytesDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_BytesDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_BytesDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""BytesDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BytesDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_BytesDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_BytesDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_BytesBinaryDumper __pyx_vtable_9psycopg_c_8_psycopg_BytesBinaryDumper;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_BytesBinaryDumper(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CDumper(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CDumper*)__pyx_vtabptr_9psycopg_c_8_psycopg_BytesBinaryDumper;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_BytesBinaryDumper[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17BytesBinaryDumper_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CDumper},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_BytesBinaryDumper},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_BytesBinaryDumper},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper_spec = {
  "psycopg_c._psycopg.BytesBinaryDumper",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""BytesBinaryDumper", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_BytesBinaryDumper), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CDumper, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CDumper, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CDumper, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_BytesBinaryDumper, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_BytesBinaryDumper, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ByteaLoader __pyx_vtable_9psycopg_c_8_psycopg_ByteaLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ByteaLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_ByteaLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_ByteaLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11ByteaLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_ByteaLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_ByteaLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_ByteaLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_ByteaLoader_spec = {
  "psycopg_c._psycopg.ByteaLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_ByteaLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_ByteaLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""ByteaLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ByteaLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_ByteaLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_ByteaLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_ByteaBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_ByteaBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_ByteaBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_ByteaBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_ByteaBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_17ByteaBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg_CLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_ByteaBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_ByteaBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader_spec = {
  "psycopg_c._psycopg.ByteaBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""ByteaBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_ByteaBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_ByteaBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_ByteaBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg__UUIDLoader __pyx_vtable_9psycopg_c_8_psycopg__UUIDLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg__UUIDLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg_CLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg__UUIDLoader;
  p->_object_new = Py_None; Py_INCREF(Py_None);
  p->_uuid_type = Py_None; Py_INCREF(Py_None);
  p->_safeuuid_unknown = Py_None; Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->_object_new);
  Py_CLEAR(p->_uuid_type);
  Py_CLEAR(p->_safeuuid_unknown);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_9psycopg_c_8_psycopg_CLoader(o);
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)o;
  e = __pyx_tp_traverse_9psycopg_c_8_psycopg_CLoader(o, v, a); if (e) return e;
  if (p->_object_new) {
    e = (*v)(p->_object_new, a); if (e) return e;
  }
  if (p->_uuid_type) {
    e = (*v)(p->_uuid_type, a); if (e) return e;
  }
  if (p->_safeuuid_unknown) {
    e = (*v)(p->_safeuuid_unknown, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *p = (struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *)o;
  __pyx_tp_clear_9psycopg_c_8_psycopg_CLoader(o);
  tmp = ((PyObject*)p->_object_new);
  p->_object_new = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_uuid_type);
  p->_uuid_type = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_safeuuid_unknown);
  p->_safeuuid_unknown = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg__UUIDLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_3__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_11_UUIDLoader_5__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg__UUIDLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg__UUIDLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg__UUIDLoader_spec = {
  "psycopg_c._psycopg._UUIDLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg__UUIDLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg__UUIDLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""_UUIDLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg__UUIDLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg__UUIDLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDLoader __pyx_vtable_9psycopg_c_8_psycopg_UUIDLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_UUIDLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__UUIDLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_UUIDLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_UUIDLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_10UUIDLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_UUIDLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_UUIDLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_UUIDLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_UUIDLoader_spec = {
  "psycopg_c._psycopg.UUIDLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_UUIDLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_UUIDLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""UUIDLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_UUIDLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_UUIDLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_9psycopg_c_8_psycopg_UUIDBinaryLoader __pyx_vtable_9psycopg_c_8_psycopg_UUIDBinaryLoader;

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg_UUIDBinaryLoader(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *p;
  PyObject *o = __pyx_tp_new_9psycopg_c_8_psycopg__UUIDLoader(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader *)o);
  p->__pyx_base.__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_9psycopg_c_8_psycopg_CLoader*)__pyx_vtabptr_9psycopg_c_8_psycopg_UUIDBinaryLoader;
  return o;
}

static PyMethodDef __pyx_methods_9psycopg_c_8_psycopg_UUIDBinaryLoader[] = {
  {"__reduce_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_1__reduce_cython__, METH_NOARGS, 0},
  {"__setstate_cython__", (PyCFunction)__pyx_pw_9psycopg_c_8_psycopg_16UUIDBinaryLoader_3__setstate_cython__, METH_O, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader},
  {Py_tp_methods, (void *)__pyx_methods_9psycopg_c_8_psycopg_UUIDBinaryLoader},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg_UUIDBinaryLoader},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader_spec = {
  "psycopg_c._psycopg.UUIDBinaryLoader",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""UUIDBinaryLoader", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg_UUIDBinaryLoader), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg__UUIDLoader, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg__UUIDLoader, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg__UUIDLoader, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_9psycopg_c_8_psycopg_UUIDBinaryLoader, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg_UUIDBinaryLoader, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct__connect(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct__connect > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct__connect[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct__connect];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct__connect(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct__connect) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_conn);
  Py_CLEAR(p->__pyx_v_conninfo);
  Py_CLEAR(p->__pyx_v_encoding);
  Py_CLEAR(p->__pyx_v_ready);
  Py_CLEAR(p->__pyx_v_wait);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct__connect < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct__connect[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct__connect++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct__connect(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_conn) {
    e = (*v)(((PyObject *)p->__pyx_v_conn), a); if (e) return e;
  }
  if (p->__pyx_v_encoding) {
    e = (*v)(p->__pyx_v_encoding, a); if (e) return e;
  }
  if (p->__pyx_v_ready) {
    e = (*v)(p->__pyx_v_ready, a); if (e) return e;
  }
  if (p->__pyx_v_wait) {
    e = (*v)(p->__pyx_v_wait, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct__connect},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct__connect},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct__connect},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct__connect",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct__connect", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct__connect), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct__connect, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct__connect, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct__connect, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_cancel_conn);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_cancel_conn) {
    e = (*v)(((PyObject *)p->__pyx_v_cancel_conn), a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_1_cancel",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_1_cancel", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pgconn);
  Py_CLEAR(p->__pyx_v_rv);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_pgconn) {
    e = (*v)(((PyObject *)p->__pyx_v_pgconn), a); if (e) return e;
  }
  if (p->__pyx_v_rv) {
    e = (*v)(p->__pyx_v_rv, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_2_execute",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_2_execute", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_3_send(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_3_send > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_3_send[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_3_send];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_3_send(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_3_send) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pgconn);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_3_send < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_3_send[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_3_send++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_3_send(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_pgconn) {
    e = (*v)(((PyObject *)p->__pyx_v_pgconn), a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_3_send},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_3_send},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_3_send},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_3_send",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_3_send", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_3_send), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_3_send, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_3_send, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_3_send, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_genexpr);
  Py_CLEAR(p->__pyx_v_pgconn);
  Py_CLEAR(p->__pyx_v_result);
  Py_CLEAR(p->__pyx_v_results);
  Py_CLEAR(p->__pyx_t_0);
  Py_CLEAR(p->__pyx_t_1);
  Py_CLEAR(p->__pyx_t_2);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_genexpr) {
    e = (*v)(p->__pyx_v_genexpr, a); if (e) return e;
  }
  if (p->__pyx_v_pgconn) {
    e = (*v)(((PyObject *)p->__pyx_v_pgconn), a); if (e) return e;
  }
  if (p->__pyx_v_result) {
    e = (*v)(((PyObject *)p->__pyx_v_result), a); if (e) return e;
  }
  if (p->__pyx_v_results) {
    e = (*v)(p->__pyx_v_results, a); if (e) return e;
  }
  if (p->__pyx_t_0) {
    e = (*v)(p->__pyx_t_0, a); if (e) return e;
  }
  if (p->__pyx_t_1) {
    e = (*v)(p->__pyx_t_1, a); if (e) return e;
  }
  if (p->__pyx_t_2) {
    e = (*v)(p->__pyx_t_2, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_4_fetch_many",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_4_fetch_many", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_outer_scope);
  Py_CLEAR(p->__pyx_genexpr_arg_0);
  Py_CLEAR(p->__pyx_v_res);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_outer_scope) {
    e = (*v)(((PyObject *)p->__pyx_outer_scope), a); if (e) return e;
  }
  if (p->__pyx_genexpr_arg_0) {
    e = (*v)(p->__pyx_genexpr_arg_0, a); if (e) return e;
  }
  if (p->__pyx_v_res) {
    e = (*v)(p->__pyx_v_res, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_5_genexpr",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_5_genexpr", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pgconn);
  Py_CLEAR(p->__pyx_v_ready);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_pgconn) {
    e = (*v)(((PyObject *)p->__pyx_v_pgconn), a); if (e) return e;
  }
  if (p->__pyx_v_ready) {
    e = (*v)(p->__pyx_v_ready, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_6_fetch",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_6_fetch", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_commands);
  Py_CLEAR(p->__pyx_v_pgconn);
  Py_CLEAR(p->__pyx_v_r);
  Py_CLEAR(p->__pyx_v_ready);
  Py_CLEAR(p->__pyx_v_res);
  Py_CLEAR(p->__pyx_v_results);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_commands) {
    e = (*v)(p->__pyx_v_commands, a); if (e) return e;
  }
  if (p->__pyx_v_pgconn) {
    e = (*v)(((PyObject *)p->__pyx_v_pgconn), a); if (e) return e;
  }
  if (p->__pyx_v_r) {
    e = (*v)(((PyObject *)p->__pyx_v_r), a); if (e) return e;
  }
  if (p->__pyx_v_ready) {
    e = (*v)(p->__pyx_v_ready, a); if (e) return e;
  }
  if (p->__pyx_v_res) {
    e = (*v)(p->__pyx_v_res, a); if (e) return e;
  }
  if (p->__pyx_v_results) {
    e = (*v)(p->__pyx_v_results, a); if (e) return e;
  }
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_7_pipeline_communicate",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_7_pipeline_communicate", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error > 0) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(t, __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error))))
  {
    o = (PyObject*)__pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error[--__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error];
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(Py_TYPE(o));
    #endif
    memset(o, 0, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error));
    #if CYTHON_COMPILING_IN_LIMITED_API
    (void) PyObject_Init(o, t);
    #else
    (void) PyObject_INIT(o, t);
    #endif
    PyObject_GC_Track(o);
  } else
  #endif
  {
    o = __Pyx_AllocateExtensionType(t, 1);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(PyObject *o) {
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely(__Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->__pyx_v_pgconn);
  #if CYTHON_USE_FREELISTS
  if (likely((int)(__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error < 8) & __PYX_CHECK_FINAL_TYPE_FOR_FREELISTS(Py_TYPE(o), __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error))))
  {
    __pyx_mstate_global->__pyx_freelist_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error[__pyx_mstate_global->__pyx_freecount_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error++] = ((struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *)o);
  } else
  #endif
  {
    PyTypeObject *tp = Py_TYPE(o);
    #if CYTHON_USE_TYPE_SLOTS
    (*tp->tp_free)(o);
    #else
    {
      freefunc tp_free = (freefunc)PyType_GetSlot(tp, Py_tp_free);
      if (tp_free) tp_free(o);
    }
    #endif
    #if CYTHON_USE_TYPE_SPECS
    Py_DECREF(tp);
    #endif
  }
}

static int __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *)o;
  {
    e = __Pyx_call_type_traverse(o, 1, v, a);
    if (e) return e;
  }
  if (p->__pyx_v_pgconn) {
    e = (*v)(((PyObject *)p->__pyx_v_pgconn), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *p = (struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error *)o;
  tmp = ((PyObject*)p->__pyx_v_pgconn);
  p->__pyx_v_pgconn = ((struct __pyx_obj_9psycopg_c_2pq_PGconn *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error},
  {Py_tp_clear, (void *)__pyx_tp_clear_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error},
  {Py_tp_new, (void *)__pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error},
  {0, 0},
};
static PyType_Spec __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error_spec = {
  "psycopg_c._psycopg.__pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error",
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC,
  __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error_slots,
};
#else

static PyTypeObject __pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error = {
  PyVarObject_HEAD_INIT(0, 0)
  "psycopg_c._psycopg.""__pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error", /*tp_name*/
  sizeof(struct __pyx_obj_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, /*tp_dealloc*/
  0, /*tp_vectorcall_offset*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  0, /*tp_as_async*/
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, /*tp_traverse*/
  __pyx_tp_clear_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #if !CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if PY_VERSION_HEX >= 0x030d00A4
  0, /*tp_versions_used*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
/* #### Code section: initfunc_declarations ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate); /*proto*/
/* #### Code section: init_module ### */

static int __Pyx_modinit_global_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_v_9psycopg_c_8_psycopg_WAIT_W = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_WAIT_R = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_WAIT_RW = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_PY_READY_NONE = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_PY_READY_R = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_PY_READY_W = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_PY_READY_RW = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_date_toordinal = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_date_fromordinal = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_datetime_astimezone = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_time_utcoffset = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_timedelta_total_seconds = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_timezone_utc = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg__month_abbr = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg__timezones = Py_None; Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg__special_float = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg__special_decimal = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg__decimal_special = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_v_9psycopg_c_8_psycopg__contexts = ((PyObject*)Py_None); Py_INCREF(Py_None);
  __pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i = Py_None; Py_INCREF(Py_None);
  __pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_9psycopg_c_8_psycopg_CDumper = &__pyx_vtable_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_CDumper.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_7CDumper_cdump;
  __pyx_vtable_9psycopg_c_8_psycopg_CDumper.get_key = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_7CDumper_get_key;
  __pyx_vtable_9psycopg_c_8_psycopg_CDumper.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_7CDumper_upgrade;
  __pyx_vtable_9psycopg_c_8_psycopg_CDumper.ensure_size = (char *(*)(PyObject *, Py_ssize_t, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_7CDumper_ensure_size;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_CDumper_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper)) __PYX_ERR(5, 26, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_CDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper) < (0)) __PYX_ERR(5, 26, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper = &__pyx_type_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper) < (0)) __PYX_ERR(5, 26, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_CDumper) < (0)) __PYX_ERR(5, 26, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper) < (0)) __PYX_ERR(5, 26, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper) < (0)) __PYX_ERR(5, 26, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CDumper) < (0)) __PYX_ERR(5, 26, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_CLoader = &__pyx_vtable_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_CLoader.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_7CLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_CLoader_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader)) __PYX_ERR(5, 144, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_CLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader) < (0)) __PYX_ERR(5, 144, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader = &__pyx_type_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader) < (0)) __PYX_ERR(5, 144, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_CLoader) < (0)) __PYX_ERR(5, 144, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader) < (0)) __PYX_ERR(5, 144, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader) < (0)) __PYX_ERR(5, 144, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_CLoader) < (0)) __PYX_ERR(5, 144, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__CRecursiveLoader = &__pyx_vtable_9psycopg_c_8_psycopg__CRecursiveLoader;
  __pyx_vtable_9psycopg_c_8_psycopg__CRecursiveLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader)) __PYX_ERR(5, 164, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader) < (0)) __PYX_ERR(5, 164, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader = &__pyx_type_9psycopg_c_8_psycopg__CRecursiveLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader) < (0)) __PYX_ERR(5, 164, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader, __pyx_vtabptr_9psycopg_c_8_psycopg__CRecursiveLoader) < (0)) __PYX_ERR(5, 164, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader) < (0)) __PYX_ERR(5, 164, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_CRecursiveLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader) < (0)) __PYX_ERR(5, 164, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader) < (0)) __PYX_ERR(5, 164, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_RowLoader_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader)) __PYX_ERR(9, 46, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_RowLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader) < (0)) __PYX_ERR(9, 46, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader = &__pyx_type_9psycopg_c_8_psycopg_RowLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader) < (0)) __PYX_ERR(9, 46, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_RowLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader) < (0)) __PYX_ERR(9, 46, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader) < (0)) __PYX_ERR(9, 46, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_RowDumper_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper)) __PYX_ERR(9, 53, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_RowDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper) < (0)) __PYX_ERR(9, 53, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper = &__pyx_type_9psycopg_c_8_psycopg_RowDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper) < (0)) __PYX_ERR(9, 53, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_RowDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper) < (0)) __PYX_ERR(9, 53, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper) < (0)) __PYX_ERR(9, 53, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Transformer = &__pyx_vtable_9psycopg_c_8_psycopg_Transformer;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer.set_pgresult = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, struct __pyx_obj_9psycopg_c_2pq_PGresult *, int __pyx_skip_dispatch, struct __pyx_opt_args_9psycopg_c_8_psycopg_11Transformer_set_pgresult *__pyx_optional_args))__pyx_f_9psycopg_c_8_psycopg_11Transformer_set_pgresult;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer.as_literal = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_11Transformer_as_literal;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer.get_row_dumper = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *))__pyx_f_9psycopg_c_8_psycopg_11Transformer_get_row_dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer.get_dumper_by_oid = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *))__pyx_f_9psycopg_c_8_psycopg_11Transformer_get_dumper_by_oid;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer.dump_sequence = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_11Transformer_dump_sequence;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer.load_sequence = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_11Transformer_load_sequence;
  __pyx_vtable_9psycopg_c_8_psycopg_Transformer._c_get_loader = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_Transformer *, PyObject *, PyObject *))__pyx_f_9psycopg_c_8_psycopg_11Transformer__c_get_loader;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Transformer_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer)) __PYX_ERR(9, 62, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Transformer_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer) < (0)) __PYX_ERR(9, 62, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer = &__pyx_type_9psycopg_c_8_psycopg_Transformer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer) < (0)) __PYX_ERR(9, 62, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_vtabptr_9psycopg_c_8_psycopg_Transformer) < (0)) __PYX_ERR(9, 62, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer) < (0)) __PYX_ERR(9, 62, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Transformer, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer) < (0)) __PYX_ERR(9, 62, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Transformer) < (0)) __PYX_ERR(9, 62, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_ArrayLoader = &__pyx_vtable_9psycopg_c_8_psycopg_ArrayLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ArrayLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__CRecursiveLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ArrayLoader.__pyx_base.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_11ArrayLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_ArrayLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader)) __PYX_ERR(11, 31, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_ArrayLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader) < (0)) __PYX_ERR(11, 31, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader = &__pyx_type_9psycopg_c_8_psycopg_ArrayLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader) < (0)) __PYX_ERR(11, 31, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_ArrayLoader) < (0)) __PYX_ERR(11, 31, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader) < (0)) __PYX_ERR(11, 31, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ArrayLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader) < (0)) __PYX_ERR(11, 31, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader) < (0)) __PYX_ERR(11, 31, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_ArrayBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_ArrayBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ArrayBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__CRecursiveLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ArrayBinaryLoader.__pyx_base.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_17ArrayBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 60, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader)) __PYX_ERR(11, 60, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader) < (0)) __PYX_ERR(11, 60, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_ArrayBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__CRecursiveLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader) < (0)) __PYX_ERR(11, 60, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_ArrayBinaryLoader) < (0)) __PYX_ERR(11, 60, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader) < (0)) __PYX_ERR(11, 60, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ArrayBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader) < (0)) __PYX_ERR(11, 60, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader) < (0)) __PYX_ERR(11, 60, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DateDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DateDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DateDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DateDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_10DateDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DateDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper)) __PYX_ERR(1, 68, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DateDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper) < (0)) __PYX_ERR(1, 68, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper = &__pyx_type_9psycopg_c_8_psycopg_DateDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper) < (0)) __PYX_ERR(1, 68, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DateDumper) < (0)) __PYX_ERR(1, 68, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper) < (0)) __PYX_ERR(1, 68, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DateDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper) < (0)) __PYX_ERR(1, 68, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper) < (0)) __PYX_ERR(1, 68, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DateBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DateBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DateBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_16DateBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper)) __PYX_ERR(1, 88, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper) < (0)) __PYX_ERR(1, 88, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_DateBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper) < (0)) __PYX_ERR(1, 88, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryDumper) < (0)) __PYX_ERR(1, 88, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper) < (0)) __PYX_ERR(1, 88, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DateBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper) < (0)) __PYX_ERR(1, 88, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper) < (0)) __PYX_ERR(1, 88, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper = &__pyx_vtable_9psycopg_c_8_psycopg__BaseTimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeDumper.__pyx_base.get_key = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_get_key;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeDumper.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper_upgrade;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeDumper._get_offset = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg__BaseTimeDumper *, PyObject *))__pyx_f_9psycopg_c_8_psycopg_15_BaseTimeDumper__get_offset;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper)) __PYX_ERR(1, 104, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper) < (0)) __PYX_ERR(1, 104, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper = &__pyx_type_9psycopg_c_8_psycopg__BaseTimeDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper) < (0)) __PYX_ERR(1, 104, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper) < (0)) __PYX_ERR(1, 104, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper) < (0)) __PYX_ERR(1, 104, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseTimeDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper) < (0)) __PYX_ERR(1, 104, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper) < (0)) __PYX_ERR(1, 104, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeTextDumper = &__pyx_vtable_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeTextDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimeTextDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 126, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper)) __PYX_ERR(1, 126, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper) < (0)) __PYX_ERR(1, 126, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper = &__pyx_type_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper) < (0)) __PYX_ERR(1, 126, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeTextDumper) < (0)) __PYX_ERR(1, 126, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper) < (0)) __PYX_ERR(1, 126, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseTimeTextDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper) < (0)) __PYX_ERR(1, 126, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper) < (0)) __PYX_ERR(1, 126, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimeDumper = &__pyx_vtable_9psycopg_c_8_psycopg_TimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeDumper.__pyx_base.__pyx_base.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_10TimeDumper_upgrade;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 142, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimeDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper)) __PYX_ERR(1, 142, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimeDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper) < (0)) __PYX_ERR(1, 142, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper = &__pyx_type_9psycopg_c_8_psycopg_TimeDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper) < (0)) __PYX_ERR(1, 142, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_TimeDumper) < (0)) __PYX_ERR(1, 142, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper) < (0)) __PYX_ERR(1, 142, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimeDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper) < (0)) __PYX_ERR(1, 142, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper) < (0)) __PYX_ERR(1, 142, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzDumper = &__pyx_vtable_9psycopg_c_8_psycopg_TimeTzDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeTzDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeTzDumper.__pyx_base.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_12TimeTzDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimeTzDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper)) __PYX_ERR(1, 154, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimeTzDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper) < (0)) __PYX_ERR(1, 154, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper = &__pyx_type_9psycopg_c_8_psycopg_TimeTzDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper) < (0)) __PYX_ERR(1, 154, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzDumper) < (0)) __PYX_ERR(1, 154, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper) < (0)) __PYX_ERR(1, 154, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimeTzDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper) < (0)) __PYX_ERR(1, 154, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper) < (0)) __PYX_ERR(1, 154, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_cdump;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryDumper.__pyx_base.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryDumper_upgrade;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper)) __PYX_ERR(1, 164, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper) < (0)) __PYX_ERR(1, 164, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_TimeBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper) < (0)) __PYX_ERR(1, 164, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryDumper) < (0)) __PYX_ERR(1, 164, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper) < (0)) __PYX_ERR(1, 164, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimeBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper) < (0)) __PYX_ERR(1, 164, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper) < (0)) __PYX_ERR(1, 164, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_TimeTzBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeTzBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeTzBinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper)) __PYX_ERR(1, 188, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper) < (0)) __PYX_ERR(1, 188, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_TimeTzBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper) < (0)) __PYX_ERR(1, 188, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_TimeTzBinaryDumper) < (0)) __PYX_ERR(1, 188, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper) < (0)) __PYX_ERR(1, 188, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimeTzBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper) < (0)) __PYX_ERR(1, 188, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper) < (0)) __PYX_ERR(1, 188, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper = &__pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeDumper.__pyx_base.get_key = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_get_key;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeDumper.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_upgrade;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper)) __PYX_ERR(1, 212, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper) < (0)) __PYX_ERR(1, 212, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper = &__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper) < (0)) __PYX_ERR(1, 212, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper) < (0)) __PYX_ERR(1, 212, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper) < (0)) __PYX_ERR(1, 212, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseDatetimeDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper) < (0)) __PYX_ERR(1, 212, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper) < (0)) __PYX_ERR(1, 212, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeTextDumper = &__pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeTextDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseDatetimeTextDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper)) __PYX_ERR(1, 226, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper) < (0)) __PYX_ERR(1, 226, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper = &__pyx_type_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper) < (0)) __PYX_ERR(1, 226, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeTextDumper) < (0)) __PYX_ERR(1, 226, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper) < (0)) __PYX_ERR(1, 226, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseDatetimeTextDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper) < (0)) __PYX_ERR(1, 226, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper) < (0)) __PYX_ERR(1, 226, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DatetimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeDumper.__pyx_base.__pyx_base.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_14DatetimeDumper_upgrade;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DatetimeDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper)) __PYX_ERR(1, 244, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DatetimeDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper) < (0)) __PYX_ERR(1, 244, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper = &__pyx_type_9psycopg_c_8_psycopg_DatetimeDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper) < (0)) __PYX_ERR(1, 244, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeDumper) < (0)) __PYX_ERR(1, 244, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper) < (0)) __PYX_ERR(1, 244, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DatetimeDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper) < (0)) __PYX_ERR(1, 244, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper) < (0)) __PYX_ERR(1, 244, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper)) __PYX_ERR(1, 256, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper) < (0)) __PYX_ERR(1, 256, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper = &__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper) < (0)) __PYX_ERR(1, 256, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzDumper) < (0)) __PYX_ERR(1, 256, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper) < (0)) __PYX_ERR(1, 256, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DatetimeNoTzDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper) < (0)) __PYX_ERR(1, 256, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper) < (0)) __PYX_ERR(1, 256, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DatetimeBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeBinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_cdump;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeBinaryDumper.__pyx_base.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_upgrade;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 262, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper)) __PYX_ERR(1, 262, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper) < (0)) __PYX_ERR(1, 262, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_DatetimeBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper) < (0)) __PYX_ERR(1, 262, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeBinaryDumper) < (0)) __PYX_ERR(1, 262, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper) < (0)) __PYX_ERR(1, 262, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DatetimeBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper) < (0)) __PYX_ERR(1, 262, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper) < (0)) __PYX_ERR(1, 262, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper)) __PYX_ERR(1, 287, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper) < (0)) __PYX_ERR(1, 287, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper) < (0)) __PYX_ERR(1, 287, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper) < (0)) __PYX_ERR(1, 287, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper) < (0)) __PYX_ERR(1, 287, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DatetimeNoTzBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper) < (0)) __PYX_ERR(1, 287, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper) < (0)) __PYX_ERR(1, 287, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaDumper = &__pyx_vtable_9psycopg_c_8_psycopg_TimedeltaDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimedeltaDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimedeltaDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_15TimedeltaDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper)) __PYX_ERR(1, 306, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper) < (0)) __PYX_ERR(1, 306, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper = &__pyx_type_9psycopg_c_8_psycopg_TimedeltaDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper) < (0)) __PYX_ERR(1, 306, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaDumper) < (0)) __PYX_ERR(1, 306, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper) < (0)) __PYX_ERR(1, 306, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimedeltaDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper) < (0)) __PYX_ERR(1, 306, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper) < (0)) __PYX_ERR(1, 306, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimedeltaBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_TimedeltaBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper)) __PYX_ERR(1, 343, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper) < (0)) __PYX_ERR(1, 343, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_TimedeltaBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper) < (0)) __PYX_ERR(1, 343, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_TimedeltaBinaryDumper) < (0)) __PYX_ERR(1, 343, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper) < (0)) __PYX_ERR(1, 343, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimedeltaBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper) < (0)) __PYX_ERR(1, 343, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper) < (0)) __PYX_ERR(1, 343, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DateLoader = &__pyx_vtable_9psycopg_c_8_psycopg_DateLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_DateLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_DateLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_10DateLoader_cload;
  __pyx_vtable_9psycopg_c_8_psycopg_DateLoader._error_date = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_DateLoader *, char const *, PyObject *))__pyx_f_9psycopg_c_8_psycopg_10DateLoader__error_date;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 368, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DateLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader)) __PYX_ERR(1, 368, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DateLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader) < (0)) __PYX_ERR(1, 368, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader = &__pyx_type_9psycopg_c_8_psycopg_DateLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader) < (0)) __PYX_ERR(1, 368, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_DateLoader) < (0)) __PYX_ERR(1, 368, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader) < (0)) __PYX_ERR(1, 368, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DateLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader) < (0)) __PYX_ERR(1, 368, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader) < (0)) __PYX_ERR(1, 368, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_DateBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_DateBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_DateBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16DateBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 422, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader)) __PYX_ERR(1, 422, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader) < (0)) __PYX_ERR(1, 422, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_DateBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader) < (0)) __PYX_ERR(1, 422, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_DateBinaryLoader) < (0)) __PYX_ERR(1, 422, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader) < (0)) __PYX_ERR(1, 422, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DateBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader) < (0)) __PYX_ERR(1, 422, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader) < (0)) __PYX_ERR(1, 422, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimeLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimeLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_10TimeLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimeLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader)) __PYX_ERR(1, 442, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimeLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader) < (0)) __PYX_ERR(1, 442, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader = &__pyx_type_9psycopg_c_8_psycopg_TimeLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader) < (0)) __PYX_ERR(1, 442, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimeLoader) < (0)) __PYX_ERR(1, 442, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader) < (0)) __PYX_ERR(1, 442, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimeLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader) < (0)) __PYX_ERR(1, 442, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader) < (0)) __PYX_ERR(1, 442, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimeBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16TimeBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 472, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader)) __PYX_ERR(1, 472, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader) < (0)) __PYX_ERR(1, 472, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_TimeBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader) < (0)) __PYX_ERR(1, 472, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimeBinaryLoader) < (0)) __PYX_ERR(1, 472, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader) < (0)) __PYX_ERR(1, 472, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimeBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader) < (0)) __PYX_ERR(1, 472, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader) < (0)) __PYX_ERR(1, 472, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimetzLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimetzLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimetzLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimetzLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_12TimetzLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 501, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimetzLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader)) __PYX_ERR(1, 501, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimetzLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader) < (0)) __PYX_ERR(1, 501, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader = &__pyx_type_9psycopg_c_8_psycopg_TimetzLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader) < (0)) __PYX_ERR(1, 501, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimetzLoader) < (0)) __PYX_ERR(1, 501, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader) < (0)) __PYX_ERR(1, 501, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimetzLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader) < (0)) __PYX_ERR(1, 501, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader) < (0)) __PYX_ERR(1, 501, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimetzBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimetzBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimetzBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimetzBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_18TimetzBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 538, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader)) __PYX_ERR(1, 538, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader) < (0)) __PYX_ERR(1, 538, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_TimetzBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader) < (0)) __PYX_ERR(1, 538, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimetzBinaryLoader) < (0)) __PYX_ERR(1, 538, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader) < (0)) __PYX_ERR(1, 538, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimetzBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader) < (0)) __PYX_ERR(1, 538, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader) < (0)) __PYX_ERR(1, 538, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimestampLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimestampLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestampLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestampLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader_cload;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestampLoader._cload_pg = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_TimestampLoader *, char const *, char const *))__pyx_f_9psycopg_c_8_psycopg_15TimestampLoader__cload_pg;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimestampLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader)) __PYX_ERR(1, 573, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimestampLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader) < (0)) __PYX_ERR(1, 573, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader = &__pyx_type_9psycopg_c_8_psycopg_TimestampLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader) < (0)) __PYX_ERR(1, 573, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimestampLoader) < (0)) __PYX_ERR(1, 573, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader) < (0)) __PYX_ERR(1, 573, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimestampLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader) < (0)) __PYX_ERR(1, 573, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader) < (0)) __PYX_ERR(1, 573, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimestampBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimestampBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestampBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestampBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_21TimestampBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader)) __PYX_ERR(1, 677, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader) < (0)) __PYX_ERR(1, 677, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_TimestampBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader) < (0)) __PYX_ERR(1, 677, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimestampBinaryLoader) < (0)) __PYX_ERR(1, 677, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader) < (0)) __PYX_ERR(1, 677, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimestampBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader) < (0)) __PYX_ERR(1, 677, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader) < (0)) __PYX_ERR(1, 677, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimestamptzLoader = &__pyx_vtable_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseTimestamptzLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 714, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader)) __PYX_ERR(1, 714, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader) < (0)) __PYX_ERR(1, 714, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader = &__pyx_type_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader) < (0)) __PYX_ERR(1, 714, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader, __pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimestamptzLoader) < (0)) __PYX_ERR(1, 714, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader) < (0)) __PYX_ERR(1, 714, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseTimestamptzLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader) < (0)) __PYX_ERR(1, 714, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader) < (0)) __PYX_ERR(1, 714, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimestamptzLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzLoader.__pyx_base.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader_cload;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzLoader._cload_notimpl = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_TimestamptzLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_17TimestamptzLoader__cload_notimpl;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader)) __PYX_ERR(1, 721, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader) < (0)) __PYX_ERR(1, 721, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader = &__pyx_type_9psycopg_c_8_psycopg_TimestamptzLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader) < (0)) __PYX_ERR(1, 721, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzLoader) < (0)) __PYX_ERR(1, 721, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader) < (0)) __PYX_ERR(1, 721, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimestamptzLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader) < (0)) __PYX_ERR(1, 721, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader) < (0)) __PYX_ERR(1, 721, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TimestamptzBinaryLoader.__pyx_base.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 806, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader)) __PYX_ERR(1, 806, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader) < (0)) __PYX_ERR(1, 806, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_TimestamptzBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimestamptzLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader) < (0)) __PYX_ERR(1, 806, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TimestamptzBinaryLoader) < (0)) __PYX_ERR(1, 806, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader) < (0)) __PYX_ERR(1, 806, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TimestamptzBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader) < (0)) __PYX_ERR(1, 806, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader) < (0)) __PYX_ERR(1, 806, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntervalLoader = &__pyx_vtable_9psycopg_c_8_psycopg_IntervalLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_IntervalLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_IntervalLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader_cload;
  __pyx_vtable_9psycopg_c_8_psycopg_IntervalLoader._cload_notimpl = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_IntervalLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_14IntervalLoader__cload_notimpl;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntervalLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader)) __PYX_ERR(1, 868, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntervalLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader) < (0)) __PYX_ERR(1, 868, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader = &__pyx_type_9psycopg_c_8_psycopg_IntervalLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader) < (0)) __PYX_ERR(1, 868, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_IntervalLoader) < (0)) __PYX_ERR(1, 868, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader) < (0)) __PYX_ERR(1, 868, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntervalLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader) < (0)) __PYX_ERR(1, 868, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader) < (0)) __PYX_ERR(1, 868, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntervalBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_IntervalBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_IntervalBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_IntervalBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_20IntervalBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader)) __PYX_ERR(1, 979, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader) < (0)) __PYX_ERR(1, 979, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_IntervalBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader) < (0)) __PYX_ERR(1, 979, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_IntervalBinaryLoader) < (0)) __PYX_ERR(1, 979, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader) < (0)) __PYX_ERR(1, 979, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntervalBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader) < (0)) __PYX_ERR(1, 979, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader) < (0)) __PYX_ERR(1, 979, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper = &__pyx_vtable_9psycopg_c_8_psycopg__IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__IntDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__IntDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_10_IntDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__IntDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper)) __PYX_ERR(12, 57, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__IntDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper) < (0)) __PYX_ERR(12, 57, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper = &__pyx_type_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper) < (0)) __PYX_ERR(12, 57, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper) < (0)) __PYX_ERR(12, 57, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper) < (0)) __PYX_ERR(12, 57, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper) < (0)) __PYX_ERR(12, 57, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper) < (0)) __PYX_ERR(12, 57, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper = &__pyx_vtable_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__IntOrSubclassDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__IntOrSubclassDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper)) __PYX_ERR(12, 79, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper) < (0)) __PYX_ERR(12, 79, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper = &__pyx_type_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper) < (0)) __PYX_ERR(12, 79, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper) < (0)) __PYX_ERR(12, 79, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper) < (0)) __PYX_ERR(12, 79, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntOrSubclassDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper) < (0)) __PYX_ERR(12, 79, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper) < (0)) __PYX_ERR(12, 79, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int2Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_Int2Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int2Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 97, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int2Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper)) __PYX_ERR(12, 97, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int2Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper) < (0)) __PYX_ERR(12, 97, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper = &__pyx_type_9psycopg_c_8_psycopg_Int2Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper) < (0)) __PYX_ERR(12, 97, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Int2Dumper) < (0)) __PYX_ERR(12, 97, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper) < (0)) __PYX_ERR(12, 97, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int2Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper) < (0)) __PYX_ERR(12, 97, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper) < (0)) __PYX_ERR(12, 97, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int4Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_Int4Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int4Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int4Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper)) __PYX_ERR(12, 103, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int4Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper) < (0)) __PYX_ERR(12, 103, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper = &__pyx_type_9psycopg_c_8_psycopg_Int4Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper) < (0)) __PYX_ERR(12, 103, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Int4Dumper) < (0)) __PYX_ERR(12, 103, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper) < (0)) __PYX_ERR(12, 103, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int4Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper) < (0)) __PYX_ERR(12, 103, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper) < (0)) __PYX_ERR(12, 103, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int8Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_Int8Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int8Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int8Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper)) __PYX_ERR(12, 109, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int8Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper) < (0)) __PYX_ERR(12, 109, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper = &__pyx_type_9psycopg_c_8_psycopg_Int8Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper) < (0)) __PYX_ERR(12, 109, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Int8Dumper) < (0)) __PYX_ERR(12, 109, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper) < (0)) __PYX_ERR(12, 109, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int8Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper) < (0)) __PYX_ERR(12, 109, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper) < (0)) __PYX_ERR(12, 109, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericDumper = &__pyx_vtable_9psycopg_c_8_psycopg_IntNumericDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_IntNumericDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntNumericDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper)) __PYX_ERR(12, 115, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntNumericDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper) < (0)) __PYX_ERR(12, 115, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper = &__pyx_type_9psycopg_c_8_psycopg_IntNumericDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper) < (0)) __PYX_ERR(12, 115, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericDumper) < (0)) __PYX_ERR(12, 115, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper) < (0)) __PYX_ERR(12, 115, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntNumericDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper) < (0)) __PYX_ERR(12, 115, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper) < (0)) __PYX_ERR(12, 115, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_16Int2BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 121, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper)) __PYX_ERR(12, 121, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper) < (0)) __PYX_ERR(12, 121, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_Int2BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper) < (0)) __PYX_ERR(12, 121, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryDumper) < (0)) __PYX_ERR(12, 121, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper) < (0)) __PYX_ERR(12, 121, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int2BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper) < (0)) __PYX_ERR(12, 121, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper) < (0)) __PYX_ERR(12, 121, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_16Int4BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper)) __PYX_ERR(12, 131, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper) < (0)) __PYX_ERR(12, 131, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_Int4BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper) < (0)) __PYX_ERR(12, 131, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryDumper) < (0)) __PYX_ERR(12, 131, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper) < (0)) __PYX_ERR(12, 131, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int4BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper) < (0)) __PYX_ERR(12, 131, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper) < (0)) __PYX_ERR(12, 131, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_16Int8BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper)) __PYX_ERR(12, 141, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper) < (0)) __PYX_ERR(12, 141, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_Int8BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper) < (0)) __PYX_ERR(12, 141, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryDumper) < (0)) __PYX_ERR(12, 141, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper) < (0)) __PYX_ERR(12, 141, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int8BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper) < (0)) __PYX_ERR(12, 141, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper) < (0)) __PYX_ERR(12, 141, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_IntNumericBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_IntNumericBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_IntNumericBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper)) __PYX_ERR(12, 176, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper) < (0)) __PYX_ERR(12, 176, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_IntNumericBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper) < (0)) __PYX_ERR(12, 176, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_IntNumericBinaryDumper) < (0)) __PYX_ERR(12, 176, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper) < (0)) __PYX_ERR(12, 176, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntNumericBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper) < (0)) __PYX_ERR(12, 176, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper) < (0)) __PYX_ERR(12, 176, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntDumper = &__pyx_vtable_9psycopg_c_8_psycopg_IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_IntDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_IntDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_9IntDumper_cdump;
  __pyx_vtable_9psycopg_c_8_psycopg_IntDumper.__pyx_base.get_key = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_9IntDumper_get_key;
  __pyx_vtable_9psycopg_c_8_psycopg_IntDumper.__pyx_base.upgrade = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, int __pyx_skip_dispatch))__pyx_f_9psycopg_c_8_psycopg_9IntDumper_upgrade;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper)) __PYX_ERR(12, 186, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper) < (0)) __PYX_ERR(12, 186, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper = &__pyx_type_9psycopg_c_8_psycopg_IntDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper) < (0)) __PYX_ERR(12, 186, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_IntDumper) < (0)) __PYX_ERR(12, 186, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper) < (0)) __PYX_ERR(12, 186, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntDumper_2, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper) < (0)) __PYX_ERR(12, 186, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper) < (0)) __PYX_ERR(12, 186, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_IntBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_IntBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_IntDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper)) __PYX_ERR(12, 240, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper) < (0)) __PYX_ERR(12, 240, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_IntBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper) < (0)) __PYX_ERR(12, 240, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_IntBinaryDumper) < (0)) __PYX_ERR(12, 240, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper) < (0)) __PYX_ERR(12, 240, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper) < (0)) __PYX_ERR(12, 240, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper) < (0)) __PYX_ERR(12, 240, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_IntLoader = &__pyx_vtable_9psycopg_c_8_psycopg_IntLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_IntLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_IntLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_9IntLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_IntLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader)) __PYX_ERR(12, 251, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_IntLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader) < (0)) __PYX_ERR(12, 251, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader = &__pyx_type_9psycopg_c_8_psycopg_IntLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader) < (0)) __PYX_ERR(12, 251, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_IntLoader) < (0)) __PYX_ERR(12, 251, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader) < (0)) __PYX_ERR(12, 251, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_IntLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader) < (0)) __PYX_ERR(12, 251, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader) < (0)) __PYX_ERR(12, 251, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Int2BinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16Int2BinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader)) __PYX_ERR(12, 271, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader) < (0)) __PYX_ERR(12, 271, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_Int2BinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader) < (0)) __PYX_ERR(12, 271, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_Int2BinaryLoader) < (0)) __PYX_ERR(12, 271, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader) < (0)) __PYX_ERR(12, 271, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int2BinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader) < (0)) __PYX_ERR(12, 271, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader) < (0)) __PYX_ERR(12, 271, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Int4BinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16Int4BinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader)) __PYX_ERR(12, 282, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader) < (0)) __PYX_ERR(12, 282, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_Int4BinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader) < (0)) __PYX_ERR(12, 282, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_Int4BinaryLoader) < (0)) __PYX_ERR(12, 282, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader) < (0)) __PYX_ERR(12, 282, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int4BinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader) < (0)) __PYX_ERR(12, 282, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader) < (0)) __PYX_ERR(12, 282, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Int8BinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16Int8BinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 293, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader)) __PYX_ERR(12, 293, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader) < (0)) __PYX_ERR(12, 293, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_Int8BinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader) < (0)) __PYX_ERR(12, 293, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_Int8BinaryLoader) < (0)) __PYX_ERR(12, 293, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader) < (0)) __PYX_ERR(12, 293, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Int8BinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader) < (0)) __PYX_ERR(12, 293, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader) < (0)) __PYX_ERR(12, 293, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_OidBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_OidBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_OidBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_OidBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_15OidBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 304, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader)) __PYX_ERR(12, 304, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader) < (0)) __PYX_ERR(12, 304, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_OidBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader) < (0)) __PYX_ERR(12, 304, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_OidBinaryLoader) < (0)) __PYX_ERR(12, 304, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader) < (0)) __PYX_ERR(12, 304, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_OidBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader) < (0)) __PYX_ERR(12, 304, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader) < (0)) __PYX_ERR(12, 304, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__FloatDumper = &__pyx_vtable_9psycopg_c_8_psycopg__FloatDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__FloatDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__FloatDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_12_FloatDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__FloatDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper)) __PYX_ERR(12, 315, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__FloatDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper) < (0)) __PYX_ERR(12, 315, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper = &__pyx_type_9psycopg_c_8_psycopg__FloatDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper) < (0)) __PYX_ERR(12, 315, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__FloatDumper) < (0)) __PYX_ERR(12, 315, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper) < (0)) __PYX_ERR(12, 315, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_FloatDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper) < (0)) __PYX_ERR(12, 315, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper) < (0)) __PYX_ERR(12, 315, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_FloatDumper = &__pyx_vtable_9psycopg_c_8_psycopg_FloatDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_FloatDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__FloatDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 344, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_FloatDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper)) __PYX_ERR(12, 344, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_FloatDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper) < (0)) __PYX_ERR(12, 344, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper = &__pyx_type_9psycopg_c_8_psycopg_FloatDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper) < (0)) __PYX_ERR(12, 344, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_FloatDumper) < (0)) __PYX_ERR(12, 344, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper) < (0)) __PYX_ERR(12, 344, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_FloatDumper_2, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper) < (0)) __PYX_ERR(12, 344, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper) < (0)) __PYX_ERR(12, 344, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Float4Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_Float4Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Float4Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__FloatDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Float4Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper)) __PYX_ERR(12, 350, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Float4Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper) < (0)) __PYX_ERR(12, 350, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper = &__pyx_type_9psycopg_c_8_psycopg_Float4Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper) < (0)) __PYX_ERR(12, 350, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Float4Dumper) < (0)) __PYX_ERR(12, 350, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper) < (0)) __PYX_ERR(12, 350, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Float4Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper) < (0)) __PYX_ERR(12, 350, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper) < (0)) __PYX_ERR(12, 350, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_FloatBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_FloatBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_FloatBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_FloatBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_17FloatBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper)) __PYX_ERR(12, 356, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper) < (0)) __PYX_ERR(12, 356, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_FloatBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper) < (0)) __PYX_ERR(12, 356, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_FloatBinaryDumper) < (0)) __PYX_ERR(12, 356, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper) < (0)) __PYX_ERR(12, 356, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_FloatBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper) < (0)) __PYX_ERR(12, 356, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper) < (0)) __PYX_ERR(12, 356, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_18Float4BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 373, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper)) __PYX_ERR(12, 373, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper) < (0)) __PYX_ERR(12, 373, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_Float4BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper) < (0)) __PYX_ERR(12, 373, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryDumper) < (0)) __PYX_ERR(12, 373, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper) < (0)) __PYX_ERR(12, 373, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Float4BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper) < (0)) __PYX_ERR(12, 373, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper) < (0)) __PYX_ERR(12, 373, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_FloatLoader = &__pyx_vtable_9psycopg_c_8_psycopg_FloatLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_FloatLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_FloatLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_11FloatLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_FloatLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader)) __PYX_ERR(12, 390, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_FloatLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader) < (0)) __PYX_ERR(12, 390, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader = &__pyx_type_9psycopg_c_8_psycopg_FloatLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader) < (0)) __PYX_ERR(12, 390, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_FloatLoader) < (0)) __PYX_ERR(12, 390, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader) < (0)) __PYX_ERR(12, 390, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_FloatLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader) < (0)) __PYX_ERR(12, 390, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader) < (0)) __PYX_ERR(12, 390, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Float4BinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_18Float4BinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader)) __PYX_ERR(12, 402, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader) < (0)) __PYX_ERR(12, 402, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_Float4BinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader) < (0)) __PYX_ERR(12, 402, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_Float4BinaryLoader) < (0)) __PYX_ERR(12, 402, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader) < (0)) __PYX_ERR(12, 402, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Float4BinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader) < (0)) __PYX_ERR(12, 402, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader) < (0)) __PYX_ERR(12, 402, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_Float8BinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_Float8BinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Float8BinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_Float8BinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_18Float8BinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader)) __PYX_ERR(12, 416, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader) < (0)) __PYX_ERR(12, 416, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_Float8BinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader) < (0)) __PYX_ERR(12, 416, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_Float8BinaryLoader) < (0)) __PYX_ERR(12, 416, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader) < (0)) __PYX_ERR(12, 416, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_Float8BinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader) < (0)) __PYX_ERR(12, 416, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader) < (0)) __PYX_ERR(12, 416, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DecimalDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DecimalDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DecimalDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DecimalDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_13DecimalDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DecimalDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper)) __PYX_ERR(12, 430, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DecimalDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper) < (0)) __PYX_ERR(12, 430, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper = &__pyx_type_9psycopg_c_8_psycopg_DecimalDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper) < (0)) __PYX_ERR(12, 430, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DecimalDumper) < (0)) __PYX_ERR(12, 430, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper) < (0)) __PYX_ERR(12, 430, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DecimalDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper) < (0)) __PYX_ERR(12, 430, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper) < (0)) __PYX_ERR(12, 430, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NumericLoader = &__pyx_vtable_9psycopg_c_8_psycopg_NumericLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_13NumericLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NumericLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader)) __PYX_ERR(12, 454, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NumericLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader) < (0)) __PYX_ERR(12, 454, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader = &__pyx_type_9psycopg_c_8_psycopg_NumericLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader) < (0)) __PYX_ERR(12, 454, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_NumericLoader) < (0)) __PYX_ERR(12, 454, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader) < (0)) __PYX_ERR(12, 454, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NumericLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader) < (0)) __PYX_ERR(12, 454, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader) < (0)) __PYX_ERR(12, 454, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_19NumericBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader)) __PYX_ERR(12, 475, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader) < (0)) __PYX_ERR(12, 475, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_NumericBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader) < (0)) __PYX_ERR(12, 475, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryLoader) < (0)) __PYX_ERR(12, 475, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader) < (0)) __PYX_ERR(12, 475, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NumericBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader) < (0)) __PYX_ERR(12, 475, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader) < (0)) __PYX_ERR(12, 475, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_DecimalBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_DecimalBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DecimalBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_DecimalBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_19DecimalBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper)) __PYX_ERR(12, 529, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper) < (0)) __PYX_ERR(12, 529, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_DecimalBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper) < (0)) __PYX_ERR(12, 529, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_DecimalBinaryDumper) < (0)) __PYX_ERR(12, 529, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper) < (0)) __PYX_ERR(12, 529, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_DecimalBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper) < (0)) __PYX_ERR(12, 529, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper) < (0)) __PYX_ERR(12, 529, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__MixedNumericDumper = &__pyx_vtable_9psycopg_c_8_psycopg__MixedNumericDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__MixedNumericDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper)) __PYX_ERR(12, 539, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper) < (0)) __PYX_ERR(12, 539, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper = &__pyx_type_9psycopg_c_8_psycopg__MixedNumericDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper) < (0)) __PYX_ERR(12, 539, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__MixedNumericDumper) < (0)) __PYX_ERR(12, 539, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper) < (0)) __PYX_ERR(12, 539, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_MixedNumericDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper) < (0)) __PYX_ERR(12, 539, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper) < (0)) __PYX_ERR(12, 539, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NumericDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NumericDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__MixedNumericDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_13NumericDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NumericDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper)) __PYX_ERR(12, 554, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NumericDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper) < (0)) __PYX_ERR(12, 554, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper = &__pyx_type_9psycopg_c_8_psycopg_NumericDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper) < (0)) __PYX_ERR(12, 554, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NumericDumper) < (0)) __PYX_ERR(12, 554, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper) < (0)) __PYX_ERR(12, 554, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NumericDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper) < (0)) __PYX_ERR(12, 554, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper) < (0)) __PYX_ERR(12, 554, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__MixedNumericDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NumericBinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_19NumericBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper)) __PYX_ERR(12, 572, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper) < (0)) __PYX_ERR(12, 572, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_NumericBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper) < (0)) __PYX_ERR(12, 572, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NumericBinaryDumper) < (0)) __PYX_ERR(12, 572, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper) < (0)) __PYX_ERR(12, 572, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NumericBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper) < (0)) __PYX_ERR(12, 572, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper) < (0)) __PYX_ERR(12, 572, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_BoolDumper = &__pyx_vtable_9psycopg_c_8_psycopg_BoolDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_10BoolDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_BoolDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper)) __PYX_ERR(13, 10, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_BoolDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper) < (0)) __PYX_ERR(13, 10, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper = &__pyx_type_9psycopg_c_8_psycopg_BoolDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper) < (0)) __PYX_ERR(13, 10, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_BoolDumper) < (0)) __PYX_ERR(13, 10, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper) < (0)) __PYX_ERR(13, 10, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BoolDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper) < (0)) __PYX_ERR(13, 10, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper) < (0)) __PYX_ERR(13, 10, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_16BoolBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper)) __PYX_ERR(13, 40, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper) < (0)) __PYX_ERR(13, 40, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_BoolBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper) < (0)) __PYX_ERR(13, 40, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryDumper) < (0)) __PYX_ERR(13, 40, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper) < (0)) __PYX_ERR(13, 40, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BoolBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper) < (0)) __PYX_ERR(13, 40, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper) < (0)) __PYX_ERR(13, 40, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_BoolLoader = &__pyx_vtable_9psycopg_c_8_psycopg_BoolLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_10BoolLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_BoolLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader)) __PYX_ERR(13, 62, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_BoolLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader) < (0)) __PYX_ERR(13, 62, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader = &__pyx_type_9psycopg_c_8_psycopg_BoolLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader) < (0)) __PYX_ERR(13, 62, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_BoolLoader) < (0)) __PYX_ERR(13, 62, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader) < (0)) __PYX_ERR(13, 62, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BoolLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader) < (0)) __PYX_ERR(13, 62, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader) < (0)) __PYX_ERR(13, 62, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_BoolBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16BoolBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(13, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader)) __PYX_ERR(13, 72, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader) < (0)) __PYX_ERR(13, 72, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_BoolBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader) < (0)) __PYX_ERR(13, 72, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_BoolBinaryLoader) < (0)) __PYX_ERR(13, 72, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader) < (0)) __PYX_ERR(13, 72, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BoolBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader) < (0)) __PYX_ERR(13, 72, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader) < (0)) __PYX_ERR(13, 72, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPInt16Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt16Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 10, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper)) __PYX_ERR(14, 10, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper) < (0)) __PYX_ERR(14, 10, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper = &__pyx_type_9psycopg_c_8_psycopg_NPInt16Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper) < (0)) __PYX_ERR(14, 10, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16Dumper) < (0)) __PYX_ERR(14, 10, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper) < (0)) __PYX_ERR(14, 10, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPInt16Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper) < (0)) __PYX_ERR(14, 10, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper) < (0)) __PYX_ERR(14, 10, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPInt32Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt32Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper)) __PYX_ERR(14, 16, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper) < (0)) __PYX_ERR(14, 16, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper = &__pyx_type_9psycopg_c_8_psycopg_NPInt32Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper) < (0)) __PYX_ERR(14, 16, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32Dumper) < (0)) __PYX_ERR(14, 16, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper) < (0)) __PYX_ERR(14, 16, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPInt32Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper) < (0)) __PYX_ERR(14, 16, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper) < (0)) __PYX_ERR(14, 16, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64Dumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPInt64Dumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt64Dumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper)) __PYX_ERR(14, 22, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper) < (0)) __PYX_ERR(14, 22, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper = &__pyx_type_9psycopg_c_8_psycopg_NPInt64Dumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper) < (0)) __PYX_ERR(14, 22, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64Dumper) < (0)) __PYX_ERR(14, 22, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper) < (0)) __PYX_ERR(14, 22, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPInt64Dumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper) < (0)) __PYX_ERR(14, 22, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper) < (0)) __PYX_ERR(14, 22, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPNumericDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPNumericDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPNumericDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper)) __PYX_ERR(14, 28, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPNumericDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper) < (0)) __PYX_ERR(14, 28, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper = &__pyx_type_9psycopg_c_8_psycopg_NPNumericDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper) < (0)) __PYX_ERR(14, 28, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericDumper) < (0)) __PYX_ERR(14, 28, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper) < (0)) __PYX_ERR(14, 28, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPNumericDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper) < (0)) __PYX_ERR(14, 28, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper) < (0)) __PYX_ERR(14, 28, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPInt16BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt16BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt16BinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 34, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper)) __PYX_ERR(14, 34, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper) < (0)) __PYX_ERR(14, 34, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_NPInt16BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper) < (0)) __PYX_ERR(14, 34, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt16BinaryDumper) < (0)) __PYX_ERR(14, 34, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper) < (0)) __PYX_ERR(14, 34, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPInt16BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper) < (0)) __PYX_ERR(14, 34, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper) < (0)) __PYX_ERR(14, 34, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPInt32BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt32BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt32BinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper)) __PYX_ERR(14, 44, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper) < (0)) __PYX_ERR(14, 44, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_NPInt32BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper) < (0)) __PYX_ERR(14, 44, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt32BinaryDumper) < (0)) __PYX_ERR(14, 44, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper) < (0)) __PYX_ERR(14, 44, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPInt32BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper) < (0)) __PYX_ERR(14, 44, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper) < (0)) __PYX_ERR(14, 44, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64BinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPInt64BinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt64BinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPInt64BinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper)) __PYX_ERR(14, 54, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper) < (0)) __PYX_ERR(14, 54, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_NPInt64BinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper) < (0)) __PYX_ERR(14, 54, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPInt64BinaryDumper) < (0)) __PYX_ERR(14, 54, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper) < (0)) __PYX_ERR(14, 54, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPInt64BinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper) < (0)) __PYX_ERR(14, 54, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper) < (0)) __PYX_ERR(14, 54, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_NPNumericBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPNumericBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__IntDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_NPNumericBinaryDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(14, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper)) __PYX_ERR(14, 64, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper) < (0)) __PYX_ERR(14, 64, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_NPNumericBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper) < (0)) __PYX_ERR(14, 64, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_NPNumericBinaryDumper) < (0)) __PYX_ERR(14, 64, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper) < (0)) __PYX_ERR(14, 64, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_NPNumericBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper) < (0)) __PYX_ERR(14, 64, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper) < (0)) __PYX_ERR(14, 64, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__BaseStrDumper = &__pyx_vtable_9psycopg_c_8_psycopg__BaseStrDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseStrDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__BaseStrDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_14_BaseStrDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__BaseStrDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper)) __PYX_ERR(15, 24, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__BaseStrDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper) < (0)) __PYX_ERR(15, 24, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper = &__pyx_type_9psycopg_c_8_psycopg__BaseStrDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper) < (0)) __PYX_ERR(15, 24, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__BaseStrDumper) < (0)) __PYX_ERR(15, 24, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper) < (0)) __PYX_ERR(15, 24, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BaseStrDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper) < (0)) __PYX_ERR(15, 24, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper) < (0)) __PYX_ERR(15, 24, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg__StrBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__StrBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseStrDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper)) __PYX_ERR(15, 68, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper) < (0)) __PYX_ERR(15, 68, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg__StrBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper) < (0)) __PYX_ERR(15, 68, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper) < (0)) __PYX_ERR(15, 68, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper) < (0)) __PYX_ERR(15, 68, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper) < (0)) __PYX_ERR(15, 68, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper) < (0)) __PYX_ERR(15, 68, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 73, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper)) __PYX_ERR(15, 73, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper) < (0)) __PYX_ERR(15, 73, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper) < (0)) __PYX_ERR(15, 73, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumper) < (0)) __PYX_ERR(15, 73, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper) < (0)) __PYX_ERR(15, 73, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrBinaryDumper_2, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper) < (0)) __PYX_ERR(15, 73, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper) < (0)) __PYX_ERR(15, 73, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperVarchar = &__pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;
  __pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumperVarchar.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar)) __PYX_ERR(15, 79, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar) < (0)) __PYX_ERR(15, 79, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar = &__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperVarchar;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar) < (0)) __PYX_ERR(15, 79, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar, __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperVarchar) < (0)) __PYX_ERR(15, 79, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar) < (0)) __PYX_ERR(15, 79, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrBinaryDumperVarchar, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar) < (0)) __PYX_ERR(15, 79, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar) < (0)) __PYX_ERR(15, 79, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperName = &__pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumperName;
  __pyx_vtable_9psycopg_c_8_psycopg_StrBinaryDumperName.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrBinaryDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName)) __PYX_ERR(15, 85, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName) < (0)) __PYX_ERR(15, 85, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName = &__pyx_type_9psycopg_c_8_psycopg_StrBinaryDumperName;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName) < (0)) __PYX_ERR(15, 85, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName, __pyx_vtabptr_9psycopg_c_8_psycopg_StrBinaryDumperName) < (0)) __PYX_ERR(15, 85, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName) < (0)) __PYX_ERR(15, 85, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrBinaryDumperName, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName) < (0)) __PYX_ERR(15, 85, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName) < (0)) __PYX_ERR(15, 85, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper = &__pyx_vtable_9psycopg_c_8_psycopg__StrDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__StrDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__BaseStrDumper;
  __pyx_vtable_9psycopg_c_8_psycopg__StrDumper.__pyx_base.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_10_StrDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__StrDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper)) __PYX_ERR(15, 91, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__StrDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper) < (0)) __PYX_ERR(15, 91, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper = &__pyx_type_9psycopg_c_8_psycopg__StrDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseStrDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper) < (0)) __PYX_ERR(15, 91, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper, __pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper) < (0)) __PYX_ERR(15, 91, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper) < (0)) __PYX_ERR(15, 91, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper) < (0)) __PYX_ERR(15, 91, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper) < (0)) __PYX_ERR(15, 91, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumper = &__pyx_vtable_9psycopg_c_8_psycopg_StrDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_StrDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper)) __PYX_ERR(15, 107, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper) < (0)) __PYX_ERR(15, 107, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper = &__pyx_type_9psycopg_c_8_psycopg_StrDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper) < (0)) __PYX_ERR(15, 107, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumper) < (0)) __PYX_ERR(15, 107, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper) < (0)) __PYX_ERR(15, 107, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrDumper_2, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper) < (0)) __PYX_ERR(15, 107, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper) < (0)) __PYX_ERR(15, 107, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperVarchar = &__pyx_vtable_9psycopg_c_8_psycopg_StrDumperVarchar;
  __pyx_vtable_9psycopg_c_8_psycopg_StrDumperVarchar.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar)) __PYX_ERR(15, 113, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar) < (0)) __PYX_ERR(15, 113, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar = &__pyx_type_9psycopg_c_8_psycopg_StrDumperVarchar;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar) < (0)) __PYX_ERR(15, 113, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar, __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperVarchar) < (0)) __PYX_ERR(15, 113, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar) < (0)) __PYX_ERR(15, 113, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrDumperVarchar, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar) < (0)) __PYX_ERR(15, 113, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar) < (0)) __PYX_ERR(15, 113, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperName = &__pyx_vtable_9psycopg_c_8_psycopg_StrDumperName;
  __pyx_vtable_9psycopg_c_8_psycopg_StrDumperName.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrDumperName_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName)) __PYX_ERR(15, 119, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrDumperName_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName) < (0)) __PYX_ERR(15, 119, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName = &__pyx_type_9psycopg_c_8_psycopg_StrDumperName;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName) < (0)) __PYX_ERR(15, 119, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName, __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperName) < (0)) __PYX_ERR(15, 119, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName) < (0)) __PYX_ERR(15, 119, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrDumperName, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName) < (0)) __PYX_ERR(15, 119, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName) < (0)) __PYX_ERR(15, 119, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperUnknown = &__pyx_vtable_9psycopg_c_8_psycopg_StrDumperUnknown;
  __pyx_vtable_9psycopg_c_8_psycopg_StrDumperUnknown.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__StrDumper;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown)) __PYX_ERR(15, 125, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown) < (0)) __PYX_ERR(15, 125, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown = &__pyx_type_9psycopg_c_8_psycopg_StrDumperUnknown;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown) < (0)) __PYX_ERR(15, 125, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown, __pyx_vtabptr_9psycopg_c_8_psycopg_StrDumperUnknown) < (0)) __PYX_ERR(15, 125, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown) < (0)) __PYX_ERR(15, 125, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_StrDumperUnknown, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown) < (0)) __PYX_ERR(15, 125, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperUnknown) < (0)) __PYX_ERR(15, 125, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__TextLoader = &__pyx_vtable_9psycopg_c_8_psycopg__TextLoader;
  __pyx_vtable_9psycopg_c_8_psycopg__TextLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg__TextLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_11_TextLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 130, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__TextLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader)) __PYX_ERR(15, 130, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__TextLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader) < (0)) __PYX_ERR(15, 130, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader = &__pyx_type_9psycopg_c_8_psycopg__TextLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader) < (0)) __PYX_ERR(15, 130, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader, __pyx_vtabptr_9psycopg_c_8_psycopg__TextLoader) < (0)) __PYX_ERR(15, 130, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader) < (0)) __PYX_ERR(15, 130, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TextLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader) < (0)) __PYX_ERR(15, 130, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader) < (0)) __PYX_ERR(15, 130, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TextLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TextLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TextLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__TextLoader;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TextLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader)) __PYX_ERR(15, 167, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TextLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader) < (0)) __PYX_ERR(15, 167, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader = &__pyx_type_9psycopg_c_8_psycopg_TextLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader) < (0)) __PYX_ERR(15, 167, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TextLoader) < (0)) __PYX_ERR(15, 167, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader) < (0)) __PYX_ERR(15, 167, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TextLoader_2, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader) < (0)) __PYX_ERR(15, 167, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader) < (0)) __PYX_ERR(15, 167, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_TextBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_TextBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_TextBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__TextLoader;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader)) __PYX_ERR(15, 173, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader) < (0)) __PYX_ERR(15, 173, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_TextBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader) < (0)) __PYX_ERR(15, 173, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_TextBinaryLoader) < (0)) __PYX_ERR(15, 173, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader) < (0)) __PYX_ERR(15, 173, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_TextBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader) < (0)) __PYX_ERR(15, 173, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader) < (0)) __PYX_ERR(15, 173, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_BytesDumper = &__pyx_vtable_9psycopg_c_8_psycopg_BytesDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BytesDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BytesDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_11BytesDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_BytesDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper)) __PYX_ERR(15, 179, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_BytesDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper) < (0)) __PYX_ERR(15, 179, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper = &__pyx_type_9psycopg_c_8_psycopg_BytesDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper) < (0)) __PYX_ERR(15, 179, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_BytesDumper) < (0)) __PYX_ERR(15, 179, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper) < (0)) __PYX_ERR(15, 179, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BytesDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper) < (0)) __PYX_ERR(15, 179, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper) < (0)) __PYX_ERR(15, 179, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_BytesBinaryDumper = &__pyx_vtable_9psycopg_c_8_psycopg_BytesBinaryDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BytesBinaryDumper.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CDumper;
  __pyx_vtable_9psycopg_c_8_psycopg_BytesBinaryDumper.__pyx_base.cdump = (Py_ssize_t (*)(struct __pyx_obj_9psycopg_c_8_psycopg_CDumper *, PyObject *, PyObject *, Py_ssize_t))__pyx_f_9psycopg_c_8_psycopg_17BytesBinaryDumper_cdump;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 271, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper)) __PYX_ERR(15, 271, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper) < (0)) __PYX_ERR(15, 271, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper = &__pyx_type_9psycopg_c_8_psycopg_BytesBinaryDumper;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper) < (0)) __PYX_ERR(15, 271, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper, __pyx_vtabptr_9psycopg_c_8_psycopg_BytesBinaryDumper) < (0)) __PYX_ERR(15, 271, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper) < (0)) __PYX_ERR(15, 271, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_BytesBinaryDumper, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper) < (0)) __PYX_ERR(15, 271, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper) < (0)) __PYX_ERR(15, 271, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_ByteaLoader = &__pyx_vtable_9psycopg_c_8_psycopg_ByteaLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ByteaLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ByteaLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_11ByteaLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_ByteaLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader)) __PYX_ERR(15, 287, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_ByteaLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader) < (0)) __PYX_ERR(15, 287, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader = &__pyx_type_9psycopg_c_8_psycopg_ByteaLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader) < (0)) __PYX_ERR(15, 287, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_ByteaLoader) < (0)) __PYX_ERR(15, 287, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader) < (0)) __PYX_ERR(15, 287, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ByteaLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader) < (0)) __PYX_ERR(15, 287, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader) < (0)) __PYX_ERR(15, 287, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_ByteaBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_ByteaBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ByteaBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_ByteaBinaryLoader.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_17ByteaBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader)) __PYX_ERR(15, 306, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader) < (0)) __PYX_ERR(15, 306, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_ByteaBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader) < (0)) __PYX_ERR(15, 306, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_ByteaBinaryLoader) < (0)) __PYX_ERR(15, 306, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader) < (0)) __PYX_ERR(15, 306, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_ByteaBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader) < (0)) __PYX_ERR(15, 306, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader) < (0)) __PYX_ERR(15, 306, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg__UUIDLoader = &__pyx_vtable_9psycopg_c_8_psycopg__UUIDLoader;
  __pyx_vtable_9psycopg_c_8_psycopg__UUIDLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg_CLoader;
  __pyx_vtable_9psycopg_c_8_psycopg__UUIDLoader._return_uuid = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg__UUIDLoader *, uint64_t, uint64_t))__pyx_f_9psycopg_c_8_psycopg_11_UUIDLoader__return_uuid;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg__UUIDLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader)) __PYX_ERR(2, 29, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg__UUIDLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader) < (0)) __PYX_ERR(2, 29, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader = &__pyx_type_9psycopg_c_8_psycopg__UUIDLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader) < (0)) __PYX_ERR(2, 29, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader, __pyx_vtabptr_9psycopg_c_8_psycopg__UUIDLoader) < (0)) __PYX_ERR(2, 29, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader) < (0)) __PYX_ERR(2, 29, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_UUIDLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader) < (0)) __PYX_ERR(2, 29, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader) < (0)) __PYX_ERR(2, 29, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_UUIDLoader = &__pyx_vtable_9psycopg_c_8_psycopg_UUIDLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_UUIDLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__UUIDLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_UUIDLoader.__pyx_base.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_10UUIDLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_UUIDLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader)) __PYX_ERR(2, 57, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_UUIDLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader) < (0)) __PYX_ERR(2, 57, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader = &__pyx_type_9psycopg_c_8_psycopg_UUIDLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader) < (0)) __PYX_ERR(2, 57, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_UUIDLoader) < (0)) __PYX_ERR(2, 57, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader) < (0)) __PYX_ERR(2, 57, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_UUIDLoader_2, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader) < (0)) __PYX_ERR(2, 57, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader) < (0)) __PYX_ERR(2, 57, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_8_psycopg_UUIDBinaryLoader = &__pyx_vtable_9psycopg_c_8_psycopg_UUIDBinaryLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_UUIDBinaryLoader.__pyx_base = *__pyx_vtabptr_9psycopg_c_8_psycopg__UUIDLoader;
  __pyx_vtable_9psycopg_c_8_psycopg_UUIDBinaryLoader.__pyx_base.__pyx_base.cload = (PyObject *(*)(struct __pyx_obj_9psycopg_c_8_psycopg_CLoader *, char const *, size_t))__pyx_f_9psycopg_c_8_psycopg_16UUIDBinaryLoader_cload;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader)) __PYX_ERR(2, 85, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader) < (0)) __PYX_ERR(2, 85, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader = &__pyx_type_9psycopg_c_8_psycopg_UUIDBinaryLoader;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader->tp_base = __pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__UUIDLoader;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader) < (0)) __PYX_ERR(2, 85, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader, __pyx_vtabptr_9psycopg_c_8_psycopg_UUIDBinaryLoader) < (0)) __PYX_ERR(2, 85, __pyx_L1_error)
  if (__Pyx_MergeVtables(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader) < (0)) __PYX_ERR(2, 85, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_UUIDBinaryLoader, (PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader) < (0)) __PYX_ERR(2, 85, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject *) __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader) < (0)) __PYX_ERR(2, 85, __pyx_L1_error)
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect)) __PYX_ERR(8, 32, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct__connect;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct__connect->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel)) __PYX_ERR(8, 89, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel) < (0)) __PYX_ERR(8, 89, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel) < (0)) __PYX_ERR(8, 89, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_1_cancel->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute)) __PYX_ERR(8, 116, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute) < (0)) __PYX_ERR(8, 116, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute) < (0)) __PYX_ERR(8, 116, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_2_execute->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send)) __PYX_ERR(8, 132, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send) < (0)) __PYX_ERR(8, 132, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_3_send;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send) < (0)) __PYX_ERR(8, 132, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_3_send->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many)) __PYX_ERR(8, 166, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many) < (0)) __PYX_ERR(8, 166, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many) < (0)) __PYX_ERR(8, 166, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_4_fetch_many->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr)) __PYX_ERR(8, 189, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr) < (0)) __PYX_ERR(8, 189, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr) < (0)) __PYX_ERR(8, 189, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_5_genexpr->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch)) __PYX_ERR(8, 218, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch) < (0)) __PYX_ERR(8, 218, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch) < (0)) __PYX_ERR(8, 218, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_6_fetch->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate)) __PYX_ERR(8, 265, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate) < (0)) __PYX_ERR(8, 265, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate) < (0)) __PYX_ERR(8, 265, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_7_pipeline_communicate->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error_spec, NULL); if (unlikely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error)) __PYX_ERR(1, 1111, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error_spec, __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error) < (0)) __PYX_ERR(1, 1111, __pyx_L1_error)
  #else
  __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error = &__pyx_type_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error) < (0)) __PYX_ERR(1, 1111, __pyx_L1_error)
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount((PyObject*)__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error);
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error->tp_dictoffset && __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_mstate->__pyx_ptype_9psycopg_c_8_psycopg___pyx_scope_struct_8___pyx_f_9psycopg_c_8_psycopg__get_timestamp_load_error->tp_getattro = PyObject_GenericGetAttr;
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("psycopg_c.pq"); if (unlikely(!__pyx_t_1)) __PYX_ERR(16, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGconn = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "PGconn",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGconn), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGconn),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGconn), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGconn),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGconn), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGconn),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGconn) __PYX_ERR(16, 24, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_PGconn = (struct __pyx_vtabstruct_9psycopg_c_2pq_PGconn*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGconn); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_PGconn)) __PYX_ERR(16, 24, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGresult = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "PGresult",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGresult), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGresult),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGresult), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGresult),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGresult), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGresult),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGresult) __PYX_ERR(16, 38, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_PGresult = (struct __pyx_vtabstruct_9psycopg_c_2pq_PGresult*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGresult); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_PGresult)) __PYX_ERR(16, 38, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGcancelConn = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "PGcancelConn",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGcancelConn), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGcancelConn),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGcancelConn), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGcancelConn),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGcancelConn), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGcancelConn),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGcancelConn) __PYX_ERR(16, 45, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_PGcancelConn = (struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancelConn*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGcancelConn); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_PGcancelConn)) __PYX_ERR(16, 45, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGcancel = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "PGcancel",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGcancel), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGcancel),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGcancel), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGcancel),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PGcancel), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PGcancel),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGcancel) __PYX_ERR(16, 52, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_PGcancel = (struct __pyx_vtabstruct_9psycopg_c_2pq_PGcancel*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PGcancel); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_PGcancel)) __PYX_ERR(16, 52, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_Escaping = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "Escaping",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_Escaping), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_Escaping),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_Escaping), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_Escaping),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_Escaping), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_Escaping),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_Escaping) __PYX_ERR(16, 59, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_Escaping = (struct __pyx_vtabstruct_9psycopg_c_2pq_Escaping*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_Escaping); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_Escaping)) __PYX_ERR(16, 59, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PQBuffer = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "PQBuffer",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PQBuffer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PQBuffer),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PQBuffer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PQBuffer),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_PQBuffer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_PQBuffer),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PQBuffer) __PYX_ERR(16, 69, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_PQBuffer = (struct __pyx_vtabstruct_9psycopg_c_2pq_PQBuffer*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_PQBuffer); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_PQBuffer)) __PYX_ERR(16, 69, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_9psycopg_c_2pq_ViewBuffer = __Pyx_ImportType_3_2_4(__pyx_t_1, "psycopg_c.pq", "ViewBuffer",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(struct __pyx_obj_9psycopg_c_2pq_ViewBuffer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_ViewBuffer),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(struct __pyx_obj_9psycopg_c_2pq_ViewBuffer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_ViewBuffer),
  #else
  sizeof(struct __pyx_obj_9psycopg_c_2pq_ViewBuffer), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(struct __pyx_obj_9psycopg_c_2pq_ViewBuffer),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_ViewBuffer) __PYX_ERR(16, 77, __pyx_L1_error)
  __pyx_vtabptr_9psycopg_c_2pq_ViewBuffer = (struct __pyx_vtabstruct_9psycopg_c_2pq_ViewBuffer*)__Pyx_GetVtable(__pyx_mstate->__pyx_ptype_9psycopg_c_2pq_ViewBuffer); if (unlikely(!__pyx_vtabptr_9psycopg_c_2pq_ViewBuffer)) __PYX_ERR(16, 77, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(17, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4type_type) __PYX_ERR(17, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(18, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_4bool_bool = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "bool",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyLongObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyLongObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyLongObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyLongObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_4bool_bool) __PYX_ERR(18, 8, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(19, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_7complex_complex = __Pyx_ImportType_3_2_4(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "complex",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyComplexObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  0, 0,
  #else
  sizeof(PyComplexObject), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyComplexObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_7complex_complex) __PYX_ERR(19, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("datetime"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_mstate->__pyx_ptype_7cpython_8datetime_date = __Pyx_ImportType_3_2_4(__pyx_t_1, "datetime", "date",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyDateTime_Date), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Date),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyDateTime_Date), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Date),
  #else
  sizeof(PyDateTime_Date), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Date),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_8datetime_date) __PYX_ERR(4, 43, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_7cpython_8datetime_time = __Pyx_ImportType_3_2_4(__pyx_t_1, "datetime", "time",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyDateTime_Time), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Time),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyDateTime_Time), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Time),
  #else
  sizeof(PyDateTime_Time), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Time),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_8datetime_time) __PYX_ERR(4, 56, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_7cpython_8datetime_datetime = __Pyx_ImportType_3_2_4(__pyx_t_1, "datetime", "datetime",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyDateTime_DateTime), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_DateTime),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyDateTime_DateTime), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_DateTime),
  #else
  sizeof(PyDateTime_DateTime), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_DateTime),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_8datetime_datetime) __PYX_ERR(4, 82, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_7cpython_8datetime_timedelta = __Pyx_ImportType_3_2_4(__pyx_t_1, "datetime", "timedelta",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyDateTime_Delta), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Delta),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyDateTime_Delta), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Delta),
  #else
  sizeof(PyDateTime_Delta), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_Delta),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_8datetime_timedelta) __PYX_ERR(4, 120, __pyx_L1_error)
  __pyx_mstate->__pyx_ptype_7cpython_8datetime_tzinfo = __Pyx_ImportType_3_2_4(__pyx_t_1, "datetime", "tzinfo",
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyDateTime_TZInfo), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_TZInfo),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyDateTime_TZInfo), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_TZInfo),
  #else
  sizeof(PyDateTime_TZInfo), __PYX_GET_STRUCT_ALIGNMENT_3_2_4(PyDateTime_TZInfo),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_2_4); if (!__pyx_mstate->__pyx_ptype_7cpython_8datetime_tzinfo) __PYX_ERR(4, 133, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  {
    __pyx_t_1 = PyImport_ImportModule("psycopg_c.pq"); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    const char * __pyx_import_signature = __Pyx_PyBytes_AsString(__pyx_mstate_global->__pyx_kp_b_int_PyObject_char_Py_ssize_t__bu);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (unlikely(!__pyx_import_signature)) __PYX_ERR(0, 1, __pyx_L1_error)
    #endif
    const char * __pyx_import_name = __pyx_import_signature + 40;
    void (**const __pyx_import_pointers[])(void) = {(void (**)(void))&__pyx_f_9psycopg_c_2pq__buffer_as_string_and_size, (void (**)(void)) NULL};
    void (**const *__pyx_import_pointer)(void) = __pyx_import_pointers;
    const char *__pyx_import_current_signature = __pyx_import_signature;
    while (*__pyx_import_pointer) {
      if (__Pyx_ImportFunction_3_2_4(__pyx_t_1, __pyx_import_name, *__pyx_import_pointer, __pyx_import_current_signature) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
      ++__pyx_import_pointer;
      __pyx_import_name = strchr(__pyx_import_name, '\0') + 1;
      __pyx_import_signature = strchr(__pyx_import_signature, '\0') + 1;
      if (*__pyx_import_signature != '\0') __pyx_import_current_signature = __pyx_import_signature;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec__psycopg(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec__psycopg},
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  {Py_mod_gil, __Pyx_FREETHREADING_COMPATIBLE},
  #endif
  #if PY_VERSION_HEX >= 0x030C0000 && CYTHON_USE_MODULE_STATE
  {Py_mod_multiple_interpreters, Py_MOD_MULTIPLE_INTERPRETERS_NOT_SUPPORTED},
  #endif
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "_psycopg",
      __pyx_k_psycopg_c__psycopg_optimization, /* m_doc */
    #if CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstatetype), /* m_size */
    #else
      (CYTHON_PEP489_MULTI_PHASE_INIT) ? 0 : -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif

/* PyModInitFuncType */
#ifndef CYTHON_NO_PYINIT_EXPORT
  #define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#else
  #ifdef __cplusplus
  #define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
  #else
  #define __Pyx_PyMODINIT_FUNC PyObject *
  #endif
#endif

__Pyx_PyMODINIT_FUNC PyInit__psycopg(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit__psycopg(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
/* ModuleCreationPEP489 */
#if CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
static PY_INT64_T __Pyx_GetCurrentInterpreterId(void) {
    {
        PyObject *module = PyImport_ImportModule("_interpreters"); // 3.13+ I think
        if (!module) {
            PyErr_Clear(); // just try the 3.8-3.12 version
            module = PyImport_ImportModule("_xxsubinterpreters");
            if (!module) goto bad;
        }
        PyObject *current = PyObject_CallMethod(module, "get_current", NULL);
        Py_DECREF(module);
        if (!current) goto bad;
        if (PyTuple_Check(current)) {
            PyObject *new_current = PySequence_GetItem(current, 0);
            Py_DECREF(current);
            current = new_current;
            if (!new_current) goto bad;
        }
        long long as_c_int = PyLong_AsLongLong(current);
        Py_DECREF(current);
        return as_c_int;
    }
  bad:
    PySys_WriteStderr("__Pyx_GetCurrentInterpreterId failed. Try setting the C define CYTHON_PEP489_MULTI_PHASE_INIT=0\n");
    return -1;
}
#endif
#if !CYTHON_USE_MODULE_STATE
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    static PY_INT64_T main_interpreter_id = -1;
#if CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
    PY_INT64_T current_id = GraalPyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_GRAAL
    PY_INT64_T current_id = PyInterpreterState_GetIDFromThreadState(PyThreadState_Get());
#elif CYTHON_COMPILING_IN_LIMITED_API && (__PYX_LIMITED_VERSION_HEX < 0x03090000\
      || ((defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)) && __PYX_LIMITED_VERSION_HEX < 0x030A0000))
    PY_INT64_T current_id = __Pyx_GetCurrentInterpreterId();
#elif CYTHON_COMPILING_IN_LIMITED_API
    PY_INT64_T current_id = PyInterpreterState_GetID(PyInterpreterState_Get());
#else
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
#endif
    if (unlikely(current_id == -1)) {
        return -1;
    }
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return 0;
    } else if (unlikely(main_interpreter_id != current_id)) {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#endif
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    #if !CYTHON_USE_MODULE_STATE
    if (__Pyx_check_single_interpreter())
        return NULL;
    #endif
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec__psycopg(PyObject *__pyx_pyinit_module)
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  __pyx_mstatetype *__pyx_mstate = NULL;
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  size_t __pyx_t_7;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *(*__pyx_t_11)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module '_psycopg' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #else
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_t_1 = __pyx_pyinit_module;
  Py_INCREF(__pyx_t_1);
  #else
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #if CYTHON_USE_MODULE_STATE
  {
    int add_module_result = __Pyx_State_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "_psycopg" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = __pyx_t_1;
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  PyUnstable_Module_SetGIL(__pyx_m, Py_MOD_GIL_NOT_USED);
  #endif
  __pyx_mstate = __pyx_mstate_global;
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_mstate->__pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_mstate->__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_mstate->__pyx_d);
  __pyx_mstate->__pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_mstate->__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_cython_runtime = __Pyx_PyImport_AddModuleRef("cython_runtime"); if (unlikely(!__pyx_mstate->__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_mstate->__pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /* ImportRefnannyAPI */
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
    PyErr_Clear();
    __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
    if (!__Pyx_RefNanny)
        Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  
__Pyx_RefNannySetupContext("PyInit__psycopg", 0);
  __Pyx_init_runtime_version();
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_mstate->__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_mstate->__pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_mstate->__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Library function declarations ---*/
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__pyx_module_is_main_psycopg_c___psycopg) {
    if (PyObject_SetAttr(__pyx_m, __pyx_mstate_global->__pyx_n_u_name_2, __pyx_mstate_global->__pyx_n_u_main) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "psycopg_c._psycopg")) {
      if (unlikely((PyDict_SetItemString(modules, "psycopg_c._psycopg", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_CreateCodeObjects(__pyx_mstate) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code(__pyx_mstate);
  (void)__Pyx_modinit_variable_export_code(__pyx_mstate);
  (void)__Pyx_modinit_function_export_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_type_init_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code(__pyx_mstate);
  if (unlikely((__Pyx_modinit_function_import_code(__pyx_mstate) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/

  /* "psycopg_c/_psycopg.pyx":14
 * from psycopg_c._psycopg cimport oids
 * 
 * import logging             # <<<<<<<<<<<<<<
 * 
 * from psycopg.pq import Format as _pq_Format
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_logging, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 14, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_logging, __pyx_t_2) < (0)) __PYX_ERR(0, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg.pyx":16
 * import logging
 * 
 * from psycopg.pq import Format as _pq_Format             # <<<<<<<<<<<<<<
 * from psycopg._enums import PyFormat as _py_Format
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Format};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg_pq, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Format};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pq_Format, __pyx_t_4) < (0)) __PYX_ERR(0, 16, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg.pyx":17
 * 
 * from psycopg.pq import Format as _pq_Format
 * from psycopg._enums import PyFormat as _py_Format             # <<<<<<<<<<<<<<
 * 
 * logger = logging.getLogger("psycopg")
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PyFormat};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg__enums, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 17, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PyFormat};
    __pyx_t_3 = 0; {
      __pyx_t_4 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_py_Format, __pyx_t_4) < (0)) __PYX_ERR(0, 17, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg.pyx":19
 * from psycopg._enums import PyFormat as _py_Format
 * 
 * logger = logging.getLogger("psycopg")             # <<<<<<<<<<<<<<
 * 
 * PQ_TEXT = _pq_Format.TEXT
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_logging); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_getLogger); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_mstate_global->__pyx_n_u_psycopg};
    __pyx_t_2 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_6, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 19, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_logger, __pyx_t_2) < (0)) __PYX_ERR(0, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg.pyx":21
 * logger = logging.getLogger("psycopg")
 * 
 * PQ_TEXT = _pq_Format.TEXT             # <<<<<<<<<<<<<<
 * PQ_BINARY = _pq_Format.BINARY
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_pq_Format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PQ_TEXT, __pyx_t_6) < (0)) __PYX_ERR(0, 21, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg.pyx":22
 * 
 * PQ_TEXT = _pq_Format.TEXT
 * PQ_BINARY = _pq_Format.BINARY             # <<<<<<<<<<<<<<
 * 
 * PG_AUTO = _py_Format.AUTO
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_pq_Format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_BINARY); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PQ_BINARY, __pyx_t_2) < (0)) __PYX_ERR(0, 22, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg.pyx":24
 * PQ_BINARY = _pq_Format.BINARY
 * 
 * PG_AUTO = _py_Format.AUTO             # <<<<<<<<<<<<<<
 * PG_TEXT = _py_Format.TEXT
 * PG_BINARY = _py_Format.BINARY
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_py_Format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_AUTO); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PG_AUTO, __pyx_t_6) < (0)) __PYX_ERR(0, 24, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg.pyx":25
 * 
 * PG_AUTO = _py_Format.AUTO
 * PG_TEXT = _py_Format.TEXT             # <<<<<<<<<<<<<<
 * PG_BINARY = _py_Format.BINARY
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_py_Format); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_TEXT); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PG_TEXT, __pyx_t_2) < (0)) __PYX_ERR(0, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg.pyx":26
 * PG_AUTO = _py_Format.AUTO
 * PG_TEXT = _py_Format.TEXT
 * PG_BINARY = _py_Format.BINARY             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_py_Format); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PG_BINARY, __pyx_t_6) < (0)) __PYX_ERR(0, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":16
 * # Copyright (C) 2020 The Psycopg Team
 * 
 * from typing import Any             # <<<<<<<<<<<<<<
 * 
 * cimport cython
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Any};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_typing, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 16, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_6);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Any};
    __pyx_t_3 = 0; {
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_6, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_2) < (0)) __PYX_ERR(5, 16, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":32
 *     cdef pq.PGconn _pgconn
 * 
 *     oid = oids.INVALID_OID             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INVALID_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(5, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":57
 *         raise NotImplementedError()
 * 
 *     def dump(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         """Return the Postgres representation of *obj* as Python array of bytes"""
 *         cdef rv = PyByteArray_FromStringAndSize("", 0)
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Buffer_None) < (0)) __PYX_ERR(5, 57, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CDumper_3dump, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CDumper_dump, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[9])); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, __pyx_mstate_global->__pyx_n_u_dump, __pyx_t_2) < (0)) __PYX_ERR(5, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":64
 *         return rv
 * 
 *     def quote(self, obj) -> Buffer:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef char *ptr_out
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Buffer) < (0)) __PYX_ERR(5, 64, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CDumper_5quote, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CDumper_quote, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[10])); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, __pyx_mstate_global->__pyx_n_u_quote, __pyx_t_6) < (0)) __PYX_ERR(5, 64, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":120
 *         return rv
 * 
 *     cpdef object get_key(self, object obj, object format):             # <<<<<<<<<<<<<<
 *         return self.cls
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CDumper_7get_key, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CDumper_get_key, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[11])); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 120, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, __pyx_mstate_global->__pyx_n_u_get_key, __pyx_t_6) < (0)) __PYX_ERR(5, 120, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":123
 *         return self.cls
 * 
 *     cpdef object upgrade(self, object obj, object format):             # <<<<<<<<<<<<<<
 *         return self
 * 
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CDumper_9upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[12])); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_6) < (0)) __PYX_ERR(5, 123, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CDumper_11__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[13])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CDumper_13__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[14])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/adapt.pyx":157
 *         raise NotImplementedError()
 * 
 *     def load(self, object data) -> Any:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef Py_ssize_t length
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Any) < (0)) __PYX_ERR(5, 157, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CLoader_3load, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CLoader_load, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[15])); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_CLoader, __pyx_mstate_global->__pyx_n_u_load, __pyx_t_2) < (0)) __PYX_ERR(5, 157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CLoader_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[16])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7CLoader_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[17])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17_CRecursiveLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRecursiveLoader___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[18])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17_CRecursiveLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_CRecursiveLoader___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[19])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":19
 * from psycopg_c._psycopg cimport endian
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 19, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_6) < (0)) __PYX_ERR(7, 19, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":22
 * 
 * 
 * cdef int32_t _binary_null = -1             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_v_9psycopg_c_8_psycopg__binary_null = -1;

  /* "psycopg_c/_psycopg/copy.pyx":95
 * 
 * 
 * def format_row_binary(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_row, __pyx_mstate_global->__pyx_kp_u_Sequence_Any) < (0)) __PYX_ERR(7, 95, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_tx, __pyx_mstate_global->__pyx_n_u_Transformer) < (0)) __PYX_ERR(7, 95, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_out, __pyx_mstate_global->__pyx_n_u_bytearray) < (0)) __PYX_ERR(7, 95, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(7, 95, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_1format_row_binary, 0, __pyx_mstate_global->__pyx_n_u_format_row_binary, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[20])); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_format_row_binary, __pyx_t_6) < (0)) __PYX_ERR(7, 95, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":210
 * 
 * 
 * def format_row_text(row: Sequence[Any], tx: Transformer, out: bytearray) -> None:             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t size = PyByteArray_GET_SIZE(out)
 * 
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_row, __pyx_mstate_global->__pyx_kp_u_Sequence_Any) < (0)) __PYX_ERR(7, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_tx, __pyx_mstate_global->__pyx_n_u_Transformer) < (0)) __PYX_ERR(7, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_out, __pyx_mstate_global->__pyx_n_u_bytearray) < (0)) __PYX_ERR(7, 210, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(7, 210, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_3format_row_text, 0, __pyx_mstate_global->__pyx_n_u_format_row_text, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[21])); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 210, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_format_row_text, __pyx_t_2) < (0)) __PYX_ERR(7, 210, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":237
 * 
 * 
 * def parse_row_binary(data, tx: Transformer) -> tuple[Any, ...]:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *ptr
 *     cdef Py_ssize_t bufsize
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_tx, __pyx_mstate_global->__pyx_n_u_Transformer) < (0)) __PYX_ERR(7, 237, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_tuple_Any) < (0)) __PYX_ERR(7, 237, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_5parse_row_binary, 0, __pyx_mstate_global->__pyx_n_u_parse_row_binary, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[22])); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 237, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_row_binary, __pyx_t_6) < (0)) __PYX_ERR(7, 237, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/copy.pyx":272
 * 
 * 
 * def parse_row_text(data, tx: Transformer) -> tuple[Any, ...]:             # <<<<<<<<<<<<<<
 *     cdef unsigned char *fstart
 *     cdef Py_ssize_t size
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(7, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_tx, __pyx_mstate_global->__pyx_n_u_Transformer) < (0)) __PYX_ERR(7, 272, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_tuple_Any) < (0)) __PYX_ERR(7, 272, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_7parse_row_text, 0, __pyx_mstate_global->__pyx_n_u_parse_row_text, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[23])); if (unlikely(!__pyx_t_2)) __PYX_ERR(7, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_parse_row_text, __pyx_t_2) < (0)) __PYX_ERR(7, 272, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":9
 * from cpython.object cimport PyObject_CallFunctionObjArgs
 * 
 * from time import monotonic             # <<<<<<<<<<<<<<
 * from collections import deque
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_monotonic};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_time, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 9, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_monotonic};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 9, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(8, 9, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":10
 * 
 * from time import monotonic
 * from collections import deque             # <<<<<<<<<<<<<<
 * 
 * from psycopg import errors as e
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_deque};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_collections, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 10, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_deque};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 10, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(8, 10, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":12
 * from collections import deque
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * from psycopg.pq import abc
 * from psycopg.abc import PipelineCommand, PQGen
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 12, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_6) < (0)) __PYX_ERR(8, 12, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":13
 * 
 * from psycopg import errors as e
 * from psycopg.pq import abc             # <<<<<<<<<<<<<<
 * from psycopg.abc import PipelineCommand, PQGen
 * from psycopg._enums import Ready, Wait
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_abc};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg_pq, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 13, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_abc};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(8, 13, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":14
 * from psycopg import errors as e
 * from psycopg.pq import abc
 * from psycopg.abc import PipelineCommand, PQGen             # <<<<<<<<<<<<<<
 * from psycopg._enums import Ready, Wait
 * from psycopg._encodings import conninfo_encoding
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PipelineCommand,__pyx_mstate_global->__pyx_n_u_PQGen};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg_abc, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 14, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_PipelineCommand,__pyx_mstate_global->__pyx_n_u_PQGen};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(8, 14, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":15
 * from psycopg.pq import abc
 * from psycopg.abc import PipelineCommand, PQGen
 * from psycopg._enums import Ready, Wait             # <<<<<<<<<<<<<<
 * from psycopg._encodings import conninfo_encoding
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Ready,__pyx_mstate_global->__pyx_n_u_Wait};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg__enums, __pyx_imported_names, 2, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 15, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Ready,__pyx_mstate_global->__pyx_n_u_Wait};
    for (__pyx_t_3=0; __pyx_t_3 < 2; __pyx_t_3++) {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 15, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(8, 15, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":16
 * from psycopg.abc import PipelineCommand, PQGen
 * from psycopg._enums import Ready, Wait
 * from psycopg._encodings import conninfo_encoding             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_conninfo_encoding};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg__encodings, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(8, 16, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_conninfo_encoding};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(8, 16, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":19
 * 
 * 
 * cdef object WAIT_W = Wait.W             # <<<<<<<<<<<<<<
 * cdef object WAIT_R = Wait.R
 * cdef object WAIT_RW = Wait.RW
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Wait); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_W); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_W);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_WAIT_W, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":20
 * 
 * cdef object WAIT_W = Wait.W
 * cdef object WAIT_R = Wait.R             # <<<<<<<<<<<<<<
 * cdef object WAIT_RW = Wait.RW
 * cdef object PY_READY_NONE = Ready.NONE
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Wait); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_R); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 20, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_R);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_WAIT_R, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":21
 * cdef object WAIT_W = Wait.W
 * cdef object WAIT_R = Wait.R
 * cdef object WAIT_RW = Wait.RW             # <<<<<<<<<<<<<<
 * cdef object PY_READY_NONE = Ready.NONE
 * cdef object PY_READY_R = Ready.R
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Wait); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_RW); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 21, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_WAIT_RW);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_WAIT_RW, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":22
 * cdef object WAIT_R = Wait.R
 * cdef object WAIT_RW = Wait.RW
 * cdef object PY_READY_NONE = Ready.NONE             # <<<<<<<<<<<<<<
 * cdef object PY_READY_R = Ready.R
 * cdef object PY_READY_W = Ready.W
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_NONE); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 22, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_PY_READY_NONE);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_PY_READY_NONE, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":23
 * cdef object WAIT_RW = Wait.RW
 * cdef object PY_READY_NONE = Ready.NONE
 * cdef object PY_READY_R = Ready.R             # <<<<<<<<<<<<<<
 * cdef object PY_READY_W = Ready.W
 * cdef object PY_READY_RW = Ready.RW
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_R); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 23, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_PY_READY_R);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_PY_READY_R, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":24
 * cdef object PY_READY_NONE = Ready.NONE
 * cdef object PY_READY_R = Ready.R
 * cdef object PY_READY_W = Ready.W             # <<<<<<<<<<<<<<
 * cdef object PY_READY_RW = Ready.RW
 * cdef int READY_NONE = Ready.NONE
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_W); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 24, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_PY_READY_W);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_PY_READY_W, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":25
 * cdef object PY_READY_R = Ready.R
 * cdef object PY_READY_W = Ready.W
 * cdef object PY_READY_RW = Ready.RW             # <<<<<<<<<<<<<<
 * cdef int READY_NONE = Ready.NONE
 * cdef int READY_R = Ready.R
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_RW); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_PY_READY_RW);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_PY_READY_RW, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":26
 * cdef object PY_READY_W = Ready.W
 * cdef object PY_READY_RW = Ready.RW
 * cdef int READY_NONE = Ready.NONE             # <<<<<<<<<<<<<<
 * cdef int READY_R = Ready.R
 * cdef int READY_W = Ready.W
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_NONE); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(8, 26, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_9psycopg_c_8_psycopg_READY_NONE = __pyx_t_8;

  /* "psycopg_c/_psycopg/generators.pyx":27
 * cdef object PY_READY_RW = Ready.RW
 * cdef int READY_NONE = Ready.NONE
 * cdef int READY_R = Ready.R             # <<<<<<<<<<<<<<
 * cdef int READY_W = Ready.W
 * cdef int READY_RW = Ready.RW
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_R); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 27, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyLong_As_int(__pyx_t_6); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(8, 27, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_9psycopg_c_8_psycopg_READY_R = __pyx_t_8;

  /* "psycopg_c/_psycopg/generators.pyx":28
 * cdef int READY_NONE = Ready.NONE
 * cdef int READY_R = Ready.R
 * cdef int READY_W = Ready.W             # <<<<<<<<<<<<<<
 * cdef int READY_RW = Ready.RW
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_W); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 28, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_PyLong_As_int(__pyx_t_2); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(8, 28, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_9psycopg_c_8_psycopg_READY_W = __pyx_t_8;

  /* "psycopg_c/_psycopg/generators.pyx":29
 * cdef int READY_R = Ready.R
 * cdef int READY_W = Ready.W
 * cdef int READY_RW = Ready.RW             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Ready); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_RW); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 29, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_8 = __Pyx_PyLong_As_int(__pyx_t_6); if (unlikely((__pyx_t_8 == (int)-1) && PyErr_Occurred())) __PYX_ERR(8, 29, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_9psycopg_c_8_psycopg_READY_RW = __pyx_t_8;

  /* "psycopg_c/_psycopg/generators.pyx":32
 * 
 * 
 * def connect(conninfo: str, *, timeout: float = 0.0) -> PQGenConn[abc.PGconn]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to create a database connection without blocking.
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyFloat_FromDouble(((double)0.0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_timeout, __pyx_t_2) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_conninfo, __pyx_mstate_global->__pyx_n_u_str) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_timeout, __pyx_mstate_global->__pyx_n_u_float) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGenConn_abc_PGconn) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9connect, 0, __pyx_mstate_global->__pyx_n_u_connect, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[0])); if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 32, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsKwDict(__pyx_t_4, __pyx_t_6);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_connect, __pyx_t_4) < (0)) __PYX_ERR(8, 32, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":89
 * 
 * 
 * def cancel(pq.PGcancelConn cancel_conn, *, timeout: float = 0.0) -> PQGenConn[None]:             # <<<<<<<<<<<<<<
 *     cdef libpq.PGcancelConn *pgcancelconn_ptr = cancel_conn.pgcancelconn_ptr
 *     cdef int status
*/
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(8, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyFloat_FromDouble(((double)0.0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_timeout, __pyx_t_2) < (0)) __PYX_ERR(8, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_timeout, __pyx_mstate_global->__pyx_n_u_float) < (0)) __PYX_ERR(8, 89, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGenConn_None) < (0)) __PYX_ERR(8, 89, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12cancel, 0, __pyx_mstate_global->__pyx_n_u_cancel, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[1])); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 89, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetDefaultsKwDict(__pyx_t_6, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_cancel, __pyx_t_6) < (0)) __PYX_ERR(8, 89, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":116
 * 
 * 
 * def execute(pq.PGconn pgconn) -> PQGen[list[abc.PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator sending a query and returning results without blocking.
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGen_list_abc_PGresult) < (0)) __PYX_ERR(8, 116, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15execute, 0, __pyx_mstate_global->__pyx_n_u_execute, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[2])); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_execute, __pyx_t_2) < (0)) __PYX_ERR(8, 116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":132
 * 
 * 
 * def send(pq.PGconn pgconn) -> PQGen[None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator to send a query to the server without blocking.
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGen_None) < (0)) __PYX_ERR(8, 132, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18send, 0, __pyx_mstate_global->__pyx_n_u_send, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[3])); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_send, __pyx_t_6) < (0)) __PYX_ERR(8, 132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":166
 * 
 * 
 * def fetch_many(pq.PGconn pgconn) -> PQGen[list[PGresult]]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving results from the database without blocking.
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGen_list_PGresult) < (0)) __PYX_ERR(8, 166, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21fetch_many, 0, __pyx_mstate_global->__pyx_n_u_fetch_many, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[5])); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 166, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_fetch_many, __pyx_t_2) < (0)) __PYX_ERR(8, 166, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":218
 * 
 * 
 * def fetch(pq.PGconn pgconn) -> PQGen[PGresult | None]:             # <<<<<<<<<<<<<<
 *     """
 *     Generator retrieving a single result from the database without blocking.
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGen_PGresult_None) < (0)) __PYX_ERR(8, 218, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_24fetch, 0, __pyx_mstate_global->__pyx_n_u_fetch, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[6])); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_fetch, __pyx_t_6) < (0)) __PYX_ERR(8, 218, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/generators.pyx":265
 * 
 * 
 * def pipeline_communicate(             # <<<<<<<<<<<<<<
 *     pq.PGconn pgconn, commands: deque[PipelineCommand]
 * ) -> PQGen[list[list[PGresult]]]:
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(8, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_commands, __pyx_mstate_global->__pyx_kp_u_deque_PipelineCommand) < (0)) __PYX_ERR(8, 265, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_PQGen_list_list_PGresult) < (0)) __PYX_ERR(8, 265, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_27pipeline_communicate, 0, __pyx_mstate_global->__pyx_n_u_pipeline_communicate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[7])); if (unlikely(!__pyx_t_2)) __PYX_ERR(8, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pipeline_communicate, __pyx_t_2) < (0)) __PYX_ERR(8, 265, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":21
 * from cpython.sequence cimport PySequence_Fast_GET_SIZE
 * 
 * from typing import Sequence             # <<<<<<<<<<<<<<
 * 
 * from psycopg import errors as e
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Sequence};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_typing, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 21, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Sequence};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 21, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(9, 21, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":23
 * from typing import Sequence
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * from psycopg.pq import Format as PqFormat
 * from psycopg.rows import Row
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 23, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_6) < (0)) __PYX_ERR(9, 23, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":24
 * 
 * from psycopg import errors as e
 * from psycopg.pq import Format as PqFormat             # <<<<<<<<<<<<<<
 * from psycopg.rows import Row
 * from psycopg._encodings import conn_encoding
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Format};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg_pq, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 24, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Format};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 24, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_PqFormat, __pyx_t_6) < (0)) __PYX_ERR(9, 24, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":25
 * from psycopg import errors as e
 * from psycopg.pq import Format as PqFormat
 * from psycopg.rows import Row             # <<<<<<<<<<<<<<
 * from psycopg._encodings import conn_encoding
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Row};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg_rows, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 25, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Row};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(9, 25, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":26
 * from psycopg.pq import Format as PqFormat
 * from psycopg.rows import Row
 * from psycopg._encodings import conn_encoding             # <<<<<<<<<<<<<<
 * 
 * NoneType = type(None)
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_conn_encoding};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg__encodings, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(9, 26, __pyx_L1_error)
  }
  __pyx_t_2 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_2);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_conn_encoding};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_2, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 26, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(9, 26, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":28
 * from psycopg._encodings import conn_encoding
 * 
 * NoneType = type(None)             # <<<<<<<<<<<<<<
 * 
 * # internal structure: you are not supposed to know this. But it's worth some
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_NoneType, ((PyObject *)Py_TYPE(Py_None))) < (0)) __PYX_ERR(9, 28, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9RowLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_RowLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[24])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RowLoader, (type(self), 0xa44f3c5, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RowLoader__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9RowLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_RowLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[25])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowLoader, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9RowDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_RowDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[26])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_RowDumper, (type(self), 0x597b60c, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_RowDumper__set_state(self, __pyx_state)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9RowDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_RowDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[27])); if (unlikely(!__pyx_t_2)) __PYX_ERR(6, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_RowDumper, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_2) < (0)) __PYX_ERR(6, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":112
 *         self._none_oid = -1
 * 
 *     @classmethod             # <<<<<<<<<<<<<<
 *     def from_context(cls, context: "AdaptContext" | None):
 *         """
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_context, __pyx_mstate_global->__pyx_kp_u_AdaptContext_None) < (0)) __PYX_ERR(9, 112, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_3from_context, __Pyx_CYFUNCTION_CLASSMETHOD | __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_from_context, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[28])); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_from_context, __pyx_t_6) < (0)) __PYX_ERR(9, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_GetNameInClass(__pyx_t_6, (PyObject*)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_from_context); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_Method_ClassMethod(__pyx_t_6); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_from_context, __pyx_t_2) < (0)) __PYX_ERR(9, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_5set_pgresult, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_set_pgresult, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[29])); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_2, __pyx_mstate_global->__pyx_tuple[1]);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_set_pgresult, __pyx_t_2) < (0)) __PYX_ERR(9, 131, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":172
 *         self._row_loaders = loaders
 * 
 *     def set_dumper_types(self, types: Sequence[int], format: PqFormat) -> None:             # <<<<<<<<<<<<<<
 *         # NOTE: impl detail - final _row_dumpers must be a list type
 *         # (assumed by format_row_binary and format_row_text)
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_types, __pyx_mstate_global->__pyx_kp_u_Sequence_int) < (0)) __PYX_ERR(9, 172, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_format, __pyx_mstate_global->__pyx_n_u_PqFormat) < (0)) __PYX_ERR(9, 172, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(9, 172, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_7set_dumper_types, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_set_dumper_types, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[30])); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 172, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_set_dumper_types, __pyx_t_6) < (0)) __PYX_ERR(9, 172, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":189
 *         self.formats = [format] * ntypes
 * 
 *     def set_loader_types(self, types: Sequence[int], format: PqFormat) -> None:             # <<<<<<<<<<<<<<
 *         cdef types_fast = PySequence_Fast(types, "'types' is not a valid sequence")
 *         cdef Py_ssize_t ntypes = PySequence_Fast_GET_SIZE(types_fast)
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_types, __pyx_mstate_global->__pyx_kp_u_Sequence_int) < (0)) __PYX_ERR(9, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_format, __pyx_mstate_global->__pyx_n_u_PqFormat) < (0)) __PYX_ERR(9, 189, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_None) < (0)) __PYX_ERR(9, 189, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_9set_loader_types, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_set_loader_types, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[31])); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 189, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_set_loader_types, __pyx_t_2) < (0)) __PYX_ERR(9, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":205
 *         self._row_loaders = loaders
 * 
 *     cpdef as_literal(self, obj):             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>PG_TEXT)
*/
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_11as_literal, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_as_literal, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[32])); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 205, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_as_literal, __pyx_t_2) < (0)) __PYX_ERR(9, 205, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":246
 *         return rv
 * 
 *     def get_dumper(self, obj, format) -> "Dumper":             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_dumper = self.get_row_dumper(
 *             <PyObject *>obj, <PyObject *>format)
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Dumper) < (0)) __PYX_ERR(9, 246, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_13get_dumper, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_get_dumper, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[33])); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_get_dumper, __pyx_t_6) < (0)) __PYX_ERR(9, 246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":355
 *         return ptr
 * 
 *     cpdef dump_sequence(self, object params, object formats):             # <<<<<<<<<<<<<<
 *         cdef int i
 *         cdef PyObject *dumper_ptr  # borrowed pointer to row dumper
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_15dump_sequence, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_dump_sequence, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[34])); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_dump_sequence, __pyx_t_6) < (0)) __PYX_ERR(9, 355, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":431
 *         return out
 * 
 *     def load_rows(self, int row0, int row1, object make_row) -> list[Row]:             # <<<<<<<<<<<<<<
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_list_Row) < (0)) __PYX_ERR(9, 431, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_17load_rows, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_load_rows, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[35])); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_load_rows, __pyx_t_2) < (0)) __PYX_ERR(9, 431, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":487
 *         return records
 * 
 *     def load_row(self, int row, object make_row) -> Row:             # <<<<<<<<<<<<<<
 *         if self._pgresult is None:
 *             raise e.InterfaceError("result not set")
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Row) < (0)) __PYX_ERR(9, 487, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_19load_row, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_load_row, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[36])); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_load_row, __pyx_t_6) < (0)) __PYX_ERR(9, 487, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":533
 *         return record
 * 
 *     cpdef object load_sequence(self, record: Sequence[Buffer | None]):             # <<<<<<<<<<<<<<
 *         cdef record_fast = PySequence_Fast(record, "'record' is not a valid sequence")
 *         cdef Py_ssize_t nfields = PySequence_Fast_GET_SIZE(record_fast)
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_record, __pyx_mstate_global->__pyx_kp_u_Sequence_Buffer_None) < (0)) __PYX_ERR(9, 533, __pyx_L1_error)
  __pyx_t_2 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_21load_sequence, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_load_sequence, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[37])); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_2);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_2, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_load_sequence, __pyx_t_2) < (0)) __PYX_ERR(9, 533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "psycopg_c/_psycopg/transform.pyx":567
 *         return out
 * 
 *     def get_loader(self, oid: int, format: PqFormat) -> "Loader":             # <<<<<<<<<<<<<<
 *         cdef PyObject *row_loader = self._c_get_loader(
 *             <PyObject *>oid, <PyObject *>format)
*/
  __pyx_t_2 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_2)) __PYX_ERR(9, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_oid, __pyx_mstate_global->__pyx_n_u_int) < (0)) __PYX_ERR(9, 567, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_format, __pyx_mstate_global->__pyx_n_u_PqFormat) < (0)) __PYX_ERR(9, 567, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Loader) < (0)) __PYX_ERR(9, 567, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_23get_loader, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer_get_loader, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[38])); if (unlikely(!__pyx_t_6)) __PYX_ERR(9, 567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Transformer, __pyx_mstate_global->__pyx_n_u_get_loader, __pyx_t_6) < (0)) __PYX_ERR(9, 567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_25__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[39])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11Transformer_27__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Transformer___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[40])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/waiting.pyx":9
 * from cpython.object cimport PyObject_CallFunctionObjArgs
 * 
 * from os import fstat             # <<<<<<<<<<<<<<
 * from typing import TypeVar
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_fstat};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_os, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 9, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_6);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_fstat};
    __pyx_t_3 = 0; {
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_6, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 9, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_2) < (0)) __PYX_ERR(10, 9, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/waiting.pyx":10
 * 
 * from os import fstat
 * from typing import TypeVar             # <<<<<<<<<<<<<<
 * 
 * from psycopg import errors as e
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TypeVar};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_typing, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 10, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_6);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_TypeVar};
    __pyx_t_3 = 0; {
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_6, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 10, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_2) < (0)) __PYX_ERR(10, 10, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/waiting.pyx":12
 * from typing import TypeVar
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * 
 * RV = TypeVar("RV")
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(10, 12, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_6);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_6, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_2)) __PYX_ERR(10, 12, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_2) < (0)) __PYX_ERR(10, 12, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/waiting.pyx":14
 * from psycopg import errors as e
 * 
 * RV = TypeVar("RV")             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_TypeVar); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_RV};
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_4, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(10, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_RV, __pyx_t_6) < (0)) __PYX_ERR(10, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/_psycopg/waiting.pyx":201
 * 
 * 
 * def wait_c(gen: PQGen[RV], int fileno, interval = 0.0) -> RV:             # <<<<<<<<<<<<<<
 *     """
 *     Wait for a generator using poll or select.
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(10, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_gen, __pyx_mstate_global->__pyx_kp_u_PQGen_RV) < (0)) __PYX_ERR(10, 201, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_RV) < (0)) __PYX_ERR(10, 201, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_30wait_c, 0, __pyx_mstate_global->__pyx_n_u_wait_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[41])); if (unlikely(!__pyx_t_4)) __PYX_ERR(10, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_wait_c, __pyx_t_4) < (0)) __PYX_ERR(10, 201, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/array.pyx":20
 * from psycopg_c.pq.libpq cimport Oid
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(11, 20, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(11, 20, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_6) < (0)) __PYX_ERR(11, 20, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/array.pyx":33
 * cdef class ArrayLoader(_CRecursiveLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     base_oid = 0
 *     delimiter = b","
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_4) < (0)) __PYX_ERR(11, 33, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/array.pyx":34
 * 
 *     format = PQ_TEXT
 *     base_oid = 0             # <<<<<<<<<<<<<<
 *     delimiter = b","
 * 
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader, __pyx_mstate_global->__pyx_n_u_base_oid, __pyx_mstate_global->__pyx_int_0) < (0)) __PYX_ERR(11, 34, __pyx_L1_error)

  /* "psycopg_c/types/array.pyx":35
 *     format = PQ_TEXT
 *     base_oid = 0
 *     delimiter = b","             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *row_loader
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ArrayLoader, __pyx_mstate_global->__pyx_n_u_delimiter, __pyx_mstate_global->__pyx_kp_b__6) < (0)) __PYX_ERR(11, 35, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11ArrayLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ArrayLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[42])); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11ArrayLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ArrayLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[43])); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/array.pyx":63
 * cdef class ArrayBinaryLoader(_CRecursiveLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef PyObject *row_loader
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_4)) __PYX_ERR(11, 63, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ArrayBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_4) < (0)) __PYX_ERR(11, 63, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17ArrayBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ArrayBinaryLoader___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[44])); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_4) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17ArrayBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ArrayBinaryLoader___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[45])); if (unlikely(!__pyx_t_4)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_4);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_4) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":25
 *     cdef int *_uspad
 * 
 * from datetime import date, datetime, time, timedelta, timezone             # <<<<<<<<<<<<<<
 * from zoneinfo import ZoneInfo
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_date,__pyx_mstate_global->__pyx_n_u_datetime,__pyx_mstate_global->__pyx_n_u_time,__pyx_mstate_global->__pyx_n_u_timedelta,__pyx_mstate_global->__pyx_n_u_timezone};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_datetime, __pyx_imported_names, 5, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 25, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_date,__pyx_mstate_global->__pyx_n_u_datetime,__pyx_mstate_global->__pyx_n_u_time,__pyx_mstate_global->__pyx_n_u_timedelta,__pyx_mstate_global->__pyx_n_u_timezone};
    for (__pyx_t_3=0; __pyx_t_3 < 5; __pyx_t_3++) {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 25, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(1, 25, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":26
 * 
 * from datetime import date, datetime, time, timedelta, timezone
 * from zoneinfo import ZoneInfo             # <<<<<<<<<<<<<<
 * 
 * from psycopg_c._psycopg cimport endian
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ZoneInfo};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_zoneinfo, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 26, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_ZoneInfo};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 26, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(1, 26, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":30
 * from psycopg_c._psycopg cimport endian
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * 
 * # Initialise the datetime C API
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 30, __pyx_L1_error)
  }
  __pyx_t_4 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_4);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_4, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 30, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_6) < (0)) __PYX_ERR(1, 30, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":33
 * 
 * # Initialise the datetime C API
 * cdt.import_datetime()             # <<<<<<<<<<<<<<
 * 
 * cdef enum:
*/
  __pyx_f_7cpython_8datetime_import_datetime();

  /* "psycopg_c/types/datetime.pyx":51
 *     PY_DATE_MIN_DAYS = 1  # date.min.toordinal()
 * 
 * cdef object date_toordinal = date.toordinal             # <<<<<<<<<<<<<<
 * cdef object date_fromordinal = date.fromordinal
 * cdef object datetime_astimezone = datetime.astimezone
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_date); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_toordinal); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 51, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_date_toordinal);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_date_toordinal, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":52
 * 
 * cdef object date_toordinal = date.toordinal
 * cdef object date_fromordinal = date.fromordinal             # <<<<<<<<<<<<<<
 * cdef object datetime_astimezone = datetime.astimezone
 * cdef object time_utcoffset = time.utcoffset
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_date); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_fromordinal); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 52, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_date_fromordinal);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_date_fromordinal, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":53
 * cdef object date_toordinal = date.toordinal
 * cdef object date_fromordinal = date.fromordinal
 * cdef object datetime_astimezone = datetime.astimezone             # <<<<<<<<<<<<<<
 * cdef object time_utcoffset = time.utcoffset
 * cdef object timedelta_total_seconds = timedelta.total_seconds
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_datetime); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_astimezone); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 53, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_datetime_astimezone);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_datetime_astimezone, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":54
 * cdef object date_fromordinal = date.fromordinal
 * cdef object datetime_astimezone = datetime.astimezone
 * cdef object time_utcoffset = time.utcoffset             # <<<<<<<<<<<<<<
 * cdef object timedelta_total_seconds = timedelta.total_seconds
 * cdef object timezone_utc = timezone.utc
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_time); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_utcoffset); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 54, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_time_utcoffset);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_time_utcoffset, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":55
 * cdef object datetime_astimezone = datetime.astimezone
 * cdef object time_utcoffset = time.utcoffset
 * cdef object timedelta_total_seconds = timedelta.total_seconds             # <<<<<<<<<<<<<<
 * cdef object timezone_utc = timezone.utc
 * cdef object pg_datetime_epoch = datetime(2000, 1, 1)
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_timedelta); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_total_seconds); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 55, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_timedelta_total_seconds);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_timedelta_total_seconds, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":56
 * cdef object time_utcoffset = time.utcoffset
 * cdef object timedelta_total_seconds = timedelta.total_seconds
 * cdef object timezone_utc = timezone.utc             # <<<<<<<<<<<<<<
 * cdef object pg_datetime_epoch = datetime(2000, 1, 1)
 * cdef object pg_datetimetz_epoch = datetime(2000, 1, 1, tzinfo=timezone.utc)
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_timezone); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_utc); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 56, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_timezone_utc);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_timezone_utc, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;

  /* "psycopg_c/types/datetime.pyx":57
 * cdef object timedelta_total_seconds = timedelta.total_seconds
 * cdef object timezone_utc = timezone.utc
 * cdef object pg_datetime_epoch = datetime(2000, 1, 1)             # <<<<<<<<<<<<<<
 * cdef object pg_datetimetz_epoch = datetime(2000, 1, 1, tzinfo=timezone.utc)
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_datetime); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_mstate_global->__pyx_tuple[3], NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_pg_datetime_epoch, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":58
 * cdef object timezone_utc = timezone.utc
 * cdef object pg_datetime_epoch = datetime(2000, 1, 1)
 * cdef object pg_datetimetz_epoch = datetime(2000, 1, 1, tzinfo=timezone.utc)             # <<<<<<<<<<<<<<
 * 
 * cdef object _month_abbr = {
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_datetime); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_timezone); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_utc); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_tzinfo, __pyx_t_5) < (0)) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_mstate_global->__pyx_tuple[3], __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg_pg_datetimetz_epoch, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":60
 * cdef object pg_datetimetz_epoch = datetime(2000, 1, 1, tzinfo=timezone.utc)
 * 
 * cdef object _month_abbr = {             # <<<<<<<<<<<<<<
 *     n: i
 *     for i, n in enumerate(
*/
  { /* enter inner scope */
    __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 60, __pyx_L4_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_mstate_global->__pyx_int_1);
    __pyx_t_9 = __pyx_mstate_global->__pyx_int_1;

    /* "psycopg_c/types/datetime.pyx":63
 *     n: i
 *     for i, n in enumerate(
 *         b"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(), 1             # <<<<<<<<<<<<<<
 *     )
 * }
*/
    __pyx_t_6 = __pyx_mstate_global->__pyx_kp_b_Jan_Feb_Mar_Apr_May_Jun_Jul_Aug;
    __Pyx_INCREF(__pyx_t_6);
    __pyx_t_7 = 0;
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
      __pyx_t_4 = __Pyx_PyObject_FastCallMethod((PyObject*)__pyx_mstate_global->__pyx_n_u_split, __pyx_callargs+__pyx_t_7, (1-__pyx_t_7) | (1*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 63, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
    }

    /* "psycopg_c/types/datetime.pyx":62
 * cdef object _month_abbr = {
 *     n: i
 *     for i, n in enumerate(             # <<<<<<<<<<<<<<
 *         b"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(), 1
 *     )
*/
    __pyx_t_6 = __pyx_t_4; __Pyx_INCREF(__pyx_t_6);
    __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      {
        Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_6);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 62, __pyx_L4_error)
        #endif
        if (__pyx_t_3 >= __pyx_temp) break;
      }
      __pyx_t_4 = __Pyx_PyList_GetItemRefFast(__pyx_t_6, __pyx_t_3, __Pyx_ReferenceSharing_OwnStrongReference);
      ++__pyx_t_3;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 62, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n);
      __Pyx_DECREF_SET(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_INCREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i);
      __Pyx_DECREF_SET(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i, __pyx_t_9);
      __Pyx_GIVEREF(__pyx_t_9);
      __pyx_t_4 = __Pyx_PyLong_AddObjC(__pyx_t_9, __pyx_mstate_global->__pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 62, __pyx_L4_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_9);
      __pyx_t_9 = ((PyObject*)__pyx_t_4);
      __pyx_t_4 = 0;

      /* "psycopg_c/types/datetime.pyx":61
 * 
 * cdef object _month_abbr = {
 *     n: i             # <<<<<<<<<<<<<<
 *     for i, n in enumerate(
 *         b"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(), 1
*/
      if (unlikely(PyDict_SetItem(__pyx_t_5, (PyObject*)__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n, (PyObject*)__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i))) __PYX_ERR(1, 61, __pyx_L4_error)

      /* "psycopg_c/types/datetime.pyx":62
 * cdef object _month_abbr = {
 *     n: i
 *     for i, n in enumerate(             # <<<<<<<<<<<<<<
 *         b"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(), 1
 *     )
*/
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
    __Pyx_GOTREF(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i);
    __Pyx_DECREF_SET(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i, Py_None);
    __Pyx_GOTREF(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n);
    __Pyx_DECREF_SET(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n, Py_None);
    goto __pyx_L8_exit_scope;
    __pyx_L4_error:;
    __Pyx_GOTREF(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i);
    __Pyx_DECREF_SET(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_i, Py_None);
    __Pyx_GOTREF(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n);
    __Pyx_DECREF_SET(__pyx_8genexpr1__pyx_v_9psycopg_c_8_psycopg_n, Py_None);
    goto __pyx_L1_error;
    __pyx_L8_exit_scope:;
  } /* exit inner scope */
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg__month_abbr);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg__month_abbr, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":71
 * cdef class DateDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     oid = oids.DATE_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 71, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 71, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":72
 * 
 *     format = PQ_TEXT
 *     oid = oids.DATE_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_DATE_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 72, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 72, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10DateDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[46])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10DateDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[47])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":91
 * cdef class DateBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.DATE_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 91, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 91, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":92
 * 
 *     format = PQ_BINARY
 *     oid = oids.DATE_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_DATE_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 92, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateBinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[48])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateBinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[49])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":106
 * cdef class _BaseTimeDumper(CDumper):
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         # Use (cls,) to report the need to upgrade to a dumper for timetz (the
 *         # Frankenstein of the data types).
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_1get_key, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimeDumper_get_key, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[50])); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper, __pyx_mstate_global->__pyx_n_u_get_key, __pyx_t_5) < (0)) __PYX_ERR(1, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":114
 *             return (self.cls,)
 * 
 *     cpdef upgrade(self, obj: time, format):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_obj, __pyx_mstate_global->__pyx_n_u_time) < (0)) __PYX_ERR(1, 114, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_3upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimeDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[51])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 114, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_6) < (0)) __PYX_ERR(1, 114, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimeDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[52])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15_BaseTimeDumper_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimeDumper___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[53])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":128
 * cdef class _BaseTimeTextDumper(_BaseTimeDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseTimeTextDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(1, 128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimeTextDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[54])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_BaseTimeTextDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimeTextDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[55])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":145
 * cdef class TimeDumper(_BaseTimeTextDumper):
 * 
 *     oid = oids.TIME_OID             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj, format):
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIME_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(1, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":147
 *     oid = oids.TIME_OID
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if not obj.tzinfo:
 *             return self
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TimeDumper_1upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[56])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_6) < (0)) __PYX_ERR(1, 147, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TimeDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[57])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TimeDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[58])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":157
 * cdef class TimeTzDumper(_BaseTimeTextDumper):
 * 
 *     oid = oids.TIMETZ_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIMETZ_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(1, 157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12TimeTzDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeTzDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[59])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12TimeTzDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeTzDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[60])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":167
 * cdef class TimeBinaryDumper(_BaseTimeDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.TIME_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(1, 167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":168
 * 
 *     format = PQ_BINARY
 *     oid = oids.TIME_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIME_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 168, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(1, 168, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":181
 *         return sizeof(beus)
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if not obj.tzinfo:
 *             return self
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryDumper_1upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeBinaryDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[61])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 181, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_6) < (0)) __PYX_ERR(1, 181, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeBinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[62])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeBinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[63])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":191
 * cdef class TimeTzBinaryDumper(_BaseTimeDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.TIMETZ_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(1, 191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":192
 * 
 *     format = PQ_BINARY
 *     oid = oids.TIMETZ_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIMETZ_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeTzBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(1, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeTzBinaryDumper___reduce_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[64])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18TimeTzBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeTzBinaryDumper___setstate_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[65])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":214
 * cdef class _BaseDatetimeDumper(CDumper):
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         # Use (cls,) to report the need to upgrade (downgrade, actually) to a
 *         # dumper for naive timestamp.
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_1get_key, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseDatetimeDumper_get_key, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[66])); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper, __pyx_mstate_global->__pyx_n_u_get_key, __pyx_t_6) < (0)) __PYX_ERR(1, 214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/datetime.pyx":222
 *             return (self.cls,)
 * 
 *     cpdef upgrade(self, obj: time, format):             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_obj, __pyx_mstate_global->__pyx_n_u_time) < (0)) __PYX_ERR(1, 222, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_3upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseDatetimeDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[67])); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_5) < (0)) __PYX_ERR(1, 222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseDatetimeDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[68])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_BaseDatetimeDumper_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseDatetimeDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[69])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":228
 * cdef class _BaseDatetimeTextDumper(_BaseDatetimeDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__BaseDatetimeTextDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 228, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseDatetimeTextDumper___reduce, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[70])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_23_BaseDatetimeTextDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseDatetimeTextDumper___setsta, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[71])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":247
 * cdef class DatetimeDumper(_BaseDatetimeTextDumper):
 * 
 *     oid = oids.TIMESTAMPTZ_OID             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj, format):
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIMESTAMPTZ_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":249
 *     oid = oids.TIMESTAMPTZ_OID
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if obj.tzinfo:
 *             return self
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14DatetimeDumper_1upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[72])); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_5) < (0)) __PYX_ERR(1, 249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14DatetimeDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[73])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14DatetimeDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[74])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":259
 * cdef class DatetimeNoTzDumper(_BaseDatetimeTextDumper):
 * 
 *     oid = oids.TIMESTAMP_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIMESTAMP_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeNoTzDumper___reduce_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[75])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18DatetimeNoTzDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeNoTzDumper___setstate_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[76])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":265
 * cdef class DatetimeBinaryDumper(_BaseDatetimeDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.TIMESTAMPTZ_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 265, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 265, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":266
 * 
 *     format = PQ_BINARY
 *     oid = oids.TIMESTAMPTZ_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIMESTAMPTZ_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 266, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 266, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":280
 *         return sizeof(beus)
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         if obj.tzinfo:
 *             return self
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_1upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeBinaryDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[77])); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeBinaryDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_5) < (0)) __PYX_ERR(1, 280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeBinaryDumper___reduce_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[78])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20DatetimeBinaryDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeBinaryDumper___setstate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[79])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":290
 * cdef class DatetimeNoTzBinaryDumper(_BaseDatetimeDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.TIMESTAMP_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":291
 * 
 *     format = PQ_BINARY
 *     oid = oids.TIMESTAMP_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TIMESTAMP_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DatetimeNoTzBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeNoTzBinaryDumper___reduc, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[80])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_24DatetimeNoTzBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DatetimeNoTzBinaryDumper___setst, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[81])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":309
 * cdef class TimedeltaDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     oid = oids.INTERVAL_OID
 *     cdef int _style
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":310
 * 
 *     format = PQ_TEXT
 *     oid = oids.INTERVAL_OID             # <<<<<<<<<<<<<<
 *     cdef int _style
 * 
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INTERVAL_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 310, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15TimedeltaDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimedeltaDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[82])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15TimedeltaDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimedeltaDumper___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[83])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":346
 * cdef class TimedeltaBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.INTERVAL_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 346, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":347
 * 
 *     format = PQ_BINARY
 *     oid = oids.INTERVAL_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INTERVAL_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimedeltaBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(1, 347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimedeltaBinaryDumper___reduce_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[84])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21TimedeltaBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimedeltaBinaryDumper___setstate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[85])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":371
 * cdef class DateLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     cdef int _order
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10DateLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[86])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10DateLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[87])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":425
 * cdef class DateBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DateBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 425, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateBinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[88])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16DateBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DateBinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[89])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":445
 * cdef class TimeLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 445, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 445, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TimeLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[90])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TimeLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[91])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":475
 * cdef class TimeBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimeBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeBinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[92])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TimeBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimeBinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[93])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":504
 * cdef class TimetzLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimetzLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 504, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12TimetzLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimetzLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[94])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12TimetzLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimetzLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[95])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":541
 * cdef class TimetzBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimetzBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 541, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18TimetzBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimetzBinaryLoader___reduce_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[96])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18TimetzBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimetzBinaryLoader___setstate_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[97])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":576
 * cdef class TimestampLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     cdef int _order
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestampLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15TimestampLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestampLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[98])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15TimestampLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestampLoader___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[99])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":680
 * cdef class TimestampBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 680, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestampBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 680, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21TimestampBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestampBinaryLoader___reduce_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[100])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21TimestampBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestampBinaryLoader___setstate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[101])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimestamptzLoader___reduce, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[102])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_22_BaseTimestamptzLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseTimestamptzLoader___setstat, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[103])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":724
 * cdef class TimestamptzLoader(_BaseTimestamptzLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     cdef int _order
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 724, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17TimestamptzLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestamptzLoader___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[104])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17TimestamptzLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestamptzLoader___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[105])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":809
 * cdef class TimestamptzBinaryLoader(_BaseTimestamptzLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TimestamptzBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 809, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestamptzBinaryLoader___reduce, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[106])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_23TimestamptzBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TimestamptzBinaryLoader___setsta, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[107])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":871
 * cdef class IntervalLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     cdef int _style
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 871, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntervalLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 871, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14IntervalLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntervalLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[108])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14IntervalLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntervalLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[109])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":982
 * cdef class IntervalBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 982, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntervalBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(1, 982, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20IntervalBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntervalBinaryLoader___reduce_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[110])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20IntervalBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntervalBinaryLoader___setstate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[111])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":1099
 * 
 * 
 * cdef object _timezone_from_seconds(int sec, __cache={}):  # no-cython-lint             # <<<<<<<<<<<<<<
 *     cdef object pysec = sec
 *     cdef PyObject *ptr = PyDict_GetItem(__cache, pysec)
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_mstate_global->__pyx_k__8 = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":1134
 * 
 * 
 * cdef _timezones = {}             # <<<<<<<<<<<<<<
 * _timezones[None] = timezone_utc
 * _timezones[b"UTC"] = timezone_utc
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg__timezones);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg__timezones, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/datetime.pyx":1135
 * 
 * cdef _timezones = {}
 * _timezones[None] = timezone_utc             # <<<<<<<<<<<<<<
 * _timezones[b"UTC"] = timezone_utc
 * 
*/
  if (unlikely((PyObject_SetItem(__pyx_v_9psycopg_c_8_psycopg__timezones, Py_None, __pyx_v_9psycopg_c_8_psycopg_timezone_utc) < 0))) __PYX_ERR(1, 1135, __pyx_L1_error)

  /* "psycopg_c/types/datetime.pyx":1136
 * cdef _timezones = {}
 * _timezones[None] = timezone_utc
 * _timezones[b"UTC"] = timezone_utc             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (unlikely((PyObject_SetItem(__pyx_v_9psycopg_c_8_psycopg__timezones, __pyx_mstate_global->__pyx_n_b_UTC, __pyx_v_9psycopg_c_8_psycopg_timezone_utc) < 0))) __PYX_ERR(1, 1136, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":18
 * from cpython.unicode cimport PyUnicode_DecodeUTF8
 * 
 * import sys             # <<<<<<<<<<<<<<
 * from decimal import Context, Decimal, DefaultContext
 * 
*/
  __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_sys, 0, 0, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 18, __pyx_L1_error)
  __pyx_t_5 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_sys, __pyx_t_5) < (0)) __PYX_ERR(12, 18, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":19
 * 
 * import sys
 * from decimal import Context, Decimal, DefaultContext             # <<<<<<<<<<<<<<
 * 
 * from psycopg_c._psycopg cimport endian
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Context,__pyx_mstate_global->__pyx_n_u_Decimal,__pyx_mstate_global->__pyx_n_u_DefaultContext};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_decimal, __pyx_imported_names, 3, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 19, __pyx_L1_error)
  }
  __pyx_t_5 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_5);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Context,__pyx_mstate_global->__pyx_n_u_Decimal,__pyx_mstate_global->__pyx_n_u_DefaultContext};
    for (__pyx_t_3=0; __pyx_t_3 < 3; __pyx_t_3++) {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_5, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 19, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(12, 19, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":23
 * from psycopg_c._psycopg cimport endian
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * from psycopg._wrappers import Int2, Int4, Int8, IntNumeric
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 23, __pyx_L1_error)
  }
  __pyx_t_5 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_5);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_5, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 23, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_6) < (0)) __PYX_ERR(12, 23, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":24
 * 
 * from psycopg import errors as e
 * from psycopg._wrappers import Int2, Int4, Int8, IntNumeric             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Int2,__pyx_mstate_global->__pyx_n_u_Int4,__pyx_mstate_global->__pyx_n_u_Int8,__pyx_mstate_global->__pyx_n_u_IntNumeric};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg__wrappers, __pyx_imported_names, 4, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(12, 24, __pyx_L1_error)
  }
  __pyx_t_5 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_5);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_Int2,__pyx_mstate_global->__pyx_n_u_Int4,__pyx_mstate_global->__pyx_n_u_Int8,__pyx_mstate_global->__pyx_n_u_IntNumeric};
    for (__pyx_t_3=0; __pyx_t_3 < 4; __pyx_t_3++) {
      __pyx_t_6 = __Pyx_ImportFrom(__pyx_t_5, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 24, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_6) < (0)) __PYX_ERR(12, 24, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":54
 * # _IntOrSubclassDumper and _MixedNumericDumper ctors
 * # change it to int or (int, numpy.integer) once
 * _int_classes = None             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_int_classes, Py_None) < (0)) __PYX_ERR(12, 54, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":59
 * cdef class _IntDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":64
 *         return dump_int_to_text(obj, rv, offset)
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t length
 * 
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Buffer_None) < (0)) __PYX_ERR(12, 64, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10_IntDumper_1quote, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper_quote, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[112])); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 64, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntDumper, __pyx_mstate_global->__pyx_n_u_quote, __pyx_t_6) < (0)) __PYX_ERR(12, 64, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10_IntDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[113])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10_IntDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[114])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":81
 * cdef class _IntOrSubclassDumper(_IntDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 81, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__IntOrSubclassDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 81, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntOrSubclassDumper___reduce_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[115])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_20_IntOrSubclassDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntOrSubclassDumper___setstate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[116])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":100
 * cdef class Int2Dumper(_IntOrSubclassDumper):
 * 
 *     oid = oids.INT2_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT2_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10Int2Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int2Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[117])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10Int2Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int2Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[118])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":106
 * cdef class Int4Dumper(_IntOrSubclassDumper):
 * 
 *     oid = oids.INT4_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT4_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 106, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 106, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10Int4Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int4Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[119])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10Int4Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int4Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[120])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":112
 * cdef class Int8Dumper(_IntOrSubclassDumper):
 * 
 *     oid = oids.INT8_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT8_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 112, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 112, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10Int8Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int8Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[121])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10Int8Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int8Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[122])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":118
 * cdef class IntNumericDumper(_IntOrSubclassDumper):
 * 
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16IntNumericDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntNumericDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[123])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16IntNumericDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntNumericDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[124])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":124
 * cdef class Int2BinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.INT2_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":125
 * 
 *     format = PQ_BINARY
 *     oid = oids.INT2_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT2_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 125, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 125, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int2BinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[125])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int2BinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[126])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":134
 * cdef class Int4BinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.INT4_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 134, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":135
 * 
 *     format = PQ_BINARY
 *     oid = oids.INT4_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT4_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int4BinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[127])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int4BinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[128])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":144
 * cdef class Int8BinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.INT8_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 144, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":145
 * 
 *     format = PQ_BINARY
 *     oid = oids.INT8_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT8_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 145, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 145, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int8BinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[129])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int8BinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[130])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":179
 * cdef class IntNumericBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.NUMERIC_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 179, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 179, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":180
 * 
 *     format = PQ_BINARY
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 180, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(12, 180, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntNumericBinaryDumper___reduce, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[131])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_22IntNumericBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntNumericBinaryDumper___setstat, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[132])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":188
 * cdef class IntDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":196
 *         )
 * 
 *     cpdef get_key(self, obj, format):             # <<<<<<<<<<<<<<
 *         cdef long long val
 *         cdef int overflow
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_1get_key, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper_get_key, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[133])); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_get_key, __pyx_t_6) < (0)) __PYX_ERR(12, 196, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":215
 *                 return IntNumeric
 * 
 *     _int2_dumper = Int2Dumper             # <<<<<<<<<<<<<<
 *     _int4_dumper = Int4Dumper
 *     _int8_dumper = Int8Dumper
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_int2_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2Dumper)) < (0)) __PYX_ERR(12, 215, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":216
 * 
 *     _int2_dumper = Int2Dumper
 *     _int4_dumper = Int4Dumper             # <<<<<<<<<<<<<<
 *     _int8_dumper = Int8Dumper
 *     _int_numeric_dumper = IntNumericDumper
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_int4_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4Dumper)) < (0)) __PYX_ERR(12, 216, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":217
 *     _int2_dumper = Int2Dumper
 *     _int4_dumper = Int4Dumper
 *     _int8_dumper = Int8Dumper             # <<<<<<<<<<<<<<
 *     _int_numeric_dumper = IntNumericDumper
 * 
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_int8_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8Dumper)) < (0)) __PYX_ERR(12, 217, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":218
 *     _int4_dumper = Int4Dumper
 *     _int8_dumper = Int8Dumper
 *     _int_numeric_dumper = IntNumericDumper             # <<<<<<<<<<<<<<
 * 
 *     cpdef upgrade(self, obj, format):
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_int_numeric_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericDumper)) < (0)) __PYX_ERR(12, 218, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":220
 *     _int_numeric_dumper = IntNumericDumper
 * 
 *     cpdef upgrade(self, obj, format):             # <<<<<<<<<<<<<<
 *         cdef long long val
 *         cdef int overflow
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_3upgrade, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper_upgrade, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[134])); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntDumper, __pyx_mstate_global->__pyx_n_u_upgrade, __pyx_t_6) < (0)) __PYX_ERR(12, 220, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper___reduce_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[135])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9IntDumper_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntDumper___setstate_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[136])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":243
 * cdef class IntBinaryDumper(IntDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     _int2_dumper = Int2BinaryDumper
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 243, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 243, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":245
 *     format = PQ_BINARY
 * 
 *     _int2_dumper = Int2BinaryDumper             # <<<<<<<<<<<<<<
 *     _int4_dumper = Int4BinaryDumper
 *     _int8_dumper = Int8BinaryDumper
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper, __pyx_mstate_global->__pyx_n_u_int2_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryDumper)) < (0)) __PYX_ERR(12, 245, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":246
 * 
 *     _int2_dumper = Int2BinaryDumper
 *     _int4_dumper = Int4BinaryDumper             # <<<<<<<<<<<<<<
 *     _int8_dumper = Int8BinaryDumper
 *     _int_numeric_dumper = IntNumericBinaryDumper
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper, __pyx_mstate_global->__pyx_n_u_int4_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryDumper)) < (0)) __PYX_ERR(12, 246, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":247
 *     _int2_dumper = Int2BinaryDumper
 *     _int4_dumper = Int4BinaryDumper
 *     _int8_dumper = Int8BinaryDumper             # <<<<<<<<<<<<<<
 *     _int_numeric_dumper = IntNumericBinaryDumper
 * 
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper, __pyx_mstate_global->__pyx_n_u_int8_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryDumper)) < (0)) __PYX_ERR(12, 247, __pyx_L1_error)

  /* "psycopg_c/types/numeric.pyx":248
 *     _int4_dumper = Int4BinaryDumper
 *     _int8_dumper = Int8BinaryDumper
 *     _int_numeric_dumper = IntNumericBinaryDumper             # <<<<<<<<<<<<<<
 * 
 * 
*/
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntBinaryDumper, __pyx_mstate_global->__pyx_n_u_int_numeric_dumper, ((PyObject *)__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntNumericBinaryDumper)) < (0)) __PYX_ERR(12, 248, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15IntBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntBinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[137])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15IntBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntBinaryDumper___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[138])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":254
 * cdef class IntLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_IntLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 254, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9IntLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[139])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9IntLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_IntLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[140])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":274
 * cdef class Int2BinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int2BinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 274, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int2BinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[141])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int2BinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int2BinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[142])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":285
 * cdef class Int4BinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int4BinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int4BinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[143])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int4BinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int4BinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[144])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":296
 * cdef class Int8BinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Int8BinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 296, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int8BinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[145])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16Int8BinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Int8BinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[146])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":307
 * cdef class OidBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 307, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_OidBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 307, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15OidBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_OidBinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[147])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15OidBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_OidBinaryLoader___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[148])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":317
 * cdef class _FloatDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 317, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":329
 *         return length
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_float, value)
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Buffer_None) < (0)) __PYX_ERR(12, 329, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12_FloatDumper_1quote, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatDumper_quote, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[149])); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 329, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__FloatDumper, __pyx_mstate_global->__pyx_n_u_quote, __pyx_t_5) < (0)) __PYX_ERR(12, 329, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12_FloatDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[150])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12_FloatDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[151])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":338
 * 
 * cdef dict _special_float = {
 *     b"inf": b"'Infinity'::float8",             # <<<<<<<<<<<<<<
 *     b"-inf": b"'-Infinity'::float8",
 *     b"nan": b"'NaN'::float8",
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_b_inf, __pyx_mstate_global->__pyx_kp_b_Infinity_float8) < (0)) __PYX_ERR(12, 338, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_kp_b_inf_2, __pyx_mstate_global->__pyx_kp_b_Infinity_float8_2) < (0)) __PYX_ERR(12, 338, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_b_nan, __pyx_mstate_global->__pyx_kp_b_NaN_float8) < (0)) __PYX_ERR(12, 338, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg__special_float);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg__special_float, ((PyObject*)__pyx_t_5));
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":347
 * cdef class FloatDumper(_FloatDumper):
 * 
 *     oid = oids.FLOAT8_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_FLOAT8_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(12, 347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11FloatDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatDumper___reduce_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[152])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11FloatDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatDumper___setstate_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[153])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":353
 * cdef class Float4Dumper(_FloatDumper):
 * 
 *     oid = oids.FLOAT4_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_FLOAT4_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 353, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(12, 353, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12Float4Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float4Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[154])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_12Float4Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float4Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[155])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":359
 * cdef class FloatBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.FLOAT8_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 359, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":360
 * 
 *     format = PQ_BINARY
 *     oid = oids.FLOAT8_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_FLOAT8_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 360, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(12, 360, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17FloatBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatBinaryDumper___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[156])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17FloatBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatBinaryDumper___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[157])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":376
 * cdef class Float4BinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.FLOAT4_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 376, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 376, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":377
 * 
 *     format = PQ_BINARY
 *     oid = oids.FLOAT4_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_FLOAT4_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(12, 377, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float4BinaryDumper___reduce_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[158])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float4BinaryDumper___setstate_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[159])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":393
 * cdef class FloatLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 393, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_FloatLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 393, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11FloatLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[160])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11FloatLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_FloatLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[161])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":405
 * cdef class Float4BinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float4BinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 405, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float4BinaryLoader___reduce_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[162])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18Float4BinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float4BinaryLoader___setstate_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[163])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":419
 * cdef class Float8BinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 419, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_Float8BinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 419, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18Float8BinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float8BinaryLoader___reduce_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[164])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_18Float8BinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_Float8BinaryLoader___setstate_cy, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[165])); if (unlikely(!__pyx_t_5)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_5);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_5) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":433
 * cdef class DecimalDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     oid = oids.NUMERIC_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_5) < (0)) __PYX_ERR(12, 433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":434
 * 
 *     format = PQ_TEXT
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_5 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 434, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_5) < (0)) __PYX_ERR(12, 434, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":439
 *         return dump_decimal_to_text(obj, rv, offset)
 * 
 *     def quote(self, obj) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         value = bytes(self.dump(obj))
 *         cdef PyObject *ptr = PyDict_GetItem(_special_decimal, value)
*/
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Buffer_None) < (0)) __PYX_ERR(12, 439, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13DecimalDumper_1quote, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DecimalDumper_quote, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[166])); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalDumper, __pyx_mstate_global->__pyx_n_u_quote, __pyx_t_6) < (0)) __PYX_ERR(12, 439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13DecimalDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DecimalDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[167])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13DecimalDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DecimalDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[168])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":448
 * 
 * cdef dict _special_decimal = {
 *     b"Infinity": b"'Infinity'::numeric",             # <<<<<<<<<<<<<<
 *     b"-Infinity": b"'-Infinity'::numeric",
 *     b"NaN": b"'NaN'::numeric",
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_b_Infinity, __pyx_mstate_global->__pyx_kp_b_Infinity_numeric) < (0)) __PYX_ERR(12, 448, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_kp_b_Infinity_2, __pyx_mstate_global->__pyx_kp_b_Infinity_numeric_2) < (0)) __PYX_ERR(12, 448, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_b_NaN, __pyx_mstate_global->__pyx_kp_b_NaN_numeric) < (0)) __PYX_ERR(12, 448, __pyx_L1_error)
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg__special_decimal);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg__special_decimal, ((PyObject*)__pyx_t_6));
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":457
 * cdef class NumericLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 457, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(12, 457, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NumericLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[169])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NumericLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[170])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":465
 * 
 * cdef dict _decimal_special = {
 *     NUMERIC_NAN: Decimal("NaN"),             # <<<<<<<<<<<<<<
 *     NUMERIC_PINF: Decimal("Infinity"),
 *     NUMERIC_NINF: Decimal("-Infinity"),
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_5 = __Pyx_PyLong_From_int(NUMERIC_NAN); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 465, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_n_u_NaN};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 465, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (PyDict_SetItem(__pyx_t_6, __pyx_t_5, __pyx_t_4) < (0)) __PYX_ERR(12, 465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "psycopg_c/types/numeric.pyx":466
 * cdef dict _decimal_special = {
 *     NUMERIC_NAN: Decimal("NaN"),
 *     NUMERIC_PINF: Decimal("Infinity"),             # <<<<<<<<<<<<<<
 *     NUMERIC_NINF: Decimal("-Infinity"),
 * }
*/
  __pyx_t_4 = __Pyx_PyLong_From_int(NUMERIC_PINF); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_2)) __PYX_ERR(12, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_10, __pyx_mstate_global->__pyx_n_u_Infinity};
    __pyx_t_5 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_2, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 466, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
  }
  if (PyDict_SetItem(__pyx_t_6, __pyx_t_4, __pyx_t_5) < (0)) __PYX_ERR(12, 465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "psycopg_c/types/numeric.pyx":467
 *     NUMERIC_NAN: Decimal("NaN"),
 *     NUMERIC_PINF: Decimal("Infinity"),
 *     NUMERIC_NINF: Decimal("-Infinity"),             # <<<<<<<<<<<<<<
 * }
 * 
*/
  __pyx_t_5 = __Pyx_PyLong_From_int(NUMERIC_NINF); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_Decimal); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_2, __pyx_mstate_global->__pyx_kp_u_Infinity_2};
    __pyx_t_4 = __Pyx_PyObject_FastCall((PyObject*)__pyx_t_10, __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 467, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
  }
  if (PyDict_SetItem(__pyx_t_6, __pyx_t_5, __pyx_t_4) < (0)) __PYX_ERR(12, 465, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg__decimal_special);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg__decimal_special, ((PyObject*)__pyx_t_6));
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":470
 * }
 * 
 * cdef dict _contexts = {}             # <<<<<<<<<<<<<<
 * for _i in range(DefaultContext.prec):
 *     _contexts[_i] = DefaultContext
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_XGOTREF(__pyx_v_9psycopg_c_8_psycopg__contexts);
  __Pyx_DECREF_SET(__pyx_v_9psycopg_c_8_psycopg__contexts, ((PyObject*)__pyx_t_6));
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_6 = 0;

  /* "psycopg_c/types/numeric.pyx":471
 * 
 * cdef dict _contexts = {}
 * for _i in range(DefaultContext.prec):             # <<<<<<<<<<<<<<
 *     _contexts[_i] = DefaultContext
 * 
*/
  __pyx_t_4 = NULL;
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_DefaultContext); if (unlikely(!__pyx_t_5)) __PYX_ERR(12, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_mstate_global->__pyx_n_u_prec); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = 1;
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_t_10};
    __pyx_t_6 = __Pyx_PyObject_FastCall((PyObject*)(&PyRange_Type), __pyx_callargs+__pyx_t_7, (2-__pyx_t_7) | (__pyx_t_7*__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET));
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 471, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
  }
  __pyx_t_10 = PyObject_GetIter(__pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __pyx_t_11 = (CYTHON_COMPILING_IN_LIMITED_API) ? PyIter_Next : __Pyx_PyObject_GetIterNextFunc(__pyx_t_10); if (unlikely(!__pyx_t_11)) __PYX_ERR(12, 471, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  for (;;) {
    {
      __pyx_t_6 = __pyx_t_11(__pyx_t_10);
      if (unlikely(!__pyx_t_6)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) __PYX_ERR(12, 471, __pyx_L1_error)
          PyErr_Clear();
        }
        break;
      }
    }
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_i, __pyx_t_6) < (0)) __PYX_ERR(12, 471, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "psycopg_c/types/numeric.pyx":472
 * cdef dict _contexts = {}
 * for _i in range(DefaultContext.prec):
 *     _contexts[_i] = DefaultContext             # <<<<<<<<<<<<<<
 * 
 * 
*/
    __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_DefaultContext); if (unlikely(!__pyx_t_6)) __PYX_ERR(12, 472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(__pyx_v_9psycopg_c_8_psycopg__contexts == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(12, 472, __pyx_L1_error)
    }
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_mstate_global->__pyx_n_u_i); if (unlikely(!__pyx_t_4)) __PYX_ERR(12, 472, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely((PyDict_SetItem(__pyx_v_9psycopg_c_8_psycopg__contexts, __pyx_t_4, __pyx_t_6) < 0))) __PYX_ERR(12, 472, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "psycopg_c/types/numeric.pyx":471
 * 
 * cdef dict _contexts = {}
 * for _i in range(DefaultContext.prec):             # <<<<<<<<<<<<<<
 *     _contexts[_i] = DefaultContext
 * 
*/
  }
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/numeric.pyx":478
 * cdef class NumericBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(12, 478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericBinaryLoader___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[171])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericBinaryLoader___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[172])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/numeric.pyx":532
 * cdef class DecimalBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.NUMERIC_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(12, 532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/numeric.pyx":533
 * 
 *     format = PQ_BINARY
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_10 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 533, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_DecimalBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_10) < (0)) __PYX_ERR(12, 533, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19DecimalBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DecimalBinaryDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[173])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19DecimalBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_DecimalBinaryDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[174])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/numeric.pyx":541
 * cdef class _MixedNumericDumper(CDumper):
 * 
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, cls, context: AdaptContext | None = None):
*/
  __pyx_t_10 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__MixedNumericDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_10) < (0)) __PYX_ERR(12, 541, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_MixedNumericDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MixedNumericDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[175])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19_MixedNumericDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_MixedNumericDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[176])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/numeric.pyx":557
 * cdef class NumericDumper(_MixedNumericDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(12, 557, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NumericDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[177])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NumericDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[178])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/numeric.pyx":575
 * cdef class NumericBinaryDumper(_MixedNumericDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_10)) __PYX_ERR(12, 575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NumericBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(12, 575, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericBinaryDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[179])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NumericBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NumericBinaryDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[180])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/bool.pyx":13
 * cdef class BoolDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     oid = oids.BOOL_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_10)) __PYX_ERR(13, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(13, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/bool.pyx":14
 * 
 *     format = PQ_TEXT
 *     oid = oids.BOOL_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_10 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_BOOL_OID); if (unlikely(!__pyx_t_10)) __PYX_ERR(13, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_10) < (0)) __PYX_ERR(13, 14, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/bool.pyx":31
 *         return 1
 * 
 *     def quote(self, obj: bool) -> Buffer | None:             # <<<<<<<<<<<<<<
 *         if obj is True:
 *             return b"true"
*/
  __pyx_t_10 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_10)) __PYX_ERR(13, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_obj, __pyx_mstate_global->__pyx_n_u_bool) < (0)) __PYX_ERR(13, 31, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_kp_u_Buffer_None) < (0)) __PYX_ERR(13, 31, __pyx_L1_error)
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10BoolDumper_1quote, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolDumper_quote, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[181])); if (unlikely(!__pyx_t_6)) __PYX_ERR(13, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_6, __pyx_t_10);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolDumper, __pyx_mstate_global->__pyx_n_u_quote, __pyx_t_6) < (0)) __PYX_ERR(13, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10BoolDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[182])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10BoolDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[183])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/bool.pyx":43
 * cdef class BoolBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.BOOL_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(13, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(13, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/bool.pyx":44
 * 
 *     format = PQ_BINARY
 *     oid = oids.BOOL_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_BOOL_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(13, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(13, 44, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolBinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[184])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolBinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[185])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/bool.pyx":65
 * cdef class BoolLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(13, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(13, 65, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10BoolLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[186])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10BoolLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[187])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/bool.pyx":75
 * cdef class BoolBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(13, 75, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BoolBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(13, 75, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolBinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[188])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16BoolBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BoolBinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[189])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":13
 * cdef class NPInt16Dumper(_IntDumper):
 * 
 *     oid = oids.INT2_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT2_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 13, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NPInt16Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt16Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[190])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NPInt16Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt16Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[191])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":19
 * cdef class NPInt32Dumper(_IntDumper):
 * 
 *     oid = oids.INT4_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT4_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 19, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 19, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NPInt32Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt32Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[192])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NPInt32Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt32Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[193])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":25
 * cdef class NPInt64Dumper(_IntDumper):
 * 
 *     oid = oids.INT8_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT8_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 25, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64Dumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 25, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NPInt64Dumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt64Dumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[194])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13NPInt64Dumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt64Dumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[195])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":31
 * cdef class NPNumericDumper(_IntDumper):
 * 
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 31, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 31, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15NPNumericDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPNumericDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[196])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15NPNumericDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPNumericDumper___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[197])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":37
 * cdef class NPInt16BinaryDumper(_IntDumper):
 * 
 *     oid = oids.INT2_OID             # <<<<<<<<<<<<<<
 *     format = PQ_BINARY
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT2_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 37, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 37, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":38
 * 
 *     oid = oids.INT2_OID
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 38, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt16BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(14, 38, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt16BinaryDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[198])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NPInt16BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt16BinaryDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[199])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":47
 * cdef class NPInt32BinaryDumper(_IntDumper):
 * 
 *     oid = oids.INT4_OID             # <<<<<<<<<<<<<<
 *     format = PQ_BINARY
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT4_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":48
 * 
 *     oid = oids.INT4_OID
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt32BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(14, 48, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt32BinaryDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[200])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NPInt32BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt32BinaryDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[201])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":57
 * cdef class NPInt64BinaryDumper(_IntDumper):
 * 
 *     oid = oids.INT8_OID             # <<<<<<<<<<<<<<
 *     format = PQ_BINARY
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_INT8_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 57, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":58
 * 
 *     oid = oids.INT8_OID
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPInt64BinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(14, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt64BinaryDumper___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[202])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19NPInt64BinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPInt64BinaryDumper___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[203])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":67
 * cdef class NPNumericBinaryDumper(_IntDumper):
 * 
 *     oid = oids.NUMERIC_OID             # <<<<<<<<<<<<<<
 *     format = PQ_BINARY
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NUMERIC_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 67, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(14, 67, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/numpy.pyx":68
 * 
 *     oid = oids.NUMERIC_OID
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(14, 68, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_NPNumericBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(14, 68, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPNumericBinaryDumper___reduce_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[204])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_21NPNumericBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_NPNumericBinaryDumper___setstate, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[205])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":16
 * from psycopg_c.pq cimport Escaping, _buffer_as_string_and_size, libpq
 * 
 * from psycopg import errors as e             # <<<<<<<<<<<<<<
 * from psycopg._encodings import pg2pyenc
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 16, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_6);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_errors};
    __pyx_t_3 = 0; {
      __pyx_t_10 = __Pyx_ImportFrom(__pyx_t_6, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 16, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      switch (__pyx_t_3) {
        case 0:
        if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_e, __pyx_t_10) < (0)) __PYX_ERR(15, 16, __pyx_L1_error)
        break;
        default:;
      }
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":17
 * 
 * from psycopg import errors as e
 * from psycopg._encodings import pg2pyenc             # <<<<<<<<<<<<<<
 * 
 * 
*/
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_pg2pyenc};
    __pyx_t_1 = __Pyx_Import(__pyx_mstate_global->__pyx_n_u_psycopg__encodings, __pyx_imported_names, 1, NULL, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(15, 17, __pyx_L1_error)
  }
  __pyx_t_6 = __pyx_t_1;
  __Pyx_GOTREF(__pyx_t_6);
  {
    PyObject* const __pyx_imported_names[] = {__pyx_mstate_global->__pyx_n_u_pg2pyenc};
    __pyx_t_3 = 0; {
      __pyx_t_10 = __Pyx_ImportFrom(__pyx_t_6, __pyx_imported_names[__pyx_t_3]); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 17, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_10);
      if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_imported_names[__pyx_t_3], __pyx_t_10) < (0)) __PYX_ERR(15, 17, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
    }
  }
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14_BaseStrDumper_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseStrDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[206])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_14_BaseStrDumper_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BaseStrDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[207])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":70
 * cdef class _StrBinaryDumper(_BaseStrDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 70, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(15, 70, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16_StrBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[208])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16_StrBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumper___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[209])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":76
 * cdef class StrBinaryDumper(_StrBinaryDumper):
 * 
 *     oid = oids.TEXT_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TEXT_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 76, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 76, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15StrBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumper___reduce_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[210])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_15StrBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumper___setstate_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[211])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":82
 * cdef class StrBinaryDumperVarchar(_StrBinaryDumper):
 * 
 *     oid = oids.VARCHAR_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_VARCHAR_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperVarchar, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 82, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumperVarchar___reduce, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[212])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_22StrBinaryDumperVarchar_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumperVarchar___setstat, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[213])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":88
 * cdef class StrBinaryDumperName(_StrBinaryDumper):
 * 
 *     oid = oids.NAME_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NAME_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 88, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrBinaryDumperName, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 88, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19StrBinaryDumperName_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumperName___reduce_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[214])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_19StrBinaryDumperName_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrBinaryDumperName___setstate_c, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[215])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":93
 * cdef class _StrDumper(_BaseStrDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__StrDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(15, 93, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10_StrDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[216])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10_StrDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[217])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":110
 * cdef class StrDumper(_StrDumper):
 * 
 *     oid = oids.TEXT_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_TEXT_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 110, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 110, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9StrDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumper___reduce_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[218])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_9StrDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumper___setstate_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[219])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":116
 * cdef class StrDumperVarchar(_StrDumper):
 * 
 *     oid = oids.VARCHAR_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_VARCHAR_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperVarchar, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16StrDumperVarchar_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumperVarchar___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[220])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16StrDumperVarchar_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumperVarchar___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[221])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":122
 * cdef class StrDumperName(_StrDumper):
 * 
 *     oid = oids.NAME_OID             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_NAME_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_StrDumperName, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13StrDumperName_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumperName___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[222])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_13StrDumperName_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumperName___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[223])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16StrDumperUnknown_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumperUnknown___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[224])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16StrDumperUnknown_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_StrDumperUnknown___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[225])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":132
 * cdef class _TextLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef int is_utf8
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg__TextLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(15, 132, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11_TextLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TextLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[226])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11_TextLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TextLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[227])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":170
 * cdef class TextLoader(_TextLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 170, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TextLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(15, 170, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TextLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TextLoader___reduce_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[228])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10TextLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TextLoader___setstate_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[229])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":176
 * cdef class TextBinaryLoader(_TextLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 176, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_TextBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(15, 176, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TextBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TextBinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[230])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_6 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16TextBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_TextBinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[231])); if (unlikely(!__pyx_t_6)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_6);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_6) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":182
 * cdef class BytesDumper(CDumper):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 *     oid = oids.BYTEA_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 182, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_6) < (0)) __PYX_ERR(15, 182, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":183
 * 
 *     format = PQ_TEXT
 *     oid = oids.BYTEA_OID             # <<<<<<<<<<<<<<
 * 
 *     # 0: not set, 1: just  single "'" quote, 3: " E'" quote
*/
  __pyx_t_6 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_BYTEA_OID); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 183, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_6) < (0)) __PYX_ERR(15, 183, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "psycopg_c/types/string.pyx":217
 *         return len_out
 * 
 *     def quote(self, obj) -> Buffer:             # <<<<<<<<<<<<<<
 *         cdef char *ptr
 *         cdef Py_ssize_t length
*/
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(15, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_mstate_global->__pyx_n_u_return, __pyx_mstate_global->__pyx_n_u_Buffer) < (0)) __PYX_ERR(15, 217, __pyx_L1_error)
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11BytesDumper_3quote, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BytesDumper_quote, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[232])); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_10, __pyx_t_6);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesDumper, __pyx_mstate_global->__pyx_n_u_quote, __pyx_t_10) < (0)) __PYX_ERR(15, 217, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11BytesDumper_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BytesDumper___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[233])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11BytesDumper_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BytesDumper___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[234])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/string.pyx":274
 * cdef class BytesBinaryDumper(CDumper):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 *     oid = oids.BYTEA_OID
 * 
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 274, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(15, 274, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/string.pyx":275
 * 
 *     format = PQ_BINARY
 *     oid = oids.BYTEA_OID             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t cdump(self, obj, bytearray rv, Py_ssize_t offset) except -1:
*/
  __pyx_t_10 = __Pyx_PyLong_From___pyx_anon_enum(__pyx_e_9psycopg_c_8_psycopg_4oids_BYTEA_OID); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 275, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_BytesBinaryDumper, __pyx_mstate_global->__pyx_n_u_oid, __pyx_t_10) < (0)) __PYX_ERR(15, 275, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17BytesBinaryDumper_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BytesBinaryDumper___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[235])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17BytesBinaryDumper_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_BytesBinaryDumper___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[236])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/string.pyx":290
 * cdef class ByteaLoader(CLoader):
 * 
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ByteaLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(15, 290, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11ByteaLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ByteaLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[237])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11ByteaLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ByteaLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[238])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/string.pyx":309
 * cdef class ByteaBinaryLoader(CLoader):
 * 
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_10)) __PYX_ERR(15, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_ByteaBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(15, 309, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17ByteaBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ByteaBinaryLoader___reduce_cytho, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[239])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_17ByteaBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_ByteaBinaryLoader___setstate_cyt, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[240])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11_UUIDLoader_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_UUIDLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[241])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_11_UUIDLoader_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_UUIDLoader___setstate_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[242])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/uuid.pyx":59
 * @cython.final
 * cdef class UUIDLoader(_UUIDLoader):
 *     format = PQ_TEXT             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_TEXT); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 59, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_UUIDLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(2, 59, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10UUIDLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_UUIDLoader___reduce_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[243])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_10UUIDLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_UUIDLoader___setstate_cython_2, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[244])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/types/uuid.pyx":87
 * @cython.final
 * cdef class UUIDBinaryLoader(_UUIDLoader):
 *     format = PQ_BINARY             # <<<<<<<<<<<<<<
 * 
 *     cdef object cload(self, const char *data, size_t length):
*/
  __Pyx_GetModuleGlobalName(__pyx_t_10, __pyx_mstate_global->__pyx_n_u_PQ_BINARY); if (unlikely(!__pyx_t_10)) __PYX_ERR(2, 87, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (__Pyx_SetItemOnTypeDict(__pyx_mstate_global->__pyx_ptype_9psycopg_c_8_psycopg_UUIDBinaryLoader, __pyx_mstate_global->__pyx_n_u_format, __pyx_t_10) < (0)) __PYX_ERR(2, 87, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16UUIDBinaryLoader_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_UUIDBinaryLoader___reduce_cython, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[245])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_reduce_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_16UUIDBinaryLoader_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_mstate_global->__pyx_n_u_UUIDBinaryLoader___setstate_cyth, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[246])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_setstate_cython, __pyx_t_10) < (0)) __PYX_ERR(6, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":4
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
 * def __pyx_unpickle_RowLoader(__pyx_type, long __pyx_checksum, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_result
 *     __Pyx_CheckUnpickleChecksum(__pyx_checksum, 0xa44f3c5, 0xae386f0, 0x36ee688, b'cloader, loadfunc, pyloader')
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_32__pyx_unpickle_RowLoader, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowLoader, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[247])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowLoader, __pyx_t_10) < (0)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "(tree fragment)":1
 * cdef extern from *:             # <<<<<<<<<<<<<<
 *     int __Pyx_CheckUnpickleChecksum(long, long, long, long, const char*) except -1
 *     int __Pyx_UpdateUnpickledDict(object, object, Py_ssize_t) except -1
*/
  __pyx_t_10 = __Pyx_CyFunction_New(&__pyx_mdef_9psycopg_c_8_psycopg_34__pyx_unpickle_RowDumper, 0, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowDumper, NULL, __pyx_mstate_global->__pyx_n_u_psycopg_c__psycopg, __pyx_mstate_global->__pyx_d, ((PyObject *)__pyx_mstate_global->__pyx_codeobj_tab[248])); if (unlikely(!__pyx_t_10)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030E0000
  PyUnstable_Object_EnableDeferredRefcount(__pyx_t_10);
  #endif
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_pyx_unpickle_RowDumper, __pyx_t_10) < (0)) __PYX_ERR(6, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "psycopg_c/_psycopg.pyx":1
 * """             # <<<<<<<<<<<<<<
 * psycopg_c._psycopg optimization module.
 * 
*/
  __pyx_t_10 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_10)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  if (PyDict_SetItem(__pyx_mstate_global->__pyx_d, __pyx_mstate_global->__pyx_n_u_test, __pyx_t_10) < (0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  if (__pyx_m) {
    if (__pyx_mstate->__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init psycopg_c._psycopg", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init psycopg_c._psycopg");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #else
  return __pyx_m;
  #endif
}
/* #### Code section: pystring_table ### */
/* #### Code section: cached_builtins ### */

static int __Pyx_InitCachedBuiltins(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(1, 62, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_mstate->__pyx_n_u_object); if (!__pyx_builtin_object) __PYX_ERR(2, 39, __pyx_L1_error)

  /* Cached unbound methods */
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_items.method_name = &__pyx_mstate->__pyx_n_u_items_2;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_mstate->__pyx_umethod_PyDict_Type_values.method_name = &__pyx_mstate->__pyx_n_u_values;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.type = (PyObject*)&PyList_Type;
  __pyx_mstate->__pyx_umethod_PyList_Type_pop.method_name = &__pyx_mstate->__pyx_n_u_pop;
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static int __Pyx_InitCachedConstants(__pyx_mstatetype *__pyx_mstate) {
  __Pyx_RefNannyDeclarations
  CYTHON_UNUSED_VAR(__pyx_mstate);
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "psycopg_c/_psycopg/adapt.pyx":117
 * 
 *         if esc.escape_string(b"\\") == b"\\":
 *             rv = bytes(rv).replace(b"\\", b"\\\\")             # <<<<<<<<<<<<<<
 *         return rv
 * 
*/
  __pyx_mstate_global->__pyx_tuple[0] = PyTuple_Pack(2, __pyx_mstate_global->__pyx_kp_b_, __pyx_mstate_global->__pyx_kp_b__2); if (unlikely(!__pyx_mstate_global->__pyx_tuple[0])) __PYX_ERR(5, 117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[0]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[0]);

  /* "psycopg_c/_psycopg/transform.pyx":131
 *         return self._pgresult
 * 
 *     cpdef set_pgresult(             # <<<<<<<<<<<<<<
 *         self,
 *         pq.PGresult result,
*/
  __pyx_mstate_global->__pyx_tuple[1] = PyTuple_Pack(2, Py_True, Py_None); if (unlikely(!__pyx_mstate_global->__pyx_tuple[1])) __PYX_ERR(9, 131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[1]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[1]);

  /* "psycopg_c/_psycopg/waiting.pyx":201
 * 
 * 
 * def wait_c(gen: PQGen[RV], int fileno, interval = 0.0) -> RV:             # <<<<<<<<<<<<<<
 *     """
 *     Wait for a generator using poll or select.
*/
  __pyx_mstate_global->__pyx_tuple[2] = PyTuple_Pack(1, ((PyObject*)__pyx_mstate_global->__pyx_float_0_0)); if (unlikely(!__pyx_mstate_global->__pyx_tuple[2])) __PYX_ERR(10, 201, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[2]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[2]);

  /* "psycopg_c/types/datetime.pyx":57
 * cdef object timedelta_total_seconds = timedelta.total_seconds
 * cdef object timezone_utc = timezone.utc
 * cdef object pg_datetime_epoch = datetime(2000, 1, 1)             # <<<<<<<<<<<<<<
 * cdef object pg_datetimetz_epoch = datetime(2000, 1, 1, tzinfo=timezone.utc)
 * 
*/
  __pyx_mstate_global->__pyx_tuple[3] = PyTuple_Pack(3, __pyx_mstate_global->__pyx_int_2000, __pyx_mstate_global->__pyx_int_1, __pyx_mstate_global->__pyx_int_1); if (unlikely(!__pyx_mstate_global->__pyx_tuple[3])) __PYX_ERR(1, 57, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_mstate_global->__pyx_tuple[3]);
  __Pyx_GIVEREF(__pyx_mstate_global->__pyx_tuple[3]);
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_tuple;
    for (Py_ssize_t i=0; i<4; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static int __Pyx_InitConstants(__pyx_mstatetype *__pyx_mstate) {
  CYTHON_UNUSED_VAR(__pyx_mstate);
  {
    const struct { const unsigned int length: 9; } index[] = {{21},{13},{36},{8},{9},{17},{19},{8},{4},{179},{15},{21},{11},{22},{9},{21},{25},{27},{54},{13},{23},{13},{1},{1},{0},{1},{2},{8},{40},{46},{36},{56},{44},{30},{6},{17},{21},{22},{40},{17},{22},{39},{19},{21},{28},{39},{13},{24},{6},{19},{19},{21},{24},{22},{26},{24},{38},{40},{34},{33},{31},{32},{30},{22},{7},{6},{62},{31},{9},{45},{42},{2},{37},{9},{22},{70},{9},{8},{9},{19},{27},{42},{36},{51},{31},{50},{28},{27},{33},{32},{30},{24},{28},{27},{26},{14},{35},{36},{25},{35},{36},{38},{35},{37},{15},{15},{22},{29},{17},{32},{24},{24},{9},{45},{28},{5},{20},{16},{4},{3},{17},{35},{37},{11},{29},{31},{2},{6},{19},{37},{39},{27},{27},{23},{41},{43},{14},{32},{34},{15},{33},{35},{23},{23},{19},{37},{39},{22},{40},{42},{16},{34},{36},{16},{34},{36},{10},{28},{30},{16},{10},{28},{30},{6},{17},{35},{37},{11},{29},{31},{17},{35},{37},{11},{29},{31},{17},{7},{25},{27},{12},{15},{13},{15},{7},{25},{27},{12},{17},{35},{37},{19},{17},{7},{9},{13},{16},{34},{36},{16},{34},{36},{10},{28},{30},{10},{28},{30},{20},{38},{40},{28},{14},{32},{34},{22},{24},{42},{44},{18},{36},{38},{7},{19},{37},{39},{13},{31},{33},{19},{14},{18},{36},{38},{18},{36},{38},{12},{30},{32},{18},{36},{38},{17},{35},{37},{12},{11},{30},{29},{32},{31},{18},{11},{29},{31},{6},{8},{4},{16},{34},{36},{16},{34},{36},{10},{28},{30},{4},{16},{34},{36},{16},{34},{36},{10},{28},{30},{4},{16},{34},{36},{16},{34},{36},{10},{28},{30},{15},{33},{35},{10},{9},{28},{27},{30},{29},{17},{16},{17},{9},{27},{29},{10},{22},{40},{42},{16},{34},{36},{20},{38},{40},{14},{13},{20},{38},{40},{14},{32},{34},{19},{37},{39},{4},{19},{37},{39},{13},{31},{33},{19},{37},{39},{13},{31},{33},{19},{37},{39},{13},{31},{33},{21},{39},{41},{15},{33},{35},{3},{4},{8},{17},{19},{37},{39},{19},{37},{39},{13},{31},{33},{13},{31},{33},{15},{33},{35},{16},{7},{9},{7},{5},{9},{7},{15},{8},{16},{8},{20},{1},{2},{2},{5},{3},{9},{27},{29},{9},{27},{29},{16},{8},{16},{19},{37},{39},{22},{40},{42},{15},{34},{33},{36},{35},{10},{13},{31},{33},{16},{34},{36},{16},{34},{36},{9},{28},{27},{30},{29},{4},{16},{34},{36},{11},{10},{29},{28},{31},{30},{16},{34},{36},{24},{16},{34},{36},{10},{28},{30},{18},{10},{28},{30},{18},{36},{38},{12},{30},{32},{21},{39},{41},{15},{33},{35},{21},{39},{41},{15},{33},{35},{23},{41},{43},{17},{35},{37},{18},{36},{38},{12},{30},{32},{11},{29},{31},{22},{25},{24},{22},{22},{20},{21},{25},{28},{28},{24},{7},{3},{4},{16},{34},{36},{11},{10},{29},{28},{31},{30},{1},{4},{13},{1},{8},{3},{8},{9},{10},{8},{10},{18},{6},{1},{8},{8},{9},{10},{4},{6},{7},{9},{6},{11},{9},{5},{9},{17},{18},{5},{3},{3},{11},{8},{4},{13},{11},{7},{13},{10},{8},{17},{7},{6},{4},{4},{8},{4},{8},{5},{7},{9},{5},{8},{5},{2},{4},{13},{10},{7},{1},{6},{8},{9},{6},{3},{7},{2},{7},{4},{5},{10},{27},{5},{6},{13},{5},{6},{17},{15},{7},{12},{11},{6},{5},{8},{3},{7},{3},{9},{10},{17},{17},{7},{10},{46},{12},{2},{1},{5},{8},{3},{12},{12},{12},{12},{19},{7},{8},{4},{13},{11},{7},{5},{6},{4},{8},{9},{13},{6},{7},{6},{7},{8},{8},{3},{12},{3},{10},{7},{9},{4},{8},{7},{4},{7},{11},{6},{6},{5},{3},{6},{3},{2},{3},{6},{16},{14},{8},{16},{6},{10},{5},{20},{11},{3},{7},{8},{10},{4},{7},{18},{14},{17},{11},{9},{18},{10},{12},{3},{7},{10},{7},{5},{14},{12},{11},{10},{24},{24},{14},{12},{5},{1},{5},{6},{7},{10},{17},{13},{7},{7},{3},{6},{7},{6},{3},{4},{4},{10},{10},{11},{6},{2},{1},{6},{3},{7},{4},{4},{16},{16},{11},{12},{12},{10},{12},{19},{5},{4},{5},{3},{5},{6},{3},{3},{8},{3},{5},{4},{9},{7},{8},{9},{13},{2},{5},{10},{6},{6},{6},{7},{12},{3},{9},{5},{5},{6},{4},{6},{7},{8},{1},{4},{9},{18},{19},{19},{20},{47},{13},{14},{1},{2},{0},{2},{1},{1},{4},{66},{35},{46},{290},{352},{42},{10},{110},{5},{123},{26},{26},{25},{78},{94},{28},{27},{27},{81},{113},{505},{295},{299},{220},{65},{65},{364},{7},{17},{9},{32},{9},{226},{10},{466},{129},{191},{5},{2},{8},{5},{60},{12},{36},{60},{5},{55},{11},{213},{248},{6},{5},{8},{3},{1},{9},{3},{4},{5},{5},{3},{3},{4}};
    #if (CYTHON_COMPRESS_STRINGS) == 3 && __PYX_LIMITED_VERSION_HEX >= 0x030e0000 /* compression: zstd (6569 bytes) */
const char* const cstring = "(\265/\375`\nM\375\314\000:\306t)H\340\3208\0070\314\363D\236\2170\306\346\211<\037a \014\230\035a \014\306)\357\006kcK\221\266E\272!\261\326I\204\270pz\227\203\337\316\374\014o7f>G\242;P\200\203\014\252\003-\000)\177\304?\212p\241\215A\002U\002\267\002|\245\322l\320a\336\251\"\327\272\334\206\251\370?\306\337\013\277\016_\276\303W\345\377\345\314M\330\330j\276u\306\337\222\211\340\204\t\335\266m]\320\325\334\005o\333w\341\266\331\223\214\023\016\361\306^=m\300'\030\247\273\367}q\327\365\225F\264Z\177\353'\226y^\334fY\241\331\036\317\372]\035\267`\265-\372[\327\345u~\211\330\352\014\202\341\346\327\306\352\277\207o\327\202\201- ^\354KK\334`\265\256]\275\217\275\302\327\225\331\027\213K\335*+\265f\345S3\350\307Y\350si\215\377?\316\356\353\375x\330\276^\271f\207\205\267R_\273\322\260\214\200AUm_d\331\225\372-m\277\2323\317\272\273/\357\267\350IP\301\241\335\036\344\266\313\337g\275/\004\361}\205\233k\313\275\337\231?P\227\367V\3712h\271\356\353\316\237w\252\231\205\257\020\213\225\303\356\263\036\310\303L\343\375w-\253~\337w6B\034|Y\276_\227\177\"\357\311\2711\032\375\365\177k\013V~\222\301T\032\334\272\373C\374\3735\370\272\212\332\342\313\325\177\205x\363\333\272\036\376\347b\217\271}i\357\277\223}u\361\026\376/\226\265\207\337V\316\362j[\036\0163\353\276hD\320\263\334o\236g+M\313K\207\037\216\357\217\210S,\276\303\037\302\276g?\027\271\312\002\003#\203Y\251$|t,\337\336\367\227U+\tU\317\353\026\337\371\207\357\373\235\340\341_\270_\343\354t8;/\035g\177X`\3748\252\235\227\337\237\005\361AW_\257n8_nO\225\377\256\370\267\005k\346\217k\230\305\312\312\251/\373A\221\363\357\206\\e\345\272\177o\373u\\\270\353\346\335\277x]=l\253\314\214\214\313\316\315N\305\372y'~\317\255~\316\253\373V\234]\\\254\251\334\272x}\236u<\233I\234Z\370j\276-\267^\265\311\361\361\251\336\375l\020\316\021\371\305\227\205s\\N\372\301Whsz/\277\352\343\373=x\301\212o\365~\207\365\271\3123\306\266\253*vL\324\350g\261\302\017\217\263N\215QO\\\366\034\347\032\016Z/u\n{\023w\"\270\272\332\022\241\232""\020wV*\257-?,Z\264\330\320\261:\247\356mjP\326\251\2743Q\301\357\251\2550U?\034\212\250\242\006SU\333\022\225{\020\025[\021.\247\031\032\232\023\014\014L\213\026X\333X\267m\357\206\341\326\361\360w\010\206|[\326&\343<\363\314]\234\267\304\255\371\356\356\007n\316\272\256\275\355ns\277w\220\336(\030\254C\276;\373\201\257[\262\337\372\263!,\350?\240\356\2028|\205\033\250{W\267\3116\021\024\3050o0p{\3318\013Z\035\333/\335k\020\006n|g\220\263\376\0033\270\205[\013\024\301\230\026\270_V[p\347\027\\\026An\303@\034\3168\366/\213\273\2133\3178\277\366\177\241\227_[f_\017\204\357\366,\273\367\317\310\304l\3735w\357\215\351\017\312\333\276\333\267\354\336\270M\177\253\225Il[\207C\026\353\363t\336\033\013\334\\;_\226\346\260?\333\345O\303\213\270\271:\376\254\347a'\353\366\377o\315\301\355]o\333Z!\367\236\267\305\357\364o\373\373r\267\277\016\250\263\334wV\363\r\337\255\333\266\375\372v/t\267\207\237\025r_\316\034~\356\271\337\226\343>\033\304\271\335\217/\017\263\316\335K\276\035\026\267\365n\336\266\376\216\263\231\205s\036\347\025)\376\343,\277\032\305\306\257E\201\242\005n{\307\262\336>\257\333^Y\263>\253\237\337o\333\366E\277\020\267\374{\317G[W\247\355\211\177Y\035\315{\266\355Y\266'\226yD\317>\017\n\236\023<<\254\347\341\262\327\331xwmd\342\316\266\211\257\254w`;\252\235U\212\233\325\206\263\343]\023=\034\024W:\326\002\005\013\250\035\235\033\035\023:\336\313n\211\315\006}\026w\226\245\277G\233\320\231\231\221\211\34132\034\204\215\320*\353\374o\313\335Xny\315\352\203\356\326a\367<5[\215W\263?<\317!l\245y\017\227\375J\267\300P|\240\215\177\313\346\267\375\260\251\340I\351\344|\250\371\260m\335\313\207\224\211\225O\312\236f\\X<\364nf\301\261\214\201p(z\366\365\016\371\326\317\341|\273\367~^^^j\313\007\206\234\205\267\254f\325\177\035h\211\324 \003\311\240&r\240R\321Zg\006\263\200\352\334PC\2313.\2234Ec\235\256\002\035E\343\247=9\230P{\306\314[f(q\320M%\022\366<\201\t\351\030C\354\2302\216\230:\001\222\3444\2354\017\320\007\250\322D*5\225\035H\223\001\033\037\014PQ\271""\201\344)\005\250\214\202\020\034r\204\024\352\031iP$SdV\000A\017\244\372H\303X\226\312\233\216\352'tj\014gv\006\3229i\311\006\0375R\271\352\035}%c\000\005\031\241\242\222\353)\235\207#\003\220\024T\332\305\314\200\007\214\264\031K\0375\330(\363Qz]\325UD\246\215\204\021\324\316(\3200u\216\3561\302\224\223\226&\375\2064\t9AE$lT\031U\021F\221\236\352#\375\301\006\212\212L\217\262\207t\231\270(15\224\2462\302hG\004\343\315\314\300\200\r\0025`\"H\223\223tb0\241$\3634\3014\364sn\200\200B\030\241)\232\215\014\212\241\224\260\201\302\372%3\324R$\003)j\034\371HM\343.!K,\224\"\345\252\347\220&s\245\374\310\006\245\n%(\214\024@\2125KRIC\035\255\345\204\261r\222\246N\r\025\255\264\240Sf&0Q5M\365\224\n!%\251\211L\010\345J\177`\202S2\350&\222\013&Ky\241\027 I\316\2372Un\265\222G\"\030\tIS\274[\031R$\034\005\214!\242\316\002F&P0`\303\243\206\310\344J\004/H\007\250\223\233\326\264 \242\331\234!\314\021S\2272\345\202\024#\312\3101V\020\321<\330\322\325[\310\005!)\311D!@Q$\316\210\301T\372\364\024&\243\252\246\242\241\320>3C\211\323SJR\3219c\202\232\224R\022\315\3029c\236(]LRQ\257&\017R\022\224\244TK\225\254\356\"\033\220\244\2523\310\224\225\002J\026\344I)V\336\036#G\214%\363\244\024\225\016\310\222\220\232\210$\t\361\031\203f\007>RQ\t3\365\013$\037yF\004%RDV\030qf\037\0365\023\351\215\t<RR_\221)\222\301(2`\003\244\006\312\244\200\202\242x\324H\246P\227\351)\246\3233Uf\205\220\324\222)$\210qd\324\035F\323(\362\221\252H\024\022\306LfV@\006F\312\220&r\201G\2522K\346M\211*O\364R7y\244)s4A\004\025\361\250\241H\006#\024F\252\220$\322\302\310g\007<R\221\t+UJRi\241\233:\312\200\215\0005P\035e\204n\036\266\333\266\355\266m\260l\001\037j\216-\336\237e\335\333m;\003b\225\223S\323\223\332H\250zv\266\n\r\315V!\025@a\3475\003\210:\250\240\251\216kvH\307\005e\200\312(\245$\005$\221\307\210\001#\221QhT{!\322\360\350\330\010\251qBO\033h\315|R\027\032-\2121f\246\206!\246B\0220\251z\212\02053\315\n\230B\007(\312\322@$\\\030c\204 1\214#\243\224G\205\002\3212\234\005L\230\212\322H\r\341\026k\202\210^d""\003\363\302\t\275\tD\033f\005Fi\205\216Qm\010\204\346\341\005}!\033l\240\001:RSM;\251\2336P\216\025\034*Tp\360\360p\204\010\301ac\303\221\342H\211bll\324\200\301Q\236\321\014\204\002\271PW\207v-\320\026*Z\211\233\227\004\024\341\000\312z\364]\240.V\350j\007\355\031\352\030R@\0232eL\000f\005\0147#\212Y\020\r\001 F\251\205\261`\\\315@:h\304\314>HNd\237\240\245\032\251\007\345DAQ>\244\250\022\212\300\200\352\2149\337t\225\001\026\2445\004 \226F\201\006\200\006;\023\004\215@\370p\"\231\"&I\331y=\006T$\rj\004\260`s\036\033\223UR\340\235i\364H#I\300l@\207\251\344(\025\364\0070\021ci\244G\022\321\tS\321\203:6\320\256r\262j)\032\212\366\247-_P=FH:K\244`cM\312\010\212*\001\230\310\016@i\207Q\302\214\300(\025\321(@*YF\250\203\003hH\nJM\364\002\371X\225\364U:c:9N\017\323\246v\366\230(]\231\202bm\t\322=T\245\013\003\364\3034\231>\030^U\306\224_C\216fN\r-\350I\367F\244\241\026$T2\024\311S=\002\271\000\0359l\005y\222\032\350)%\364\243\333\220\037\252\013$\262D\tI\352\240\201\311\324W\310\215k\226D \2004\"S\235\322\030\203\001\033\tjt\037\034U\317L\0024U>p`\340\203`\245\255 j0vvt\315\016\330\274r3\216F\022I(e\005l\224\251\316\216s\203\254kH\241@:Wf\312DQ\246\260f\212\351\323c:\nI\014\331JA`\000\300\305\364T}\306\250\240\353\230\372F9\267\311c\306\230\274\254)G1>\262f '\200\306\004\346\205\222\245\005\331A\222\034(mz\212j\303zMGqc\207FC/N\325)\301,)W\335\300\003U)\241\303 \321N#j\260R\006A\000\204s\305\204\321G\300N\231\023\024\206\350T\260\"OBR\021\355\305L\365\217\226R\2075\250\303\250\202$\225L\315\210\210$IA\322\030cP@p\330\300\200@\234\357t\345\003\003\004\243h\022\2438\210\206 \na\204pB\234@d\206\306$I2\035XU\310\225\343\034>\211\013\315\211\353\026\205\320l\266\3670\327\267\320\350\365&1;\2117\222\313l\241\362\307\005R\250_OS\013J*.\360\027l\243\316p\350)\216\322\215G\roV\262cF*f\n+nN\363\013\327\240\ra_G\376\007\355&\273\346\255hl\0315)\007\033\236\230{\225\020\236m\204<B\240\374F\301\025\230\263\254\0044\3204\312\265\177\232\252\025\3411\350e\010\237\355\266\377\257\207^""\232\013\037y\226\252\235\013\377\310\001$\376\326m\341\212\010_\031\332\200\352^k\016\016\204\005\265I\210\301\306<\242\\\256\213\010\3649\312\307\264K\275\234\tPLe]\027\354C\366\034\031T\203\037m\231\242\275\2231\031\327\262\247^\t\257\"\267\262F\r{A\2452\273,\356\244\203\242\003\251\305\216yrS\210^\\\003\235\356\024\304TuJd\223\351\305\204'\010\364\243h( \025u\231(#\2645\203\327\004\203\225\227\213\002q\2308\314\254\213H\335\324YxT\214\253\244\001v\224.\002\307#\200\322\332\004\236\240>\345!\234\263\270\370\221\217n\362Zl\325]\330\266\272\033\025\030\227\243\177\226tY0\017<\021\341\002v\270Bv\232m\260\231u\345If\345\305\203\374br\021\024O\374\2101\226\370\254\311\274\0261\177\367,1\247\025\267\351\013\034\243\244\366\303\003g\\i\006\205A\242\212\375n\314t\324?5\277\325R\366\212c\\\305\227\237\177\000\335\251\306\260\332\242\000\205p\0344TGj\003O\031.\276\366\314>\310w/\320\000\371Rm\002Gk\361\022\316OrV\300\322\306\244J\236\243\3368](\253Sn\376\336X5&\226\364:\214N\340\222\263\223\327\205\017l\374\242\221\364\261\021\202\327$\303\357\\\261\363'\242\245\350\317\345\016P<\016\251\305\035\303\311>`\007\253w*\206\343\204\005i\216]\305\351\232N*\237\276{\212\361,@\365lpS\010[\253\301:;Pz\346\240nn\326\237\253q\373\374P\213B\360\312\213v\370\302j\2234\023X\r\312\362\245Y\327\211\213\006\332m\354\366\032\252\210\001\325\2169\204%\255\254r\331&\214\"\322\331\331\342\226\337\017\247\276\245\"\271\203U\347}\321}\333\374\025\025H\315as\223<z\350\314\014\021\355\217\253\232\030\231\352\353\346\302\360\224\3727\306\245\223\244\372\263\021\301&\323\2340a\010\324F\254#<p\203\212fK\014\220\033\302(\245\355\3064d\344!\212j,\275=!\203\371k\017\360\002Y\201\300\264\363\226\214\220\275s\023\246\222i9\264)@Z\217\374\216\272)\310\234\337\223\352\220\253?2\274\377\242j8!,\033\211G\365\n\006D\243SV\337\222\345JR\204\005\246\2463\341\233\214ek\250#O\313\303%\217(\327Rr\223\270\235\272RD$]\205\263\240\225\262r\002\rFT./\313\276d\026&\021\230\210\177a\267\367\277\273\010\227\375\3027Q\375""\202\031\245\333\346*|Y\237\241\002q\005\356{\333\210\177Z\014\203H\361Ao\"\315o2\236\317\300\233F!\320\375\303~\245V\271\224\036X\340\302\211&n\236'T9\217\342\240{\255i\221\200-\316\302}L\314\353\227c\216\214D\001\207\025\032\224\371B\243G_\373\272O\277-\341\031\023\273%\003\327\312\343\014\\!U\345\311\033\t\022q\356X\035ICi\217\t\216x!\373o\205A\"\307\217\260~\213\246\273\201]x7X\223C\335E\362\221(\252\243{\016%\005#\rD|\n0\007v.}K\236\370D[h\241\016g\321\317Se\374\2023\317\245r\270X\314\030\037\324D>\255Q\200\304}u.\215\257\010\264\207\356\201\355\204C\215lG\273.\243\314\026\2521\302\363\232\216\332\340\356\215m\343gPO]\214\273b\346m7\372\234\265\210Z|\357\262\037\346\243\001V\304P\3035@\007\222G2\360\n\252\010*\017\034\300\352g\252\037\211\340m\246\017\016\347LX2*O\252\007w\232\277\247\324,3P5\276\373b\270\207\214A\240?\265~\367|W\274\370}:j#\202c5vt\351\r@U\206R_\010\006\372\003\251\304\004f\307\035\366\256wA\205\2447\014D\333-\000>@\362\177\031\357#\217\000\271*D\274\310@y\327%L\214\212\177\300\022\251EU\014v>f[\2702^L\213\364\035\2529\030\033\031\204\342G\316\223\316\325\361]\035\235j\274\\\245-*Y\272x@\005,\327\355\325[z*\"\021\221\244;\020\025\013\035\2058\004A\214\237\353%N]\367\274\256\372:`$\355\373\364e\246o\277\212XSQ\203\"Z \021\026\251N9o\201\221\\\370\346\305\201\303\004\274Fi0\310:\222\205\345\241h\324@\214\277${\016\313\220\330,cws\301\377\364r\221\227\373M\233\037\317\317'F\211\020E\246\352\\\243\225\206\014!\364\034\260\000\274\350R\230\004{\202\342@@\003U\243\n\273\304Y=\240!\270\373\021\206%\341\206\301?&\214\211\223\243DM\261\370\230\244\034\210b\232\177>\000<qsI\023\237\341\256\367Q\263\242\253\260\204\351p~\\\243(8\320C\024-\241\245\3479\217\255n\201\004\332\246\334\216\373'|QV\261\206\235G\264\277\243\007\365\025}T\250\031\225+A4whe\221\331\234\030]\371\310\025\r\001d\0142\345\304#\363]\274Or^\303\000\352\345\006\335xC\227\r\367i8\030\351\200\261<\207\355\023\334[\217I=1\273\022C\335\247\2255a\375\334`S\032*@#\226\234{\033\310\320I\331^""\230\027\001\204\356\024\035\344\217\271q\374\235\016A\177\376\"9\315S\346\362\214~D\351OIg]\033\241?\265\031\315N/\366\211 `\220F\202/\232`\374\375\023q\t\250\374\003B\250V~\245\330\352Q\013JO\221\306%\261r3F\036\235\003h\236 \200\006\301+\247Q2Q\0361o\010\334\245\314\3014w\030d5\365\000\210Q\344\270|\255o\317i\352\202\312\363B\204\222;\300\231STl\237\363\332)R^n\272U\203\212\243\256\202a\322\017\266\362\240\007\251\007c\337R\313<\326\017i,E\266a\310\223dV\036\025&\363\231j\220\252\207'\324\037\207-\235qXj\322n\325\263\203\014)\013\254\n3\025\3175C5\010bO\270\264\te\374\360\253~\004\031D\177(\306\033\266x\304\0342\321\2419\203M\202v\242F!w=j]j\250\367\247\325\340Kh\024!\033\\\301h\t\363O\263\177\004\004\312#e\027\374\350\352sD\033/!\265\375D\202\037\026\245\002iB\305R\036\204\003-\007\236Y\244\243\207(\357\364@\200\360no\300\034h\333\t\323\225*\267\027\264\224\237L\363a\177\004\205.\034\322q/\263\0315;\373\032|\317\255F\247\252E\304\200\202\244g\333\355q\267Zd\032\363\240\3467U/UF\2058z!\241\013\236;\3401\237\316\023H\314`\363\343\375\347\331@-)\2119\311\347\364\017\221\373\327\271\245^\212d2\204%+^\251$\327D\274\306t\207\201ooX\265\036*\023~\203\227\311\3455\212\2724+\310\223b\261\255\211\206\364n\206p\001&\325\343\362\254\201\270D\270\346R\266\226y\302\256\213\373\271]`\016E\365\234\253\226\330L\t`\037FjY\244&F1_q\205\035\251\246U\227\206\316`B\360U\223-#\2233\023\260\212g\235&$\236\373\004M\323\te;uN\325\255\025\264\0146\324E\226zb\276\354@e\201\216C7\251\243\231\3052|)B\322\200r\031\260y\335\253@4h\277\262:/\322\266/G\304\200GxcVq\036a\250\345\3375\204\2209tY%\002\331\\O\022\002\007|'\372z\304Y\r\373\265\002\261@\216\350\257\224x\376\377\263hy\372\233<TsA\024\353\275\346l\225\022\206f\2417\274O\253\367\262\2661W\242\371q\247o]8\007\025\335/\2035d\3157X\366\354\375\201\302xL%\344\376\025\230\345^r\235\n\032\010_\232O\363\003\254 )U\255.\215\031\365\343\030}\217.\205\204\3432\207\030\027\r\271\233\306\2224\313\264\301\201\352g\201K\356@\303>\372\256\026b]\354&""\2213\234~\206u\305\034\320b\366h\272J\370\352`\327\330\342l\000j:\234\341\377\222'\305UAU\352\263\372\267\216\346F$ST~\021\256\306\371\035\211 \225\216\204\212\323\236H\220u\355e\244\335\231\255\262F\356z\252\3673=\026d\341\252\250\326\227\312D\240\352\005\005\024T\336\035QP\321L\231\377\017\267\362\247\370\236\302\240\241\207\363k\204\217\t\303\246\232\375\324\t\227\336f\325X\226\247\344\263\232\234\252\2103\"A\331\372m\030-g4\266\341\036F\314l\336\252\324F\306\274\332\247\265\255\342\253\021\275\363\232\010\252R\024\373(\267\001\200{fS\231h&_,\034\264i\200\362,M\331\352\010\343\004d\210j\013 \021(\005\027m\025\2327S\346\353\014\214\033\336\177k\r\325/\001p\210\230\r:\302\372\277\314\232\024)\322\003\343Dd-\220%\322\307Ei_\203\341\032d\207\266\345q\372\241\327D\217@q\352\000\037\235\223\312\270\227Q5\210\354,\200/\372.\312oz\344\256\253\014\252<\367:\237\235H\037\322S\214\025\256\241\303\223\0248e\331?w\264\370}\364M!\200\354\342+1\370\004\n\321\232\225\233A\034\266k\277D\315\205k\r\020\242m5\207+P\254\335\326W\331&t\375\312\000\231k\335\302\335j\257 \320\236Y\236\365\240\204\344*\250\304g\357\355\256\013\353\303\235U\240)\270\263\024\277\320\212\r\200\224\\z'/\177\370<\"\302:&\363x\302\334]\353\014\341\265\203,7/a\277\346\260\241?,.\341Y\243]\311h\313d\361R\364~\210\207\230\226\314y&\370@\213\024\337\006I\001\266\300\\\332T\266\002\000\3277\377b:\310\252g\325\306X\330\021\020\215Y\004J\256\375\316ZF#RSd\030\226\250\356\347\357{\376\345\014?\304Y\343\256\353>wp>r(\0058\033y\241\002\355\377\035\373\356\203\002\305\264\376w\372:\317\316\316G\014\245\0304\262R\235=\036\360G\310\371PUWB\314\306\207\331H9\333[g\222C\234 \267Q\374\233\240E\325A\371k\250\237\342\242\263\273b\033\224\352.\n\336.\037\035\216\3615\027\357\200\251$\010y\244\260\246\307(\251\372\177\t\256\261\177\362\264\374.(\250\307\304%\007\300\364\311\262wP\035q\351\303\302\353sJx9\270\311P@\201\266.r@I\263Pl\264\264\2655\372\257l\204\r\343\243\277e]\256\345s|(\261\211\352+\266\316$\374#\035\350w\213\365""\212\3730_\314\222\305\225X)\345\306r\373\022\326qw\266\310\\d\304e\312\235A\217\026\246\006\234\362B\22596\340\276\246\247A\300\276\204l(6b\226\336\0070A\221b\223y\027|\244\345\377\006}{\2131\354\315P\262\214%O\204\244\327\tN\273\025\177\016s\254\241\027H\320\326\365\n\346.LH\377\377@\025\276\366\010\263\300tY\026@\313\223\"\005\242\020\330\2029wfFX\025R\251y\311\251\000\nBka\240|\261\034\206\207\355\214\300\0333$\226\317\"\232\263\311vh\304i\324\003\033\206\354 82\231\252\362\213\200\"\255\231\364Og\267:\r\021z\314\036%\207\332|VG\355\273\272\350c\302\227a\302^\336\003\021E\371\014\360\346s\337\205\345\307\243sC\263[\347\211E5+\312~Z<=\r|n\214\320\273\014N\002\2269\001\032\327\304\004x\273\3505\321\020\370T\363\324\276\250\266\010\332\262\2251$\003iz\224lA@\254\323\240\025\236/\325\247qI@.\216\306\226.\206\203iw\270\202\306\344C\216|\271o\361\361\237\023\345I@\215FW\213^\2642v\014\026\201z\220'\215\322\221\265\227\353\010\335\231\321h\366\220>\221R$\320\253S\003\027\032\265\251\016\215\2000\242\323> \027\310L\002\373\275\022\007\321?\310\350r\223\220\305\354\006\013C\2027\225\3633\327=\330\372\224\235'\260a2[\022Z.\237\317M\357\263\251\333\177*\346\324g5\340\236\207\370\363\034\232\307]W2\0367\366\376\326\037\222-?\242$\364\223\035\346e!\356\352\204!\350B[\262\237(u\034\031,j\210\240NH\312a\203LI\257\025\177\3222_\000\233fH!\235\000\020\016\212\306DR\323I+\260\317\316>\221X\226\351\333\304K\311\333*fKs\254\324\320\234\257\202\247V\020\375\035*G\246\355\255u\001v\253\004\374r\022B\303OMv\232\000\353\020ura%\204b\330*\233\327I^\035\322\315%\325,\340`n\020\327E4\n\331\216\001\211tP\234anQ\210\2112\254J*\266\341\250\233\226\263\310\224\332\003\322\225\345|\025\326+b#\020\004L#\300H(_\371\273\017\023j\023W\025\367+O\321(H`R\247\312qU\231[\266AL\307#\032\343C4\033\242J\314\207\3231\306\315\351\225\214\017;B\017\3103f\372\204\262\003\304\207\302\037\204\022\332\306\210\223\373\364Y\311\255N\320nq\257\357\264\263H^.\365\244\202r \202\267?\003I\350w\203\301\2426\025G\306m'""\354\271\030\371\264\210\267:\022l\343D\213\200a@\325\242\203\240\233\323\324q\001\377\270\312\355,&n\207\202P\010\320\365\006IS\n[\237%\212\261\360Q$\010\261\262\214s,+|\323\3462\274Q\341\003\232j\r\"\031\264)p\263\316\036\300\337\220~gP\\]qf\026\221ldc\024s/\206\270wqQ\016\230\372\325\351\020T4\246:\320\252\371\333\264l\375\351\013^\321\030\364\211\265\336\306d\3731\326\272\375V\216>\3625.\254\212\377k\273%\014\213-Z\373\005\272\277\222\241\257\201.\240\241\032\370\244\321d\370\344\3044\324:r{\354*\006\261.\220\365s\030\023{\317\375\363UJ\340\330b\005pP\013 b\356\344A\031D\217\316[\273\021@\352\255~\276X\343\244p\013p\241G5\323H\215\260^\361(C?\003\036\230kP\217\256\341\236 :";
    PyObject *data = __Pyx_DecompressString(cstring, 6569, 3);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) == 2 /* compression: bz2 (6370 bytes) */
const char* const cstring = "BZh91AY&SY\r\226\216v\000\004\032\177\377\377\377\377\377\377\377\377\377\377\377\377\377\277\377\377\377@@@@@@@@@@@@@\000@\000`\034<\353\247\326\226\326\252)R=\273{=\336\274\347\201\342\242\335\356\361\356\303q[myqu\246\273\016\343\005B\212f\301.\332\2229\334p8\2625!A\203\203\321\000\017\241\200\004\241\t\nyD\332f\251\236\243!\243\024\3656h\322\236Si\244\331\245=\246M0\004jM4<\223hz)\223\322i\264F\232i\246\023\365A\240\222@\023 M)\246\2020\221\376\251\204\323\023Q\352fP\365=L\203M\001\247\244\006\206\200\320\000\0004\3235\r\251\352\004\246\200\244\211\001\243F\215\000\032\r4\323M2\032\000\007\246\223F\200\000\r\000\000\32044\000z\200\223R\024\323 !\t\223\t\352\230\002h\362\023@hi\243A\240h\001\240\006\201\240\036\240\320\014\232`\215\n\251\372\247\242db0\2322d\321\246\0012\030\206h\231\006#\000\023\t\210\304h10\000\004\300#&\t\022\t\246\223S\t\246$\3010CD\311M\246h\236\232j\217I\351\036\246F\200\000\000\000\000\000\006\200\017l\234\233\314\315\202F\250\334\257\025\271{\336\355_\270\305\307\024\030O\373\005&p\364<O\304K\177\237c\326\365\332aA\354@\264=\232\365\317j\260&\022\2144^\311N\360\363\002\273\025;m\023\027\205,F\021\306\343\371\276\277\273\264m\215\266\277\277\253V\255Y\346m\314\330n\366\347\266\0021E\235!\022-UE\014\262\234\rf\275g\262D\320LD\303U!\375\025\316\00180\014<\250\213\377\030\004\221\204\346\262o\334DVD\021\213\026\014`\214dU\213 \306D\022#\"\310\210\261E\"\253\020\317Q\253T\276`\005\017\036(\321\226+MgT\330\332@\330\230\350P\275\357\\E\221&\325\021VB(\010\221\202\240\210\251\030\n fVC\207[\200\2571\220^\367z&\2610TP$\334\365p\224\215\2060\220\317\177'.\303\\\023PC%QH\2420\324X\260i\266@\340\"\305\024X\261\2120\024\231\014\271\227\006\207&\306!{FGHa\246\264\r\000\231\221\250i\204^\242Dg:0f\331\212\326\264\355\234:\030Z\252\002\326\264\265#3!\031\215<K\326\345(7\200\2605\336\000\210\"\211\30533\003CM1\016\020\344AUE\2661\254\233M\313CE\307\220\\W\013\337\212\225U\307\262HS\036`D(\265\206\324&b\315\264G\321_h\023\335$u\2523\207\014\272\240\361\343""\302\255=x\353\016=\255\r\261\231\033\261\305b\257&\213\354\"\226VR\220`\271\034hR\230\353\023\261b\352\304,\310\177 \303\024\267\004\205)\344\372A\250P\037i\027\013\253\342)\236\214\241[\"N\371\3473#$ZV\213\2221\037\021\216r\035\024\335\204\343L\260\342\324\322\276e\251\270\324\217o\335\330\376\037\277\336\365\217M\217nm\374\275\251\373\036\314\242\021\t\217\367[\303\364Op\217.@h\347R\236\326?\357<<\021v\357k\007\366\303\017\013\375\266\326\217\330\310\316\206\315\001\266\3608\360\345\366\376\311\200\265\301\306\372+<\177y\374\330w\275\351\304\317G\034\206\361C\271\216\322\342\316\364\300\214\302'\271|\333\343:\037s\003\216\361\276\374U\372\371\343Wu\034\374\227\225M\274\304Y\352\252\233\364a\355\270\221V4\233H\255G'x\030\274\267\005\034\326w\271GA\336+C\305\264\253\236cX\302\265\306U\204\\\370\251BTx\014\3504\207M\264\204\307\247Ms(\0226a]\370\226W\357\321\242|\031\034\216F\021\240z\231a\344\361\213K\225\261\217\014kEV\310\235r\374o\374\247\221.l\003\000\263\335\243u\317\253\347\256\232\353\367OK\317\021\332H\355|\016\345}\230\240\305\007\264\371\325\356Z\306\023\360\212\026s\017\242\322rTaH\214g*6\003 m8\243\032\234\244\312\322)\036\275'\313\355\314\331k\0220\301hFK\035ZI\327,{\360>\226\006\013\003m\275]\370\325z\3331\230l\226\207\257E\263\036\303x\230\341\273pfZ\307'\003X\020\342\344\237\242\375V\347p\354t/\322?\240\303\247\300|\353GR_\367\307\346\210y\305\3214\373F\306\335)\366\030\0259g\3348\351\317?\027\177\265\321\374\237\325\230fo'~\326\261\231f\317=~rm\031\\\273\001y3\376\323\273\324\234\275C;\004\303\241\223,\354P\347\025\346\2471\023{\216\271\037>'\253L\3232V\377\005{\373\362\363\375m\376\217\350\267\037\017\251\236\357\255\360\232\260\252\022P\307\252\020\002\2068\201\001\344\030ey\214\376)\024,g\263\177\235\177/f\226\326E\220\346\353stuCV\212\242\260.#\323+\036G\004\335\371\207<\264\267\372\241\221\016\264v@\230#\347\035P0\021\t\246\210\307C\330|\032\336\036\226f\220\335\226\352u\344\202\341\323\331.\363L;d\222IC\321JLZ\346Z\261W+w\356UAUN\256\205\364""\206fs^z\311\2212&SW\353\367?$\335\345\371\372\035\264Q@QG\335\321\266@\333&\3203F!\330\320\322SL\246\2470\357q`.`\246\022\224\252\252\243RH\227\235c9)\332PFS\321!\t\021\314)d\202Q\024D\256\034y\031gX\354\266\205\334\350\004\t\331\373xK\026\211\310\243\306\263\373o\200\240[\r\213\3375S\341'\265m\343\016No\220\251Zn\363^\371\221\004G3 \300\032A\251\032HG(cr5|5\323\353\346\257*\377\255e\313\206#0\356D\316H\310\016\335\003\033\222\033{$\2577\342jF\353\"\004\332C\305\342E$\214\200\320\321\356\313\305T\362\3574K\247Hqk7\262\206c\255\3516\347\241\033\316\257\222\375\254x\034\n\2508\253^\243\360\264H\276tkW\010A\345iL,B\006\026q'\322Uu\237\205\243\027\340\231\253[<8\354\370\316\325s\243_2\363\365nz\367\245\345k]\316\215\357+X\275\357K\316\326\275V6\355\323-\273M\273\270\212,\\\035j\262\210\242\316\201\325\365\177\2760i\315\231\352\343\005\206d4x\246\360\277?V\033\216\271\327;\356\337\246I\236\343r\"\212hUGu\"\312\252\252*Z\326\351\264\313\361\357\234=\327=a^\243\207\256\354{\r\236\303w\260\363\272\235M\327\312\256\016\307c\356-\246*\246\375z\260\356\275orW<Q\263:6\266\337r\331\354\255\356NM\327}n\035\256\327}\2668\242\346N\363\005\367\333uX\2661j\250\335\306*\352\346\341\330\344\355l\357n\350\357u:\233\273V\333\216(\223\311\344\370\246\241\266\334\357\021\013\212\324\245\270\0348.\007On\237/\342t-z\315\335\317\335\352\r!\2444\351/\320l\350\337\020666\003\036~\361\037o|\032\026\300\373\210\030iD\226\224iF\236\336\331\362\377\260\227g\231w\362w\374\315\233\337\223~\301p\344\357\212\024\356.K[\236\250YbUeT,P2hj\253\274\252\221\033\031\242\336>Sj0\241\312H\372B\201 \221\342\335\314\033r^7\243\204jf\346\227\017\007\275n\341\360\337\001_\022\257\213\\\273\255\323L\254\246LSGK\025wG5\320\322\306l\247KVI\255\213\207GF\356\035\035\025\322\257\213j\256\034\347@\350\316\205\270\035i\332\254t\337R\250QE\024QKk\350\026\343\202W\001P\363V^\242d\017OE\242-\021\"D\245/\002'2\"R\234\216~\2776\207\315\305\225(\252\271\032\306;\275\236\236\341\233\020\023\273y0\272\362\217\244RT\236\006\331g""\217\247\021\374\204\033\360\3339\270\006\333\235c\035\216\371\272R\252\270\027!)\204LU\3255(\227\211xQTXB%{\340\350\240\370\n\314\317\315\315\333\362K\367\361'\365\212\234\276\\\274\225eN\224\214\023\004\302\327\352\317\275o\277\213\343\351;f\025z[a\r1\303\223!\222~\374\022[4\213\230\343\016?\004\361CH\317bs\232_\275\332J\205\206-SH\253UAT(\242\233\312\241E\033\0245B\212o\266\373\235>K\246\252\307\331\245UU\354\234\247)9g)\3219I<\036\227g\215u\372\205\026\343\332aX\340T\336\262\014\203\337\364IHZ\312R\225z\r\"\263$u\225\341\002\2748o\272\200\377&s3Xi0fkl\316fR\020 set\036\235>\217C\032L\251Jdc&C\2409r\263&\022\216Gs8\007\016\254\236\217\255@\370|\3668\366\255nJ\241K\264\332\252H/\004\222S'\223\212\220,\205$\244\213 r$>\252d\213t)\224\220\323J,\204\005\206\244\230\350\205H0\202\311\"\242H(\260D\021\220\226aI\024P\025`\002\252&\004\272\260Nh7\010}w\312>\2071\375\352\222!.\275\035\002\303Z\334\264 Y\272\022\232\020+\316Y[\"\3752\304\240\213\346Y\317;\027\302\264\004\201T\203\335\356\367Ik\342\323\331\254\337\\\263\320k\210%9\251\220&|\320\027n\247\360\225\2057h\341\213\246&\024#\374\321l\253\231Y\200%\311\224\262n\0331\344\342\223x\000\205G\031\316\225\245iL\206\234\243;\003\372\317\"\330\363\271J\303(\211\311\220\313\264\016^Y\276r/\241\374y\352\3761Y\214\013ro\277\025\200\250\000\017\212\032=\231\323\345\010\256s_c\245\357\031^\321\333\244c\030s\024\032\334\252\216\030Xb\322\202\333g\357\243\301y\315\025\344\211\341\203\304\206\377\234\373`\205\334r\304\362b\350\243\321\242K\010\023\212\207Xa\274\017\372\201|=\314]A\276\350\345\265Dl\\B@\035:5\337\277\351\003\255$m\232\006\235G\217@\340\234\362E \2618&\351\337\"\232=#d\"bU@\205\033\212JS\022\031\030Z0O\0078k\216A\232\221\206\353a\237\271\337\207n\314n\306!\216\013\007\177\302\271\247*\017\005?\203\241\210\211Xi\243h\367,\230w+ \206\300r\014\232J\364\274\350<Dk\364\320\272m\314t{\207m\332\034\322\363\205\2727xP:\316o\261\320]\034^\233\343\257\035/,\347\004\224A\311\275m[\361\to(\366@\310K\026}um\0079,{\035\247\254""\331EH\245w0\270\220!9\335\221\222t\272\0059\302\315\347v:\210\31254\303#\"w\325S\340\270q\343\204p&\310\313\033\265$\217>Q\310\214\246\325M\263>9Q\321\224\336\333\304'\207.\344=\023--T\313I\236\331\363\314\201\264\r\202\324\325]\220\220.\316~c\233\273\335\246\306\301&\301\235\310\177\312\263\013\332\366\304D\265\252\3050[\304,X\356\030\241\237a\323j7\262\257\362\231N\030\372g\027\305\302\254s@\034'^n\262\262\341h5\232X\362\354\200\001\362\215\371C\350L\221\200?\276\367VL\372\225\244^\346u\230\206Q\002\026\030\214\3505j\315\025h\245\355\226\204ss\013\265\034\347?\233\277xi<f\211\307''\221\326\212|\257n\005\025-oT\226\034n\241\353\274\203\027@\227DW\024\\\306\334\213\212\n*\253t\312\246\240\245e\213\202\220P\254\245GGK\221\r\303\024\370;\251Xn\244\013\t!\261X\254\305\217\253\030\243]XhI\006;\352.&1\304e\222$\222BHI$%DUTTUDUUU\025EDTU\030\304DUUUDUTDTEEb*\"\"\252\252\252\252\252\"**\"\210\252\250\252\253Y\316\375\363p\006\233|\306w`^\365\364-\010R\276s\230\006\332\342\262\361\330\315\003\001X@\311y\267Z\242\303\216\303e\214\004o\2116\236\t\341z\274\244\226\213\026\240\204-N\260\\\235\262\213\350\226\227'\275\024\367\346r\3501\320p\226k\255\027\256KPP!+\235\214\326rz\220Z\\\310\037p\3375\226\223v\033\026\227\264[\326\332N\363G\267\223[\330`\246\014\236\313E6U\320\334t1\025c\025VEQTQb\210\300TTET\022h\225\004H\301\020b*)\025UTX*\220TV*\242\014)\225\001R\251\2104\312#\020(U,\324UY\025EQE\212#$TTET\022Z\252$\210\211\215\312!\241\2672u\236\211\221\266:I_\004\200\210\263\306\247\036\221\326\242\336\251h'CyxX\004\342\332\215\327y\267\343\007.U\326xX\316\211\007\022\021~\233\032\223\032\006&\365'\030\000\255\031\314\206\222\005m\205\022\256\227{\032\365\034\365\232\223\006\014\251\364&\304\330\275\260\022zQp\357;\227ww\304n\377\337B\017\263\221\317\273Z\355\344\232\364\033\343\231\035\275|\264Fe\362{\312O\031$~bu\030\252\023GD-9:?\032(%Bo\323*S\210\316%\245\027\327\257\323\313\313\324\352e\307k\232N\356Ddb\023\221\244o\314\033\273\\\330\340\351\336/&5\235:\n=\326\2438+WN\207""\226\220\322\221\206a\nb\214 \350\3275\334r\3062J\00162R\360\232I\002\221(\\\014\003\325\312\271yK\341\345\346\331\271 5l\037a\350\346)\201\273\342L:z\221\227_\206<'\257\247\241[\320^\2026\207\203m\266\r\252\252\252\252\203\"\253\"\221\320J\022$F\003\030\230i<\370\364)\306\335\0264\373\022\000\031\201\225\322\304\325\370Gg\235\362\226\226\031a\234p\361<\234\373\242\213\320\353\226\375/6!\275\213\353\277+w\242\254Dfq4&l=A\256\304t\230a\323\333\231CF\332\210\333\217\310i7\036\347\353\225\360\300k\251V\321s\304Sr\303\342'\007\016\007\003\203\3643n\223\327S\223\223rP\3134\272\216\237P\260w8\353\274;\372\225\037\005UUU\025Ub\252\207\026\335~\250[l\014(\245\206\021\021\023\"\034\ru.<{\010\244\253i\2772pO,x\370K\014qE[c:\030qu\023\354,\313\231L5d<S$\214:\360x\274\236t\240Y\303\351|\177\022\016\344\300\037\376\033M\267\267\031Z=$\231\264Fil\224\224\310D\372yi\214\340\332j1\021\267\034>~\235!\336\254Q%\311\277FE\301\244\201\214\023\n\"\004w\264@\224\301\006\022\020\030y\357K\316\207\022\273\225\214\255\327\306\264\026(2I\t\306\210U\025Z\363\314\347\346\310\313,\253\206\222\222\326i\305\005r\230\003\027N5\252X\243\222\321cR\020&CA\021#\\H\325\267tn\230\220\005\014\354\006\201;\354\251$J\260\332\240\253\021O\316S\245-T8!\000\205c\017p\352\236\243\273\250f\243Yn\367\340k\231\241I\002\354`\232\263\301\302\344\227\237@\\I\r\244vu3\256\027\010\006\301\347^\304\245s-\0242I\\\211\306`\020\300\033\000j\240J\013Z\213\014dK\022\365\321\333\267/\036\207\307w\343\032\036N\210\235_/\207\r\233\215p\302\023\r~\261Qx\204}\241$&\322i \371y\3405\272u\364\241\233\304Fx\324\345\246\345\247JJ\336\003u>\202Dk\017\006\215\021\003\t\0022\233\303\3069\217\366\311Fn\315Z\031I\026\034lQh\313\300\360\274\210F\254Bk\030s\033\321\201\237\013\227\205\231\342\013\020D!#\n\340\270\340\210\363|*]\241\306\205\262\321\035\302\207\276>\2477\003\210\322\240\355\017\026\263\236Z&L>d\r\361\302\006\3334$\305\343\362\333z\003f\2604j\210\331I\256\323\322\201\364\204\322B\027\311HG\010\005\316\205\223H\337\257n\311""\231\240\211\020&g\236f\224+\010\301\243x0_I\320;7o.V\300\346Y\\w\251Tj\322\001\303\261\r\\\251\271#v\210\207\314\206[A-Pt\367\363\230\353\357H\210\245\331\232:4\300\230g`\3410p\206\340oH\272D\241\351Z\362\211\265\222\221\024\356\254Ql\245\254Y\2765P\266\262\r\352RZ\2335U\322!\273\233p\252,P\026\022K*\000EP\000\372\307b\216`\214\206\025\201D\006\020\245@\024\021\230^\352T\201I\000\224\341\017\241\007\222DR~\321/\216\201\320\205AtK\020\301\212\313\257\253\237\027\347\327\334\257\314\222\005\320h\274\234\335\014\260\367\242\235\277<\232\266\251^+fk\006CH\t\241\237j \330\330\200t\337\331\275mH\3440-\263w\343j_\245b\n\032\240\362\312\016\377U\326\244y\304\315\213\361\322h\322\324\2048\343P\2539\215\270\220.y\t\000y\016\364\273{z\212\354\214q\335(\333:Km\242\214\037\206\231\372J\006\r\261\273\262\036V\355\321:3Q\"\034\017t\353L%\010\2569\323F\203\263D\346\\\014,\002p\375\270\330\2760y\031\307.nu\250EN0\345]\242I\315\035\244\361 ^SnIB\317\212\265dY:\264\236\375\362\250c\2036\317\322x\304\327\241\n\341y3\366I\376\217;((\026\316\351\310zH~Z\026\036\302@\252\320y\031f\025\212\356\313t/j\214G\277\266K\226}\302\026\033:\022\350\003\301y\372\275\355\206z\3712}\\*{NB\riy\341\3245t\361\220\027\314e\257lj\331c\230\251!J\252\252\252\254\0061UH\252\253i\235\334[\030\242\251J*\224\\\021\021\004A\021\004D\030@\211J\316\227E!e|!\304\212RV\0244C\0243\032\230H\205\200\231\310\3149\242\331E\320\2000\224\344\026(\357~M\022\234\350\254\321\223J\001\2461$.\304\0212\303I\2230\270\351\246\346\272N\007+D\246n\005\202\rj\220\264\202\036\315b\006F9X%\240\352\270\306#8\320$\201O\242QIY\002\203'\367\377\322\342\357\306\326\213m\324[\r\350ffd\314\327mj\207h\344\020\215)=\360>P\222\344g\320w\251]\021\362o\024\376=u\235\361\203\350\201\013\212zN\274\214\347\000\337\203\311b\361\032\251\333m\300\362y\301\306\362\313!\266\333m6\335\261\371:\304u\210\353\016\265\327\326}Zs\236\275\253\214\362 B\361'\331\024Hk\315\354Mz_K\374>\275\001s\253@\332\033^\207\322\007\261\002m8\240\276\221\t!\264!\202\221\217v'9""\366Y\3603/'\273\303\275oK\037\200\016\377!\260\347t\226\344\314\312\2703(\274\215V\257m\246\032;\203\251vC\236#\255\213\271Cf\261\277P(4o\3351\017,\307\202\341P\0132W\313\253\273h\251\216\203j\260\2036-\034y\240\314Y\372\315\270\264\232\330\237h\304\244\201\210Y\335^\376\031\006X\235\374\026/w\207\t\243\224\246\010\206\270\276;! u\"l@\330\201\264\004K\n\324\301\341\215cx\205\206\3400\265\361\272%\205+_aP\013Q\327\034\217@\233I\235\231\370\201 V\206\001\321\270Y\032\004\304\304\320p\006k^\227Z\243\206\365\270\372\263&\034\252\207)\177_\000\276\030\263\243\357\375>\377\265_c\317[\224\225z\262\372\341\373\023\372\236\237\254\353g\250\305 \240\253\004H>\224`mOH\267\224|\242\255'\242\010zKBI\312\223\356\213\001\212,\336Z\254\302\206P\250'\262v^\217\351:$Q\026Q>\213\331\363eG\267\341\027\257\023\305\242\036\326E\0360,\261c\362\177\003\024\236\005\227\316\022\275\233\225V\tL\356\222\220S\023\320\265\217U0Z\252%P|\323\352\227~\2456\303\355r^\250\371#\3174s\021L\3307\354n\335\275\357c}C.IMn{C\301w\033\313\243\260\020$\337\226\327\227\351\257\224i\253v\345\311\212SH<\372\373\016\007h~b!z\323\277\207\007%\316TQ\310\340\225i\260\025\252CQ\244\305<Ah\365\216\333\337Z\351p}'8\376\331\334\322\0234\262j!\010x\032\027'\334\3457\017\272\236\034x\217O\363>\304\230\031\206M\262\036{\327\357j\021\361\237\241\355\376@\377\232</\000\241\256\3470*0\377h\367\360\361\242\035^\004h\205\023\211;r\257*\0246(\271\324\333\364\025\354P\356\251\270\210\326\023F\254s\216\351;K\362\374-\210\375S\317!\024\204\201l\270l\354\301\3469U\220\034YbD\241l\034N_\216l\354\023\025$\3735\027\262\352\005\370\251RN\210\224\202\032\007o\234\361\177\237\325!7\024\3437\216|\027>A\265\t\304N_\216\322.0\305\261\2757\037\265f'Z.\004\025\256\021\327\366X(>2\233C\244\n\341\253V\375\355w\356\020\031\312\333\316g\304\311\005[\261j\347\330\260T+{\234\304\0073\322\340\3709\267k\024\353H\316\2565[\025\371>\213\022H\241$Y6b\343\3044\033\215&$\251\334\255MC\271\202\230(\257m\001\300\342\243-/\366\205X\325 \324\266[\002\373GZ""\242\244U\006\r\2176y\360\246S)\247u\225\025w\343\303\231V2\357\024J\264V\373\257\225\340\300\334\247\n0\311\262\367\275\346\276\341\254\312\311\305\257Gbg\201\312\375\205*\254\204\250\376\362w\360\266Z\271V\242(\265}\254\327\244:Dv\252\245\203b:-t\336\364\373\317Z\332\260\250\253ex\026\360\3666I\342YR\303V\256\346\260\304\002\273\326\335\234'\273\323\010\336\"\272\226\267\306\024\275\356\266\362/\002A\351yK\246\376#\210\357.\253\2708\333s\354/\360\267m\237\207e\206<q\373/\202\220T\254{\2746\360]i\316s-\310\234^\366_\264\n\334\016\270\336f\210{?\302\256\273\245eB\2532V\256\317GYU\2660\226K+B\225\222\311\354rTJ\326\242\036F\212\227Kii\033\356ug\025\017\316\264#\014\2734u\251RJ&\305Wx5\212:\277(\257b}\023\\\247\257G\311\275\225\364\266\266\266?^{v7\037\271\217\303\247\327\361\233\203n\317\324I\360\006\324\371<\346\356\356\244\370\2204\r\201\004h\376\202\001\177`\326\022\000\376\250\261\204\rMN\214q\302)\225\301Z9x\316\240-\024+\203\270\001:x@\253\361\3146\363\256\273\017\203AF?\263:nl\341sZ\033\331Y\275\251\271\223\247|&\375V\263\207\371K\037B1`\357dc-9U\361\265\261z~}Z\275\316\214\363\201M\375\275#\311[,\223\305S\244\024\324\325v*.]\0072\230o9\257y\243\336BQ\303P\364()u\rKHb\207t\320>n\331M#\035\363)I\351\247\211%\215\311~y\tx\313Nv\211\327\321\347\223a\245gh\322\264f\370\247d\320\213\313\207\245s4\232f1\2011\356\241\276\232\235\305\345M\226:!3\364\217Q1\231\226\354\222\273\243\014\213\0130\254\236\243.h\202\307{j4\322\320i\024\360\352\354\307\305\223\021U1J\022Wzf[e\252\211\272\246ELM\022\261^\\)\202\207z\207%\026\257+\2253\226\263G\252\227%\3361\025\242\200j\250|yu\210\273\314S\025\204U \311\272\222n\3502jHRR,2\326,\242\345>Dd\335\274t\363:=T\244e\032>\222\261\352)=\311\223Y1O{\333\312\234\251\214\321CW[\251\246\311\322\337Q%\211\3224z\230\325c\346DT\030\303\273V>\205\243&%(\"\035YR\256\262\3472f\371\2268\327b\245\206\211'\325\252\307t\224\220&S0\\R\363\352\265\235\251\177\342\356H\247\n\022\001\262\321\316\300";
    PyObject *data = __Pyx_DecompressString(cstring, 6370, 2);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #elif (CYTHON_COMPRESS_STRINGS) != 0 /* compression: zlib (6702 bytes) */
const char* const cstring = "x\332\255\\\313{\323F\327OhhC\t\220@\200P\240(\334\002-\244\004\002\244iy\373\206\204Rz\t\271\230\322\013T\217,\313\211\212#9\222\234\304\320\367{\272\314RK-\265\324\322K/\263d\251\245\227\376\023\372'\274\2773#Y\262%\313\376\236\357{J\244\2313Gg\316\234\373H\343N-\024\244\262\265\250k\226\262gM\t\177\t\313\272\246<\256\024\213\212\021t\026\237\257\374*\310\222\246\351\226\220W\204\212\251\024\004U\023\312jY)\251\232\"l\351\005ej\251\262UV\214\251\333\317\264\242\252\251V\365\231\266#\225\324\202\360\342\305\263%\241 YR\033\300\264\014U\333\230\372Q\227\nx\210&Y\326-E\2606%KX\254Z\233\272&\250\246P\000\375\274bH\226R\252\262Gd\013L\001I\023V\236\254\334\236\235\233\025$\255 \030\312\237\212l\231\202Y\311\313%\3114\025S\320\213B\276\242\226,\260iU\313\2129-<+\nU\275\"h\n\230\267t\241\014\274\370\003\326\246\242\t\246bQC\230bk\225,U\327D<N\234\n\005\325\300$\352\216BO\177+\225Leze\365\251\242Ap\332\357\264\200\327QW\312\313\323+Oe4906\376\373\312SC1+%+\220m\000]\3739h\224T\323j\341\274\216\0039\321\224\201\216G^\257\350\246\265a(\353\253?\n\244R\241\250*\245\202\031*\020\\Y\022\304\262\374\342G\341\306\235\275;wn\n\371\252\245\230\353\312vE\321d\345\367\005\255\372\272\325i\263\203\010\254j\326\353o\246o\315\013R\241 \202\252\222\227\n\240\\\2562M\317\363)\231\372\266TR\031M\\\324+Z\241\003o\003pI\260\244\274 q\311+P'tGMC\337\355\300.)\332\206\265)({2\224\010\2450p\013\247\250\033[\222\025\322\324\224]f\233y\005p\245\013m\255\240n\2500\034\210C\253l)\260/!\257j\222Q\205I\225!OE\343F@\2700\336\212B\223\264PMuC\233\027\356\354q\371A\274S\026\314\3120\025\342K\021\342\000\310K1@!\0258\237\216\272\253b\255\317\202\336\272U-\265\223\264\324\255$\300\264\244\255r:\324z\313).\201\267tj\300\000HVJ%\266h\241(\251%\2450\337\016$D\275bA\te8D!4*\251$WJ\222\305\005\255\027\213\344I$\353\267\252V\324\205\251\320\370\n\025\316\036\265K\360}x\034\267(Bf\256H\366\251\221\243\305\031\210@\010\nPF\033\250\254\227\030\32653\0064u\371\rX\220K:\202U\034nI\206\225\300\356\\\224\256\231\225-""20U+\003\034\361Q)\025HfR\251\244\313\264Z2\007R}Y\021\311\010$\266\214T\254\212\326\211w\355sx\210TewS\301\234\005\326\334ReC\347}fF\226\256\013%\311\330P\204\033R\221|\251\252H\2060s\347\207\233\363B\017\204\326\260\271\005^\204\033\201/\360\361\370\343\251\343\005R\315\357+A\220_\324\267\266\020k_\027TS\312\227\024EcW\303\300\322\020\216\013%\222V<\360@\242o\0212 h\343+\030\036\310#m\010/r\213\302\215k\246p\033\362\277\031sd\262\232-iO\335\252l1\261\355\"HC\031P\017\032\334\261\005s\223\004K\tH\022\312f\025>\2771-Q\352\232\376\226!\334\n\242LW\344\362v\033\346\206\254j\005\205%+E\330\225T\213A\315J\271\254\223\211 \263T\267 \216\333j\220\320\31017 \336\220\257[,\322\220EJH\016fY\262\344M\312N\272\240[\324(\260\204h\316\263\306\215\233\204\330\232\300\344I(ONH\326\253\232\\\240\310\253\226\262\205gXL_\323w_37\001\031D\244\r\300\024\230'\224E\253$\026\rC\252\316\013\n\274\233\307\310\304\320\246\232\210\253y\026\322\023\230[\252ir\223W-\025\341g\352\335T\002G\203+?\232\022\270\231\025\240b\315dN\251q\251\243\235x\004v\037\352q\352?S \000\221K\224\376D\021K\251\310\212(B@,\251j\272v\0339~\207f\027E\231\030\021\305@y\242\374E\330\374\202+\275\\\335K\031\243L\320ehC\321\250\224\320\r\263\013\202eH\232I\334w\031'\033\201\204\332GYu\361E^\327Kip\3620r\205\264\261 \215\244\r\361\352\210F\202Z\201\031\216b!m\t[\025\223Ua\252&\227*\005\205l\334\332\205?\nwx-\244\357\232\275p8y\346\371yu\203\205'\211\264h\261\234\322\356\005\371\252\260\302\3521\330\222^1\036EY\246{\334\351\007g^h\307J\rA}\240\314\0137,CA\2145\244\r\330\243u\323\252\224K\254\210\271%LOO\277\216\331_+\363\265YeA\221U\020&\267F\274\322\254\266A^q\304\000P\032\nRr\245\226\371\233\361\007(\031Q\222\261*f\033!C\221\nU^C\200\343\212\366F\323w\265\233\301\275\277\300\031\"\353\250\241yP\210\312\252\212U\274=\307\311\263j\006V\300\303\323\024K\372\224\333$\026\356\027^\344\236C6\013\344\234\217Y\251\303K\360\004`\272\345\2372S\277(\246\241\300&i\261\035H1\222\231\304\272\223y\274\370\370\331\362\302\332\257\342c""\311T\226\002'\342;\214\024P\222|:Rb\2324\264\r\305\022\337(\325\264\241Jy\303\000\307mC9T\330)\214E\340\036\314\265!\2463\270n\031\261\031Z\275.\204\343\343\351\364r\355\262\314\365\222c\256\267\014s\351\362\313\245\313.\227\224[\256\037\231\345\372\223W.*y\271\205\245C3&\351\304K\332'\342=w\005\316Kg?I;\005#\203*\237\271\263\237E5\233\327\210\313,\376\2629\013F\267+\330\356Q?\3421\213\273\014\276X\035\362\230\312\341\266Ew\002R\350\246\240$\311\023R\214d&\261l2f\233\252;\001\351$\315\236\312&\244\030\311Lb}\221\341\252Y\344\235\305n\364\026\273\323\n\207\250`]lw\347\305\224)B\237^\344\322[\354&\341\305\356\322\r\207(\237\211\213k\212\\1LuG\t\334\266\023\220\342\261)(\311Ib\373\327\034\337\351-\266\366~\021\200\336\225 *KOhS\263\304\336,\230J\330Q\342\352\354\354'\371J\301H\260\025\341p\326;\373YT\273/\226p\".\263\370\313\346,\342)\213\233l>(\277u\312\255\023\226N7\005\253\257\031B\223lO\334\275\252\205\336\205Bz!\020B\227\365\334\333\264uv\302\273\317\234\202\331\225\007\302M\316\323\317\014\031\264y\021\034\334\332\326\222\004\245L\222\212\324u\2268\341\036$\373$\306\343\322\022\337Z\006\276\374-\202\2125\033\347)\tI\316\233\212\223\230<\216\305} \t\311\246\335\335s8V\234\343l^{p9\227\340r\256\017.\347\372\3422!\334>d\333K\264\034+F3\250\022c\355.\224\273\326\216\355\243\351K\351\217!ng\014\020\023h\246$3D\310^\232D\337K\254\273\364\027\227Og?9E\nFb\236\010\207\363\322\331\317\242\332\235{\302\211\270\314\342/\223\263Y\372\353X\363l\3175\317\366\261\346\331\2165\317\366\\\363l\037k\236\215\270\314\342/\223\2639\372\353X\363\\\3175\317\365\261\346\271\2165\317\365\\\363\\\037k\236\213\270\314\342/\223\263\216\345\366\\m\3170\001\234\026\265 D\264Z\251\024\273\206\207\370X\032\353\375\014\206\273\336\010\302\"E\324\rJ\006\000Z\312\311\320J\246:\226\371\213\303\250\325!\333\024h\352$\351x\0313v\316\320\233v\266\376\236\033\353\301\007\330H\201\235\260t}\245`\245\361\255\030EI\3465<\353iR)\352\354H\245\016oI\300R\227\226\206\225>9\360\332i\367\242\332\235\236\370""\223\272\247\024\332\244\232\002J\021V*R\202\374\362\363\345'\313+`c\346A\334\034R@\311)\322\221\222Sp\2646\302=H\366 v\357n\202\327{w\373\340\365\336\335\276x\275w\267\215p\017\222=\210=\230M\360\372`\266\017^\037\314\366\305\353\203\3316\302=Hf\021K\t\n\251\3004\342}\006\224\026b\007\371\236\2043HJ\313\374\014\211\246\344\252e:K\262\036~\301`\016\237\266\252\276\326\324\347\212\342h\334\211S@=\310ww\376vq\365\020VOQq\2046.{\360\327\235\263\347j!\316|G7I0\211\220$Y\246\257t\252\036\306\352\225\247\"}\264\300\215\177\022@#\367\344\227\034;\377\262\262\032\002W9\260\375c\365\3126/\261W\014\035\311w\213\276\350s\222U\016\027\305\225\352\036\376\226T\331\022\227\261e\\S\212kk?\257\275\\\243\2575k\372.\376qA\266\032\311%\305\207\022\213\301 _i\253\221J\240\2734\326\245\242B\007\246\304\340\353Ox\002G\\\267\214\270Uvt\227\245-%\005\224\234<\035)\311F;\332\317\222!oJF:\264\347$\021^\257y:\373=I\247$\300$F\257YS\363o\353\263J\253\021\310\270\207t{\312\225#\274\010\324\333\321\317 \031at\247\032\351\251\267\206\372\321M\244\225\014}di\"S\007\335\007\311\267\351\303O<vt\366\223\023\246`$\365JH\021\301\340\305s\324L\247\332\365ut\333`r\031\331\243\035\3572s=\337\224\346\372xK\232\353\362\2064\202\007\253\357\350g\315\226\275\206\210\373,\276\2639N\362\032q\231\305_6g\355\357X\223\220t\232\275\337\314r\2548\325lz\331\224\nJ\311\222:\031M\000\323i\247\241u\237\244\203|O\302\331$\331G\323N\223J\000\323\311\247\241u\237\244\203|O\302}\220\264\336\246r\336\016\316\230\"\201\2305Ub\222>\310g\023N\262\337\017\347\3751\035\3477\233\325L.\303\303U \0245S\350\264\rf\221\231\226L\261D\247\213\245R\034J\037/\305\360Xi|\240h\350[\242\314\277\r\304\341\364\352\206\237\325\353\204\362S6q(\373Ni\350\273i03\001L\343\302l\315&\262\263^\235c|\316\3641DCv\034\214\2668H\324/r\213T\032\322_\\\217\235\375\244\214S0\222\211\221\220\"\202Ab\214\232\351T\273&\306\266\301\304d\331\243/_J\252%\2764T\213\216H\022\356/\277a\243\367L+\352R^f\247\001\025\303d\347\rE]-Df\201\026;\r&\231\341\251*\311\254j""\262\252O\313\272\241W,\354\024L\311\262v\244R\236\276\365\322\303y\205\037\371\312+\032?6\237\307\324\001H\327K\371JQ\321\n\270\232\352[\205\235\344\245Y\371\001i~%\013\303\024\301\013\035Y\205\306D\221\275\251\202\024\202\006l\213\216yR\027,\210\252&Z\206$+yI~\303\016,\313%S\326K2\235kf\337\250\321c\373\031vd\231\376DX\225N\007gY\207\0377\013\2163\0077\221\035t\216\2168S\213\216i\206\3678\005r\010\231\035P\243#\244tJ,<\266X\220\252f\001\003\304fA\311W6\202\303r\255\203\375\354\214\260(\026h\003\305o\005\223\254\273\315\t\003s/[Fp$Va\223+!\013\n;\t\211)\331qbS1e~T\272\240\354\341?\271b)$\364\242b\311\233\354\"B\026\325\2505\3755\035\263.\231\377\232\246\023\236{e\203)\256\250Bk:}Z17\3418\264\356\"}\216\341'U\371\225\274V\344\007\376c\000\022\007\357\232\361\220Am\335\000\277R\251\310\204KW\254\272X\321d\021*\325\202\331\241\\\374\373Q\337\330P\214(\264D-1\317\254\224\000l\275\"B\274)m(\301\033\344(\356\220\231\210\255\023\220\014\310\237\210\026\254\232\242\276\243\030X\330.\261\020\370\215(\252\252\232\207\341\305N.\303\310\254\273!\007h\317\306\332s\261\266\030\374\036\206\265\203\023\252\301pp\37694mf\331`\240\345J1f\3204\261qeg\231\271\363\020\367a\240l\005\314\266 \311\027\035\234v.1\361\321\025\366!B\315\360\021\\\337(\364\334\226\264\027;$on\2611\275P))\341\335\334\3225\335\3225U\326\260\361\022E~\305]\331\245\313\236\0258\267\246ky\310\362\r&\321X\304\305\212\305<]\313U=\377'\376\301{\240,\335\304\022\313\222!m\231\354\347\0221\303\211\372d$\345\215\273\345*V\003\203\3431\201\374\023\206\317\r\220_y\037\322\013\177?%\222{W\300,\224G\347G\003\207.\353e\374+)E\253\314\217\207\232by;\370hX6\024984\034\236noy\264\031\203T\266\242\336\256!\225\311\373Zg\347\363r\353\334q\2531-v\220-o\207-\322\030\261n\031\"\244!\226\253!/U\026;\312U\030\205\010\360\236(o*\362\033\023\242d=\236\263x;0Pj\222\274y\253\242\225U\371\r\264\327z\225\222\204\007\371\207\301wX\036 }nW\244\022\327-\373\332b0F \032\370)\277\232\321)\363dN\n\001\312\03657\210!C)\227\020\211\3012\347\232_""\321\261*\206\006\001\340\337\035\374\315\220\276\271WP\213\033m\3242\321D\3042vL\304\261\222\2227e3\260USA\360\300Pg\025\320\231\371\243\276\311\022b`\301\361\"\000\355\340(},e\212)\351\323\334T\213\026\345+\263\214\274h\0322\033\3466fZ\206Y\305\024\324\307u\303\2626\301;\3731PX\364\007\277\215\t3\250\245\007A\320\322-\350;X\227\265\307\330f\027\261\210|\313\1775\307\177\376S)S>\t\366r\025xK\310b\305Bp\227\371\257\205\304JE-\260\003\314\374\0243\035\266\247?Q\336\225\014\244\254\r\232\234\250\275zu\347\316\235\326\257\014\247Z\215\371y\026\337\347\242_ F\240\030$\210imX\001\354{I\023\276U\362\302O\222!,\224\r\334\253\302\367\025\r\177%a\241\262!\254+e\341\271l\t\313\372\216\260\244\310S\313\322r4\005\357\004\224\006^\275\372\375\365-\201\377t\304\022n\254T\237\263P\"|vK\240\327+\302gh\254TE\223\324\"\002|s@\344?\313\020Q\263\360\343\371\"\022\276H\343\376\320\025w\346\237\017\007\216\\q'\335\007\336\230w\315\333\256\r6\206O\354[\366\003g\314\271\346l\373C\347\235\231\346\360I\377\344\027\030\033\252-4\206'\335q\367go\306{R\033\257\2556\206?q&\235Yg\233\236\002\366,a\034\335\237\335\177\347\\qV\033#'\355I\373\033P\007\r\202\032\366)\373[\347\252#\265F\032\243\367k\253\265B}\222\370\270\352\316\272okc\315\341+\376\225{\265\231\177\216\017\0349i\237w\026\234\234;\326\030>c\027\234\311\346\360\310\376S\373\2763\350\214\023\375\323\366\232m9\0171\303\254\273\355\r6FN\354\357\330/\330\014\243\023\316`s\364\234s\311\033\364.\326\320\037\267\177pv]\325\333Eg\374\242\363\273\367\221\267W\333\251\2576&>u6\335\242\267\320\034\237\360'\260\316\306e\272\\\020\334\301\306\205\333\336\317\265\271\372\203\203\261\306\370\005\377\302\\}\260q\356\252\373\324\373\252V:\270r\260\332\004\003\2536Vs\001L\376\342\276\360&i\235_\332O\235\031\360\346\237\236\251\2155F?qn\271\233\236\024H\350\337\007\203\335%t\337>d_\261\177\301z?\361f=\243v\252\366]}\t\017D\322zP\223jV}\246\213\264.9\177b\265\247\275|m\360\237\341\201#g\333%v\006j\002\303\277\273\203P!x\037\265?\262+\201t!\250\223\320\343""\256+\271\026\224\273\320\030=\005\0338\355\0240\3518V\327\204\304Do\301{]G\177\3029\352>\364n\326\036\24231\351\236\367\236\0062\272p\331\275\341]\257\r6' ,\360\324\270N\027\341\252\273\320\020fjgj{\365\235\003\310[\360\205\257\353\013\215\2137\240\202w\365[\007\362\3731\322\324\230\203\005B\352\356\004\226 5\241\313\252\363\021x\036=\347\237\203\2254\306?uJ\336\215\332dK\352\260M\347\231\233\363Nz\017H\016L\276\347\234s`\231I\330\264'\033#\247\354\231\306\2611\330\335\002k7q\371\312Q\335m\177\340s\357K\177v\351`\301\037\272\356_\177T\177\375~\222\254\371\013\370\301\024\3246<\351O~Y\037\303\n\207/8\337C,\333\377|<p\344\330\376\023\373\264-\331\020$|\3423o\322\373\272\206\3669X\343\037\314'.\324\231U\256\332\233N\213\301uo\030\"\031\036\361\311L\374\001H#\232\222\024y\331=\345.\270\360\245\223\366gP\307*i,\232\306\276fo;\203l\016\377\"\031\346\350\005\347\211{\301\3531O\003D\236\301\025&a\212h\376\000\"\303\356!w\362o\346\240\367\366\245P\034\376\251\317\301\371Rm0e\344\232\273\352\026<<Cl\216\204c\263\366vsd\334^r\202Gf\367\267\371#\303\307\366\377\000'\001\320`\256\273JC\367h-\316\207N\236\231\336\232\273\335l\003\036r\257\272yo\320\037\002\3374\323q\377\030\211v\026\213\215\024y\332\316\221\005\273\207\241\360\261\346\310\247\216\344X.\334\354\370\276\264_!\355R,0\240\210\237\335\031\367\2117\356A\216\361\340\024\362\032ZE\373\002\023c\366\327\230k\310]\010\327\336\032\214\257\236\234\354\204\177\234\230\275_\033$\2539\272?\023\310\342\350\376\274\275\316\354\027\206\374\3269\345<\005\267\243g\3614\273\244\0013\010\316\372gIM\013\335\351Z\316#\370\376X3\326\354\216\340\237\247xN+\030\0318r\301\371\306\303\322\306!D\330\372so\206YVs\370\262\177y\276>Y\207\375L8\037S\210\"I\234\262\257\302\3658[\243\366\341\300\302F\0219\357\200\341\213u\211G\216S\316\217\010\307\343\223\356%@\317\205A\343+O\255\355\002e\002\316\365\257\272T\267\016f\020\r\334\243\210\247\233\365\342\301B\343\002\017\256\233\204CB\230\253\3154\t\371\021\334\n\341\342h\355\253\372\006\302.\202\321j""+b\\bF\261\356\r6\271\340\317;_\221\2736\206?e\321p\214\270\216\371\355\270?~+\010d,[\254;#\010O\024c\020\255k\323\210\266\243\027\021\022\211\357\263\010\367,m\274\013\202\335\370E\377\"\211d\266\276MQ\361\007\367]\355F\375:\036\301\">b\035\340\\\307\354{\336v\223\220\021A(a\374\20007\205\370\010\321\277s?\207\353\206\r\266\010\222\330,\372\227\301\007\304t\014\006~\256\366y}\265\376\347\373\241\367`\215%>\272Im\221\357\t\205\215\266\014\364\322]$\327\212\341\374\340\232\036\313\000\317\354\325 \014\264\234\341\252\273\344\235\240\3505\341\034v^\3010\330\370;\367\246\367\260\006\331\234\261\337 \262c\202\260\001\357\376\231\325\005\010\211\307\367\21363Vr\014\013\334\357B\326C\336\242g\325\356\326\326jf\375\n\305A*$\276vL\312[\343\3662n#g\355\377\201\307mz\205\332\355:3\340\252\363\001\231\317y\272\220\207\237s\257\203\316\002\211\210\"\304\006\342\3078\231\356](|\342\212{\0279\026\321\271v\265&\361\356/\336\313\332B-\00713\264{\024b\032\023\010\261M\320\374\032V0J\201b\017I\355Q\375p}\225\\b\0172\300\\\277\201\261\253\224\230yi\362\026\013c\205\311\0307\224 \235PDB\334\037\263\207\354'\264t\216\314\363\022b\363\r\036`x8\323\2614\211\322p\024\277\310\366N\354o\222\307\034\337\227\355Oa\252\210\320\227\341L\367Y\242\226`'\214\342\016t\246P!\203'\216]b\261\355\241w\031yx\344\214\177\206y>\013+\304\004\257\006\346 \222u\330\375*\207?E\367\205\313\243\327?g\006\216\234g\214\355RXmP\3716\305\312#Z\023|v5\255Aqt\017\001\364\024\014k\214\303?B\367\264\303\004to_\013\r,\024\221\351\334\300:\036\"tp\213\002\347\237^jL\234#;\372\311\031\243\247\036\242\232Y\24581\342,\271#\264\006`\302\030\374q*\tF\216\241v\341EL\203\262\326E\3477\316e\324n\206\351\345\030oY6\205\035\237\252\204\000\026L\361\211\363\031r(+\300x\272F\025\023O\330\026Udg\355=\026+V\243\214\375#\254\342\325\373\261\0369{\210%T\nw\253\360\305k\244\305\306\360E\"\340\337\242J&\236<\346\250`&\303\036r\026\241\000\305\273\353\255f\022@ \354\217\000\255\207\302\257\302s,Y\321\227p\225\027\265\311\032\345\336\310""\350F\270_V\303,A\016\n\261\237\367\317\337\206c!\304\014\273\307=\211\207\035\362\031\t\256p\005\302\273\352\311\360\255+\265u\304\275q\026\363\233\301-H\267d\222K\265\341\372!\n\236\221a\322\014sD\207\2452D\223\325f\330h$\033-\363\315\271\347h\313\021\031p\216\342\0147\341\221\377o\023>\316\275\220,y+\320\360`\302\222\233al\344\267+W\211\217Q\377\004\245\230A\016\207\005\372C7\275\261d\374$\375\036\245\334\363\367`c\350\343\375\317mh\215\344\215\204\364\rOe\215VJ\245(qb\377\r\017\246<\276\203\265o\260\342G\336\007\224\200!#\377\0249\311()u\206t5c/B\202C\250\305[\025=\3546\250\337~B\004\204\036*\300\371\213\322}\346\346g\032q\207m}\352\312\301\014\262n|7D\240f\307^\247Xo\3173/\334kn\030 \221\211\231\340\375\001\244;,\027Q\3400\305\257\035\367W6\313v}\220@\023\320\303Xch\334\376\036c\024\026\017_v\317z\207\274IH\370\360\221\375\217\250\204\013t\331\030\036\263\307Ha\005\330\311=[F\325g\261\355\335\007\336=\257X[\202\307\256\325\003\273&\231\230\224\034Q\3515i\321\254\214\341\025\333}\373\003\233K\322\236wVa\234\330\006\214!Z\254\243\346, \364\313\336D\355d\355\177\203\321\030\035\013I\037\262\247`f\217\201v\035\">\205\314\267\203,t\246\276}\360\301\301\275\003)d\343\370iRZ\223\212\016h\251\361\t\331\360\207\336fM\251\337\255\257\302\237\217\235\366\307gx>k0\037\343\376\376\262\366\230\0000z\354\355\240\210:\017\372\274\3744x\305p\217\031\356\025\236 \311\263\326Q\\\2175\307)\225r\210\177\221\024mRx`\336\307\013M\222.H\r\363\207^\260\214\203m\366i;\3570M\215\354\337\345U\374\337\264\207<||?g\177\002?|\207\350 5\206\310\362f\260\207\277\345\242\363\321\337;\373/\221\222h+>|2 \332\034\246D\374%\014\347~\355\203\332l\355\355\301\331\367\207\337\257\373+9?\367\207\377\207\342+Ez\222\352\020\377\304gD\025F\371\006H\010\267m\220\261$\003*\366\276\017\016\306\261\207\374?2\362\312\177%\373\362\246\277\371\306\177\243\373\272\345[\357\376\031\030\370kp\341\020n\013\207\226\350\266t\350;\272}wh\215nk\207~\245\333\257\207~;\324'\373\376\300\244;\346b\025\ra\262q\370C\177\000""\372\365\007\020\204\247\375\351\177\037\034\177\017\276\317\007uxs\3500\177\223r\237\266\034\215\241\243\373\217\2302X\014\274O\271\202y\330\031d(\325\237zX\203\337}\352l\241\244\031\344a\3508YKg\030\362\007P\323\336\242\374\242\241\212l\237\013\236\022l\356\273\315\205\220\3677pq\363\205;\265\243\365\257\016\336\370\253k\215\241S\366\227\316wl\273\n)\374e?\244\310\3659K\244\307a\366\2406C\341\217\3339\221\361/}\301\312\240XP\250\240b\303\343\223|+HcG\367'\367gP|V\330^\0051\345\027*\245\210\332C(\263\0255\332C\005E\373m\373cd\323]\227\275]\331\345\001\376Kr9\346\200M$\3639\354\006\203\024u\327~\t\217\225X%m\277\205n&\033\035\216\251\324\302\335[\247\2234\301K\340\027\376\000\n\220)\177\n\201\374\237\321\201\303\303\177WY\240\001?\177RHn\016\205\357U\230\210\336\332'i\220\270\031b\273k&\177\036\273\020\311\217\020\243? \275\014\223\274\302\035\311 \177k$5\306\316\206\341\255\337\036\n\341`_t\326\376\017m(`V\376y\354x\374\333\313\357\245f\253K{\2173\266\346.\370\327\276A\324\032d\333a2\220\017kj}\033\274\372GY\3152\306\371G\\\276f\316\317_3\331\377\020\"|\305\271,-\257\254\257\376(.\254/>{F_\215s\337\316I\246\254\252E\372\337\230\251ZQ\2234\313\250(\377\005\306\227wd";
    PyObject *data = __Pyx_DecompressString(cstring, 6702, 1);
    if (unlikely(!data)) __PYX_ERR(0, 1, __pyx_L1_error)
    const char* const bytes = __Pyx_PyBytes_AsString(data);
    #if !CYTHON_ASSUME_SAFE_MACROS
    if (likely(bytes)); else { Py_DECREF(data); __PYX_ERR(0, 1, __pyx_L1_error) }
    #endif
    #else /* compression: none (19978 bytes) */
const char* const bytes = "'AdaptContext' | NoneBuffer | NoneCOPY cannot be used in pipeline mode'Dumper'-InfinityInvalid UUID dataInvalid UUID string'Loader'NoneNote that Cython is deliberately stricter than PEP-484 and rejects subclasses of builtin types. If you need to pass subclasses then set the 'annotation_typing' directive to False.PQGenConn[None]PQGenConn[abc.PGconn]PQGen[None]PQGen[PGresult | None]PQGen[RV]PQGen[list[PGresult]]PQGen[list[abc.PGresult]]PQGen[list[list[PGresult]]]PostgreSQL text fields cannot contain NUL (0x00) bytesSequence[Any]Sequence[Buffer | None]Sequence[int]?.,: add_notebad copy data: field delimiter not foundbad copy data: got a tab at the end of the rowbad copy data: length exceeding databad copy format: got a newline before the end of the rowbad ndigits in numeric binary representationbad value for numeric sign: 0x bytescan't parse date can't parse interval can't parse interval: can't parse interval with IntervalStyle can't parse time can't parse timestamp can't parse timestamptz with DateStyle can't parse timetz cancellation failed: cancellation timeout expiredcannot calculate the offset of tzinfo ' cannot dump cannot load sequence of class connection failed: connection is bad: connection polled: %sconnection socket closedconnection started: %sconnection timeout expiredconsuming input failed: couldn't allocate for escape_bytea of couldn't allocate for unescape_bytea of %+d day %+d second %+d microseconddate too large (after year 10K): date too large (after year 10K)date too small (before year 1): date too small (before year 1)deque[PipelineCommand]disableenableerror handling PostgreSQL timezone: %r; will use UTC (%s - %s) exceeding the maximum allowed expected format should be a psycopg.adapt.Format, not format should be a psycopg.pq.Format, not gcindefinite wait not supported anymore-infinityinteger expected, got  is a dispatcher to other dumpers: dump() is not supposed to be calledisenabled items: list[Row] loaders registeredmalformed array: empty datamalf""ormed array: hit the end of the buffermalformed array: missing initial '{'malformed array: no '=' after dimension informationmalformed array: unexpected '}'no default __reduce__ due to non-trivial __cinit__psycopg_c/_psycopg/adapt.pyxpsycopg_c/_psycopg/copy.pyxpsycopg_c/_psycopg/generators.pyxpsycopg_c/_psycopg/transform.pyxpsycopg_c/_psycopg/waiting.pyxpsycopg_c/types/bool.pyxpsycopg_c/types/datetime.pyxpsycopg_c/types/numeric.pyxpsycopg_c/types/string.pyxresult not setrow must be included between 0 and rows must be included between 0 and string too big for an inttime not supported by Python: hour=timestamp too large (after year 10K)timestamp too large (after year 10K): timestamp too small (before year 1)timestamp too small (before year 1): (tree fragment)tuple[Any, ...]unexpected DateStyle: unexpected decimal exponent: unexpected lengthunexpected number of dimensions unexpected poll status: unexpected ready value: (unknown)unknown PostgreSQL timezone: %r; will use UTCunknown oid loader not foundutf-8 values in row, got ' without a dateAUTOAnyArrayBinaryLoaderArrayBinaryLoader.__reduce_cython__ArrayBinaryLoader.__setstate_cython__ArrayLoaderArrayLoader.__reduce_cython__ArrayLoader.__setstate_cython__BCBINARY_BaseDatetimeDumper_BaseDatetimeDumper.__reduce_cython___BaseDatetimeDumper.__setstate_cython___BaseDatetimeDumper.get_key_BaseDatetimeDumper.upgrade_BaseDatetimeTextDumper_BaseDatetimeTextDumper.__reduce_cython___BaseDatetimeTextDumper.__setstate_cython___BaseStrDumper_BaseStrDumper.__reduce_cython___BaseStrDumper.__setstate_cython___BaseTimeDumper_BaseTimeDumper.__reduce_cython___BaseTimeDumper.__setstate_cython___BaseTimeDumper.get_key_BaseTimeDumper.upgrade_BaseTimeTextDumper_BaseTimeTextDumper.__reduce_cython___BaseTimeTextDumper.__setstate_cython___BaseTimestamptzLoader_BaseTimestamptzLoader.__reduce_cython___BaseTimestamptzLoader.__setstate_cython__BoolBinaryDumperBoolBinaryDumper.__reduce_cython__BoolBinaryDumper.__setstate_cython__BoolBinaryLoaderBoolBi""naryLoader.__reduce_cython__BoolBinaryLoader.__setstate_cython__BoolDumperBoolDumper.__reduce_cython__BoolDumper.__setstate_cython__BoolDumper.quoteBoolLoaderBoolLoader.__reduce_cython__BoolLoader.__setstate_cython__BufferByteaBinaryLoaderByteaBinaryLoader.__reduce_cython__ByteaBinaryLoader.__setstate_cython__ByteaLoaderByteaLoader.__reduce_cython__ByteaLoader.__setstate_cython__BytesBinaryDumperBytesBinaryDumper.__reduce_cython__BytesBinaryDumper.__setstate_cython__BytesDumperBytesDumper.__reduce_cython__BytesDumper.__setstate_cython__BytesDumper.quoteCDumperCDumper.__reduce_cython__CDumper.__setstate_cython__CDumper.dumpCDumper.get_keyCDumper.quoteCDumper.upgradeCLoaderCLoader.__reduce_cython__CLoader.__setstate_cython__CLoader.load_CRecursiveLoader_CRecursiveLoader.__reduce_cython___CRecursiveLoader.__setstate_cython__CancellationTimeoutConnectionTimeoutContextDataErrorDatabaseErrorDateBinaryDumperDateBinaryDumper.__reduce_cython__DateBinaryDumper.__setstate_cython__DateBinaryLoaderDateBinaryLoader.__reduce_cython__DateBinaryLoader.__setstate_cython__DateDumperDateDumper.__reduce_cython__DateDumper.__setstate_cython__DateLoaderDateLoader.__reduce_cython__DateLoader.__setstate_cython__DatetimeBinaryDumperDatetimeBinaryDumper.__reduce_cython__DatetimeBinaryDumper.__setstate_cython__DatetimeBinaryDumper.upgradeDatetimeDumperDatetimeDumper.__reduce_cython__DatetimeDumper.__setstate_cython__DatetimeDumper.upgradeDatetimeNoTzBinaryDumperDatetimeNoTzBinaryDumper.__reduce_cython__DatetimeNoTzBinaryDumper.__setstate_cython__DatetimeNoTzDumperDatetimeNoTzDumper.__reduce_cython__DatetimeNoTzDumper.__setstate_cython__DecimalDecimalBinaryDumperDecimalBinaryDumper.__reduce_cython__DecimalBinaryDumper.__setstate_cython__DecimalDumperDecimalDumper.__reduce_cython__DecimalDumper.__setstate_cython__DecimalDumper.quoteDefaultContextFloat4BinaryDumperFloat4BinaryDumper.__reduce_cython__Float4BinaryDumper.__setstate_cython__Float4BinaryLoaderFloat4BinaryLoader.__reduce_cython__Float4""BinaryLoader.__setstate_cython__Float4DumperFloat4Dumper.__reduce_cython__Float4Dumper.__setstate_cython__Float8BinaryLoaderFloat8BinaryLoader.__reduce_cython__Float8BinaryLoader.__setstate_cython__FloatBinaryDumperFloatBinaryDumper.__reduce_cython__FloatBinaryDumper.__setstate_cython___FloatDumperFloatDumper_FloatDumper.__reduce_cython__FloatDumper.__reduce_cython___FloatDumper.__setstate_cython__FloatDumper.__setstate_cython___FloatDumper.quoteFloatLoaderFloatLoader.__reduce_cython__FloatLoader.__setstate_cython__FormatInfinityInt2Int2BinaryDumperInt2BinaryDumper.__reduce_cython__Int2BinaryDumper.__setstate_cython__Int2BinaryLoaderInt2BinaryLoader.__reduce_cython__Int2BinaryLoader.__setstate_cython__Int2DumperInt2Dumper.__reduce_cython__Int2Dumper.__setstate_cython__Int4Int4BinaryDumperInt4BinaryDumper.__reduce_cython__Int4BinaryDumper.__setstate_cython__Int4BinaryLoaderInt4BinaryLoader.__reduce_cython__Int4BinaryLoader.__setstate_cython__Int4DumperInt4Dumper.__reduce_cython__Int4Dumper.__setstate_cython__Int8Int8BinaryDumperInt8BinaryDumper.__reduce_cython__Int8BinaryDumper.__setstate_cython__Int8BinaryLoaderInt8BinaryLoader.__reduce_cython__Int8BinaryLoader.__setstate_cython__Int8DumperInt8Dumper.__reduce_cython__Int8Dumper.__setstate_cython__IntBinaryDumperIntBinaryDumper.__reduce_cython__IntBinaryDumper.__setstate_cython___IntDumperIntDumper_IntDumper.__reduce_cython__IntDumper.__reduce_cython___IntDumper.__setstate_cython__IntDumper.__setstate_cython__IntDumper.get_key_IntDumper.quoteIntDumper.upgradeIntLoaderIntLoader.__reduce_cython__IntLoader.__setstate_cython__IntNumericIntNumericBinaryDumperIntNumericBinaryDumper.__reduce_cython__IntNumericBinaryDumper.__setstate_cython__IntNumericDumperIntNumericDumper.__reduce_cython__IntNumericDumper.__setstate_cython___IntOrSubclassDumper_IntOrSubclassDumper.__reduce_cython___IntOrSubclassDumper.__setstate_cython__InterfaceErrorInternalErrorIntervalBinaryLoaderIntervalBinaryLoader.__reduce_cython__IntervalBinaryLoade""r.__setstate_cython__IntervalLoaderIntervalLoader.__reduce_cython__IntervalLoader.__setstate_cython___MixedNumericDumper_MixedNumericDumper.__reduce_cython___MixedNumericDumper.__setstate_cython__NONENPInt16BinaryDumperNPInt16BinaryDumper.__reduce_cython__NPInt16BinaryDumper.__setstate_cython__NPInt16DumperNPInt16Dumper.__reduce_cython__NPInt16Dumper.__setstate_cython__NPInt32BinaryDumperNPInt32BinaryDumper.__reduce_cython__NPInt32BinaryDumper.__setstate_cython__NPInt32DumperNPInt32Dumper.__reduce_cython__NPInt32Dumper.__setstate_cython__NPInt64BinaryDumperNPInt64BinaryDumper.__reduce_cython__NPInt64BinaryDumper.__setstate_cython__NPInt64DumperNPInt64Dumper.__reduce_cython__NPInt64Dumper.__setstate_cython__NPNumericBinaryDumperNPNumericBinaryDumper.__reduce_cython__NPNumericBinaryDumper.__setstate_cython__NPNumericDumperNPNumericDumper.__reduce_cython__NPNumericDumper.__setstate_cython__NaNNoneNoneTypeNotSupportedErrorNumericBinaryDumperNumericBinaryDumper.__reduce_cython__NumericBinaryDumper.__setstate_cython__NumericBinaryLoaderNumericBinaryLoader.__reduce_cython__NumericBinaryLoader.__setstate_cython__NumericDumperNumericDumper.__reduce_cython__NumericDumper.__setstate_cython__NumericLoaderNumericLoader.__reduce_cython__NumericLoader.__setstate_cython__OidBinaryLoaderOidBinaryLoader.__reduce_cython__OidBinaryLoader.__setstate_cython__OperationalErrorPG_AUTOPG_BINARYPG_TEXTPQGenPQ_BINARYPQ_TEXTPipelineCommandPqFormatProgrammingErrorPyFormat__Pyx_PyDict_NextRefRRVRWReadyRowRowDumperRowDumper.__reduce_cython__RowDumper.__setstate_cython__RowLoaderRowLoader.__reduce_cython__RowLoader.__setstate_cython__SafeUUID_unknownSequence_StrBinaryDumperStrBinaryDumperNameStrBinaryDumperName.__reduce_cython__StrBinaryDumperName.__setstate_cython__StrBinaryDumperVarcharStrBinaryDumperVarchar.__reduce_cython__StrBinaryDumperVarchar.__setstate_cython__StrBinaryDumper_StrBinaryDumper.__reduce_cython__StrBinaryDumper.__reduce_cython___StrBinaryDumper.__setstate_cython__StrBinaryDumpe""r.__setstate_cython___StrDumperStrDumperNameStrDumperName.__reduce_cython__StrDumperName.__setstate_cython__StrDumperUnknownStrDumperUnknown.__reduce_cython__StrDumperUnknown.__setstate_cython__StrDumperVarcharStrDumperVarchar.__reduce_cython__StrDumperVarchar.__setstate_cython__StrDumper_StrDumper.__reduce_cython__StrDumper.__reduce_cython___StrDumper.__setstate_cython__StrDumper.__setstate_cython__TEXTTextBinaryLoaderTextBinaryLoader.__reduce_cython__TextBinaryLoader.__setstate_cython___TextLoaderTextLoader_TextLoader.__reduce_cython__TextLoader.__reduce_cython___TextLoader.__setstate_cython__TextLoader.__setstate_cython__TimeBinaryDumperTimeBinaryDumper.__reduce_cython__TimeBinaryDumper.__setstate_cython__TimeBinaryDumper.upgradeTimeBinaryLoaderTimeBinaryLoader.__reduce_cython__TimeBinaryLoader.__setstate_cython__TimeDumperTimeDumper.__reduce_cython__TimeDumper.__setstate_cython__TimeDumper.upgradeTimeLoaderTimeLoader.__reduce_cython__TimeLoader.__setstate_cython__TimeTzBinaryDumperTimeTzBinaryDumper.__reduce_cython__TimeTzBinaryDumper.__setstate_cython__TimeTzDumperTimeTzDumper.__reduce_cython__TimeTzDumper.__setstate_cython__TimedeltaBinaryDumperTimedeltaBinaryDumper.__reduce_cython__TimedeltaBinaryDumper.__setstate_cython__TimedeltaDumperTimedeltaDumper.__reduce_cython__TimedeltaDumper.__setstate_cython__TimestampBinaryLoaderTimestampBinaryLoader.__reduce_cython__TimestampBinaryLoader.__setstate_cython__TimestampLoaderTimestampLoader.__reduce_cython__TimestampLoader.__setstate_cython__TimestamptzBinaryLoaderTimestamptzBinaryLoader.__reduce_cython__TimestamptzBinaryLoader.__setstate_cython__TimestamptzLoaderTimestamptzLoader.__reduce_cython__TimestamptzLoader.__setstate_cython__TimetzBinaryLoaderTimetzBinaryLoader.__reduce_cython__TimetzBinaryLoader.__setstate_cython__TimetzLoaderTimetzLoader.__reduce_cython__TimetzLoader.__setstate_cython__TransformerTransformer.__reduce_cython__Transformer.__setstate_cython__Transformer.as_literalTransformer.dump_sequenceTran""sformer.from_contextTransformer.get_dumperTransformer.get_loaderTransformer.load_rowTransformer.load_rowsTransformer.load_sequenceTransformer.set_dumper_typesTransformer.set_loader_typesTransformer.set_pgresultTypeVarUTCUUIDUUIDBinaryLoaderUUIDBinaryLoader.__reduce_cython__UUIDBinaryLoader.__setstate_cython___UUIDLoaderUUIDLoader_UUIDLoader.__reduce_cython__UUIDLoader.__reduce_cython___UUIDLoader.__setstate_cython__UUIDLoader.__setstate_cython__WWait_WritableUUIDXZoneInfoabcadaptersarray_oidas_literalas_tupleastimezoneasyncio.coroutinesattvalbbase_oidbelengthbenfieldsbit_lengthboolbufendbufsizebytearraycancelcancel_conncintervalcires__class____class_getitem__cline_in_tracebackcloseclscolcollectionscommandsconnconn_encodingconn_statusconnectconnect_startconnectionconninfoconninfo_encodingcontextcreadydatadatedatetimedaysdeadlinedebugdecimaldelimiterdeque__dict___dictdsdumpdump_sequencedumper_ptrdumperseencodeencodingenumerateerrorsescescapedexexecutefendfetchfetch_manyfetch_many.<locals>.genexprfieldfilenofinish_pgconnfloatformatformat_row_binaryformat_row_textformatsfrom_contextfromordinalfstartfstat__func__gengenexprgetgetLoggerget_dumperget_dumper_by_oidget_error_messageget_keyget_loader_get_timestamp_load_error.<locals>.is_overflow__getstate___iiibresinfinityint_int2_dumper_int4_dumper_int8_dumper_int_classes_int_numeric_dumperintegerintervalires_is_coroutineis_overflowis_safeitemslengthloadload_rowload_rowsload_sequenceloaderloadersloggerlogging__main__make_rowmaxmicrosecondsmin__module__modulesmonotonicname__name____new__nextnfieldsnonblockingntypesnum_bsnumpyobjobjectoidosoutparamsparse_row_binaryparse_row_textpg2pyencpgcancelconn_ptrpgconnpgconn_ptrpgrespipeline_communicatepoll_statuspoppopleftpostgres_pq_Formatprecpsycopgpsycopg._encodingspsycopg._enumspsycopg._wrapperspsycopg.abcpsycopg_cpsycopg_c._psycopgpsycopg.pqpsycopg.rowsptrptr_out_py_Formatpyreadypyval__pyx_checksum__pyx_result__pyx_state__pyx_type__pyx_unpickle_RowDumper__pyx_unpickle_RowLoader__pyx""_vtable____qualname__quoterreadyrecordrecords__reduce____reduce_cython____reduce_ex__regtypereplaceresresultresultsreturnrowrow0row1row_dumperrow_loaderrow_loadersrowendrvsscalebscssecondsselfsendset_dumper_typesset_loader_typesset_loaders__set_name__set_pgresultsetdefault__setstate____setstate_cython__shiftsizesplitsrcstatestatusstrsys__test__tgtthrowtimetimedeltatimeouttimezonetoordinaltotal_secondstxtypestypes_fasttypingtzinfoupdateupgradeuse_setstateutcutcoffset_uuidvaluevalueswaitwait_cwarningzoneinfo\\\\000-Infinity'Infinity'::float8'-Infinity'::float8'Infinity'::numeric'-Infinity'::numericJan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec'NaN'::float8'NaN'::numeric\000\\\\[], -infint (PyObject *, char **, Py_ssize_t *)\000_buffer_as_string_and_size\320\004#\2401\360\006\000\t#\240!\2406\250\021\250%\250q\260\001\330\010\017\210t\2206\230\021\230%\230q\320\004\033\2301\340\010\022\320\022/\250q\260\004\260A\330\010!\240\024\240V\2501\250E\260\024\260Q\330\010\032\230!\2304\230q\330\010\017\210q\320\0044\260A\330\010\013\2104\210{\230#\230Q\330\014\022\220!\220?\240!\2401\340\010\013\2104\210r\220\023\220F\230$\230a\330\014\022\220!\220?\240!\330\0205\260Q\260d\270!\360\006\000\t$\2404\240z\260\021\340\010#\320#3\2601\360\016\000\t\022\220\033\230A\230T\240\021\330\010\026\220d\230!\340\010\014\210G\2205\230\001\230\024\230Q\330\014\025\220R\220t\2307\240!\2404\240q\250\001\330\014\017\210v\220U\230$\230a\330\020\030\230\001\340\020\031\230\037\250\001\250\035\260a\330\020\024\220K\230w\240i\250w\260a\330\024\035\230[\250\007\250x\260v\270Q\330\030\036\230h\240f\250A\340\024\030\320\030/\250q\330\"/\250q\330\034 \240\001\330\034-\250V\2608\2706\300\021\330\024\034\320\0348\270\001\330\031$\240G\250;\260l\300#\300Q\340\014\025\220Q\220a\330\014\034\230A\230X\240U\250!\340\010\013\2109\220G\2301\330\014\025\320\0251\260\021\330\020\032\230,\240h\250a\330\010\017\210q\320\004@\300\001\330\010\013\2104\210{\230#\230Q\330\014\022\220!\220?\240!\2401\340\010\013\2105""\220\002\220#\220X\230T\240\032\2504\250r\260\023\260H\270D\300\001\330\014\022\220!\220?\240!\330\0206\260a\260t\2701\360\006\000\t$\2404\240z\260\021\340\010#\320#3\2601\360\016\000\t\037\230j\250\001\250\025\250b\260\001\360\010\000\t\027\220d\230!\340\010\014\210G\2205\230\001\230\026\230q\330\014\025\220[\240\001\240\024\240Q\340\014\020\220\007\220u\230A\230T\240\021\330\020\031\230\022\2304\230w\240a\240t\2501\250A\330\020\023\2206\230\025\230d\240!\330\024\034\230A\340\024\035\230_\250A\250]\270!\330\024\030\230\013\2407\250)\2607\270!\330\030!\240\033\250G\2608\2706\300\021\330\034\"\240(\250&\260\001\340\030\034\320\0343\2601\330&3\2601\330 $\240A\330 1\260\026\260x\270v\300Q\330\030 \320 <\270A\330\035(\250\007\250{\270,\300c\310\021\340\020\031\230\021\230!\330\020 \240\001\240\030\250\025\250a\340\014\017\210y\230\007\230q\330\020\031\320\0315\260Q\330\024\036\230l\250(\260!\340\014\025\220Q\220a\330\014\033\2301\230I\240T\250\022\2506\260\021\340\010\017\210q\320\004\031\230\031\240!\330\010\013\2104\210s\220!\330\014\023\2201\330\r\021\220\023\220A\330\014\023\2201\340\014\023\220;\230i\240q\320\000+\2509\3204D\300A\320\004&\320&=\270]\310!\330\010\032\230/\250\021\250'\260\021\330\010!\320!9\270\021\270!\330\010\034\230J\240a\240q\360\n\000\t\r\210E\220\025\220a\220q\330\014\022\320\022*\250!\250<\260q\330\014\031\230\024\230^\2501\250E\260\034\270Q\330\014\025\220Q\220h\230a\330\014\033\2301\230I\240S\250\010\260\001\340\010\014\320\014\034\230A\320\000$\240A\320\004&\320&=\270]\310!\360\006\000\t\"\240\023\240A\240Q\330\010\022\220*\230A\230Q\340\010\014\210E\220\025\220a\220q\330\014\022\220%\220q\230\001\330\014\031\230\024\320\035/\250q\330\020\034\230E\240\034\250Q\330\014\025\220Q\220h\230a\330\014\033\2301\230I\240S\250\010\260\001\340\010\014\320\014\034\230A\330\010\014\210I\220U\230!\2301\330\010\014\210K\220q\230\010\240\002\240!\200A\330\010\013\2103\210a\330\014\023\2201\340\014\023\320\023+\2501\250D\260\001\200A\330\010\013\2103\210a""\330\014\023\2201\340\014\023\320\023%\240Q\240d\250!\200A\360\006\000\t\014\2103\210a\330\014\023\2204\220q\340\014\024\220D\230\001\200A\330\010\013\2104\210q\330\014\023\2201\340\010\r\210^\2301\230A\330\010\013\2104\210r\220\033\230A\230Q\330\014\023\2203\220a\220q\230\006\230b\240\001\240\024\240R\240q\340\014\023\2203\220a\220q\230\006\230b\240\002\240$\240b\250\001\320\004\034\230A\360\006\000\t\016\320\r*\250!\2504\250q\330\010\013\2104\210s\220!\330\014\025\220T\230\026\230q\240\005\240T\250\021\340\014\036\230a\230t\2401\330\014\016\210a\210u\220A\330\014\025\220R\220r\230\024\230V\2401\240E\250\024\250Q\340\010\032\230!\2304\230q\330\010\017\210q\200A\330\010\013\2104\210s\220!\330\014\023\2201\340\014\023\320\023%\240Q\240d\250!\200A\330\010\013\2104\210s\220!\330\014\023\2201\340\014\023\220<\230q\240\004\240A\200A\360\006\000\t\014\2104\210s\220!\330\014\023\2204\220q\340\014\024\220D\230\001\200A\360\010\000\t\017\320\016*\250!\2505\260\001\260\021\330\010\013\2101\330\014\023\2201\340\010\013\210:\220S\230\007\230q\330\014\017\210z\230\023\230G\2401\330\020\027\220q\340\020\027\220q\340\014\017\210z\230\023\230G\2401\330\020\027\220q\340\020\027\220q\200A\360\010\000\t\017\320\016*\250!\2505\260\001\260\021\330\010\013\2101\330\014\023\2204\320\027+\2501\250A\340\010\013\210:\220S\230\007\230q\330\014\017\210z\230\023\230G\2401\330\020\027\220t\230=\250\001\250\021\340\020\027\220t\230=\250\001\250\021\340\014\017\210z\230\023\230G\2401\330\020\027\220t\230=\250\001\250\021\340\020\027\220t\320\033/\250q\260\001\200A\360\014\000\t\034\230?\250!\330\014\024\220A\330\010\034\230O\2501\330\014\025\220Q\340\010\"\320\":\270!\2701\330\010\030\230\n\240!\2401\360\006\000\t\023\220$\220a\330\010\013\2101\330\014\020\220\005\220U\230!\2301\330\020\030\320\0300\260\001\260\035\270a\330\020\023\2206\230\023\230L\250\001\330\024!\240\037\260\001\260\031\270!\330\024\030\230\013\240;\250i\260w\270a\330\030!\320!>\270a\270t\3001\330\030 \240\013\250;\260h\270f""\300A\330\034$\240G\250;\260h\270a\330\030*\250!\2508\2601\340\030!\320!=\270Q\330\035(\250\013\260;\270g\300Q\340\024\035\230Q\340\020\031\230\021\230!\330\020\037\230q\240\005\240S\250\001\340\014\023\2201\340\010\033\230;\240a\240q\330\010\036\230j\250\001\250\021\360\006\000\t\r\210E\220\025\220a\220q\330\014\024\320\024,\250A\250]\270!\330\014\017\210v\220S\230\014\240A\330\020\031\320\0311\260\021\260.\300\001\330\020\035\230T\240\037\260\001\260\027\270\001\330\020\024\220K\230{\250)\2607\270!\330\024\035\320\035:\270!\2704\270q\330\024\034\230K\240{\260(\270&\300\001\330\030 \240\007\240{\260(\270!\330\024&\240a\240x\250q\340\024\035\320\0359\270\021\330\031$\240K\250{\270'\300\021\330\020\027\220{\240+\250Q\330\020\027\220{\240+\250Q\340\020\031\230\021\330\020\023\2204\220{\240\"\240A\330\024\030\230\r\240T\250\031\260+\270Q\270j\310\004\310A\330\020\026\220d\230!\330\020\026\220a\340\014\025\220Q\220a\330\014\033\2301\230E\240\023\240A\340\014\025\220Q\220a\330\014\034\230A\230W\240C\240q\340\014\025\220Q\220a\330\014\033\2301\230K\240s\250!\340\010\014\210I\220Q\330\010\014\210K\220q\330\010\017\210q\200A\330\010$\240D\250\017\260q\330\014\030\230\005\230\\\250\021\340\010\014\210K\220{\240)\2507\260!\330\014\026\220k\240\033\250A\340\014\026\220k\240\033\250A\340\010\r\210V\2206\230\021\230!\330\010\016\210f\220A\360\010\000\t\014\2104\210t\2204\220w\230j\250\004\250C\250t\2602\260R\260s\270#\270Q\330\014\017\210t\220<\230s\240!\330\020\024\220N\240!\330\014\027\220~\240Q\240h\250d\260-\270q\330\014\017\210y\230\003\2301\330\020\033\2301\330\020\025\220T\230\031\240&\250\004\250A\250Q\330\020\023\2203\220g\230Q\330\024\027\220t\2302\230Q\340\030#\2402\240U\250'\260\021\260$\260a\340\030#\2402\240X\250W\260A\260T\270\021\330\024\027\220t\2303\230b\240\001\330\030$\240A\340\020\033\230<\240q\330\020\036\230a\230x\240t\250=\270\005\270Q\340\014\017\210x\220q\330\020\025\220Z\230s\240$\240h\250a\340\010\013\2104\210z\230\021\230$\230a\330\014\021\220\025""\220a\220q\340\010\017\210q\320\004\034\230A\360\n\000\t\021\220\004\220E\230\021\230!\340\010\013\2104\210y\230\007\230q\330\014\022\220(\230!\2304\230q\340\014\023\2203\220o\240Q\240a\360\016\000\t\016\320\r*\250!\2504\250q\360\006\000\t\017\210h\220a\330\010\016\210c\220\036\230q\240\001\340\010\"\240!\2405\250\001\250\025\250a\250q\340\010\013\2104\210v\220Q\220e\2307\240!\360\006\000\r\037\230a\230t\2407\250\"\250A\330\014\026\320\026+\2501\250A\330\014\023\2201\220E\230\021\330\014\022\220!\2208\2302\230S\240\005\240Q\330\014\023\2201\220G\2302\230U\240!\330\014\023\2201\360\026\000\t\033\230!\2304\230w\240b\250\001\330\010\022\320\022'\240q\250\001\330\010\017\210q\220\005\220Q\330\010\017\210q\220\005\220Q\330\010\017\210q\220\005\220Q\330\010\016\210a\210x\220r\230\023\230E\240\021\330\010\017\210q\220\007\220r\230\025\230a\340\010\013\2103\210n\230A\230W\240C\240q\330\014\021\220\025\220a\220s\230(\240!\2407\250!\330\010\017\210q\200A\360\006\000\036\037\330\030\031\340\010\014\210M\230\021\340\010\013\2107\220#\220Q\330\014\020\220\014\230D\240\014\250A\330\014\017\210q\330\020\024\320\024$\240A\330\014\r\340\010#\2404\240z\260\021\330\010\014\320\014\035\230Z\240q\250\001\330\010\014\320\014\035\230Z\240q\250\001\340\010\013\2104\210q\330\014\r\340\010\013\2104\210t\2201\330\014\020\320\020 \240\001\330\014\r\340\010\013\2107\220#\220Q\330\014\032\230*\240A\240U\250!\340\010\034\230J\240a\240t\2501\360\n\000\t\r\210E\220\025\220a\220t\2301\330\014\027\220x\230q\240\005\240Q\330\014\031\230\024\230^\2501\250L\270\005\270\\\310\021\330\014\025\220Q\220h\230a\330\014\033\2301\230I\240S\250\010\260\001\340\010\014\320\014\034\230A\320\004\034\230A\330\010\020\220\005\220Q\220d\230%\230q\240\001\330\010\035\230^\2501\320,<\270A\330\010\013\2104\210s\220!\330\014\023\2208\2301\340\010\017\210y\230\004\230C\230w\240e\2502\250Q\320\004\034\230A\330\010\020\220\005\220Q\220d\230%\230q\240\001\330\010\035\230^\2501\320,>\270a\330\010\013\2104\210s\220!\330\014""\023\2208\2301\340\010\017\210y\230\004\230C\230w\240e\2502\250Q\320\004\034\230A\360\n\000\t\023\220$\220e\2301\230A\330\010\"\240!\2409\250A\250U\260!\2601\340\010\r\320\r*\250!\2504\250q\360\014\000\t\014\2104\210y\230\007\230q\330\014\017\210t\2204\220q\330\020\033\320\033-\250Q\330\024\030\230\010\240\016\250a\330\020\023\2204\220t\2303\230a\230s\240#\240U\250$\250c\260\021\260#\260S\270\001\330\024\030\230\n\240!\340\024\030\230\n\240!\340\014\036\230a\230t\2407\250\"\250D\260\010\270\002\270!\330\014\026\320\026+\2501\250A\330\014\017\210t\2208\2303\230a\330\020\027\220q\230\005\230Q\340\020\027\220q\230\005\230Q\330\020\027\220q\230\005\230Q\330\020\027\220q\230\005\230Q\330\014\022\220!\2208\2302\230T\240\031\250%\250q\330\014\023\2201\220G\2302\230T\240\033\250A\330\014\023\2201\360\014\000\t\033\230!\2304\230w\240b\250\001\330\010\022\320\022'\240q\250\001\330\010\017\210q\220\005\220Q\330\010\017\210q\220\005\220Q\330\010\017\210q\220\005\220Q\330\010\016\210a\210x\220r\230\023\230E\240\021\330\010\017\210q\220\007\220r\230\025\230a\340\010\016\210h\220a\330\010\013\2103\210m\2301\230I\240S\250\001\330\014\021\220\025\220a\220s\230(\240!\2407\250!\340\010\017\210q\200A\330\010\017\210q\200A\330#$\360\014\000\t\020\320\017\037\230q\240\001\200A\330\010\017\210t\2201\320\004)\250\021\330\010$\240D\250\017\260q\330\014\030\230\005\230\\\250\021\330\010\020\220\013\230;\240a\200\001\330\004\n\210+\220Q\320\004-\250Q\330\010\033\230?\250!\2508\2601\330\010\"\320\":\270!\2701\360\016\000\t\017\210k\230\021\230!\330\010\026\220d\230!\330\010\013\210?\230!\230=\250\003\2501\330\014\022\220!\320\023$\240A\330\020*\250!\2501\330\020\023\2201\220C\220q\230\004\230A\340\010\014\210G\2205\230\001\230\021\330\014\023\320\023+\2501\250M\270\021\330\014\017\210u\220C\220|\2401\330\020\030\230\001\340\020\031\230\037\250\001\250\035\260a\330\020\024\220K\230w\240i\250w\260a\330\024.\250a\250x\260v\270Q\270e\3001\300A\330\024\035\230[\250\007\250x\260v\270Q\270e\3001\340""\024\034\320\0348\270\001\330\031$\240G\250;\260f\270A\340\014\025\220Q\220a\330\014\034\230A\230U\240%\240q\340\010\017\210q\320\004\035\230Q\330\010\016\210a\320\000\035\320\035-\250Q\360\006\000\005\037\230a\230v\240Y\250a\250x\260q\270\001\360\006\000\005\030\220r\230\021\330\004\024\220J\230a\230q\360\006\000\005\"\240\027\250\002\250!\360\014\000\005\t\210\007\210u\220A\220Q\330\010\017\210q\330\010\021\220\021\340\010\016\210d\220!\2203\220c\230\026\230t\2404\240q\250\003\2503\250f\260D\270\005\270R\270q\330\014\017\210t\2201\220C\220s\230!\330\020\032\230!\340\020\030\230\001\330\014\024\220A\360\006\000\t\014\2105\220\003\2201\330\014\022\220!\220:\230Q\230a\330\r\021\220\021\220#\220S\230\006\230d\240$\240c\250\030\260\022\2601\330\014\022\220!\220:\230Q\230a\330\r\021\220\021\220#\220S\230\006\230d\240$\240c\250\030\260\022\2601\330\014\022\220!\220:\230Q\330\020\021\360\006\000\t\014\2105\220\002\220'\230\023\230B\230d\240&\250\001\250\023\250C\250v\260T\270\026\270q\300\003\3003\300a\330\014\024\220A\360\006\000\016\025\220C\220q\340\014\024\320\024+\2501\330\032'\240q\250\006\250h\260e\2702\270Q\360\n\000\r\025\320\0241\260\021\260$\260a\330\014\036\230a\230w\240e\2502\250W\260B\260a\330\014\022\320\022#\320#8\270\001\270\021\330\014\022\220!\330\014\023\2204\220r\230\021\330\020\023\2203\220a\220s\230#\230Q\330\024\027\220q\230\005\230S\240\001\240\021\340\024\033\2301\330\024\027\220q\230\005\320\035.\250a\250s\260!\2601\330\020\027\220q\330\020\027\220q\340\010\021\220\021\220!\330\010\027\220q\230\005\230U\240!\360\006\000\t\022\220\025\220b\230\001\360\006\000\005\014\2102\210^\2301\230A\200\001\360\010\000\005\016\210T\220\032\2304\230{\250$\250a\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2309\240G\2505\260\003\2604\260z\300\027\310\005\310S\320PT\320T^\320^e\320ef\330\004\007\200q\330\010\017\320\017*\250$\250a\250w\260k\300\027\310\001\340\010\017\320\017*\250$""\250a\250w\260k\300\021\200\001\360\010\000\005\016\210T\220\032\2304\230{\250$\250i\260t\2706\300\024\300Q\330\004\014\210G\2201\220F\230,\240a\330\004\007\200v\210W\220E\230\024\230Q\330\010\022\220!\330\010\027\220q\340\010\027\220t\2309\240G\2505\260\003\2604\260z\300\027\310\005\310S\320PT\320T\\\320\\c\320ch\320hk\320ko\320ot\320t{\360\000\000|\001A\002\360\000\000A\002D\002\360\000\000D\002H\002\360\000\000H\002R\002\360\000\000R\002Y\002\360\000\000Y\002Z\002\330\004\007\200q\330\010\017\320\017*\250$\250a\250w\260k\300\027\310\001\340\010\017\320\017*\250$\250a\250w\260k\300\021\320\000!\240\021\240\021\200\001\330 !\330\005\006\320\000\036\230a\320\000\033\320\033.\320.@\300\016\310a\330\004\033\320\033/\250q\260\001\340\004\005\330\010\032\230!\2305\240\004\240A\330\004\013\210=\230\001\360\006\000\t\033\230!\2305\240\001\330\010\016\210a\320\000\026\220h\230i\320'7\260q\320\004\036\230m\250=\270\001\330\010$\240D\250\016\260a\330\014\030\230\005\230\\\250\021\330\010\020\220\013\230;\240a\320\000\031\320\031,\320,>\270n\310A\330\004\033\320\033/\250q\260\001\340\004\005\330\010\030\230\001\230\025\230d\240!\330\004\013\210=\230\001\360\006\000\t\033\230!\2305\240\001\330\010\016\210a\320\000\037\230q\200\001\340\004\037\230q\320 0\260\013\270;\300k\320QR\330\004\023\2209\230H\240A\240Q\330\004\007\200|\2207\230!\330\010+\2501\250L\270\016\300a\330\004\013\2101\200\001\330\004'\240q\250\006\250a\320\000\037\320\037/\250q\360\006\000\005\037\230a\230v\240Y\250a\250u\260A\260Q\330\004!\240\024\240R\240q\360\006\000\005\013\210!\2101\210K\220u\230G\2401\330\004\035\230X\240Q\240a\330\004\013\2107\220!\330\004\024\220J\230a\230q\360\014\000\005\t\210\007\210u\220A\220Q\330\010\016\210a\210q\220\n\230%\230w\240a\330\010\017\210w\220a\330\010\013\2109\220C\220q\330\014\024\220A\340\014\033\2308\2401\240A\330\014\017\210t\2202\220W\230B\230a\330\020\026\220a\220z\240\021\240!\330\014\024\320\024+\2501\330\032'\240q\250\006\250e\2601\330\014\023\2201\340\010\021""\220\021\220!\330\010\027\220q\230\005\230U\240!\340\004\013\2102\210^\2301\230A\320\000\020\320\020'\320':\270!\360\020\000\005\010\200y\220\003\2201\330\010\016\210j\230\001\230\021\340\004\020\220\007\220u\230A\230Q\330\004\007\200z\220\022\2201\330\010\024\220A\340\004\013\2103\210a\340\004\005\330\010\017\210t\2201\220A\340\010\t\330\014\024\220K\230q\240\010\250\006\250a\330\014\017\210v\220S\230\001\330\020\032\230,\240a\330\021\027\220s\230!\330\020\032\230,\240a\330\021\027\220s\230!\330\020\032\230,\240a\330\021\027\220s\230!\330\020\032\230,\240a\330\021\027\220s\230!\330\020\021\330\024\031\230\021\230!\330\020\027\220}\240A\330\024\032\230!\320\033,\250A\320-N\310a\340\024\032\230!\320\033,\250A\250Q\340\020\026\220n\240A\320%?\270q\300\001\340\014\023\320\023/\250q\260\006\260i\270q\340\004\013\320\013\034\230A\330\010\021\220\022\2201\330\010\017\210q%s::%sutf-8InfinityNaNPSQL_ASCIIUTCUTF8asciifalseinfnantrue";
    PyObject *data = NULL;
    CYTHON_UNUSED_VAR(__Pyx_DecompressString);
    #endif
    PyObject **stringtab = __pyx_mstate->__pyx_string_tab;
    Py_ssize_t pos = 0;
    for (int i = 0; i < 752; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyUnicode_DecodeUTF8(bytes + pos, bytes_length, NULL);
      if (likely(string) && i >= 118) PyUnicode_InternInPlace(&string);
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
      stringtab[i] = string;
      pos += bytes_length;
    }
    for (int i = 752; i < 832; i++) {
      Py_ssize_t bytes_length = index[i].length;
      PyObject *string = PyBytes_FromStringAndSize(bytes + pos, bytes_length);
      stringtab[i] = string;
      pos += bytes_length;
      if (unlikely(!string)) {
        Py_XDECREF(data);
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    Py_XDECREF(data);
    for (Py_ssize_t i = 0; i < 832; i++) {
      if (unlikely(PyObject_Hash(stringtab[i]) == -1)) {
        __PYX_ERR(0, 1, __pyx_L1_error)
      }
    }
    #if CYTHON_IMMORTAL_CONSTANTS
    {
      PyObject **table = stringtab + 752;
      for (Py_ssize_t i=0; i<80; ++i) {
        #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
        #if PY_VERSION_HEX < 0x030E0000
        if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
        #else
        if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
        #endif
        {
          Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
        }
        #else
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
        #endif
      }
    }
    #endif
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab;
    double const c_constants[] = {0.0};
    for (int i = 0; i < 1; i++) {
      numbertab[i] = PyFloat_FromDouble(c_constants[i]);
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  {
    PyObject **numbertab = __pyx_mstate->__pyx_number_tab + 1;
    int8_t const cint_constants_1[] = {0,1,39,64};
    int16_t const cint_constants_2[] = {2000,8192,10000};
    int32_t const cint_constants_4[] = {1000000L,93828620L,172291013L};
    for (int i = 0; i < 10; i++) {
      numbertab[i] = PyLong_FromLong((i < 4 ? cint_constants_1[i - 0] : (i < 7 ? cint_constants_2[i - 4] : cint_constants_4[i - 7])));
      if (unlikely(!numbertab[i])) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #if CYTHON_IMMORTAL_CONSTANTS
  {
    PyObject **table = __pyx_mstate->__pyx_number_tab;
    for (Py_ssize_t i=0; i<11; ++i) {
      #if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
      #if PY_VERSION_HEX < 0x030E0000
      if (_Py_IsOwnedByCurrentThread(table[i]) && Py_REFCNT(table[i]) == 1)
      #else
      if (PyUnstable_Object_IsUniquelyReferenced(table[i]))
      #endif
      {
        Py_SET_REFCNT(table[i], _Py_IMMORTAL_REFCNT_LOCAL);
      }
      #else
      Py_SET_REFCNT(table[i], _Py_IMMORTAL_INITIAL_REFCNT);
      #endif
    }
  }
  #endif
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_codeobjects ### */
typedef struct {
    unsigned int argcount : 3;
    unsigned int num_posonly_args : 1;
    unsigned int num_kwonly_args : 1;
    unsigned int nlocals : 4;
    unsigned int flags : 10;
    unsigned int first_line : 11;
} __Pyx_PyCode_New_function_description;
/* NewCodeObj.proto */
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
);


static int __Pyx_CreateCodeObjects(__pyx_mstatetype *__pyx_mstate) {
  PyObject* tuple_dedup_map = PyDict_New();
  if (unlikely(!tuple_dedup_map)) return -1;
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 1, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 32};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_conninfo, __pyx_mstate->__pyx_n_u_timeout, __pyx_mstate->__pyx_n_u_conn, __pyx_mstate->__pyx_n_u_pgconn_ptr, __pyx_mstate->__pyx_n_u_conn_status, __pyx_mstate->__pyx_n_u_poll_status, __pyx_mstate->__pyx_n_u_wait, __pyx_mstate->__pyx_n_u_ready, __pyx_mstate->__pyx_n_u_deadline, __pyx_mstate->__pyx_n_u_encoding};
    __pyx_mstate_global->__pyx_codeobj_tab[0] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_connect, __pyx_mstate->__pyx_kp_b_iso88591_hi_7q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[0])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 1, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 89};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cancel_conn, __pyx_mstate->__pyx_n_u_timeout, __pyx_mstate->__pyx_n_u_pgcancelconn_ptr, __pyx_mstate->__pyx_n_u_status, __pyx_mstate->__pyx_n_u_deadline};
    __pyx_mstate_global->__pyx_codeobj_tab[1] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_cancel, __pyx_mstate->__pyx_kp_b_iso88591_94DA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[1])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 116};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pgconn, __pyx_mstate->__pyx_n_u_rv};
    __pyx_mstate_global->__pyx_codeobj_tab[2] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_execute, __pyx_mstate->__pyx_kp_b_iso88591__12, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[2])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 132};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pgconn, __pyx_mstate->__pyx_n_u_pgconn_ptr, __pyx_mstate->__pyx_n_u_ready, __pyx_mstate->__pyx_n_u_cires};
    __pyx_mstate_global->__pyx_codeobj_tab[3] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_send, __pyx_mstate->__pyx_kp_b_iso88591_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[3])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {0, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 189};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_res};
    __pyx_mstate_global->__pyx_codeobj_tab[4] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_kp_b_iso88591__13, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[4])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 7, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 166};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pgconn, __pyx_mstate->__pyx_n_u_results, __pyx_mstate->__pyx_n_u_status, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_pgres, __pyx_mstate->__pyx_n_u_genexpr, __pyx_mstate->__pyx_n_u_genexpr};
    __pyx_mstate_global->__pyx_codeobj_tab[5] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_fetch_many, __pyx_mstate->__pyx_kp_b_iso88591_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[5])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 6, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 218};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pgconn, __pyx_mstate->__pyx_n_u_pgconn_ptr, __pyx_mstate->__pyx_n_u_cires, __pyx_mstate->__pyx_n_u_ibres, __pyx_mstate->__pyx_n_u_pgres, __pyx_mstate->__pyx_n_u_ready};
    __pyx_mstate_global->__pyx_codeobj_tab[6] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_fetch, __pyx_mstate->__pyx_kp_b_iso88591_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[6])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 12, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS|CO_GENERATOR), 265};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pgconn, __pyx_mstate->__pyx_n_u_commands, __pyx_mstate->__pyx_n_u_pgconn_ptr, __pyx_mstate->__pyx_n_u_cires, __pyx_mstate->__pyx_n_u_status, __pyx_mstate->__pyx_n_u_cready, __pyx_mstate->__pyx_n_u_pgres, __pyx_mstate->__pyx_n_u_res, __pyx_mstate->__pyx_n_u_results, __pyx_mstate->__pyx_n_u_r, __pyx_mstate->__pyx_n_u_ready, __pyx_mstate->__pyx_n_u_ibres};
    __pyx_mstate_global->__pyx_codeobj_tab[7] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_generators_py, __pyx_mstate->__pyx_n_u_pipeline_communicate, __pyx_mstate->__pyx_kp_b_iso88591__14, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[7])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1116};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_s, __pyx_mstate->__pyx_n_u_ds};
    __pyx_mstate_global->__pyx_codeobj_tab[8] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_is_overflow, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_1_1A_4r_AQ_3aq_b_Rq_3aq_b_b, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[8])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 57};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_rv, __pyx_mstate->__pyx_n_u_length};
    __pyx_mstate_global->__pyx_codeobj_tab[9] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_adapt_pyx, __pyx_mstate->__pyx_n_u_dump, __pyx_mstate->__pyx_kp_b_iso88591_1_q_A_V1E_Q_4q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[9])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 64};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_ptr, __pyx_mstate->__pyx_n_u_ptr_out, __pyx_mstate->__pyx_n_u_length, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_esc, __pyx_mstate->__pyx_n_u_rv, __pyx_mstate->__pyx_n_u_out};
    __pyx_mstate_global->__pyx_codeobj_tab[10] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_adapt_pyx, __pyx_mstate->__pyx_n_u_quote, __pyx_mstate->__pyx_kp_b_iso88591_A_E_4y_q_4q_3oQa_4q_ha_c_q_5_aq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[10])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 120};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[11] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_adapt_pyx, __pyx_mstate->__pyx_n_u_get_key, __pyx_mstate->__pyx_kp_b_iso88591_A_t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[11])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 123};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[12] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_adapt_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_A_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[12])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[13] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[13])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[14] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[14])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 157};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_data, __pyx_mstate->__pyx_n_u_ptr, __pyx_mstate->__pyx_n_u_length};
    __pyx_mstate_global->__pyx_codeobj_tab[15] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_adapt_pyx, __pyx_mstate->__pyx_n_u_load, __pyx_mstate->__pyx_kp_b_iso88591_1_6_q_t6_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[15])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[16] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[16])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[17] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[17])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[18] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[18])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[19] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[19])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 95};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_row, __pyx_mstate->__pyx_n_u_tx, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_size, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[20] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_copy_pyx, __pyx_mstate->__pyx_n_u_format_row_binary, __pyx_mstate->__pyx_kp_b_iso88591_a_q_5_A_5_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[20])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 5, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 210};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_row, __pyx_mstate->__pyx_n_u_tx, __pyx_mstate->__pyx_n_u_out, __pyx_mstate->__pyx_n_u_size, __pyx_mstate->__pyx_n_u_e};
    __pyx_mstate_global->__pyx_codeobj_tab[21] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_copy_pyx, __pyx_mstate->__pyx_n_u_format_row_text, __pyx_mstate->__pyx_kp_b_iso88591_nA_q_d_5_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[21])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 12, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 237};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_data, __pyx_mstate->__pyx_n_u_tx, __pyx_mstate->__pyx_n_u_ptr, __pyx_mstate->__pyx_n_u_bufsize, __pyx_mstate->__pyx_n_u_bufend, __pyx_mstate->__pyx_n_u_benfields, __pyx_mstate->__pyx_n_u_nfields, __pyx_mstate->__pyx_n_u_row, __pyx_mstate->__pyx_n_u_col, __pyx_mstate->__pyx_n_u_belength, __pyx_mstate->__pyx_n_u_length, __pyx_mstate->__pyx_n_u_field};
    __pyx_mstate_global->__pyx_codeobj_tab[22] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_copy_pyx, __pyx_mstate->__pyx_n_u_parse_row_binary, __pyx_mstate->__pyx_kp_b_iso88591_q_avYauAQ_Rq_1KuG1_XQa_7_Jaq_uA, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[22])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 13, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 272};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_data, __pyx_mstate->__pyx_n_u_tx, __pyx_mstate->__pyx_n_u_fstart, __pyx_mstate->__pyx_n_u_size, __pyx_mstate->__pyx_n_u_nfields, __pyx_mstate->__pyx_n_u_row, __pyx_mstate->__pyx_n_u_fend, __pyx_mstate->__pyx_n_u_rowend, __pyx_mstate->__pyx_n_u_src, __pyx_mstate->__pyx_n_u_tgt, __pyx_mstate->__pyx_n_u_col, __pyx_mstate->__pyx_n_u_num_bs, __pyx_mstate->__pyx_n_u_field};
    __pyx_mstate_global->__pyx_codeobj_tab[23] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_copy_pyx, __pyx_mstate->__pyx_n_u_parse_row_text, __pyx_mstate->__pyx_kp_b_iso88591_Q_avYaxq_r_Jaq_uAQ_q_d_3c_t4q_3, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[23])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_2, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[24] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_4_a_G1F_a_vWE_Q_q_t9G5_4z_SPT, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[24])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[25] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[25])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_state, __pyx_mstate->__pyx_n_u_dict_2, __pyx_mstate->__pyx_n_u_use_setstate};
    __pyx_mstate_global->__pyx_codeobj_tab[26] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_T_4_it6_Q_G1F_a_vWE_Q_q_t9G5_4z, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[26])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 16};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[27] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[27])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 112};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_cls, __pyx_mstate->__pyx_n_u_context};
    __pyx_mstate_global->__pyx_codeobj_tab[28] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_from_context, __pyx_mstate->__pyx_kp_b_iso88591_A_q_2, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[28])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 131};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_result, __pyx_mstate->__pyx_n_u_set_loaders, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[29] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_set_pgresult, __pyx_mstate->__pyx_kp_b_iso88591_A_M_7_Q_D_A_q_A_4z_Zq_Zq_4q_4t1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[29])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 8, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 172};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_types, __pyx_mstate->__pyx_n_u_format, __pyx_mstate->__pyx_n_u_ntypes, __pyx_mstate->__pyx_n_u_dumpers, __pyx_mstate->__pyx_n_u_i_2, __pyx_mstate->__pyx_n_u_oid, __pyx_mstate->__pyx_n_u_dumper_ptr};
    __pyx_mstate_global->__pyx_codeobj_tab[30] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_set_dumper_types, __pyx_mstate->__pyx_kp_b_iso88591_AQ_AQ_E_aq_q_q_E_Q_Qha_1IS_A_IU, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[30])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 189};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_types, __pyx_mstate->__pyx_n_u_format, __pyx_mstate->__pyx_n_u_types_fast, __pyx_mstate->__pyx_n_u_ntypes, __pyx_mstate->__pyx_n_u_loaders, __pyx_mstate->__pyx_n_u_oid, __pyx_mstate->__pyx_n_u_row_loader, __pyx_mstate->__pyx_n_u_i_2};
    __pyx_mstate_global->__pyx_codeobj_tab[31] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_set_loader_types, __pyx_mstate->__pyx_kp_b_iso88591_9_Jaq_E_aq_q_1E_Q_Qha_1IS_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[31])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 205};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj};
    __pyx_mstate_global->__pyx_codeobj_tab[32] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_as_literal, __pyx_mstate->__pyx_kp_b_iso88591_A_D_q_K_7_k_A_k_A_V6_fA_4t4wj_Ct, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[32])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 246};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format, __pyx_mstate->__pyx_n_u_row_dumper};
    __pyx_mstate_global->__pyx_codeobj_tab[33] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_get_dumper, __pyx_mstate->__pyx_kp_b_iso88591_D_q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[33])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 355};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_params, __pyx_mstate->__pyx_n_u_formats};
    __pyx_mstate_global->__pyx_codeobj_tab[34] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_dump_sequence, __pyx_mstate->__pyx_kp_b_iso88591_A_A_O1_Q_1_1_a_1_U_1_0_a_6_L_iwa, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[34])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {4, 0, 0, 15, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 431};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_row0, __pyx_mstate->__pyx_n_u_row1, __pyx_mstate->__pyx_n_u_make_row, __pyx_mstate->__pyx_n_u_res, __pyx_mstate->__pyx_n_u_ires, __pyx_mstate->__pyx_n_u_row, __pyx_mstate->__pyx_n_u_col, __pyx_mstate->__pyx_n_u_attval, __pyx_mstate->__pyx_n_u_record, __pyx_mstate->__pyx_n_u_records, __pyx_mstate->__pyx_n_u_loader, __pyx_mstate->__pyx_n_u_row_loaders, __pyx_mstate->__pyx_n_u_pyval, __pyx_mstate->__pyx_n_u_b};
    __pyx_mstate_global->__pyx_codeobj_tab[35] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_load_rows, __pyx_mstate->__pyx_kp_b_iso88591_4_Q_1_5_XT_4r_HD_6at1_4z_31_j_b, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[35])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 12, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 487};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_row, __pyx_mstate->__pyx_n_u_make_row, __pyx_mstate->__pyx_n_u_res, __pyx_mstate->__pyx_n_u_ires, __pyx_mstate->__pyx_n_u_loader, __pyx_mstate->__pyx_n_u_col, __pyx_mstate->__pyx_n_u_attval, __pyx_mstate->__pyx_n_u_record, __pyx_mstate->__pyx_n_u_row_loaders, __pyx_mstate->__pyx_n_u_pyval, __pyx_mstate->__pyx_n_u_b};
    __pyx_mstate_global->__pyx_codeobj_tab[36] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_load_row, __pyx_mstate->__pyx_kp_b_iso88591_4A_4_Q_1_4r_F_a_5Qd_4z_31_AT_d, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[36])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 533};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_record};
    __pyx_mstate_global->__pyx_codeobj_tab[37] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_load_sequence, __pyx_mstate->__pyx_kp_b_iso88591_Q_81_1_k_d_1_A_1_1Cq_A_G5_1M_uC, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[37])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 567};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_oid, __pyx_mstate->__pyx_n_u_format, __pyx_mstate->__pyx_n_u_row_loader};
    __pyx_mstate_global->__pyx_codeobj_tab[38] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_transform_pyx, __pyx_mstate->__pyx_n_u_get_loader, __pyx_mstate->__pyx_kp_b_iso88591_m_D_a_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[38])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[39] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[39])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[40] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[40])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 10, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 201};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_gen, __pyx_mstate->__pyx_n_u_fileno, __pyx_mstate->__pyx_n_u_interval, __pyx_mstate->__pyx_n_u_cinterval, __pyx_mstate->__pyx_n_u_wait, __pyx_mstate->__pyx_n_u_ready, __pyx_mstate->__pyx_n_u_pyready, __pyx_mstate->__pyx_n_u_send, __pyx_mstate->__pyx_n_u_ex, __pyx_mstate->__pyx_n_u_rv};
    __pyx_mstate_global->__pyx_codeobj_tab[41] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c__psycopg_waiting_pyx, __pyx_mstate->__pyx_n_u_wait_c, __pyx_mstate->__pyx_kp_b_iso88591_y_1_j_uAQ_z_1_A_3a_t1A_Kq_a_vS, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[41])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[42] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[42])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[43] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[43])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[44] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[44])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[45] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[45])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[46] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[46])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[47] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[47])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[48] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[48])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[49] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[49])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 106};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[50] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_get_key, __pyx_mstate->__pyx_kp_b_iso88591_A_4s_4q_D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[50])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 114};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[51] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_Q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[51])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[52] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[52])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[53] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[53])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[54] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[54])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[55] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[55])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 147};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[56] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_A_4s_1_q_A, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[56])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[57] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[57])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[58] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[58])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[59] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[59])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[60] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[60])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 181};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[61] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_A_4s_1_Qd, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[61])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[62] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[62])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[63] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[63])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[64] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[64])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[65] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[65])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 214};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[66] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_get_key, __pyx_mstate->__pyx_kp_b_iso88591_A_3a_4q_D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[66])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 222};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[67] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_Q_a, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[67])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[68] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[68])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[69] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[69])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[70] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[70])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[71] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[71])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 249};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[72] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_A_3a_1_Qd, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[72])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[73] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[73])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[74] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[74])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[75] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[75])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[76] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[76])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 280};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[77] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_datetime_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_A_3a_1_1D, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[77])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[78] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[78])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[79] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[79])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[80] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[80])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[81] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[81])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[82] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[82])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[83] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[83])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[84] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[84])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[85] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[85])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[86] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[86])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[87] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[87])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[88] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[88])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[89] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[89])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[90] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[90])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[91] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[91])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[92] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[92])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[93] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[93])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[94] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[94])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[95] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[95])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[96] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[96])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[97] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[97])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[98] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[98])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[99] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[99])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[100] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[100])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[101] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[101])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[102] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[102])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[103] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[103])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[104] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[104])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[105] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[105])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[106] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[106])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[107] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[107])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[108] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[108])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[109] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[109])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[110] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[110])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[111] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[111])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 64};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_length, __pyx_mstate->__pyx_n_u_rv};
    __pyx_mstate_global->__pyx_codeobj_tab[112] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_numeric_pyx, __pyx_mstate->__pyx_n_u_quote, __pyx_mstate->__pyx_kp_b_iso88591_A_4q_4s_T_q_T_at1_auA_Rr_V1E_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[112])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[113] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[113])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[114] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[114])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[115] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[115])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[116] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[116])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[117] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[117])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[118] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[118])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[119] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[119])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[120] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[120])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[121] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[121])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[122] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[122])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[123] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[123])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[124] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[124])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[125] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[125])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[126] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[126])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[127] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[127])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[128] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[128])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[129] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[129])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[130] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[130])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[131] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[131])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[132] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[132])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 196};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[133] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_numeric_pyx, __pyx_mstate->__pyx_n_u_get_key, __pyx_mstate->__pyx_kp_b_iso88591_A_5_1_1_S_q_z_G1_q_q_z_G1_q_q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[133])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 220};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_format};
    __pyx_mstate_global->__pyx_codeobj_tab[134] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_numeric_pyx, __pyx_mstate->__pyx_n_u_upgrade, __pyx_mstate->__pyx_kp_b_iso88591_A_5_1_4_1A_S_q_z_G1_t_t_z_G1_t_t, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[134])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[135] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[135])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[136] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[136])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[137] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[137])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[138] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[138])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[139] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[139])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[140] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[140])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[141] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[141])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[142] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[142])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[143] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[143])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[144] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[144])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[145] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[145])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[146] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[146])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[147] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[147])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[148] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[148])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 329};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_ptr};
    __pyx_mstate_global->__pyx_codeobj_tab[149] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_numeric_pyx, __pyx_mstate->__pyx_n_u_quote, __pyx_mstate->__pyx_kp_b_iso88591_A_Qd_q_1_A_4s_81_y_Cwe2Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[149])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[150] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[150])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[151] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[151])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[152] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[152])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[153] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[153])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[154] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[154])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[155] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[155])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[156] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[156])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[157] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[157])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[158] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[158])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[159] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[159])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[160] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[160])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[161] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[161])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[162] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[162])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[163] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[163])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[164] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[164])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[165] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[165])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 439};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_value, __pyx_mstate->__pyx_n_u_ptr};
    __pyx_mstate_global->__pyx_codeobj_tab[166] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_numeric_pyx, __pyx_mstate->__pyx_n_u_quote, __pyx_mstate->__pyx_kp_b_iso88591_A_Qd_q_1_a_4s_81_y_Cwe2Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[166])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[167] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[167])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[168] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[168])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[169] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[169])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[170] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[170])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[171] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[171])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[172] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[172])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[173] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[173])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[174] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[174])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[175] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[175])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[176] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[176])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[177] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[177])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[178] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[178])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[179] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[179])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[180] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[180])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 3, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 31};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_obj};
    __pyx_mstate_global->__pyx_codeobj_tab[181] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_bool_pyx, __pyx_mstate->__pyx_n_u_quote, __pyx_mstate->__pyx_kp_b_iso88591_4s_1_A_1_iq, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[181])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[182] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[182])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[183] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[183])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[184] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[184])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[185] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[185])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[186] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[186])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[187] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[187])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[188] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[188])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[189] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[189])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[190] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[190])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[191] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[191])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[192] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[192])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[193] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[193])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[194] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[194])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[195] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[195])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[196] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[196])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[197] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[197])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[198] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[198])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[199] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[199])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[200] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[200])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[201] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[201])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[202] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[202])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[203] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[203])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[204] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[204])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[205] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[205])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[206] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[206])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[207] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[207])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[208] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[208])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[209] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[209])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[210] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[210])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[211] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[211])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[212] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[212])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[213] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[213])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[214] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[214])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[215] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[215])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[216] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[216])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[217] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[217])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[218] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[218])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[219] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[219])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[220] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[220])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[221] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[221])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[222] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[222])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[223] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[223])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[224] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[224])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[225] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[225])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[226] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[226])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[227] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[227])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[228] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[228])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[229] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[229])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[230] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[230])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[231] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[231])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 9, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 217};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_obj, __pyx_mstate->__pyx_n_u_ptr, __pyx_mstate->__pyx_n_u_length, __pyx_mstate->__pyx_n_u_scs, __pyx_mstate->__pyx_n_u_escaped, __pyx_mstate->__pyx_n_u_rv, __pyx_mstate->__pyx_n_u_ptr_out, __pyx_mstate->__pyx_n_u_esc};
    __pyx_mstate_global->__pyx_codeobj_tab[232] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_psycopg_c_types_string_pyx, __pyx_mstate->__pyx_n_u_quote, __pyx_mstate->__pyx_kp_b_iso88591_A_e1A_9AU_1_4q_4y_q_t4q_Q_a_4t3, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[232])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[233] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[233])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[234] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[234])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[235] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[235])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[236] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[236])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[237] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[237])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[238] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[238])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[239] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[239])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[240] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[240])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[241] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[241])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[242] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[242])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[243] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[243])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[244] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[244])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {1, 0, 0, 1, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 1};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self};
    __pyx_mstate_global->__pyx_codeobj_tab[245] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_reduce_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[245])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {2, 0, 0, 2, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 3};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_self, __pyx_mstate->__pyx_n_u_pyx_state};
    __pyx_mstate_global->__pyx_codeobj_tab[246] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_setstate_cython, __pyx_mstate->__pyx_kp_b_iso88591_Q, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[246])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[247] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_RowLoader, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_9HAQ_7_1L_a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[247])) goto bad;
  }
  {
    const __Pyx_PyCode_New_function_description descr = {3, 0, 0, 4, (unsigned int)(CO_OPTIMIZED|CO_NEWLOCALS), 4};
    PyObject* const varnames[] = {__pyx_mstate->__pyx_n_u_pyx_type, __pyx_mstate->__pyx_n_u_pyx_checksum, __pyx_mstate->__pyx_n_u_pyx_state, __pyx_mstate->__pyx_n_u_pyx_result};
    __pyx_mstate_global->__pyx_codeobj_tab[248] = __Pyx_PyCode_New(descr, varnames, __pyx_mstate->__pyx_kp_u_tree_fragment, __pyx_mstate->__pyx_n_u_pyx_unpickle_RowDumper, __pyx_mstate->__pyx_kp_b_iso88591_q_0_kQR_9HAQ_7_1L_a_1, tuple_dedup_map); if (unlikely(!__pyx_mstate_global->__pyx_codeobj_tab[248])) goto bad;
  }
  Py_DECREF(tuple_dedup_map);
  return 0;
  bad:
  Py_DECREF(tuple_dedup_map);
  return -1;
}
/* #### Code section: init_globals ### */

static int __Pyx_InitGlobals(void) {
  /* PythonCompatibility.init */
  if (likely(__Pyx_init_co_variables() == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CommonTypesMetaclass.init */
  if (likely(__pyx_CommonTypesMetaclass_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* Generator.init */
  if (likely(__pyx_Generator_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CachedMethodType.init */
  #if CYTHON_COMPILING_IN_LIMITED_API
  {
      PyObject *typesModule=NULL;
      typesModule = PyImport_ImportModule("types");
      if (typesModule) {
          __pyx_mstate_global->__Pyx_CachedMethodType = PyObject_GetAttrString(typesModule, "MethodType");
          Py_DECREF(typesModule);
      }
  } // error handling follows
  #endif
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  /* CythonFunctionShared.init */
  if (likely(__pyx_CyFunction_init(__pyx_m) == 0)); else
  
  if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore (used by PyObjectGetAttrStrNoError) */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr (used by PyObjectGetAttrStrNoError) */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError (used by GetBuiltinName) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_mstate_global->__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
            "name '%U' is not defined", name);
    }
    return result;
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* TupleAndListFromArray (used by fastcall) */
#if !CYTHON_COMPILING_IN_CPYTHON && CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    Py_ssize_t i;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    for (i = 0; i < n; i++) {
        if (unlikely(__Pyx_PyTuple_SET_ITEM(res, i, src[i]) < (0))) {
            Py_DECREF(res);
            return NULL;
        }
        Py_INCREF(src[i]);
    }
    return res;
}
#elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_tuple);
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals (used by UnicodeEquals) */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL ||\
        !(CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS)
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals (used by fastcall) */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length, length2;
        int kind;
        void *data1, *data2;
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        #endif
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length < 0)) return -1;
        #endif
        length2 = __Pyx_PyUnicode_GET_LENGTH(s2);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(length2 < 0)) return -1;
        #endif
        if (length != length2) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    return (equals == Py_EQ);
return_ne:
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = __Pyx_PyTuple_GET_SIZE(kwnames);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(n == -1)) return NULL;
    #endif
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        if (s == namei) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        PyObject *namei = __Pyx_PyTuple_GET_ITEM(kwnames, i);
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!namei)) return NULL;
        #endif
        int eq = __Pyx_PyUnicode_Equals(s, namei, Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000 || CYTHON_COMPILING_IN_LIMITED_API
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs;
    PyObject *dict;
#if !CYTHON_ASSUME_SAFE_SIZE
    nkwargs = PyTuple_Size(kwnames);
    if (unlikely(nkwargs < 0)) return NULL;
#else
    nkwargs = PyTuple_GET_SIZE(kwnames);
#endif
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
#if !CYTHON_ASSUME_SAFE_MACROS
        PyObject *key = PyTuple_GetItem(kwnames, i);
        if (!key) goto bad;
#else
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
#endif
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* PyObjectCall (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO (used by PyObjectFastCall) */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall (used by PyObjectCallOneArg) */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject * const*args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) != (0)) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
#if CYTHON_VECTORCALL && !CYTHON_COMPILING_IN_LIMITED_API
  #if PY_VERSION_HEX < 0x03090000
    #define __Pyx_PyVectorcall_Function(callable) _PyVectorcall_Function(callable)
  #elif CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE vectorcallfunc __Pyx_PyVectorcall_Function(PyObject *callable) {
    PyTypeObject *tp = Py_TYPE(callable);
    #if defined(__Pyx_CyFunction_USED)
    if (__Pyx_CyFunction_CheckExact(callable)) {
        return __Pyx_CyFunction_func_vectorcall(callable);
    }
    #endif
    if (!PyType_HasFeature(tp, Py_TPFLAGS_HAVE_VECTORCALL)) {
        return NULL;
    }
    assert(PyCallable_Check(callable));
    Py_ssize_t offset = tp->tp_vectorcall_offset;
    assert(offset > 0);
    vectorcallfunc ptr;
    memcpy(&ptr, (char *) callable + offset, sizeof(ptr));
    return ptr;
}
  #else
    #define __Pyx_PyVectorcall_Function(callable) PyVectorcall_Function(callable)
  #endif
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject *const *args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
          #if CYTHON_COMPILING_IN_LIMITED_API
            return PyObject_Vectorcall(func, args, _nargs, NULL);
          #else
            vectorcallfunc f = __Pyx_PyVectorcall_Function(func);
            if (f) {
                return f(func, args, _nargs, NULL);
            }
          #endif
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_mstate_global->__pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* PyObjectCallOneArg (used by CallUnboundCMethod0) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* UnpackUnboundCMethod (used by CallUnboundCMethod0) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
#elif CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject **args, Py_ssize_t nargs, PyObject *kwnames) {
        return _PyObject_Vectorcall
            (method, args ? args+1 : NULL, nargs ? nargs-1 : 0, kwnames);
}
#else
static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *const *args, Py_ssize_t nargs, PyObject *kwnames) {
    return
#if PY_VERSION_HEX < 0x03090000
    _PyObject_Vectorcall
#else
    PyObject_Vectorcall
#endif
        (method, args ? args+1 : NULL, nargs ? (size_t) nargs-1 : 0, kwnames);
}
#endif
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030C0000
     METH_VARARGS | METH_KEYWORDS,
#else
     METH_FASTCALL | METH_KEYWORDS,
#endif
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method, *result=NULL;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    result = method;
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            result = unbound_method;
        }
    }
#if !CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    if (unlikely(target->method)) {
        Py_DECREF(result);
    } else
#endif
    target->method = result;
    return 0;
}

/* CallUnboundCMethod0 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        if (likely(cfunc->flag == METH_NOARGS))
            return __Pyx_CallCFunction(cfunc, self, NULL);
        if (likely(cfunc->flag == METH_FASTCALL))
            return __Pyx_CallCFunctionFast(cfunc, self, NULL, 0);
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, NULL, 0, NULL);
        if (likely(cfunc->flag == (METH_VARARGS | METH_KEYWORDS)))
            return __Pyx_CallCFunctionWithKeywords(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple, NULL);
        if (cfunc->flag == METH_VARARGS)
            return __Pyx_CallCFunction(cfunc, self, __pyx_mstate_global->__pyx_empty_tuple);
        return __Pyx__CallUnboundCMethod0(cfunc, self);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod0(&tmp_cfunc, self);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod0(cfunc, self);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *result;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
    result = __Pyx_PyObject_CallOneArg(cfunc->method, self);
    return result;
}

/* py_dict_items (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Items(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_items, d);
}

/* py_dict_values (used by OwnedDictNext) */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_values, d);
}

/* OwnedDictNext (used by ParseKeywordsImpl) */
#if CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, PyObject **ppos, PyObject **pkey, PyObject **pvalue) {
    PyObject *next = NULL;
    if (!*ppos) {
        if (pvalue) {
            PyObject *dictview = pkey ? __Pyx_PyDict_Items(p) : __Pyx_PyDict_Values(p);
            if (unlikely(!dictview)) goto bad;
            *ppos = PyObject_GetIter(dictview);
            Py_DECREF(dictview);
        } else {
            *ppos = PyObject_GetIter(p);
        }
        if (unlikely(!*ppos)) goto bad;
    }
    next = PyIter_Next(*ppos);
    if (!next) {
        if (PyErr_Occurred()) goto bad;
        return 0;
    }
    if (pkey && pvalue) {
        *pkey = __Pyx_PySequence_ITEM(next, 0);
        if (unlikely(*pkey)) goto bad;
        *pvalue = __Pyx_PySequence_ITEM(next, 1);
        if (unlikely(*pvalue)) goto bad;
        Py_DECREF(next);
    } else if (pkey) {
        *pkey = next;
    } else {
        assert(pvalue);
        *pvalue = next;
    }
    return 1;
  bad:
    Py_XDECREF(next);
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
    PyErr_FormatUnraisable("Exception ignored in __Pyx_PyDict_NextRef");
#else
    PyErr_WriteUnraisable(__pyx_mstate_global->__pyx_n_u_Pyx_PyDict_NextRef);
#endif
    if (pkey) *pkey = NULL;
    if (pvalue) *pvalue = NULL;
    return 0;
}
#else // !CYTHON_AVOID_BORROWED_REFS
static int __Pyx_PyDict_NextRef(PyObject *p, Py_ssize_t *ppos, PyObject **pkey, PyObject **pvalue) {
    int result = PyDict_Next(p, ppos, pkey, pvalue);
    if (likely(result == 1)) {
        if (pkey) Py_INCREF(*pkey);
        if (pvalue) Py_INCREF(*pvalue);
    }
    return result;
}
#endif

/* RaiseDoubleKeywords (used by ParseKeywordsImpl) */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
}

/* CallUnboundCMethod2 */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    int was_initialized = __Pyx_CachedCFunction_GetAndSetInitializing(cfunc);
    if (likely(was_initialized == 2 && cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            return __Pyx_CallCFunctionFast(cfunc, self, args, 2);
        }
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return __Pyx_CallCFunctionFastWithKeywords(cfunc, self, args, 2, NULL);
    }
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    else if (unlikely(was_initialized == 1)) {
        __Pyx_CachedCFunction tmp_cfunc = {
#ifndef __cplusplus
            0
#endif
        };
        tmp_cfunc.type = cfunc->type;
        tmp_cfunc.method_name = cfunc->method_name;
        return __Pyx__CallUnboundCMethod2(&tmp_cfunc, self, arg1, arg2);
    }
#endif
    PyObject *result = __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
    __Pyx_CachedCFunction_SetFinishedInitializing(cfunc);
    return result;
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        PyObject *result = NULL;
        PyObject *args = PyTuple_New(2);
        if (unlikely(!args)) return NULL;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = __Pyx_CallCFunctionWithKeywords(cfunc, self, args, NULL);
        else
            result = __Pyx_CallCFunction(cfunc, self, args);
        Py_DECREF(args);
        return result;
    }
#endif
    {
        PyObject *args[4] = {NULL, self, arg1, arg2};
        return __Pyx_PyObject_FastCall(cfunc->method, args+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
    }
}

/* ParseKeywordsImpl (used by ParseKeywords) */
static int __Pyx_ValidateDuplicatePosArgs(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char* function_name)
{
    PyObject ** const *name = argnames;
    while (name != first_kw_arg) {
        PyObject *key = **name;
        int found = PyDict_Contains(kwds, key);
        if (unlikely(found)) {
            if (found == 1) __Pyx_RaiseDoubleKeywordsError(function_name, key);
            goto bad;
        }
        name++;
    }
    return 0;
bad:
    return -1;
}
#if CYTHON_USE_UNICODE_INTERNALS
static CYTHON_INLINE int __Pyx_UnicodeKeywordsEqual(PyObject *s1, PyObject *s2) {
    int kind;
    Py_ssize_t len = PyUnicode_GET_LENGTH(s1);
    if (len != PyUnicode_GET_LENGTH(s2)) return 0;
    kind = PyUnicode_KIND(s1);
    if (kind != PyUnicode_KIND(s2)) return 0;
    const void *data1 = PyUnicode_DATA(s1);
    const void *data2 = PyUnicode_DATA(s2);
    return (memcmp(data1, data2, (size_t) len * (size_t) kind) == 0);
}
#endif
static int __Pyx_MatchKeywordArg_str(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    #if CYTHON_USE_UNICODE_INTERNALS
    Py_hash_t key_hash = ((PyASCIIObject*)key)->hash;
    if (unlikely(key_hash == -1)) {
        key_hash = PyObject_Hash(key);
        if (unlikely(key_hash == -1))
            goto bad;
    }
    #endif
    name = first_kw_arg;
    while (*name) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (key_hash == ((PyASCIIObject*)name_str)->hash && __Pyx_UnicodeKeywordsEqual(name_str, key)) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) {
                *index_found = (size_t) (name - argnames);
                return 1;
            }
        }
        #endif
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        PyObject *name_str = **name;
        #if CYTHON_USE_UNICODE_INTERNALS
        if (unlikely(key_hash == ((PyASCIIObject*)name_str)->hash)) {
            if (__Pyx_UnicodeKeywordsEqual(name_str, key))
                goto arg_passed_twice;
        }
        #else
        #if CYTHON_ASSUME_SAFE_SIZE
        if (PyUnicode_GET_LENGTH(name_str) == PyUnicode_GET_LENGTH(key))
        #endif
        {
            if (unlikely(name_str == key)) goto arg_passed_twice;
            int cmp = PyUnicode_Compare(name_str, key);
            if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
            if (cmp == 0) goto arg_passed_twice;
        }
        #endif
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
bad:
    return -1;
}
static int __Pyx_MatchKeywordArg_nostr(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    PyObject ** const *name;
    if (unlikely(!PyUnicode_Check(key))) goto invalid_keyword_type;
    name = first_kw_arg;
    while (*name) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (cmp == 1) {
            *index_found = (size_t) (name - argnames);
            return 1;
        }
        if (unlikely(cmp == -1)) goto bad;
        name++;
    }
    name = argnames;
    while (name != first_kw_arg) {
        int cmp = PyObject_RichCompareBool(**name, key, Py_EQ);
        if (unlikely(cmp != 0)) {
            if (cmp == 1) goto arg_passed_twice;
            else goto bad;
        }
        name++;
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
bad:
    return -1;
}
static CYTHON_INLINE int __Pyx_MatchKeywordArg(
    PyObject *key,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    size_t *index_found,
    const char *function_name)
{
    return likely(PyUnicode_CheckExact(key)) ?
        __Pyx_MatchKeywordArg_str(key, argnames, first_kw_arg, index_found, function_name) :
        __Pyx_MatchKeywordArg_nostr(key, argnames, first_kw_arg, index_found, function_name);
}
static void __Pyx_RejectUnknownKeyword(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject ** const *first_kw_arg,
    const char *function_name)
{
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos = NULL;
    #else
    Py_ssize_t pos = 0;
    #endif
    PyObject *key = NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(kwds);
    while (
        #if CYTHON_AVOID_BORROWED_REFS
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL)
        #else
        PyDict_Next(kwds, &pos, &key, NULL)
        #endif
    ) {
        PyObject** const *name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (!*name) {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp != 1) {
                if (cmp == 0) {
                    PyErr_Format(PyExc_TypeError,
                        "%s() got an unexpected keyword argument '%U'",
                        function_name, key);
                }
                #if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(key);
                #endif
                break;
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        #endif
    }
    __Pyx_END_CRITICAL_SECTION();
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(pos);
    #endif
    assert(PyErr_Occurred());
}
static int __Pyx_ParseKeywordDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t extracted = 0;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    name = first_kw_arg;
    while (*name && num_kwargs > extracted) {
        PyObject * key = **name;
        PyObject *value;
        int found = 0;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        found = PyDict_GetItemRef(kwds, key, &value);
        #else
        value = PyDict_GetItemWithError(kwds, key);
        if (value) {
            Py_INCREF(value);
            found = 1;
        } else {
            if (unlikely(PyErr_Occurred())) goto bad;
        }
        #endif
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            extracted++;
        }
        name++;
    }
    if (num_kwargs > extracted) {
        if (ignore_unknown_kwargs) {
            if (unlikely(__Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name) == -1))
                goto bad;
        } else {
            __Pyx_RejectUnknownKeyword(kwds, argnames, first_kw_arg, function_name);
            goto bad;
        }
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordDictToDict(
    PyObject *kwds,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject** const *name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    Py_ssize_t len;
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
    if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return -1;
#endif
    if (PyDict_Update(kwds2, kwds) < 0) goto bad;
    name = first_kw_arg;
    while (*name) {
        PyObject *key = **name;
        PyObject *value;
#if !CYTHON_COMPILING_IN_LIMITED_API && (PY_VERSION_HEX >= 0x030d00A2 || defined(PyDict_Pop))
        int found = PyDict_Pop(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
        }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
        int found = PyDict_GetItemRef(kwds2, key, &value);
        if (found) {
            if (unlikely(found < 0)) goto bad;
            values[name-argnames] = value;
            if (unlikely(PyDict_DelItem(kwds2, key) < 0)) goto bad;
        }
#else
    #if CYTHON_COMPILING_IN_CPYTHON
        value = _PyDict_Pop(kwds2, key, kwds2);
    #else
        value = __Pyx_CallUnboundCMethod2(&__pyx_mstate_global->__pyx_umethod_PyDict_Type_pop, kwds2, key, kwds2);
    #endif
        if (value == kwds2) {
            Py_DECREF(value);
        } else {
            if (unlikely(!value)) goto bad;
            values[name-argnames] = value;
        }
#endif
        name++;
    }
    len = PyDict_Size(kwds2);
    if (len > 0) {
        return __Pyx_ValidateDuplicatePosArgs(kwds, argnames, first_kw_arg, function_name);
    } else if (unlikely(len == -1)) {
        goto bad;
    }
    return 0;
bad:
    return -1;
}
static int __Pyx_ParseKeywordsTuple(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    PyObject *key = NULL;
    PyObject** const * name;
    PyObject** const *first_kw_arg = argnames + num_pos_args;
    for (Py_ssize_t pos = 0; pos < num_kwargs; pos++) {
#if CYTHON_AVOID_BORROWED_REFS
        key = __Pyx_PySequence_ITEM(kwds, pos);
#else
        key = __Pyx_PyTuple_GET_ITEM(kwds, pos);
#endif
#if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(!key)) goto bad;
#endif
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            PyObject *value = kwvalues[pos];
            values[name-argnames] = __Pyx_NewRef(value);
        } else {
            size_t index_found = 0;
            int cmp = __Pyx_MatchKeywordArg(key, argnames, first_kw_arg, &index_found, function_name);
            if (cmp == 1) {
                PyObject *value = kwvalues[pos];
                values[index_found] = __Pyx_NewRef(value);
            } else {
                if (unlikely(cmp == -1)) goto bad;
                if (kwds2) {
                    PyObject *value = kwvalues[pos];
                    if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
                } else if (!ignore_unknown_kwargs) {
                    goto invalid_keyword;
                }
            }
        }
        #if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(key);
        key = NULL;
        #endif
    }
    return 0;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    goto bad;
bad:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(key);
    #endif
    return -1;
}

/* ParseKeywords */
static int __Pyx_ParseKeywords(
    PyObject *kwds,
    PyObject * const *kwvalues,
    PyObject ** const argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    Py_ssize_t num_kwargs,
    const char* function_name,
    int ignore_unknown_kwargs)
{
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds)))
        return __Pyx_ParseKeywordsTuple(kwds, kwvalues, argnames, kwds2, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
    else if (kwds2)
        return __Pyx_ParseKeywordDictToDict(kwds, argnames, kwds2, values, num_pos_args, function_name);
    else
        return __Pyx_ParseKeywordDict(kwds, argnames, values, num_pos_args, num_kwargs, function_name, ignore_unknown_kwargs);
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseException */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
#elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* PyObjectFastCallMethod */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_PyObject_FastCallMethod(PyObject *name, PyObject *const *args, size_t nargsf) {
    PyObject *result;
    PyObject *attr = PyObject_GetAttr(args[0], name);
    if (unlikely(!attr))
        return NULL;
    result = __Pyx_PyObject_FastCall(attr, args+1, nargsf - 1);
    Py_DECREF(attr);
    return result;
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* pybuiltin_invalid (used by pyint_simplify) */
static void __Pyx_PyBuiltin_Invalid(PyObject *obj, const char *type_name, const char *argname) {
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    if (argname) {
        PyErr_Format(PyExc_TypeError,
            "Argument '%.200s' has incorrect type (expected %.200s, got " __Pyx_FMT_TYPENAME ")",
            argname, type_name, obj_type_name
        );
    } else {
        PyErr_Format(PyExc_TypeError,
            "Expected %.200s, got " __Pyx_FMT_TYPENAME,
            type_name, obj_type_name
        );
    }
    __Pyx_DECREF_TypeName(obj_type_name);
}

/* pyint_simplify */
static CYTHON_INLINE int __Pyx_PyInt_FromNumber(PyObject **number_var, const char *argname, int accept_none) {
    PyObject *number = *number_var;
    if (likely((accept_none && number == Py_None) || PyLong_CheckExact(number))) {
        return 0;
    }
    PyObject *int_object;
    if (likely(PyNumber_Check(number))) {
        int_object = PyNumber_Long(number);
        if (unlikely(!int_object)) goto bad;
    } else {
        __Pyx_PyBuiltin_Invalid(number, "int", argname);
        goto bad;
    }
    *number_var = int_object;
    Py_DECREF(number);
    return 0;
bad:
    *number_var = NULL;
    Py_DECREF(number);
    return -1;
}

/* ArgTypeTestFunc (used by ArgTypeTest) */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    PyObject *extra_info = __pyx_mstate_global->__pyx_empty_unicode;
    int from_annotation_subclass = 0;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (!exact) {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    } else if (exact == 2) {
        if (__Pyx_TypeCheck(obj, type)) {
            from_annotation_subclass = 1;
            extra_info = __pyx_mstate_global->__pyx_kp_u_Note_that_Cython_is_deliberately;
        }
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(type);
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")"
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        "%s%U"
#endif
        , name, type_name, obj_type_name
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
        , (from_annotation_subclass ? ". " : ""), extra_info
#endif
        );
#if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    if (exact == 2 && from_annotation_subclass) {
        PyObject *res;
        PyObject *vargs[2];
        vargs[0] = PyErr_GetRaisedException();
        vargs[1] = extra_info;
        res = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_kp_u_add_note, vargs, 2, NULL);
        Py_XDECREF(res);
        PyErr_SetRaisedException(vargs[0]);
    }
#endif
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        if (!PyErr_Occurred())
            PyErr_SetNone(PyExc_NameError);
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
    PyErr_Clear();
#elif CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS
    if (unlikely(__Pyx_PyDict_GetItemRef(__pyx_mstate_global->__pyx_d, name, &result) == -1)) PyErr_Clear();
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return result;
    }
#else
    result = _PyDict_GetItem_KnownHash(__pyx_mstate_global->__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_mstate_global->__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* CIntToDigits (used by CIntToPyUnicode) */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode (used by COrdinalToPyUnicode) */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, const char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp = PySequence_Repeat(padding, uoffset - prepend_sign);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyUnicode_Concat(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyUnicode_Concat(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* COrdinalToPyUnicode (used by CIntToPyUnicode) */
static CYTHON_INLINE int __Pyx_CheckUnicodeValue(int value) {
    return value <= 1114111;
}
static PyObject* __Pyx_PyUnicode_FromOrdinal_Padded(int value, Py_ssize_t ulength, char padding_char) {
    Py_ssize_t padding_length = ulength - 1;
    if (likely((padding_length <= 250) && (value < 0xD800 || value > 0xDFFF))) {
        char chars[256];
        if (value <= 255) {
            memset(chars, padding_char, (size_t) padding_length);
            chars[ulength-1] = (char) value;
            return PyUnicode_DecodeLatin1(chars, ulength, NULL);
        }
        char *cpos = chars + sizeof(chars);
        if (value < 0x800) {
            *--cpos = (char) (0x80 | (value & 0x3f));
            value >>= 6;
            *--cpos = (char) (0xc0 | (value & 0x1f));
        } else if (value < 0x10000) {
            *--cpos = (char) (0x80 | (value & 0x3f));
            value >>= 6;
            *--cpos = (char) (0x80 | (value & 0x3f));
            value >>= 6;
            *--cpos = (char) (0xe0 | (value & 0x0f));
        } else {
            *--cpos = (char) (0x80 | (value & 0x3f));
            value >>= 6;
            *--cpos = (char) (0x80 | (value & 0x3f));
            value >>= 6;
            *--cpos = (char) (0x80 | (value & 0x3f));
            value >>= 6;
            *--cpos = (char) (0xf0 | (value & 0x07));
        }
        cpos -= padding_length;
        memset(cpos, padding_char, (size_t) padding_length);
        return PyUnicode_DecodeUTF8(cpos, chars + sizeof(chars) - cpos, NULL);
    }
    if (value <= 127 && CYTHON_USE_UNICODE_INTERNALS) {
        const char chars[1] = {(char) value};
        return __Pyx_PyUnicode_BuildFromAscii(ulength, chars, 1, 0, padding_char);
    }
    {
        PyObject *uchar, *padding_uchar, *padding, *result;
        padding_uchar = PyUnicode_FromOrdinal(padding_char);
        if (unlikely(!padding_uchar)) return NULL;
        padding = PySequence_Repeat(padding_uchar, padding_length);
        Py_DECREF(padding_uchar);
        if (unlikely(!padding)) return NULL;
        uchar = PyUnicode_FromOrdinal(value);
        if (unlikely(!uchar)) {
            Py_DECREF(padding);
            return NULL;
        }
        result = PyUnicode_Concat(padding, uchar);
        Py_DECREF(padding);
        Py_DECREF(uchar);
        return result;
    }
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!(is_unsigned || value == 0 || value > 0) ||
                    !(sizeof(value) <= 2 || value & ~ (Py_ssize_t) 0x01fffff || __Pyx_CheckUnicodeValue((int) value)))) {
        PyErr_SetString(PyExc_OverflowError, "%c arg not in range(0x110000)");
        return NULL;
    }
    if (width <= 1) {
        return PyUnicode_FromOrdinal((int) value);
    }
    return __Pyx_PyUnicode_FromOrdinal_Padded((int) value, width, padding_char);
}
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(Py_ssize_t)*3+2];
    char *dpos, *end = digits + sizeof(Py_ssize_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    Py_ssize_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (Py_ssize_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (Py_ssize_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (Py_ssize_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject** values, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    if (max_char > 1114111) max_char = 1114111;
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - result_ulength < 0))
        goto overflow;
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = values[i];
        #if !CYTHON_COMPILING_IN_LIMITED_API
        if (__Pyx_PyUnicode_READY(uval) == (-1))
            goto bad;
        #endif
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(ulength < 0)) goto bad;
        #endif
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    Py_ssize_t i;
    PyObject *result = NULL;
    PyObject *value_tuple = PyTuple_New(value_count);
    if (unlikely(!value_tuple)) return NULL;
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    for (i=0; i<value_count; i++) {
        if (__Pyx_PyTuple_SET_ITEM(value_tuple, i, values[i]) != (0)) goto bad;
        Py_INCREF(values[i]);
    }
    result = PyUnicode_Join(__pyx_mstate_global->__pyx_empty_unicode, value_tuple);
bad:
    Py_DECREF(value_tuple);
    return result;
#endif
}

/* GetTopmostException (used by SaveResetException) */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C0000
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#elif __PYX_LIMITED_VERSION_HEX > 0x030C0000
    local_value = PyErr_GetRaisedException();
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
#if __PYX_LIMITED_VERSION_HEX > 0x030C0000
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
#else
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
#endif // __PYX_LIMITED_VERSION_HEX > 0x030C0000
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#elif __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    PyErr_SetHandledException(local_value);
    Py_XDECREF(local_value);
    Py_XDECREF(local_type);
    Py_XDECREF(local_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
#if __PYX_LIMITED_VERSION_HEX <= 0x030C0000
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
#endif
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* SetStringIndexingError (used by SetItemIntByteArray) */
static void __Pyx_SetStringIndexingError(const char* message, int has_gil) {
    if (!has_gil) {
        PyGILState_STATE gil_state = PyGILState_Ensure();
        PyErr_SetString(PyExc_IndexError, message);
        PyGILState_Release(gil_state);
    } else
        PyErr_SetString(PyExc_IndexError, message);
}

/* SetItemIntByteArray */
static CYTHON_INLINE int __Pyx_SetItemInt_ByteArray_Fast_Locked(PyObject* string, Py_ssize_t i, unsigned char v,
                                                                int wraparound, int boundscheck, int has_gil) {
    Py_ssize_t length = __Pyx_PyByteArray_GET_SIZE(string);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(length < 0)) return -1;
    #endif
    if (wraparound & unlikely(i < 0)) i += length;
    if ((!boundscheck) || likely(__Pyx_is_valid_index(i, length))) {
        #if !CYTHON_ASSUME_SAFE_MACROS
        char *asString = PyByteArray_AsString(string);
        if (unlikely(!asString)) return -1;
        asString[i] = (char)v;
        #else
        PyByteArray_AS_STRING(string)[i] = (char) v;
        #endif
        return 0;
    } else {
        __Pyx_SetStringIndexingError("bytearray index out of range", has_gil);
        return -1;
    }
}
static CYTHON_INLINE int __Pyx_SetItemInt_ByteArray_Fast(PyObject* string, Py_ssize_t i, unsigned char v,
                                                         int wraparound, int boundscheck, int has_gil, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    wraparound = wraparound && i<0;
#endif
    if (wraparound | boundscheck) {
        int result;
        __Pyx_PyCriticalSection cs;
        int lock = CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && has_gil && !__Pyx_IS_UNIQUELY_REFERENCED(string, unsafe_shared);
        if (lock) { __Pyx_PyCriticalSection_Begin(&cs, string); }
        result = __Pyx_SetItemInt_ByteArray_Fast_Locked(string, i, v, wraparound, boundscheck, has_gil);
        if (lock) { __Pyx_PyCriticalSection_End(&cs); }
        return result;
    } else {
        #if !CYTHON_ASSUME_SAFE_MACROS
        char *asString = PyByteArray_AsString(string);
        if (unlikely(!asString)) return -1;
        asString[i] = (char)v;
        #else
        PyByteArray_AS_STRING(string)[i] = (char) v;
        #endif
        return 0;
    }
}

/* PyObjectVectorCallKwBuilder */
#if CYTHON_VECTORCALL
static int __Pyx_VectorcallBuilder_AddArg(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_PyObject_FastCallDict;
    if (__Pyx_PyTuple_SET_ITEM(builder, n, key) != (0)) return -1;
    Py_INCREF(key);
    args[n] = value;
    return 0;
}
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    (void)__Pyx_VectorcallBuilder_AddArgStr;
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return __Pyx_VectorcallBuilder_AddArg(key, value, builder, args, n);
}
static int __Pyx_VectorcallBuilder_AddArgStr(const char *key, PyObject *value, PyObject *builder, PyObject **args, int n) {
    PyObject *pyKey = PyUnicode_FromString(key);
    if (!pyKey) return -1;
    return __Pyx_VectorcallBuilder_AddArg(pyKey, value, builder, args, n);
}
#else // CYTHON_VECTORCALL
CYTHON_UNUSED static int __Pyx_VectorcallBuilder_AddArg_Check(PyObject *key, PyObject *value, PyObject *builder, CYTHON_UNUSED PyObject **args, CYTHON_UNUSED int n) {
    if (unlikely(!PyUnicode_Check(key))) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        return -1;
    }
    return PyDict_SetItem(builder, key, value);
}
#endif

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!(is_unsigned || value == 0 || value > 0) ||
                    !(sizeof(value) <= 2 || value & ~ (int) 0x01fffff || __Pyx_CheckUnicodeValue((int) value)))) {
        PyErr_SetString(PyExc_OverflowError, "%c arg not in range(0x110000)");
        return NULL;
    }
    if (width <= 1) {
        return PyUnicode_FromOrdinal((int) value);
    }
    return __Pyx_PyUnicode_FromOrdinal_Padded((int) value, width, padding_char);
}
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* PyObjectSetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
    return PyObject_SetAttr(obj, attr_name, value);
}
#endif

/* pep479 */
static void __Pyx_Generator_Replace_StopIteration(int in_async_gen) {
    PyObject *exc, *val, *tb, *cur_exc, *new_exc;
    __Pyx_PyThreadState_declare
    int is_async_stopiteration = 0;
    CYTHON_MAYBE_UNUSED_VAR(in_async_gen);
    __Pyx_PyThreadState_assign
    cur_exc = __Pyx_PyErr_CurrentExceptionType();
    if (likely(!__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopIteration))) {
        if (in_async_gen && unlikely(__Pyx_PyErr_GivenExceptionMatches(cur_exc, PyExc_StopAsyncIteration))) {
            is_async_stopiteration = 1;
        } else {
            return;
        }
    }
    __Pyx_GetException(&exc, &val, &tb);
    Py_XDECREF(exc);
    Py_XDECREF(tb);
    new_exc = PyObject_CallFunction(PyExc_RuntimeError, "s",
        is_async_stopiteration ? "async generator raised StopAsyncIteration" :
        in_async_gen ? "async generator raised StopIteration" :
        "generator raised StopIteration");
    if (!new_exc) {
        Py_XDECREF(val);
        return;
    }
    PyException_SetCause(new_exc, val); // steals ref to val
    PyErr_SetObject(PyExc_RuntimeError, new_exc);
}

/* CoroutineSetYieldFrom (used by GeneratorYieldFrom) */
static void
__Pyx_Coroutine_Set_Owned_Yield_From(__pyx_CoroutineObject *gen, PyObject *yf) {
    assert (!gen->yieldfrom);
#if CYTHON_USE_AM_SEND
    assert (!gen->yieldfrom_am_send);
    #if PY_VERSION_HEX < 0x030A00F0
    if (__Pyx_PyType_HasFeature(Py_TYPE(yf), __Pyx_TPFLAGS_HAVE_AM_SEND))
    #endif
    {
        __Pyx_pyiter_sendfunc am_send;
        #if __PYX_LIMITED_VERSION_HEX >= 0x030A0000
        am_send = __Pyx_PyObject_TryGetSubSlot(yf, tp_as_async, am_send, __Pyx_pyiter_sendfunc);
        #else
        __Pyx_PyAsyncMethodsStruct* tp_as_async = (__Pyx_PyAsyncMethodsStruct*) Py_TYPE(yf)->tp_as_async;
        am_send = tp_as_async ? tp_as_async->am_send : NULL;
        #endif
        if (likely(am_send)) {
            gen->yieldfrom_am_send = am_send;
        }
    }
#endif
    gen->yieldfrom = yf;
}

/* dict_setdefault (used by FetchCommonType) */
static CYTHON_INLINE PyObject *__Pyx_PyDict_SetDefault(PyObject *d, PyObject *key, PyObject *default_value) {
    PyObject* value;
#if __PYX_LIMITED_VERSION_HEX >= 0x030F0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4)
    PyDict_SetDefaultRef(d, key, default_value, &value);
#elif CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    PyObject *args[] = {d, key, default_value};
    value = PyObject_VectorcallMethod(__pyx_mstate_global->__pyx_n_u_setdefault, args, 3 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#elif CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_CallMethodObjArgs(d, __pyx_mstate_global->__pyx_n_u_setdefault, key, default_value, NULL);
#else
    value = PyDict_SetDefault(d, key, default_value);
    if (unlikely(!value)) return NULL;
    Py_INCREF(value);
#endif
    return value;
}

/* LimitedApiGetTypeDict (used by SetItemOnTypeDict) */
#if CYTHON_COMPILING_IN_LIMITED_API
static Py_ssize_t __Pyx_GetTypeDictOffset(void) {
    PyObject *tp_dictoffset_o;
    Py_ssize_t tp_dictoffset;
    tp_dictoffset_o = PyObject_GetAttrString((PyObject*)(&PyType_Type), "__dictoffset__");
    if (unlikely(!tp_dictoffset_o)) return -1;
    tp_dictoffset = PyLong_AsSsize_t(tp_dictoffset_o);
    Py_DECREF(tp_dictoffset_o);
    if (unlikely(tp_dictoffset == 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' doesn't have a dictoffset");
        return -1;
    } else if (unlikely(tp_dictoffset < 0)) {
        PyErr_SetString(
            PyExc_TypeError,
            "'type' has an unexpected negative dictoffset. "
            "Please report this as Cython bug");
        return -1;
    }
    return tp_dictoffset;
}
static PyObject *__Pyx_GetTypeDict(PyTypeObject *tp) {
    static Py_ssize_t tp_dictoffset = 0;
    if (unlikely(tp_dictoffset == 0)) {
        tp_dictoffset = __Pyx_GetTypeDictOffset();
        if (unlikely(tp_dictoffset == -1 && PyErr_Occurred())) {
            tp_dictoffset = 0; // try again next time?
            return NULL;
        }
    }
    return *(PyObject**)((char*)tp + tp_dictoffset);
}
#endif

/* SetItemOnTypeDict (used by FixUpExtensionType) */
static int __Pyx__SetItemOnTypeDict(PyTypeObject *tp, PyObject *k, PyObject *v) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_SetItem(tp_dict, k, v);
    if (likely(!result)) {
        PyType_Modified(tp);
        if (unlikely(PyObject_HasAttr(v, __pyx_mstate_global->__pyx_n_u_set_name))) {
            PyObject *setNameResult = PyObject_CallMethodObjArgs(v, __pyx_mstate_global->__pyx_n_u_set_name,  (PyObject *) tp, k, NULL);
            if (!setNameResult) return -1;
            Py_DECREF(setNameResult);
        }
    }
    return result;
}

/* FixUpExtensionType (used by FetchCommonType) */
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if __PYX_LIMITED_VERSION_HEX > 0x030900B1
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#else
    const PyType_Slot *slot = spec->slots;
    int changed = 0;
#if !CYTHON_COMPILING_IN_LIMITED_API
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
#if !CYTHON_COMPILING_IN_CPYTHON
        const
#endif  // !CYTHON_COMPILING_IN_CPYTHON)
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_vectorcall_offset = memb->offset;
                    changed = 1;
                }
#endif  // CYTHON_METH_FASTCALL
#if !CYTHON_COMPILING_IN_PYPY
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                    Py_DECREF(descr);
                    if (unlikely(set_item_result < 0)) {
                        return -1;
                    }
                    changed = 1;
                }
#endif  // !CYTHON_COMPILING_IN_PYPY
            }
            memb++;
        }
    }
#endif  // !CYTHON_COMPILING_IN_LIMITED_API
#if !CYTHON_COMPILING_IN_PYPY
    slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_getset)
        slot++;
    if (slot && slot->slot == Py_tp_getset) {
        PyGetSetDef *getset = (PyGetSetDef*) slot->pfunc;
        while (getset && getset->name) {
            if (getset->name[0] == '_' && getset->name[1] == '_' && strcmp(getset->name, "__module__") == 0) {
                PyObject *descr = PyDescr_NewGetSet(type, getset);
                if (unlikely(!descr))
                    return -1;
                #if CYTHON_COMPILING_IN_LIMITED_API
                PyObject *pyname = PyUnicode_FromString(getset->name);
                if (unlikely(!pyname)) {
                    Py_DECREF(descr);
                    return -1;
                }
                int set_item_result = __Pyx_SetItemOnTypeDict(type, pyname, descr);
                Py_DECREF(pyname);
                #else
                CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
                int set_item_result = PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr);
                #endif
                Py_DECREF(descr);
                if (unlikely(set_item_result < 0)) {
                    return -1;
                }
                changed = 1;
            }
            ++getset;
        }
    }
#else
    CYTHON_UNUSED_VAR(__Pyx__SetItemOnTypeDict);
#endif  // !CYTHON_COMPILING_IN_PYPY
    if (changed)
        PyType_Modified(type);
#endif  // PY_VERSION_HEX > 0x030900B1
    return 0;
}

/* AddModuleRef (used by FetchSharedCythonModule) */
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
  static PyObject *__Pyx_PyImport_AddModuleObjectRef(PyObject *name) {
      PyObject *module_dict = PyImport_GetModuleDict();
      PyObject *m;
      if (PyMapping_GetOptionalItem(module_dict, name, &m) < 0) {
          return NULL;
      }
      if (m != NULL && PyModule_Check(m)) {
          return m;
      }
      Py_XDECREF(m);
      m = PyModule_NewObject(name);
      if (m == NULL)
          return NULL;
      if (PyDict_CheckExact(module_dict)) {
          PyObject *new_m;
          (void)PyDict_SetDefaultRef(module_dict, name, m, &new_m);
          Py_DECREF(m);
          return new_m;
      } else {
           if (PyObject_SetItem(module_dict, name, m) != 0) {
                Py_DECREF(m);
                return NULL;
            }
            return m;
      }
  }
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *py_name = PyUnicode_FromString(name);
      if (!py_name) return NULL;
      PyObject *module = __Pyx_PyImport_AddModuleObjectRef(py_name);
      Py_DECREF(py_name);
      return module;
  }
#elif __PYX_LIMITED_VERSION_HEX >= 0x030d0000
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif

/* FetchSharedCythonModule (used by FetchCommonType) */
static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef(__PYX_ABI_MODULE_NAME);
}

/* FetchCommonType (used by CommonTypesMetaclass) */
#if __PYX_LIMITED_VERSION_HEX < 0x030C0000
static PyObject* __Pyx_PyType_FromMetaclass(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *result = __Pyx_PyType_FromModuleAndSpec(module, spec, bases);
    if (result && metaclass) {
        PyObject *old_tp = (PyObject*)Py_TYPE(result);
    Py_INCREF((PyObject*)metaclass);
#if __PYX_LIMITED_VERSION_HEX >= 0x03090000
        Py_SET_TYPE(result, metaclass);
#else
        result->ob_type = metaclass;
#endif
        Py_DECREF(old_tp);
    }
    return result;
}
#else
#define __Pyx_PyType_FromMetaclass(me, mo, s, b) PyType_FromMetaclass(me, mo, s, b)
#endif
static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t expected_basicsize) {
    Py_ssize_t basicsize;
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (expected_basicsize == 0) {
        return 0; // size is inherited, nothing useful to check
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
    if (unlikely(!py_basicsize)) return -1;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = NULL;
    if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) return -1;
#else
    basicsize = ((PyTypeObject*) cached_type)->tp_basicsize;
#endif
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyTypeObject *metaclass, PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module = NULL, *cached_type = NULL, *abi_module_dict, *new_cached_type, *py_object_name;
    int get_item_ref_result;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    py_object_name = PyUnicode_FromString(object_name);
    if (!py_object_name) return NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) goto done;
    abi_module_dict = PyModule_GetDict(abi_module);
    if (!abi_module_dict) goto done;
    get_item_ref_result = __Pyx_PyDict_GetItemRef(abi_module_dict, py_object_name, &cached_type);
    if (get_item_ref_result == 1) {
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else if (unlikely(get_item_ref_result == -1)) {
        goto bad;
    }
    cached_type = __Pyx_PyType_FromMetaclass(
        metaclass,
        CYTHON_USE_MODULE_STATE ? module : abi_module,
        spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    new_cached_type = __Pyx_PyDict_SetDefault(abi_module_dict, py_object_name, cached_type);
    if (unlikely(new_cached_type != cached_type)) {
        if (unlikely(!new_cached_type)) goto bad;
        Py_DECREF(cached_type);
        cached_type = new_cached_type;
        if (__Pyx_VerifyCachedType(
                cached_type,
                object_name,
                spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    } else {
        Py_DECREF(new_cached_type);
    }
done:
    Py_XDECREF(abi_module);
    Py_DECREF(py_object_name);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

/* CommonTypesMetaclass (used by CoroutineBase) */
static PyObject* __pyx_CommonTypesMetaclass_get_module(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED void* context) {
    return PyUnicode_FromString(__PYX_ABI_MODULE_NAME);
}
#if __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject* __pyx_CommonTypesMetaclass_call(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *args, CYTHON_UNUSED PyObject *kwds) {
    PyErr_SetString(PyExc_TypeError, "Cannot instantiate Cython internal types");
    return NULL;
}
static int __pyx_CommonTypesMetaclass_setattr(CYTHON_UNUSED PyObject *self, CYTHON_UNUSED PyObject *attr, CYTHON_UNUSED PyObject *value) {
    PyErr_SetString(PyExc_TypeError, "Cython internal types are immutable");
    return -1;
}
#endif
static PyGetSetDef __pyx_CommonTypesMetaclass_getset[] = {
    {"__module__", __pyx_CommonTypesMetaclass_get_module, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_CommonTypesMetaclass_slots[] = {
    {Py_tp_getset, (void *)__pyx_CommonTypesMetaclass_getset},
    #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {Py_tp_call, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_new, (void*)__pyx_CommonTypesMetaclass_call},
    {Py_tp_setattro, (void*)__pyx_CommonTypesMetaclass_setattr},
    #endif
    {0, 0}
};
static PyType_Spec __pyx_CommonTypesMetaclass_spec = {
    __PYX_TYPE_MODULE_PREFIX "_common_types_metatype",
    0,
    0,
    Py_TPFLAGS_IMMUTABLETYPE |
    Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT,
    __pyx_CommonTypesMetaclass_slots
};
static int __pyx_CommonTypesMetaclass_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    PyObject *bases = PyTuple_Pack(1, &PyType_Type);
    if (unlikely(!bases)) {
        return -1;
    }
    mstate->__pyx_CommonTypesMetaclassType = __Pyx_FetchCommonTypeFromSpec(NULL, module, &__pyx_CommonTypesMetaclass_spec, bases);
    Py_DECREF(bases);
    if (unlikely(mstate->__pyx_CommonTypesMetaclassType == NULL)) {
        return -1;
    }
    return 0;
}

/* CallTypeTraverse (used by CoroutineBase) */
#if !CYTHON_USE_TYPE_SPECS || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x03090000)
#else
static int __Pyx_call_type_traverse(PyObject *o, int always_call, visitproc visit, void *arg) {
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x03090000
    if (__Pyx_get_runtime_version() < 0x03090000) return 0;
    #endif
    if (!always_call) {
        PyTypeObject *base = __Pyx_PyObject_GetSlot(o, tp_base, PyTypeObject*);
        unsigned long flags = PyType_GetFlags(base);
        if (flags & Py_TPFLAGS_HEAPTYPE) {
            return 0;
        }
    }
    Py_VISIT((PyObject*)Py_TYPE(o));
    return 0;
}
#endif

/* IterNextPlain (used by CoroutineBase) */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *__Pyx_GetBuiltinNext_LimitedAPI(void) {
    if (unlikely(!__pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache))
        __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache = __Pyx_GetBuiltinName(__pyx_mstate_global->__pyx_n_u_next);
    return __pyx_mstate_global->__Pyx_GetBuiltinNext_LimitedAPI_cache;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next_Plain(PyObject *iterator) {
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    PyObject *result;
    PyObject *next = __Pyx_GetBuiltinNext_LimitedAPI();
    if (unlikely(!next)) return NULL;
    result = PyObject_CallFunctionObjArgs(next, iterator, NULL);
    return result;
#else
    (void)__Pyx_GetBuiltinName; // only for early limited API
    iternextfunc iternext = __Pyx_PyObject_GetIterNextFunc(iterator);
    assert(iternext);
    return iternext(iterator);
#endif
}

/* PyObjectCall2Args (used by PyObjectCallMethod1) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args[3] = {NULL, arg1, arg2};
    return __Pyx_PyObject_FastCall(function, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* PyObjectGetMethod (used by PyObjectCallMethod1) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetFullyQualifiedName(tp);
    PyErr_Format(PyExc_AttributeError,
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}
#endif

/* PyObjectCallMethod1 (used by CoroutineBase) */
#if !(CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000)))
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
#endif
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[2] = {obj, arg};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_Call2Args;
    return PyObject_VectorcallMethod(method_name, args, 2 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
#endif
}

/* PyObjectCallNoArg (used by CoroutineBase) */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ReturnWithStopIteration (used by CoroutineBase) */
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async);
static CYTHON_INLINE void __Pyx_ReturnWithStopIteration(PyObject* value, int async, int iternext) {
    if (value == Py_None) {
        if (async || !iternext)
            PyErr_SetNone(async ? PyExc_StopAsyncIteration : PyExc_StopIteration);
        return;
    }
    __Pyx__ReturnWithStopIteration(value, async);
}
static void __Pyx__ReturnWithStopIteration(PyObject* value, int async) {
#if CYTHON_COMPILING_IN_CPYTHON
    __Pyx_PyThreadState_declare
#endif
    PyObject *exc;
    PyObject *exc_type = async ? PyExc_StopAsyncIteration : PyExc_StopIteration;
#if CYTHON_COMPILING_IN_CPYTHON
    if ((PY_VERSION_HEX >= (0x030C00A6)) || unlikely(PyTuple_Check(value) || PyExceptionInstance_Check(value))) {
        if (PY_VERSION_HEX >= (0x030e00A1)) {
            exc = __Pyx_PyObject_CallOneArg(exc_type, value);
        } else {
            PyObject *args_tuple = PyTuple_New(1);
            if (unlikely(!args_tuple)) return;
            Py_INCREF(value);
            PyTuple_SET_ITEM(args_tuple, 0, value);
            exc = PyObject_Call(exc_type, args_tuple, NULL);
            Py_DECREF(args_tuple);
        }
        if (unlikely(!exc)) return;
    } else {
        Py_INCREF(value);
        exc = value;
    }
    #if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    #if CYTHON_USE_EXC_INFO_STACK
    if (!__pyx_tstate->exc_info->exc_value)
    #else
    if (!__pyx_tstate->exc_type)
    #endif
    {
        Py_INCREF(exc_type);
        __Pyx_ErrRestore(exc_type, exc, NULL);
        return;
    }
    #endif
#else
    exc = __Pyx_PyObject_CallOneArg(exc_type, value);
    if (unlikely(!exc)) return;
#endif
    PyErr_SetObject(exc_type, exc);
    Py_DECREF(exc);
}

/* CoroutineBase (used by Generator) */
#if !CYTHON_COMPILING_IN_LIMITED_API
#include <frameobject.h>
#if PY_VERSION_HEX >= 0x030b00a6 && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#endif // CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void
__Pyx_Coroutine_Undelegate(__pyx_CoroutineObject *gen) {
#if CYTHON_USE_AM_SEND
    gen->yieldfrom_am_send = NULL;
#endif
    Py_CLEAR(gen->yieldfrom);
}
static int __Pyx_PyGen__FetchStopIterationValue(PyThreadState *__pyx_tstate, PyObject **pvalue) {
    PyObject *et, *ev, *tb;
    PyObject *value = NULL;
    CYTHON_UNUSED_VAR(__pyx_tstate);
    __Pyx_ErrFetch(&et, &ev, &tb);
    if (!et) {
        Py_XDECREF(tb);
        Py_XDECREF(ev);
        Py_INCREF(Py_None);
        *pvalue = Py_None;
        return 0;
    }
    if (likely(et == PyExc_StopIteration)) {
        if (!ev) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
        else if (likely(__Pyx_IS_TYPE(ev, (PyTypeObject*)PyExc_StopIteration))) {
            #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL
            value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
            if (unlikely(!value)) goto limited_api_failure;
            #else
            value = ((PyStopIterationObject *)ev)->value;
            Py_INCREF(value);
            #endif
            Py_DECREF(ev);
        }
        else if (unlikely(PyTuple_Check(ev))) {
            Py_ssize_t tuple_size = __Pyx_PyTuple_GET_SIZE(ev);
            #if !CYTHON_ASSUME_SAFE_SIZE
            if (unlikely(tuple_size < 0)) {
                Py_XDECREF(tb);
                Py_DECREF(ev);
                Py_DECREF(et);
                return -1;
            }
            #endif
            if (tuple_size >= 1) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                value = PyTuple_GET_ITEM(ev, 0);
                Py_INCREF(value);
#elif CYTHON_ASSUME_SAFE_MACROS
                value = PySequence_ITEM(ev, 0);
#else
                value = PySequence_GetItem(ev, 0);
                if (!value) goto limited_api_failure;
#endif
            } else {
                Py_INCREF(Py_None);
                value = Py_None;
            }
            Py_DECREF(ev);
        }
        else if (!__Pyx_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration)) {
            value = ev;
        }
        if (likely(value)) {
            Py_XDECREF(tb);
            Py_DECREF(et);
            *pvalue = value;
            return 0;
        }
    } else if (!__Pyx_PyErr_GivenExceptionMatches(et, PyExc_StopIteration)) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    PyErr_NormalizeException(&et, &ev, &tb);
    if (unlikely(!PyObject_TypeCheck(ev, (PyTypeObject*)PyExc_StopIteration))) {
        __Pyx_ErrRestore(et, ev, tb);
        return -1;
    }
    Py_XDECREF(tb);
    Py_DECREF(et);
#if CYTHON_COMPILING_IN_LIMITED_API
    value = PyObject_GetAttr(ev, __pyx_mstate_global->__pyx_n_u_value);
#else
    value = ((PyStopIterationObject *)ev)->value;
    Py_INCREF(value);
#endif
    Py_DECREF(ev);
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!value)) return -1;
#endif
    *pvalue = value;
    return 0;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_GRAAL || !CYTHON_ASSUME_SAFE_MACROS
  limited_api_failure:
    Py_XDECREF(et);
    Py_XDECREF(tb);
    Py_XDECREF(ev);
    return -1;
#endif
}
static CYTHON_INLINE
__Pyx_PySendResult __Pyx_Coroutine_status_from_result(PyObject **retval) {
    if (*retval) {
        return PYGEN_NEXT;
    } else if (likely(__Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, retval) == 0)) {
        return PYGEN_RETURN;
    } else {
        return PYGEN_ERROR;
    }
}
static CYTHON_INLINE
void __Pyx_Coroutine_ExceptionClear(__Pyx_ExcInfoStruct *exc_state) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_CLEAR(exc_state->exc_value);
#else
    PyObject *t, *v, *tb;
    t = exc_state->exc_type;
    v = exc_state->exc_value;
    tb = exc_state->exc_traceback;
    exc_state->exc_type = NULL;
    exc_state->exc_value = NULL;
    exc_state->exc_traceback = NULL;
    Py_XDECREF(t);
    Py_XDECREF(v);
    Py_XDECREF(tb);
#endif
}
#define __Pyx_Coroutine_AlreadyRunningError(gen)  (__Pyx__Coroutine_AlreadyRunningError(gen), (PyObject*)NULL)
static void __Pyx__Coroutine_AlreadyRunningError(__pyx_CoroutineObject *gen) {
    const char *msg;
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if ((0)) {
    #ifdef __Pyx_Coroutine_USED
    } else if (__Pyx_Coroutine_Check((PyObject*)gen)) {
        msg = "coroutine already executing";
    #endif
    #ifdef __Pyx_AsyncGen_USED
    } else if (__Pyx_AsyncGen_CheckExact((PyObject*)gen)) {
        msg = "async generator already executing";
    #endif
    } else {
        msg = "generator already executing";
    }
    PyErr_SetString(PyExc_ValueError, msg);
}
static void __Pyx_Coroutine_AlreadyTerminatedError(PyObject *gen, PyObject *value, int closing) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    CYTHON_MAYBE_UNUSED_VAR(closing);
    #ifdef __Pyx_Coroutine_USED
    if (!closing && __Pyx_Coroutine_Check(gen)) {
        PyErr_SetString(PyExc_RuntimeError, "cannot reuse already awaited coroutine");
    } else
    #endif
    if (value) {
        #ifdef __Pyx_AsyncGen_USED
        if (__Pyx_AsyncGen_CheckExact(gen))
            PyErr_SetNone(PyExc_StopAsyncIteration);
        else
        #endif
        PyErr_SetNone(PyExc_StopIteration);
    }
}
static
__Pyx_PySendResult __Pyx_Coroutine_SendEx(__pyx_CoroutineObject *self, PyObject *value, PyObject **result, int closing) {
    __Pyx_PyThreadState_declare
    PyThreadState *tstate;
    __Pyx_ExcInfoStruct *exc_state;
    PyObject *retval;
    assert(__Pyx_Coroutine_get_is_running(self));  // Callers should ensure is_running
    if (unlikely(self->resume_label == -1)) {
        __Pyx_Coroutine_AlreadyTerminatedError((PyObject*)self, value, closing);
        return PYGEN_ERROR;
    }
#if CYTHON_FAST_THREAD_STATE
    __Pyx_PyThreadState_assign
    tstate = __pyx_tstate;
#else
    tstate = __Pyx_PyThreadState_Current;
#endif
    exc_state = &self->gi_exc_state;
    if (exc_state->exc_value) {
        #if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        #else
        PyObject *exc_tb;
        #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
        exc_tb = PyException_GetTraceback(exc_state->exc_value);
        #elif PY_VERSION_HEX >= 0x030B00a4
        exc_tb = ((PyBaseExceptionObject*) exc_state->exc_value)->traceback;
        #else
        exc_tb = exc_state->exc_traceback;
        #endif
        if (exc_tb) {
            PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
            PyFrameObject *f = tb->tb_frame;
            assert(f->f_back == NULL);
            #if PY_VERSION_HEX >= 0x030B00A1
            f->f_back = PyThreadState_GetFrame(tstate);
            #else
            Py_XINCREF(tstate->frame);
            f->f_back = tstate->frame;
            #endif
            #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_CPYTHON
            Py_DECREF(exc_tb);
            #endif
        }
        #endif
    }
#if CYTHON_USE_EXC_INFO_STACK
    exc_state->previous_item = tstate->exc_info;
    tstate->exc_info = exc_state;
#else
    if (exc_state->exc_type) {
        __Pyx_ExceptionSwap(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    } else {
        __Pyx_Coroutine_ExceptionClear(exc_state);
        __Pyx_ExceptionSave(&exc_state->exc_type, &exc_state->exc_value, &exc_state->exc_traceback);
    }
#endif
    retval = self->body(self, tstate, value);
#if CYTHON_USE_EXC_INFO_STACK
    exc_state = &self->gi_exc_state;
    tstate->exc_info = exc_state->previous_item;
    exc_state->previous_item = NULL;
    __Pyx_Coroutine_ResetFrameBackpointer(exc_state);
#endif
    *result = retval;
    if (self->resume_label == -1) {
        return likely(retval) ? PYGEN_RETURN : PYGEN_ERROR;
    }
    return PYGEN_NEXT;
}
static CYTHON_INLINE void __Pyx_Coroutine_ResetFrameBackpointer(__Pyx_ExcInfoStruct *exc_state) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(exc_state);
#else
    PyObject *exc_tb;
    #if PY_VERSION_HEX >= 0x030B00a4
    if (!exc_state->exc_value) return;
    exc_tb = PyException_GetTraceback(exc_state->exc_value);
    #else
    exc_tb = exc_state->exc_traceback;
    #endif
    if (likely(exc_tb)) {
        PyTracebackObject *tb = (PyTracebackObject *) exc_tb;
        PyFrameObject *f = tb->tb_frame;
        Py_CLEAR(f->f_back);
        #if PY_VERSION_HEX >= 0x030B00a4
        Py_DECREF(exc_tb);
        #endif
    }
#endif
}
#define __Pyx_Coroutine_MethodReturnFromResult(gen, result, retval, iternext)\
    ((result) == PYGEN_NEXT ? (retval) : __Pyx__Coroutine_MethodReturnFromResult(gen, result, retval, iternext))
static PyObject *
__Pyx__Coroutine_MethodReturnFromResult(PyObject* gen, __Pyx_PySendResult result, PyObject *retval, int iternext) {
    CYTHON_MAYBE_UNUSED_VAR(gen);
    if (likely(result == PYGEN_RETURN)) {
        int is_async = 0;
        #ifdef __Pyx_AsyncGen_USED
        is_async = __Pyx_AsyncGen_CheckExact(gen);
        #endif
        __Pyx_ReturnWithStopIteration(retval, is_async, iternext);
        Py_XDECREF(retval);
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE
PyObject *__Pyx_PyGen_Send(PyGenObject *gen, PyObject *arg) {
#if PY_VERSION_HEX <= 0x030A00A1
    return _PyGen_Send(gen, arg);
#else
    PyObject *result;
    if (PyIter_Send((PyObject*)gen, arg ? arg : Py_None, &result) == PYGEN_RETURN) {
        if (PyAsyncGen_CheckExact(gen)) {
            assert(result == Py_None);
            PyErr_SetNone(PyExc_StopAsyncIteration);
        }
        else if (result == Py_None) {
            PyErr_SetNone(PyExc_StopIteration);
        }
        else {
#if PY_VERSION_HEX < 0x030d00A1
            _PyGen_SetStopIterationValue(result);
#else
            if (!PyTuple_Check(result) && !PyExceptionInstance_Check(result)) {
                PyErr_SetObject(PyExc_StopIteration, result);
            } else {
                PyObject *exc = __Pyx_PyObject_CallOneArg(PyExc_StopIteration, result);
                if (likely(exc != NULL)) {
                    PyErr_SetObject(PyExc_StopIteration, exc);
                    Py_DECREF(exc);
                }
            }
#endif
        }
        Py_DECREF(result);
        result = NULL;
    }
    return result;
#endif
}
#endif
static CYTHON_INLINE __Pyx_PySendResult
__Pyx_Coroutine_FinishDelegation(__pyx_CoroutineObject *gen, PyObject** retval) {
    __Pyx_PySendResult result;
    PyObject *val = NULL;
    assert(__Pyx_Coroutine_get_is_running(gen));
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_PyGen__FetchStopIterationValue(__Pyx_PyThreadState_Current, &val);
    result = __Pyx_Coroutine_SendEx(gen, val, retval, 0);
    Py_XDECREF(val);
    return result;
}
#if CYTHON_USE_AM_SEND
static __Pyx_PySendResult
__Pyx_Coroutine_SendToDelegate(__pyx_CoroutineObject *gen, __Pyx_pyiter_sendfunc gen_am_send, PyObject *value, PyObject **retval) {
    PyObject *ret = NULL;
    __Pyx_PySendResult delegate_result, result;
    assert(__Pyx_Coroutine_get_is_running(gen));
    delegate_result = gen_am_send(gen->yieldfrom, value, &ret);
    if (delegate_result == PYGEN_NEXT) {
        assert (ret != NULL);
        *retval = ret;
        return PYGEN_NEXT;
    }
    assert (delegate_result != PYGEN_ERROR || ret == NULL);
    __Pyx_Coroutine_Undelegate(gen);
    result = __Pyx_Coroutine_SendEx(gen, ret, retval, 0);
    Py_XDECREF(ret);
    return result;
}
#endif
static PyObject *__Pyx_Coroutine_Send(PyObject *self, PyObject *value) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result = __Pyx_Coroutine_AmSend(self, value, &retval);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
}
static __Pyx_PySendResult
__Pyx_Coroutine_AmSend(PyObject *self, PyObject *value, PyObject **retval) {
    __Pyx_PySendResult result;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, value, retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
      #if !CYTHON_USE_AM_SEND
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_Check(yf)) {
            ret = __Pyx_Coroutine_Send(yf, value);
        } else
        #endif
        #ifdef __Pyx_AsyncGen_USED
        if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
            ret = __Pyx_async_gen_asend_send(yf, value);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        if (PyCoro_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, value == Py_None ? NULL : value);
        } else
        #endif
      #endif
        {
            #if !CYTHON_COMPILING_IN_LIMITED_API || __PYX_LIMITED_VERSION_HEX >= 0x03080000
            if (value == Py_None && PyIter_Check(yf))
                ret = __Pyx_PyIter_Next_Plain(yf);
            else
            #endif
                ret = __Pyx_PyObject_CallMethod1(yf, __pyx_mstate_global->__pyx_n_u_send, value);
        }
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            *retval = ret;
            return PYGEN_NEXT;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, value, retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return result;
}
static int __Pyx_Coroutine_CloseIter(__pyx_CoroutineObject *gen, PyObject *yf) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    CYTHON_UNUSED_VAR(gen);
    assert(__Pyx_Coroutine_get_is_running(gen));
    #ifdef __Pyx_Generator_USED
    if (__Pyx_Generator_CheckExact(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    #endif
    #ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(yf)) {
        result = __Pyx_Coroutine_Close(yf, &retval);
    } else
    if (__Pyx_CoroutineAwait_CheckExact(yf)) {
        result = __Pyx_CoroutineAwait_Close((__pyx_CoroutineAwaitObject*)yf);
    } else
    #endif
    #ifdef __Pyx_AsyncGen_USED
    if (__pyx_PyAsyncGenASend_CheckExact(yf)) {
        retval = __Pyx_async_gen_asend_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    if (__pyx_PyAsyncGenAThrow_CheckExact(yf)) {
        retval = __Pyx_async_gen_athrow_close(yf, NULL);
        result = PYGEN_RETURN;
    } else
    #endif
    {
        PyObject *meth;
        result = PYGEN_RETURN;
        meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_close);
        if (unlikely(!meth)) {
            if (unlikely(PyErr_Occurred())) {
                PyErr_WriteUnraisable(yf);
            }
        } else {
            retval = __Pyx_PyObject_CallNoArg(meth);
            Py_DECREF(meth);
            if (unlikely(!retval)) {
                result = PYGEN_ERROR;
            }
        }
    }
    Py_XDECREF(retval);
    return result == PYGEN_ERROR ? -1 : 0;
}
static PyObject *__Pyx_Generator_Next(PyObject *self) {
    __Pyx_PySendResult result;
    PyObject *retval = NULL;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    #if CYTHON_USE_AM_SEND
    if (gen->yieldfrom_am_send) {
        result = __Pyx_Coroutine_SendToDelegate(gen, gen->yieldfrom_am_send, Py_None, &retval);
    } else
    #endif
    if (gen->yieldfrom) {
        PyObject *yf = gen->yieldfrom;
        PyObject *ret;
        #ifdef __Pyx_Generator_USED
        if (__Pyx_Generator_CheckExact(yf)) {
            ret = __Pyx_Generator_Next(yf);
        } else
        #endif
        #ifdef __Pyx_Coroutine_USED
        if (__Pyx_Coroutine_CheckExact(yf)) {
            ret = __Pyx_Coroutine_Send(yf, Py_None);
        } else
        #endif
        #if CYTHON_COMPILING_IN_CPYTHON && (PY_VERSION_HEX < 0x030A00A3 || !CYTHON_USE_AM_SEND)
        if (PyGen_CheckExact(yf)) {
            ret = __Pyx_PyGen_Send((PyGenObject*)yf, NULL);
        } else
        #endif
            ret = __Pyx_PyIter_Next_Plain(yf);
        if (likely(ret)) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &retval);
    } else {
        result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    }
    __Pyx_Coroutine_unset_is_running(gen);
    return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 1);
}
static PyObject *__Pyx_Coroutine_Close_Method(PyObject *self, PyObject *arg) {
    PyObject *retval = NULL;
    __Pyx_PySendResult result;
    CYTHON_UNUSED_VAR(arg);
    result = __Pyx_Coroutine_Close(self, &retval);
    if (unlikely(result == PYGEN_ERROR))
        return NULL;
    Py_XDECREF(retval);
    Py_RETURN_NONE;
}
static __Pyx_PySendResult
__Pyx_Coroutine_Close(PyObject *self, PyObject **retval) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PySendResult result;
    PyObject *yf;
    int err = 0;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        *retval = __Pyx_Coroutine_AlreadyRunningError(gen);
        return PYGEN_ERROR;
    }
    yf = gen->yieldfrom;
    if (yf) {
        Py_INCREF(yf);
        err = __Pyx_Coroutine_CloseIter(gen, yf);
        __Pyx_Coroutine_Undelegate(gen);
        Py_DECREF(yf);
    }
    if (err == 0)
        PyErr_SetNone(PyExc_GeneratorExit);
    result = __Pyx_Coroutine_SendEx(gen, NULL, retval, 1);
    if (result == PYGEN_ERROR) {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_Coroutine_unset_is_running(gen);
        if (!__Pyx_PyErr_Occurred()) {
            return PYGEN_RETURN;
        } else if (likely(__Pyx_PyErr_ExceptionMatches2(PyExc_GeneratorExit, PyExc_StopIteration))) {
            __Pyx_PyErr_Clear();
            return PYGEN_RETURN;
        }
        return PYGEN_ERROR;
    } else if (likely(result == PYGEN_RETURN && *retval == Py_None)) {
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_RETURN;
    } else {
        const char *msg;
        Py_DECREF(*retval);
        *retval = NULL;
        if ((0)) {
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_Coroutine_Check(self)) {
            msg = "coroutine ignored GeneratorExit";
        #endif
        #ifdef __Pyx_AsyncGen_USED
        } else if (__Pyx_AsyncGen_CheckExact(self)) {
            msg = "async generator ignored GeneratorExit";
        #endif
        } else {
            msg = "generator ignored GeneratorExit";
        }
        PyErr_SetString(PyExc_RuntimeError, msg);
        __Pyx_Coroutine_unset_is_running(gen);
        return PYGEN_ERROR;
    }
}
static PyObject *__Pyx__Coroutine_Throw(PyObject *self, PyObject *typ, PyObject *val, PyObject *tb,
                                        PyObject *args, int close_on_genexit) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject *yf;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen)))
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    yf = gen->yieldfrom;
    if (yf) {
        __Pyx_PySendResult result;
        PyObject *ret;
        Py_INCREF(yf);
        if (__Pyx_PyErr_GivenExceptionMatches(typ, PyExc_GeneratorExit) && close_on_genexit) {
            int err = __Pyx_Coroutine_CloseIter(gen, yf);
            Py_DECREF(yf);
            __Pyx_Coroutine_Undelegate(gen);
            if (err < 0)
                goto propagate_exception;
            goto throw_here;
        }
        if (0
        #ifdef __Pyx_Generator_USED
            || __Pyx_Generator_CheckExact(yf)
        #endif
        #ifdef __Pyx_Coroutine_USED
            || __Pyx_Coroutine_Check(yf)
        #endif
            ) {
            ret = __Pyx__Coroutine_Throw(yf, typ, val, tb, args, close_on_genexit);
        #ifdef __Pyx_Coroutine_USED
        } else if (__Pyx_CoroutineAwait_CheckExact(yf)) {
            ret = __Pyx__Coroutine_Throw(((__pyx_CoroutineAwaitObject*)yf)->coroutine, typ, val, tb, args, close_on_genexit);
        #endif
        } else {
            PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(yf, __pyx_mstate_global->__pyx_n_u_throw);
            if (unlikely(!meth)) {
                Py_DECREF(yf);
                if (unlikely(PyErr_Occurred())) {
                    __Pyx_Coroutine_unset_is_running(gen);
                    return NULL;
                }
                __Pyx_Coroutine_Undelegate(gen);
                goto throw_here;
            }
            if (likely(args)) {
                ret = __Pyx_PyObject_Call(meth, args, NULL);
            } else {
                PyObject *cargs[4] = {NULL, typ, val, tb};
                ret = __Pyx_PyObject_FastCall(meth, cargs+1, 3 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
            }
            Py_DECREF(meth);
        }
        Py_DECREF(yf);
        if (ret) {
            __Pyx_Coroutine_unset_is_running(gen);
            return ret;
        }
        result = __Pyx_Coroutine_FinishDelegation(gen, &ret);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, ret, 0);
    }
throw_here:
    __Pyx_Raise(typ, val, tb, NULL);
propagate_exception:
    {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, NULL, &retval, 0);
        __Pyx_Coroutine_unset_is_running(gen);
        return __Pyx_Coroutine_MethodReturnFromResult(self, result, retval, 0);
    }
}
static PyObject *__Pyx_Coroutine_Throw(PyObject *self, PyObject *args) {
    PyObject *typ;
    PyObject *val = NULL;
    PyObject *tb = NULL;
    if (unlikely(!PyArg_UnpackTuple(args, "throw", 1, 3, &typ, &val, &tb)))
        return NULL;
    return __Pyx__Coroutine_Throw(self, typ, val, tb, args, 1);
}
static CYTHON_INLINE int __Pyx_Coroutine_traverse_excstate(__Pyx_ExcInfoStruct *exc_state, visitproc visit, void *arg) {
#if PY_VERSION_HEX >= 0x030B00a4
    Py_VISIT(exc_state->exc_value);
#else
    Py_VISIT(exc_state->exc_type);
    Py_VISIT(exc_state->exc_value);
    Py_VISIT(exc_state->exc_traceback);
#endif
    return 0;
}
static int __Pyx_Coroutine_traverse(__pyx_CoroutineObject *gen, visitproc visit, void *arg) {
    {
        int e = __Pyx_call_type_traverse((PyObject*)gen, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(gen->closure);
    Py_VISIT(gen->classobj);
    Py_VISIT(gen->yieldfrom);
    return __Pyx_Coroutine_traverse_excstate(&gen->gi_exc_state, visit, arg);
}
static int __Pyx_Coroutine_clear(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    Py_CLEAR(gen->closure);
    Py_CLEAR(gen->classobj);
    __Pyx_Coroutine_Undelegate(gen);
    __Pyx_Coroutine_ExceptionClear(&gen->gi_exc_state);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        Py_CLEAR(((__pyx_PyAsyncGenObject*)gen)->ag_finalizer);
    }
#endif
    Py_CLEAR(gen->gi_code);
    Py_CLEAR(gen->gi_frame);
    Py_CLEAR(gen->gi_name);
    Py_CLEAR(gen->gi_qualname);
    Py_CLEAR(gen->gi_modulename);
    return 0;
}
static void __Pyx_Coroutine_dealloc(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    PyObject_GC_UnTrack(gen);
    #if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    if (gen->gi_weakreflist != NULL)
    #endif
        PyObject_ClearWeakRefs(self);
    if (gen->resume_label >= 0) {
        PyObject_GC_Track(self);
#if CYTHON_USE_TP_FINALIZE
        if (unlikely(PyObject_CallFinalizerFromDealloc(self)))
#else
        {
            destructor del = __Pyx_PyObject_GetSlot(gen, tp_del, destructor);
            if (del) del(self);
        }
        if (unlikely(Py_REFCNT(self) > 0))
#endif
        {
            return;
        }
        PyObject_GC_UnTrack(self);
    }
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        /* We have to handle this case for asynchronous generators
           right here, because this code has to be between UNTRACK
           and GC_Del. */
        Py_CLEAR(((__pyx_PyAsyncGenObject*)self)->ag_finalizer);
    }
#endif
    __Pyx_Coroutine_clear(self);
    __Pyx_PyHeapTypeObject_GC_Del(gen);
}
#if CYTHON_USE_TP_FINALIZE
static void __Pyx_Coroutine_del(PyObject *self) {
    PyObject *error_type, *error_value, *error_traceback;
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject *) self;
    __Pyx_PyThreadState_declare
    if (gen->resume_label < 0) {
        return;
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&error_type, &error_value, &error_traceback);
#ifdef __Pyx_AsyncGen_USED
    if (__Pyx_AsyncGen_CheckExact(self)) {
        __pyx_PyAsyncGenObject *agen = (__pyx_PyAsyncGenObject*)self;
        PyObject *finalizer = agen->ag_finalizer;
        if (finalizer && !agen->ag_closed) {
            PyObject *res = __Pyx_PyObject_CallOneArg(finalizer, self);
            if (unlikely(!res)) {
                PyErr_WriteUnraisable(self);
            } else {
                Py_DECREF(res);
            }
            __Pyx_ErrRestore(error_type, error_value, error_traceback);
            return;
        }
    }
#endif
    if (unlikely(gen->resume_label == 0 && !error_value)) {
#ifdef __Pyx_Coroutine_USED
#ifdef __Pyx_Generator_USED
    if (!__Pyx_Generator_CheckExact(self))
#endif
        {
        PyObject_GC_UnTrack(self);
        if (unlikely(PyErr_WarnFormat(PyExc_RuntimeWarning, 1, "coroutine '%.50S' was never awaited", gen->gi_qualname) < 0))
            PyErr_WriteUnraisable(self);
        PyObject_GC_Track(self);
        }
#endif
    } else {
        PyObject *retval = NULL;
        __Pyx_PySendResult result = __Pyx_Coroutine_Close(self, &retval);
        if (result == PYGEN_ERROR) {
            PyErr_WriteUnraisable(self);
        } else {
            Py_XDECREF(retval);
        }
    }
    __Pyx_ErrRestore(error_type, error_value, error_traceback);
}
#endif
static PyObject *
__Pyx_Coroutine_get_name(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_name;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_name(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_name, value);
    return 0;
}
static PyObject *
__Pyx_Coroutine_get_qualname(__pyx_CoroutineObject *self, void *context)
{
    PyObject *name = self->gi_qualname;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!name)) name = Py_None;
    Py_INCREF(name);
    return name;
}
static int
__Pyx_Coroutine_set_qualname(__pyx_CoroutineObject *self, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(self->gi_qualname, value);
    return 0;
}
static PyObject *
__Pyx__Coroutine_get_frame(__pyx_CoroutineObject *self)
{
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyObject *frame;
    #if PY_VERSION_HEX >= 0x030d0000
    Py_BEGIN_CRITICAL_SECTION(self);
    #endif
    frame = self->gi_frame;
    if (!frame) {
        if (unlikely(!self->gi_code)) {
            Py_RETURN_NONE;
        }
        PyObject *globals = PyDict_New();
        if (unlikely(!globals)) return NULL;
        frame = (PyObject *) PyFrame_New(
            PyThreadState_Get(),            /*PyThreadState *tstate,*/
            (PyCodeObject*) self->gi_code,  /*PyCodeObject *code,*/
            globals,                        /*PyObject *globals,*/
            0                               /*PyObject *locals*/
        );
        Py_DECREF(globals);
        if (unlikely(!frame))
            return NULL;
        if (unlikely(self->gi_frame)) {
            Py_DECREF(frame);
            frame = self->gi_frame;
        } else {
            self->gi_frame = frame;
        }
    }
    Py_INCREF(frame);
    #if PY_VERSION_HEX >= 0x030d0000
    Py_END_CRITICAL_SECTION();
    #endif
    return frame;
#else
    CYTHON_UNUSED_VAR(self);
    Py_RETURN_NONE;
#endif
}
static PyObject *
__Pyx_Coroutine_get_frame(__pyx_CoroutineObject *self, void *context) {
    CYTHON_UNUSED_VAR(context);
    PyObject *frame = self->gi_frame;
    if (frame)
        return __Pyx_NewRef(frame);
    return __Pyx__Coroutine_get_frame(self);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_New(
            PyTypeObject* type, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    __pyx_CoroutineObject *gen = PyObject_GC_New(__pyx_CoroutineObject, type);
    if (unlikely(!gen))
        return NULL;
    return __Pyx__Coroutine_NewInit(gen, body, code, closure, name, qualname, module_name);
}
static __pyx_CoroutineObject *__Pyx__Coroutine_NewInit(
            __pyx_CoroutineObject *gen, __pyx_coroutine_body_t body, PyObject *code, PyObject *closure,
            PyObject *name, PyObject *qualname, PyObject *module_name) {
    gen->body = body;
    gen->closure = closure;
    Py_XINCREF(closure);
    gen->is_running = 0;
    gen->resume_label = 0;
    gen->classobj = NULL;
    gen->yieldfrom = NULL;
    gen->yieldfrom_am_send = NULL;
    #if PY_VERSION_HEX >= 0x030B00a4 && !CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_exc_state.exc_value = NULL;
    #else
    gen->gi_exc_state.exc_type = NULL;
    gen->gi_exc_state.exc_value = NULL;
    gen->gi_exc_state.exc_traceback = NULL;
    #endif
#if CYTHON_USE_EXC_INFO_STACK
    gen->gi_exc_state.previous_item = NULL;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    gen->gi_weakreflist = NULL;
#endif
    Py_XINCREF(qualname);
    gen->gi_qualname = qualname;
    Py_XINCREF(name);
    gen->gi_name = name;
    Py_XINCREF(module_name);
    gen->gi_modulename = module_name;
    Py_XINCREF(code);
    gen->gi_code = code;
    gen->gi_frame = NULL;
    PyObject_GC_Track(gen);
    return gen;
}
static char __Pyx_Coroutine_test_and_set_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    gen->is_running = 1;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static void __Pyx_Coroutine_unset_is_running(__pyx_CoroutineObject *gen) {
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    assert(gen->is_running);
    gen->is_running = 0;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
}
static char __Pyx_Coroutine_get_is_running(__pyx_CoroutineObject *gen) {
    char result;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_BEGIN_CRITICAL_SECTION(gen);
    #endif
    result = gen->is_running;
    #if PY_VERSION_HEX >= 0x030d0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_END_CRITICAL_SECTION();
    #endif
    return result;
}
static PyObject *__Pyx_Coroutine_get_is_running_getter(PyObject *gen, void *closure) {
    CYTHON_UNUSED_VAR(closure);
    char result = __Pyx_Coroutine_get_is_running((__pyx_CoroutineObject*)gen);
    if (result) Py_RETURN_TRUE;
    else Py_RETURN_FALSE;
}
#if __PYX_HAS_PY_AM_SEND == 2
static void __Pyx_SetBackportTypeAmSend(PyTypeObject *type, __Pyx_PyAsyncMethodsStruct *static_amsend_methods, __Pyx_pyiter_sendfunc am_send) {
    Py_ssize_t ptr_offset = (char*)(type->tp_as_async) - (char*)type;
    if (ptr_offset < 0 || ptr_offset > type->tp_basicsize) {
        return;
    }
    memcpy((void*)static_amsend_methods, (void*)(type->tp_as_async), sizeof(*type->tp_as_async));
    static_amsend_methods->am_send = am_send;
    type->tp_as_async = __Pyx_SlotTpAsAsync(static_amsend_methods);
}
#endif
static PyObject *__Pyx_Coroutine_fail_reduce_ex(PyObject *self, PyObject *arg) {
    CYTHON_UNUSED_VAR(arg);
    __Pyx_TypeName self_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE((PyObject*)self));
    PyErr_Format(PyExc_TypeError, "cannot pickle '" __Pyx_FMT_TYPENAME "' object",
                         self_type_name);
    __Pyx_DECREF_TypeName(self_type_name);
    return NULL;
}

/* Generator (used by GeneratorYieldFrom) */
static PyMethodDef __pyx_Generator_methods[] = {
    {"send", (PyCFunction) __Pyx_Coroutine_Send, METH_O,
     PyDoc_STR("send(arg) -> send 'arg' into generator,\nreturn next yielded value or raise StopIteration.")},
    {"throw", (PyCFunction) __Pyx_Coroutine_Throw, METH_VARARGS,
     PyDoc_STR("throw(typ[,val[,tb]]) -> raise exception in generator,\nreturn next yielded value or raise StopIteration.")},
    {"close", (PyCFunction) __Pyx_Coroutine_Close_Method, METH_NOARGS,
     PyDoc_STR("close() -> raise GeneratorExit inside generator.")},
    {"__reduce_ex__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_O, 0},
    {"__reduce__", (PyCFunction) __Pyx_Coroutine_fail_reduce_ex, METH_NOARGS, 0},
    {0, 0, 0, 0}
};
static PyMemberDef __pyx_Generator_memberlist[] = {
    {"gi_yieldfrom", T_OBJECT, offsetof(__pyx_CoroutineObject, yieldfrom), READONLY,
     PyDoc_STR("object being iterated by 'yield from', or None")},
    {"gi_code", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_code), READONLY, NULL},
    {"__module__", T_OBJECT, offsetof(__pyx_CoroutineObject, gi_modulename), 0, 0},
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CoroutineObject, gi_weakreflist), READONLY, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyGetSetDef __pyx_Generator_getsets[] = {
    {"__name__", (getter)__Pyx_Coroutine_get_name, (setter)__Pyx_Coroutine_set_name,
     PyDoc_STR("name of the generator"), 0},
    {"__qualname__", (getter)__Pyx_Coroutine_get_qualname, (setter)__Pyx_Coroutine_set_qualname,
     PyDoc_STR("qualified name of the generator"), 0},
    {"gi_frame", (getter)__Pyx_Coroutine_get_frame, NULL,
     PyDoc_STR("Frame of the generator"), 0},
    {"gi_running", __Pyx_Coroutine_get_is_running_getter, NULL, NULL, NULL},
    {0, 0, 0, 0, 0}
};
static PyType_Slot __pyx_GeneratorType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_Coroutine_dealloc},
    {Py_tp_traverse, (void *)__Pyx_Coroutine_traverse},
    {Py_tp_iter, (void *)PyObject_SelfIter},
    {Py_tp_iternext, (void *)__Pyx_Generator_Next},
    {Py_tp_methods, (void *)__pyx_Generator_methods},
    {Py_tp_members, (void *)__pyx_Generator_memberlist},
    {Py_tp_getset, (void *)__pyx_Generator_getsets},
    {Py_tp_getattro, (void *) PyObject_GenericGetAttr},
#if CYTHON_USE_TP_FINALIZE
    {Py_tp_finalize, (void *)__Pyx_Coroutine_del},
#endif
#if __PYX_HAS_PY_AM_SEND == 1
    {Py_am_send, (void *)__Pyx_Coroutine_AmSend},
#endif
    {0, 0},
};
static PyType_Spec __pyx_GeneratorType_spec = {
    __PYX_TYPE_MODULE_PREFIX "generator",
    sizeof(__pyx_CoroutineObject),
    0,
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_WEAKREF |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | __Pyx_TPFLAGS_HAVE_AM_SEND,
    __pyx_GeneratorType_slots
};
#if __PYX_HAS_PY_AM_SEND == 2
static __Pyx_PyAsyncMethodsStruct __pyx_Generator_as_async;
#endif
static int __pyx_Generator_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_GeneratorType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_GeneratorType_spec, NULL);
    if (unlikely(!mstate->__pyx_GeneratorType)) {
        return -1;
    }
#if __PYX_HAS_PY_AM_SEND == 2
    __Pyx_SetBackportTypeAmSend(mstate->__pyx_GeneratorType, &__pyx_Generator_as_async, &__Pyx_Coroutine_AmSend);
#endif
    return 0;
}
static PyObject *__Pyx_Generator_GetInlinedResult(PyObject *self) {
    __pyx_CoroutineObject *gen = (__pyx_CoroutineObject*) self;
    PyObject *retval = NULL;
    if (unlikely(__Pyx_Coroutine_test_and_set_is_running(gen))) {
        return __Pyx_Coroutine_AlreadyRunningError(gen);
    }
    __Pyx_PySendResult result = __Pyx_Coroutine_SendEx(gen, Py_None, &retval, 0);
    __Pyx_Coroutine_unset_is_running(gen);
    (void) result;
    assert (result == PYGEN_RETURN || result == PYGEN_ERROR);
    assert ((result == PYGEN_RETURN && retval != NULL) || (result == PYGEN_ERROR && retval == NULL));
    return retval;
}

/* GeneratorYieldFrom */
#if CYTHON_USE_TYPE_SLOTS
static void __Pyx_PyIter_CheckErrorAndDecref(PyObject *source) {
    __Pyx_TypeName source_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(source));
    PyErr_Format(PyExc_TypeError,
        "iter() returned non-iterator of type '" __Pyx_FMT_TYPENAME "'", source_type_name);
    __Pyx_DECREF_TypeName(source_type_name);
    Py_DECREF(source);
}
#endif
static CYTHON_INLINE __Pyx_PySendResult __Pyx_Generator_Yield_From(__pyx_CoroutineObject *gen, PyObject *source, PyObject **retval) {
    PyObject *source_gen;
    __Pyx_PySendResult result;
#ifdef __Pyx_Coroutine_USED
    if (__Pyx_Coroutine_Check(source)) {
        Py_INCREF(source);
        source_gen = source;
        result = __Pyx_Coroutine_AmSend(source, Py_None, retval);
    } else
#endif
    {
#if CYTHON_USE_TYPE_SLOTS
        if (likely(Py_TYPE(source)->tp_iter)) {
            source_gen = Py_TYPE(source)->tp_iter(source);
            if (unlikely(!source_gen)) {
                *retval = NULL;
                return PYGEN_ERROR;
            }
            if (unlikely(!PyIter_Check(source_gen))) {
                __Pyx_PyIter_CheckErrorAndDecref(source_gen);
                *retval = NULL;
                return PYGEN_ERROR;
            }
        } else
#endif
        {
            source_gen = PyObject_GetIter(source);
            if (unlikely(!source_gen)) {
                *retval = NULL;
                return PYGEN_ERROR;
            }
        }
        *retval = __Pyx_PyIter_Next_Plain(source_gen);
        result = __Pyx_Coroutine_status_from_result(retval);
    }
    if (likely(result == PYGEN_NEXT)) {
        __Pyx_Coroutine_Set_Owned_Yield_From(gen, source_gen);
        return PYGEN_NEXT;
    }
    Py_DECREF(source_gen);
    return result;
}

/* RaiseUnboundLocalError */
static void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* RaiseClosureNameError */
static void __Pyx_RaiseClosureNameError(const char *varname) {
    PyErr_Format(PyExc_NameError, "free variable '%s' referenced before assignment in enclosing scope", varname);
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d0000
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyUnicode_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* HasAttr (used by ImportImpl) */
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!PyUnicode_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_PyObject_GetAttrStrNoError(o, n);
    if (!r) {
        return (unlikely(PyErr_Occurred())) ? -1 : 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ImportImpl (used by Import) */
static int __Pyx__Import_GetModule(PyObject *qualname, PyObject **module) {
    PyObject *imported_module = PyImport_GetModule(qualname);
    if (unlikely(!imported_module)) {
        *module = NULL;
        if (PyErr_Occurred()) {
            return -1;
        }
        return 0;
    }
    *module = imported_module;
    return 1;
}
static int __Pyx__Import_Lookup(PyObject *qualname, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject **module) {
    PyObject *imported_module;
    PyObject *top_level_package_name;
    Py_ssize_t i;
    int status, module_found;
    Py_ssize_t dot_index;
    module_found = __Pyx__Import_GetModule(qualname, &imported_module);
    if (unlikely(!module_found || module_found == -1)) {
        *module = NULL;
        return module_found;
    }
    if (imported_names) {
        for (i = 0; i < len_imported_names; i++) {
            PyObject *imported_name = imported_names[i];
#if __PYX_LIMITED_VERSION_HEX < 0x030d0000
            int has_imported_attribute = PyObject_HasAttr(imported_module, imported_name);
#else
            int has_imported_attribute = PyObject_HasAttrWithError(imported_module, imported_name);
            if (unlikely(has_imported_attribute == -1)) goto error;
#endif
            if (!has_imported_attribute) {
                goto not_found;
            }
        }
        *module = imported_module;
        return 1;
    }
    dot_index = PyUnicode_FindChar(qualname, '.', 0, PY_SSIZE_T_MAX, 1);
    if (dot_index == -1) {
        *module = imported_module;
        return 1;
    }
    if (unlikely(dot_index == -2)) goto error;
    top_level_package_name = PyUnicode_Substring(qualname, 0, dot_index);
    if (unlikely(!top_level_package_name)) goto error;
    Py_DECREF(imported_module);
    status = __Pyx__Import_GetModule(top_level_package_name, module);
    Py_DECREF(top_level_package_name);
    return status;
error:
    Py_DECREF(imported_module);
    *module = NULL;
    return -1;
not_found:
    Py_DECREF(imported_module);
    *module = NULL;
    return 0;
}
static PyObject *__Pyx__Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, PyObject *moddict, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *from_list = 0;
    int module_found;
    if (!qualname) {
        qualname = name;
    }
    module_found = __Pyx__Import_Lookup(qualname, imported_names, len_imported_names, &module);
    if (likely(module_found == 1)) {
        return module;
    } else if (unlikely(module_found == -1)) {
        return NULL;
    }
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    if (imported_names) {
#if CYTHON_COMPILING_IN_CPYTHON
        from_list = __Pyx_PyList_FromArray(imported_names, len_imported_names);
        if (unlikely(!from_list))
            goto bad;
#else
        from_list = PyList_New(len_imported_names);
        if (unlikely(!from_list)) goto bad;
        for (Py_ssize_t i=0; i<len_imported_names; ++i) {
            if (PyList_SetItem(from_list, i, __Pyx_NewRef(imported_names[i])) < 0) goto bad;
        }
#endif
    }
    if (level == -1) {
        const char* package_sep = strchr(__Pyx_MODULE_NAME, '.');
        if (package_sep != (0)) {
            module = PyImport_ImportModuleLevelObject(
                name, moddict, empty_dict, from_list, 1);
            if (unlikely(!module)) {
                if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                    goto bad;
                PyErr_Clear();
            }
        }
        level = 0;
    }
    if (!module) {
        module = PyImport_ImportModuleLevelObject(
            name, moddict, empty_dict, from_list, level);
    }
bad:
    Py_XDECREF(from_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *const *imported_names, Py_ssize_t len_imported_names, PyObject *qualname, int level) {
    return __Pyx__Import(name, imported_names, len_imported_names, qualname, __pyx_mstate_global->__pyx_d, level);
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_mstate_global->__pyx_kp_u__3);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400) ||\
                CYTHON_COMPILING_IN_GRAAL
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError, "cannot import name %S", name);
    }
    return value;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS)) {
        return __Pyx_PyList_GetItemRefFast(o, wrapped_i, unsafe_shared);
    } else
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyList_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        return __Pyx_NewRef(PyTuple_GET_ITEM(o, wrapped_i));
    }
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
#else
    (void)wraparound;
    (void)boundscheck;
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     int wraparound, int boundscheck, int unsafe_shared) {
    CYTHON_MAYBE_UNUSED_VAR(unsafe_shared);
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((CYTHON_AVOID_BORROWED_REFS || CYTHON_AVOID_THREAD_UNSAFE_BORROWED_REFS)) {
            return __Pyx_PyList_GetItemRefFast(o, n, unsafe_shared);
        } else if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            return __Pyx_NewRef(PyList_GET_ITEM(o, n));
        }
    } else
    #if !CYTHON_AVOID_BORROWED_REFS
    if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            return __Pyx_NewRef(PyTuple_GET_ITEM(o, n));
        }
    } else
    #endif
#endif
#if CYTHON_USE_TYPE_SLOTS && !CYTHON_COMPILING_IN_PYPY
    {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (!is_list && mm && mm->mp_subscript) {
            PyObject *r, *key = PyLong_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (is_list || likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    (void)wraparound;
    (void)boundscheck;
    return __Pyx_GetItemInt_Generic(o, PyLong_FromSsize_t(i));
}

/* PyLongCompare */
static CYTHON_INLINE int __Pyx_PyLong_BoolEqObjC(PyObject *op1, PyObject *op2, long intval, long inplace) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(inplace);
    if (op1 == op2) {
        return 1;
    }
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        int unequal;
        unsigned long uintval;
        Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
        const digit* digits = __Pyx_PyLong_Digits(op1);
        if (intval == 0) {
            return (__Pyx_PyLong_IsZero(op1) == 1);
        } else if (intval < 0) {
            if (__Pyx_PyLong_IsNonNeg(op1))
                return 0;
            intval = -intval;
        } else {
            if (__Pyx_PyLong_IsNeg(op1))
                return 0;
        }
        uintval = (unsigned long) intval;
#if PyLong_SHIFT * 4 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 4)) {
            unequal = (size != 5) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[4] != ((uintval >> (4 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 3 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 3)) {
            unequal = (size != 4) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[3] != ((uintval >> (3 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 2 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 2)) {
            unequal = (size != 3) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK)) | (digits[2] != ((uintval >> (2 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
#if PyLong_SHIFT * 1 < SIZEOF_LONG*8
        if (uintval >> (PyLong_SHIFT * 1)) {
            unequal = (size != 2) || (digits[0] != (uintval & (unsigned long) PyLong_MASK))
                 | (digits[1] != ((uintval >> (1 * PyLong_SHIFT)) & (unsigned long) PyLong_MASK));
        } else
#endif
            unequal = (size != 1) || (((unsigned long) digits[0]) != (uintval & (unsigned long) PyLong_MASK));
        return (unequal == 0);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = __Pyx_PyFloat_AS_DOUBLE(op1);
        return ((double)a == (double)b);
    }
    return __Pyx_PyObject_IsTrueAndDecref(
        PyObject_RichCompare(op1, op2, Py_EQ));
}

/* pybytes_as_double (used by pyobject_as_double) */
static double __Pyx_SlowPyString_AsDouble(PyObject *obj) {
    PyObject *float_value = PyFloat_FromString(obj);
    if (likely(float_value)) {
        double value = __Pyx_PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
    return (double)-1;
}
static const char* __Pyx__PyBytes_AsDouble_Copy(const char* start, char* buffer, Py_ssize_t length) {
    int last_was_punctuation = 1;
    int parse_error_found = 0;
    Py_ssize_t i;
    for (i=0; i < length; i++) {
        char chr = start[i];
        int is_punctuation = (chr == '_') | (chr == '.') | (chr == 'e') | (chr == 'E');
        *buffer = chr;
        buffer += (chr != '_');
        parse_error_found |= last_was_punctuation & is_punctuation;
        last_was_punctuation = is_punctuation;
    }
    parse_error_found |= last_was_punctuation;
    *buffer = '\0';
    return unlikely(parse_error_found) ? NULL : buffer;
}
static double __Pyx__PyBytes_AsDouble_inf_nan(const char* start, Py_ssize_t length) {
    int matches = 1;
    char sign = start[0];
    int is_signed = (sign == '+') | (sign == '-');
    start += is_signed;
    length -= is_signed;
    switch (start[0]) {
        #ifdef Py_NAN
        case 'n':
        case 'N':
            if (unlikely(length != 3)) goto parse_failure;
            matches &= (start[1] == 'a' || start[1] == 'A');
            matches &= (start[2] == 'n' || start[2] == 'N');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_NAN : Py_NAN;
        #endif
        case 'i':
        case 'I':
            if (unlikely(length < 3)) goto parse_failure;
            matches &= (start[1] == 'n' || start[1] == 'N');
            matches &= (start[2] == 'f' || start[2] == 'F');
            if (likely(length == 3 && matches))
                return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
            if (unlikely(length != 8)) goto parse_failure;
            matches &= (start[3] == 'i' || start[3] == 'I');
            matches &= (start[4] == 'n' || start[4] == 'N');
            matches &= (start[5] == 'i' || start[5] == 'I');
            matches &= (start[6] == 't' || start[6] == 'T');
            matches &= (start[7] == 'y' || start[7] == 'Y');
            if (unlikely(!matches)) goto parse_failure;
            return (sign == '-') ? -Py_HUGE_VAL : Py_HUGE_VAL;
        case '.': case '0': case '1': case '2': case '3': case '4': case '5': case '6': case '7': case '8': case '9':
            break;
        default:
            goto parse_failure;
    }
    return 0.0;
parse_failure:
    return -1.0;
}
static CYTHON_INLINE int __Pyx__PyBytes_AsDouble_IsSpace(char ch) {
    return (ch == 0x20) | !((ch < 0x9) | (ch > 0xd));
}
CYTHON_UNUSED static double __Pyx__PyBytes_AsDouble(PyObject *obj, const char* start, Py_ssize_t length) {
    double value;
    Py_ssize_t i, digits;
    const char *last = start + length;
    char *end;
    while (__Pyx__PyBytes_AsDouble_IsSpace(*start))
        start++;
    while (start < last - 1 && __Pyx__PyBytes_AsDouble_IsSpace(last[-1]))
        last--;
    length = last - start;
    if (unlikely(length <= 0)) goto fallback;
    value = __Pyx__PyBytes_AsDouble_inf_nan(start, length);
    if (unlikely(value == -1.0)) goto fallback;
    if (value != 0.0) return value;
    digits = 0;
    for (i=0; i < length; digits += start[i++] != '_');
    if (likely(digits == length)) {
        value = PyOS_string_to_double(start, &end, NULL);
    } else if (digits < 40) {
        char number[40];
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) goto fallback;
        value = PyOS_string_to_double(number, &end, NULL);
    } else {
        char *number = (char*) PyMem_Malloc((digits + 1) * sizeof(char));
        if (unlikely(!number)) goto fallback;
        last = __Pyx__PyBytes_AsDouble_Copy(start, number, length);
        if (unlikely(!last)) {
            PyMem_Free(number);
            goto fallback;
        }
        value = PyOS_string_to_double(number, &end, NULL);
        PyMem_Free(number);
    }
    if (likely(end == last) || (value == (double)-1 && PyErr_Occurred())) {
        return value;
    }
fallback:
    return __Pyx_SlowPyString_AsDouble(obj);
}

/* pyobject_as_double */
static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    if (PyUnicode_CheckExact(obj)) {
        return __Pyx_PyUnicode_AsDouble(obj);
    } else if (PyBytes_CheckExact(obj)) {
        return __Pyx_PyBytes_AsDouble(obj);
    } else if (PyByteArray_CheckExact(obj)) {
        return __Pyx_PyByteArray_AsDouble(obj);
    } else {
        PyObject* float_value;
#if !CYTHON_USE_TYPE_SLOTS
        float_value = PyNumber_Float(obj);  if ((0)) goto bad;
        (void)__Pyx_PyObject_CallOneArg;
#else
        PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
        if (likely(nb) && likely(nb->nb_float)) {
            float_value = nb->nb_float(obj);
            if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
                __Pyx_TypeName float_value_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(float_value));
                PyErr_Format(PyExc_TypeError,
                    "__float__ returned non-float (type " __Pyx_FMT_TYPENAME ")",
                    float_value_type_name);
                __Pyx_DECREF_TypeName(float_value_type_name);
                Py_DECREF(float_value);
                goto bad;
            }
        } else {
            float_value = __Pyx_PyObject_CallOneArg((PyObject*)&PyFloat_Type, obj);
        }
#endif
        if (likely(float_value)) {
            double value = __Pyx_PyFloat_AS_DOUBLE(float_value);
            Py_DECREF(float_value);
            return value;
        }
    }
bad:
    return (double)-1;
}

/* IterNext */
static PyObject *__Pyx_PyIter_Next2Default(PyObject* defval) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (!defval || unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return NULL;
        __Pyx_PyErr_Clear();
        Py_INCREF(defval);
        return defval;
    }
    if (defval) {
        Py_INCREF(defval);
        return defval;
    }
    __Pyx_PyErr_SetNone(PyExc_StopIteration);
    return NULL;
}
static void __Pyx_PyIter_Next_ErrorNoIterator(PyObject *iterator) {
    __Pyx_TypeName iterator_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(iterator));
    PyErr_Format(PyExc_TypeError,
        __Pyx_FMT_TYPENAME " object is not an iterator", iterator_type_name);
    __Pyx_DECREF_TypeName(iterator_type_name);
}
static CYTHON_INLINE PyObject *__Pyx_PyIter_Next2(PyObject* iterator, PyObject* defval) {
    PyObject* next;
#if !CYTHON_COMPILING_IN_LIMITED_API
    iternextfunc iternext = __Pyx_PyObject_TryGetSlot(iterator, tp_iternext, iternextfunc);
    if (likely(iternext)) {
        next = iternext(iterator);
        if (likely(next))
            return next;
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
        if (unlikely(iternext == &_PyObject_NextNotImplemented))
            return NULL;
    #endif
    } else if (CYTHON_USE_TYPE_SLOTS) {
        __Pyx_PyIter_Next_ErrorNoIterator(iterator);
        return NULL;
    } else
#endif
    if (unlikely(!PyIter_Check(iterator))) {
        __Pyx_PyIter_Next_ErrorNoIterator(iterator);
        return NULL;
    } else {
        next = defval ? PyIter_Next(iterator) : __Pyx_PyIter_Next_Plain(iterator);
        if (likely(next))
            return next;
    }
    return __Pyx_PyIter_Next2Default(defval);
}

/* PyObjectCallMethod0 (used by pop) */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
#if CYTHON_VECTORCALL && (__PYX_LIMITED_VERSION_HEX >= 0x030C0000 || (!CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x03090000))
    PyObject *args[1] = {obj};
    (void) __Pyx_PyObject_CallOneArg;
    (void) __Pyx_PyObject_CallNoArg;
    return PyObject_VectorcallMethod(method_name, args, 1 | PY_VECTORCALL_ARGUMENTS_OFFSET, NULL);
#else
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
#endif
}

/* pop */
static CYTHON_INLINE PyObject* __Pyx__PyObject_Pop(PyObject* L) {
    if (__Pyx_IS_TYPE(L, &PySet_Type)) {
        return PySet_Pop(L);
    }
    return __Pyx_PyObject_CallMethod0(L, __pyx_mstate_global->__pyx_n_u_pop);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
static CYTHON_INLINE PyObject* __Pyx_PyList_Pop(PyObject* L) {
    if (likely(PyList_GET_SIZE(L) > (((PyListObject*)L)->allocated >> 1))) {
        __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
        return PyList_GET_ITEM(L, PyList_GET_SIZE(L));
    }
    return __Pyx_CallUnboundCMethod0(&__pyx_mstate_global->__pyx_umethod_PyList_Type_pop, L);
}
#endif

/* PyObjectFormatAndDecref */
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatSimpleAndDecref(PyObject* s, PyObject* f) {
    if (unlikely(!s)) return NULL;
    if (likely(PyUnicode_CheckExact(s))) return s;
    return __Pyx_PyObject_FormatAndDecref(s, f);
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_FormatAndDecref(PyObject* s, PyObject* f) {
    PyObject *result;
    if (unlikely(!s)) return NULL;
    result = PyObject_Format(s, f);
    Py_DECREF(s);
    return result;
}

/* decode_c_string */
static CYTHON_INLINE PyObject* __Pyx_decode_c_string(
         const char* cstring, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    Py_ssize_t length;
    if (unlikely((start < 0) | (stop < 0))) {
        size_t slen = strlen(cstring);
        if (unlikely(slen > (size_t) PY_SSIZE_T_MAX)) {
            PyErr_SetString(PyExc_OverflowError,
                            "c-string too long to convert to Python");
            return NULL;
        }
        length = (Py_ssize_t) slen;
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (unlikely(stop <= start))
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    length = stop - start;
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* decode_c_bytes (used by decode_bytes) */
static CYTHON_INLINE PyObject* __Pyx_decode_c_bytes(
         const char* cstring, Py_ssize_t length, Py_ssize_t start, Py_ssize_t stop,
         const char* encoding, const char* errors,
         PyObject* (*decode_func)(const char *s, Py_ssize_t size, const char *errors)) {
    if (unlikely((start < 0) | (stop < 0))) {
        if (start < 0) {
            start += length;
            if (start < 0)
                start = 0;
        }
        if (stop < 0)
            stop += length;
    }
    if (stop > length)
        stop = length;
    if (unlikely(stop <= start))
        return __Pyx_NewRef(__pyx_mstate_global->__pyx_empty_unicode);
    length = stop - start;
    cstring += start;
    if (decode_func) {
        return decode_func(cstring, length, errors);
    } else {
        return PyUnicode_Decode(cstring, length, encoding, errors);
    }
}

/* PyUnicode_Unicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_Unicode(PyObject *obj) {
    if (unlikely(obj == Py_None))
        obj = __pyx_mstate_global->__pyx_kp_u_None;
    return __Pyx_NewRef(obj);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_mstate_global->__pyx_n_u_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* ModInt[int64_t] */
static CYTHON_INLINE int64_t __Pyx_mod_int64_t(int64_t a, int64_t b, int b_is_constant) {
    int64_t r = a % b;
    int64_t adapt_python = (b_is_constant ?
        ((r != 0) & ((r < 0) ^ (b < 0))) :
        ((r != 0) & ((r ^ b) < 0))
    );
    return r + adapt_python * b;
}

/* PyObjectVectorCallMethodKwBuilder */
#if !CYTHON_VECTORCALL || PY_VERSION_HEX < 0x03090000
static PyObject *__Pyx_Object_VectorcallMethod_CallFromBuilder(PyObject *name, PyObject *const *args, size_t nargsf, PyObject *kwnames) {
    PyObject *result;
    PyObject *obj = PyObject_GetAttr(args[0], name);
    if (unlikely(!obj))
        return NULL;
    result = __Pyx_Object_Vectorcall_CallFromBuilder(obj, args+1, nargsf-1, kwnames);
    Py_DECREF(obj);
    return result;
}
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_MultiplyCObj(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long a = intval;
    long b;
    const PY_LONG_LONG lla = intval;
    PY_LONG_LONG llb;
    if (unlikely(__Pyx_PyLong_IsZero(op2))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op2);
    const digit* digits = __Pyx_PyLong_Digits(op2);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op2);
    if (likely(size == 1)) {
        b = (long) digits[0];
        if (!is_positive) b *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                    b = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) b *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                    llb = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) llb *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                    b = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) b *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                    llb = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) llb *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                    b = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) b *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                    llb = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) llb *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
    }
    calculate_long:
        CYTHON_UNUSED_VAR(a);
        CYTHON_UNUSED_VAR(b);
        llb = b;
        goto calculate_long_long;
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla * llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_MultiplyCObj(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long a = intval;
    double b = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) * (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_MultiplyCObj(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op2))) {
        return __Pyx_Unpacked___Pyx_PyLong_MultiplyCObj(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op2)) {
        return __Pyx_Float___Pyx_PyLong_MultiplyCObj(op2, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_MultiplyCObj(op1, op2, inplace);
}
#endif

/* DivInt[int64_t] */
static CYTHON_INLINE int64_t __Pyx_div_int64_t(int64_t a, int64_t b, int b_is_constant) {
    int64_t q = a / b;
    int64_t r = a - q*b;
    int64_t adapt_python = (b_is_constant ?
        ((r != 0) & ((r < 0) ^ (b < 0))) :
        ((r != 0) & ((r ^ b) < 0))
    );
    return q - adapt_python;
}

/* ModInt[long] */
static CYTHON_INLINE long __Pyx_mod_long(long a, long b, int b_is_constant) {
    long r = a % b;
    long adapt_python = (b_is_constant ?
        ((r != 0) & ((r < 0) ^ (b < 0))) :
        ((r != 0) & ((r ^ b) < 0))
    );
    return r + adapt_python * b;
}

/* bytes_tailmatch */
static int __Pyx_PyBytes_SingleTailmatch(PyObject* self, PyObject* arg,
                                         Py_ssize_t start, Py_ssize_t end, int direction) {
    char* self_ptr;
    Py_ssize_t self_len;
    char* sub_ptr;
    Py_ssize_t sub_len;
    int retval;
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030b0000
    PyObject *converted_arg = NULL;
    #else
    Py_buffer view;
    view.obj = NULL;
    #endif
    #if !(CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE)
    if (PyBytes_AsStringAndSize(self, &self_ptr, &self_len) == -1) return -1;
    #else
    self_ptr = PyBytes_AS_STRING(self);
    self_len = PyBytes_GET_SIZE(self);
    #endif
    if (PyBytes_Check(arg)) {
        #if !(CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE)
        if (PyBytes_AsStringAndSize(arg, &sub_ptr, &sub_len) == -1) return -1;
        #else
        sub_ptr = PyBytes_AS_STRING(arg);
        sub_len = PyBytes_GET_SIZE(arg);
        #endif
    }
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030b0000
    else if (PyByteArray_Check(arg)) {
        sub_ptr = PyByteArray_AsString(arg);
        if (unlikely(!sub_ptr)) return -1;
        sub_len = PyByteArray_Size(arg);
        if (unlikely(sub_len < 0)) return -1;
    } else {
        PyObject *as_memoryview = PyMemoryView_FromObject(arg);
        if (!as_memoryview) return -1;
        Py_DECREF(as_memoryview);
        converted_arg = PyBytes_FromObject(arg);
        if (!converted_arg) return -1;
        if (PyBytes_AsStringAndSize(converted_arg, &sub_ptr, &sub_len) == -1) {
            Py_DECREF(converted_arg);
            return -1;
        }
    }
    #else // LIMITED_API >= 030B0000 or !LIMITED_API
    else {
        if (unlikely(PyObject_GetBuffer(arg, &view, PyBUF_SIMPLE) == -1))
            return -1;
        sub_ptr = (char*) view.buf;
        sub_len = view.len;
    }
    #endif
    if (end > self_len)
        end = self_len;
    else if (end < 0)
        end += self_len;
    if (end < 0)
        end = 0;
    if (start < 0)
        start += self_len;
    if (start < 0)
        start = 0;
    if (direction > 0) {
        if (end-sub_len > start)
            start = end - sub_len;
    }
    if (start + sub_len <= end)
        retval = !memcmp(self_ptr+start, sub_ptr, (size_t)sub_len);
    else
        retval = 0;
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030b0000
    Py_XDECREF(converted_arg);
    #else
    if (view.obj)
        PyBuffer_Release(&view);
    #endif
    return retval;
}
static int __Pyx_PyBytes_TailmatchTuple(PyObject* self, PyObject* substrings,
                                        Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = __Pyx_PyTuple_GET_SIZE(substrings);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(count < 0)) return -1;
    #endif
    for (i = 0; i < count; i++) {
        int result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = __Pyx_PyBytes_SingleTailmatch(self, PyTuple_GET_ITEM(substrings, i),
                                               start, end, direction);
#else
        PyObject* sub = __Pyx_PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = __Pyx_PyBytes_SingleTailmatch(self, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return result;
        }
    }
    return 0;
}
static int __Pyx_PyBytes_Tailmatch(PyObject* self, PyObject* substr,
                                   Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyBytes_TailmatchTuple(self, substr, start, end, direction);
    }
    return __Pyx_PyBytes_SingleTailmatch(self, substr, start, end, direction);
}

/* PyMethodNew (used by CythonFunctionShared) */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *result;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    #if __PYX_LIMITED_VERSION_HEX >= 0x030C0000
    {
        PyObject *args[] = {func, self};
        result = PyObject_Vectorcall(__pyx_mstate_global->__Pyx_CachedMethodType, args, 2, NULL);
    }
    #else
    result = PyObject_CallFunctionObjArgs(__pyx_mstate_global->__Pyx_CachedMethodType, func, self, NULL);
    #endif
    return result;
}
#else
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#endif

/* PyVectorcallFastCallDict (used by CythonFunctionShared) */
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i;
    #if CYTHON_AVOID_BORROWED_REFS
    PyObject *pos;
    #else
    Py_ssize_t pos;
    #endif
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    #if !CYTHON_ASSUME_SAFE_SIZE
    Py_ssize_t nkw = PyDict_Size(kw);
    if (unlikely(nkw == -1)) return NULL;
    #else
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    #endif
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = 0;
    i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (__Pyx_PyDict_NextRef(kw, &pos, &key, &value)) {
        keys_are_strings &=
        #if CYTHON_COMPILING_IN_LIMITED_API
            PyType_GetFlags(Py_TYPE(key));
        #else
            Py_TYPE(key)->tp_flags;
        #endif
        #if !CYTHON_ASSUME_SAFE_MACROS
        if (unlikely(PyTuple_SetItem(kwnames, i, key) < 0)) goto cleanup;
        #else
        PyTuple_SET_ITEM(kwnames, i, key);
        #endif
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(pos);
    #endif
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    Py_ssize_t kw_size =
        likely(kw == NULL) ?
        0 :
#if !CYTHON_ASSUME_SAFE_SIZE
        PyDict_Size(kw);
#else
        PyDict_GET_SIZE(kw);
#endif
    if (kw_size == 0) {
        return vc(func, args, nargs, NULL);
    }
#if !CYTHON_ASSUME_SAFE_SIZE
    else if (unlikely(kw_size == -1)) {
        return NULL;
    }
#endif
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared (used by CythonFunction) */
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunctionNoMethod(PyObject *func, void (*cfunc)(void)) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if ((PyObject*)Py_TYPE(func) == __pyx_mstate_global->__Pyx_CachedMethodType) {
        int result;
        PyObject *newFunc = PyObject_GetAttr(func, __pyx_mstate_global->__pyx_n_u_func);
        if (unlikely(!newFunc)) {
            PyErr_Clear(); // It's only an optimization, so don't throw an error
            return 0;
        }
        result = __Pyx__IsSameCyOrCFunctionNoMethod(newFunc, cfunc);
        Py_DECREF(newFunc);
        return result;
    }
    return __Pyx__IsSameCyOrCFunctionNoMethod(func, cfunc);
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void (*cfunc)(void)) {
    if (PyMethod_Check(func)) {
        func = PyMethod_GET_FUNCTION(func);
    }
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure) {
    PyObject *result;
    CYTHON_UNUSED_VAR(closure);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_doc_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name_locked(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#else
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_name_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    PyObject *result;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    Py_INCREF(op->func_qualname);
    result = op->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
#endif
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = NULL;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_defaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_kwdefaults_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    __Pyx_END_CRITICAL_SECTION();
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations_locked(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    result = __Pyx_CyFunction_get_annotations_locked(op);
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine_value(__pyx_CyFunctionObject *op) {
    int is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
    if (is_coroutine) {
        PyObject *is_coroutine_value, *module, *fromlist, *marker = __pyx_mstate_global->__pyx_n_u_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_mstate_global->__pyx_n_u_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        is_coroutine_value = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(is_coroutine_value)) {
            return is_coroutine_value;
        }
ignore:
        PyErr_Clear();
    }
    return __Pyx_PyBool_FromLong(is_coroutine);
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    PyObject *result;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    result = __Pyx_CyFunction_get_is_coroutine_value(op);
    if (unlikely(!result))
        return NULL;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    if (op->func_is_coroutine) {
        Py_DECREF(result);
        result = __Pyx_NewRef(op->func_is_coroutine);
    } else {
        op->func_is_coroutine = __Pyx_NewRef(result);
    }
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static void __Pyx_CyFunction_raise_argument_count_error(__pyx_CyFunctionObject *func, const char* message, Py_ssize_t size) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        py_name, message, size);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s (%" CYTHON_FORMAT_SSIZE_T "d given)",
        name, message, size);
#endif
}
static void __Pyx_CyFunction_raise_type_error(__pyx_CyFunctionObject *func, const char* message) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_name = __Pyx_CyFunction_get_name(func, NULL);
    if (!py_name) return;
    PyErr_Format(PyExc_TypeError,
        "%.200S() %s",
        py_name, message);
    Py_DECREF(py_name);
#else
    const char* name = ((PyCFunctionObject*)func)->m_ml->ml_name;
    PyErr_Format(PyExc_TypeError,
        "%.200s() %s",
        name, message);
#endif
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {"func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {"func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {"__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    {"func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)PyObject_GenericSetDict, 0, 0},
#else
    {"func_dict", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
    {"__dict__", (getter)PyObject_GenericGetDict, (setter)PyObject_GenericSetDict, 0, 0},
#endif
    {"func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {"func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {"func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {"func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {"__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {"__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {"_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    {"__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#endif
#if CYTHON_METH_FASTCALL
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
    {"__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {"__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    PyObject *result = NULL;
    CYTHON_UNUSED_VAR(args);
    __Pyx_BEGIN_CRITICAL_SECTION(m);
    Py_INCREF(m->func_qualname);
    result = m->func_qualname;
    __Pyx_END_CRITICAL_SECTION();
    return result;
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_dict = NULL;
#endif
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func_dict);
#elif PY_VERSION_HEX < 0x030d0000
    _PyObject_ClearManagedDict((PyObject*)m);
#else
    PyObject_ClearManagedDict((PyObject*)m);
#endif
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    Py_CLEAR(m->defaults);
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    {
        int e = __Pyx_call_type_traverse((PyObject*)m, 1, visit, arg);
        if (e) return e;
    }
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
#if PY_VERSION_HEX < 0x030C0000 || CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func_dict);
#else
    {
        int e =
#if PY_VERSION_HEX < 0x030d0000
            _PyObject_VisitManagedDict
#else
            PyObject_VisitManagedDict
#endif
                ((PyObject*)m, visit, arg);
        if (e != 0) return e;
    }
#endif
    __Pyx_VISIT_CONST(m->func_name);
    __Pyx_VISIT_CONST(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    __Pyx_VISIT_CONST(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    Py_VISIT(m->defaults);
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
    PyObject *repr;
    __Pyx_BEGIN_CRITICAL_SECTION(op);
    repr = PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
    __Pyx_END_CRITICAL_SECTION();
    return repr;
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void(*)(void))meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes no arguments", size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_SIZE
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
            __Pyx_CyFunction_raise_argument_count_error(
                (__pyx_CyFunctionObject*)func,
                "takes exactly one argument", size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
    __Pyx_CyFunction_raise_type_error(
        (__pyx_CyFunctionObject*)func, "takes no keyword arguments");
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS && CYTHON_ASSUME_SAFE_SIZE
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_SIZE
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(argc < 0)) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL && CYTHON_VECTORCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            __Pyx_CyFunction_raise_type_error(
                cyfunc, "needs an argument");
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(__Pyx_PyTuple_GET_SIZE(kwnames))) {
        __Pyx_CyFunction_raise_type_error(
            cyfunc, "takes no keyword arguments");
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes no arguments", nargs);
        return NULL;
    }
    return meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        __Pyx_CyFunction_raise_argument_count_error(
            cyfunc, "takes exactly one argument", nargs);
        return NULL;
    }
    return meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCFunctionFastWithKeywords)(void(*)(void))meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
    PyObject *self;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyCFunction meth = PyCFunction_GetFunction(cyfunc->func);
    if (unlikely(!meth)) return NULL;
#else
    PyCFunction meth = ((PyCFunctionObject*)cyfunc)->m_ml->ml_meth;
#endif
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
#if CYTHON_COMPILING_IN_LIMITED_API
        self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)cyfunc)->func);
        if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
        self = ((PyCFunctionObject*)cyfunc)->m_self;
#endif
        break;
    default:
        return NULL;
    }
    #if PY_VERSION_HEX < 0x030e00A6
    size_t nargs_value = (size_t) nargs;
    #else
    Py_ssize_t nargs_value = nargs;
    #endif
    return ((__Pyx_PyCMethod)(void(*)(void))meth)(self, cls, args, nargs_value, kwnames);
}
#endif
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if CYTHON_METH_FASTCALL
#if defined(Py_TPFLAGS_HAVE_VECTORCALL)
    Py_TPFLAGS_HAVE_VECTORCALL |
#elif defined(_Py_TPFLAGS_HAVE_VECTORCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
#endif // CYTHON_METH_FASTCALL
#if PY_VERSION_HEX >= 0x030C0000 && !CYTHON_COMPILING_IN_LIMITED_API
    Py_TPFLAGS_MANAGED_DICT |
#endif
    Py_TPFLAGS_IMMUTABLETYPE | Py_TPFLAGS_DISALLOW_INSTANTIATION |
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
static int __pyx_CyFunction_init(PyObject *module) {
    __pyx_mstatetype *mstate = __Pyx_PyModule_GetState(module);
    mstate->__pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(
        mstate->__pyx_CommonTypesMetaclassType, module, &__pyx_CyFunctionType_spec, NULL);
    if (unlikely(mstate->__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_InitDefaults(PyObject *func, PyTypeObject *defaults_type) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_CallObject((PyObject*)defaults_type, NULL); // _PyObject_New(defaults_type);
    if (unlikely(!m->defaults))
        return NULL;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_mstate_global->__pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* unicode_tailmatch */
static int __Pyx_PyUnicode_TailmatchTuple(PyObject* s, PyObject* substrings,
                                          Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = __Pyx_PyTuple_GET_SIZE(substrings);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(count < 0)) return -1;
    #endif
    for (i = 0; i < count; i++) {
        Py_ssize_t result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = PyUnicode_Tailmatch(s, PyTuple_GET_ITEM(substrings, i),
                                     start, end, direction);
#else
        PyObject* sub = __Pyx_PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = PyUnicode_Tailmatch(s, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return (int) result;
        }
    }
    return 0;
}
static int __Pyx_PyUnicode_Tailmatch(PyObject* s, PyObject* substr,
                                     Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyUnicode_TailmatchTuple(s, substr, start, end, direction);
    }
    return (int) PyUnicode_Tailmatch(s, substr, start, end, direction);
}

/* UnicodeConcatInPlace */
# if CYTHON_COMPILING_IN_CPYTHON
static int
__Pyx_unicode_modifiable(PyObject *unicode, int unsafe_shared)
{
    if (!__Pyx_IS_UNIQUELY_REFERENCED(unicode, unsafe_shared))
        return 0;
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030F0000
    if (PyUnstable_Unicode_GET_CACHED_HASH(unicode) != -1)
        return 0;
#endif
    if (!PyUnicode_CheckExact(unicode))
        return 0;
    if (PyUnicode_CHECK_INTERNED(unicode))
        return 0;
    return 1;
}
static CYTHON_INLINE PyObject *__Pyx_PyUnicode_ConcatInPlaceImpl(PyObject **p_left, PyObject *right, int unsafe_shared
        #if CYTHON_REFNANNY
        , void* __pyx_refnanny
        #endif
    ) {
    PyObject *left = *p_left;
    Py_ssize_t left_len, right_len, new_len;
    if (unlikely(__Pyx_PyUnicode_READY(left) == -1))
        return NULL;
    if (unlikely(__Pyx_PyUnicode_READY(right) == -1))
        return NULL;
    left_len = PyUnicode_GET_LENGTH(left);
    if (left_len == 0) {
        Py_INCREF(right);
        return right;
    }
    right_len = PyUnicode_GET_LENGTH(right);
    if (right_len == 0) {
        Py_INCREF(left);
        return left;
    }
    if (unlikely(left_len > PY_SSIZE_T_MAX - right_len)) {
        PyErr_SetString(PyExc_OverflowError,
                        "strings are too large to concat");
        return NULL;
    }
    new_len = left_len + right_len;
    if (__Pyx_unicode_modifiable(left, unsafe_shared)
            && PyUnicode_CheckExact(right)
            && PyUnicode_KIND(right) <= PyUnicode_KIND(left)
            && !(PyUnicode_IS_ASCII(left) && !PyUnicode_IS_ASCII(right))) {
        int ret;
        __Pyx_GIVEREF(*p_left);
        ret = PyUnicode_Resize(p_left, new_len);
        __Pyx_GOTREF(*p_left);
        if (unlikely(ret != 0))
            return NULL;
        #if PY_VERSION_HEX >= 0x030d0000
        if (unlikely(PyUnicode_CopyCharacters(*p_left, left_len, right, 0, right_len) < 0)) return NULL;
        #else
        _PyUnicode_FastCopyCharacters(*p_left, left_len, right, 0, right_len);
        #endif
        __Pyx_INCREF(*p_left);
        __Pyx_GIVEREF(*p_left);
        return *p_left;
    } else {
        return __Pyx_PyUnicode_Concat(left, right);
    }
  }
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_MultiplyObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceMultiply : PyNumber_Multiply)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op1);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT+30) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT+30) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT+30) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT+30) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT+30) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT+30) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_multiply(op1, op2);
    }
    calculate_long:
        CYTHON_UNUSED_VAR(a);
        CYTHON_UNUSED_VAR(b);
        lla = a;
        goto calculate_long_long;
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla * llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_MultiplyObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) * (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_MultiplyObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_MultiplyObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_MultiplyObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_MultiplyObjC(op1, op2, inplace);
}
#endif

/* DictGetItem */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    if (unlikely(__Pyx_PyDict_GetItemRef(d, key, &value) == 0)) { // no value, no error
        if (unlikely(PyTuple_Check(key))) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args)) {
                PyErr_SetObject(PyExc_KeyError, args);
                Py_DECREF(args);
            }
        } else {
            PyErr_SetObject(PyExc_KeyError, key);
        }
    }
    return value;
}
#endif

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_uchar___Pyx_PyUnicode_From_uint16_t(uint16_t value, Py_ssize_t width, char padding_char) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint16_t neg_one = (uint16_t) -1, const_zero = (uint16_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!(is_unsigned || value == 0 || value > 0) ||
                    !(sizeof(value) <= 2 || value & ~ (uint16_t) 0x01fffff || __Pyx_CheckUnicodeValue((int) value)))) {
        PyErr_SetString(PyExc_OverflowError, "%c arg not in range(0x110000)");
        return NULL;
    }
    if (width <= 1) {
        return PyUnicode_FromOrdinal((int) value);
    }
    return __Pyx_PyUnicode_FromOrdinal_Padded((int) value, width, padding_char);
}
static CYTHON_INLINE PyObject* __Pyx____Pyx_PyUnicode_From_uint16_t(uint16_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(uint16_t)*3+2];
    char *dpos, *end = digits + sizeof(uint16_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    uint16_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint16_t neg_one = (uint16_t) -1, const_zero = (uint16_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (uint16_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (uint16_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (uint16_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_RemainderObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceRemainder : PyNumber_Remainder)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op1);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_remainder(op1, op2);
    }
    calculate_long:
        {
            long x = a % b;
            x += ((x != 0) & ((x ^ b) < 0)) * b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx = lla % llb;
            llx += ((llx != 0) & ((llx ^ llb) < 0)) * llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyLong_RemainderObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_RemainderObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    return __Pyx_Fallback___Pyx_PyLong_RemainderObjC(op1, op2, inplace);
}
#endif

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_FloorDivideObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceFloorDivide : PyNumber_FloorDivide)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op1);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_floor_divide(op1, op2);
    }
    calculate_long:
        {
            long q, r;
            q = a / b;
            r = a - q*b;
            q -= ((r != 0) & ((r ^ b) < 0));
            return PyLong_FromLong(q);
        }
    calculate_long_long:
        {
            PY_LONG_LONG q, r;
            q = lla / llb;
            r = lla - q*llb;
            q -= ((r != 0) & ((r ^ llb) < 0));
            return PyLong_FromLongLong(q);
        }
    
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyLong_FloorDivideObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_FloorDivideObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    return __Pyx_Fallback___Pyx_PyLong_FloorDivideObjC(op1, op2, inplace);
}
#endif

/* RejectKeywords */
static void __Pyx_RejectKeywords(const char* function_name, PyObject *kwds) {
    PyObject *key = NULL;
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds))) {
        key = __Pyx_PySequence_ITEM(kwds, 0);
    } else {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *pos = NULL;
#else
        Py_ssize_t pos = 0;
#endif
#if !CYTHON_COMPILING_IN_PYPY || defined(PyArg_ValidateKeywordArguments)
        if (unlikely(!PyArg_ValidateKeywordArguments(kwds))) return;
#endif
        __Pyx_PyDict_NextRef(kwds, &pos, &key, NULL);
#if CYTHON_AVOID_BORROWED_REFS
        Py_XDECREF(pos);
#endif
    }
    if (likely(key)) {
        PyErr_Format(PyExc_TypeError,
            "%s() got an unexpected keyword argument '%U'",
            function_name, key);
        Py_DECREF(key);
    }
}

/* AllocateExtensionType */
static PyObject *__Pyx_AllocateExtensionType(PyTypeObject *t, int is_final) {
    if (is_final || likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
        allocfunc alloc_func = __Pyx_PyType_GetSlot(t, tp_alloc, allocfunc);
        return alloc_func(t, 0);
    } else {
        newfunc tp_new = __Pyx_PyType_TryGetSlot(&PyBaseObject_Type, tp_new, newfunc);
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (!tp_new) {
            PyObject *new_str = PyUnicode_FromString("__new__");
            if (likely(new_str)) {
                PyObject *o = PyObject_CallMethodObjArgs((PyObject *)&PyBaseObject_Type, new_str, t, NULL);
                Py_DECREF(new_str);
                return o;
            } else
                return NULL;
        } else
    #endif
        return tp_new(t, __pyx_mstate_global->__pyx_empty_tuple, 0);
    }
}

/* ValidateBasesTuple (used by PyType_Ready) */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_SIZE
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (unlikely(n < 0)) return -1;
#endif
    for (i = 1; i < n; i++)
    {
        PyTypeObject *b;
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetFullyQualifiedName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !CYTHON_USE_TYPE_SLOTS
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
CYTHON_UNUSED static int __Pyx_PyType_HasMultipleInheritance(PyTypeObject *t) {
    while (t) {
        PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
        if (bases) {
            return 1;
        }
        t = __Pyx_PyType_GetSlot(t, tp_base, PyTypeObject*);
    }
    return 0;
}
static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !CYTHON_COMPILING_IN_CPYTHON || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    if (!__Pyx_PyType_HasMultipleInheritance(t)) {
        return PyType_Ready(t);
    }
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400) &&\
                !CYTHON_COMPILING_IN_GRAAL
        gc = PyImport_GetModule(__pyx_mstate_global->__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_mstate_global->__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_mstate_global->__pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetVTable */
static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable (used by MergeVTables) */
static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_mstate_global->__pyx_n_u_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i=0;
    Py_ssize_t size;
    void** base_vtables;
    __Pyx_TypeName tp_base_name = NULL;
    __Pyx_TypeName base_name = NULL;
    void* unknown = (void*)-1;
    PyObject* bases = __Pyx_PyType_GetSlot(type, tp_bases, PyObject*);
    int base_depth = 0;
    {
        PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        while (base) {
            base_depth += 1;
            base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
        }
    }
    base_vtables = (void**) PyMem_Malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
#if CYTHON_COMPILING_IN_LIMITED_API
    size = PyTuple_Size(bases);
    if (size < 0) goto other_failure;
#else
    size = PyTuple_GET_SIZE(bases);
#endif
    for (i = 1; i < size; i++) {
        PyObject *basei;
        void* base_vtable;
#if CYTHON_AVOID_BORROWED_REFS
        basei = PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto other_failure;
#else
        basei = PyTuple_GET_ITEM(bases, i);
#endif
        base_vtable = __Pyx_GetVtable((PyTypeObject*)basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = __Pyx_PyType_GetSlot(base, tp_base, PyTypeObject*);
            }
        }
    }
    PyErr_Clear();
    PyMem_Free(base_vtables);
    return 0;
bad:
    {
        PyTypeObject* basei = NULL;
        PyTypeObject* tp_base = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
        tp_base_name = __Pyx_PyType_GetFullyQualifiedName(tp_base);
#if CYTHON_AVOID_BORROWED_REFS
        basei = (PyTypeObject*)PySequence_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#elif !CYTHON_ASSUME_SAFE_MACROS
        basei = (PyTypeObject*)PyTuple_GetItem(bases, i);
        if (unlikely(!basei)) goto really_bad;
#else
        basei = (PyTypeObject*)PyTuple_GET_ITEM(bases, i);
#endif
        base_name = __Pyx_PyType_GetFullyQualifiedName(basei);
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(basei);
#endif
    }
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
#if CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
really_bad: // bad has failed!
#endif
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_AVOID_BORROWED_REFS || !CYTHON_ASSUME_SAFE_MACROS
other_failure:
#endif
    PyMem_Free(base_vtables);
    return -1;
}

/* DelItemOnTypeDict (used by SetupReduce) */
static int __Pyx__DelItemOnTypeDict(PyTypeObject *tp, PyObject *k) {
    int result;
    PyObject *tp_dict;
#if CYTHON_COMPILING_IN_LIMITED_API
    tp_dict = __Pyx_GetTypeDict(tp);
    if (unlikely(!tp_dict)) return -1;
#else
    tp_dict = tp->tp_dict;
#endif
    result = PyDict_DelItem(tp_dict, k);
    if (likely(!result)) PyType_Modified(tp);
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_mstate_global->__pyx_n_u_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_mstate_global->__pyx_n_u_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_mstate_global->__pyx_n_u_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_mstate_global->__pyx_n_u_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython);
            if (likely(reduce_cython)) {
                ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_mstate_global->__pyx_n_u_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = __Pyx_SetItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = __Pyx_DelItemOnTypeDict((PyTypeObject*)type_obj, __pyx_mstate_global->__pyx_n_u_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetFullyQualifiedName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType_3_2_4
#define __PYX_HAVE_RT_ImportType_3_2_4
static PyTypeObject *__Pyx_ImportType_3_2_4(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_2_4 check_size)
{
    PyObject *result = 0;
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API)
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !( defined(Py_LIMITED_API) || (defined(CYTHON_COMPILING_IN_LIMITED_API) && CYTHON_COMPILING_IN_LIMITED_API) )
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    if (size == 0) {
        return (PyTypeObject *)result;
    }
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_2_4 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_2_4 && (size_t)basicsize > size) {
        if (PyErr_WarnFormat(NULL, 0,
                "%.200s.%.200s size changed, may indicate binary incompatibility. "
                "Expected %zd from C header, got %zd from PyObject",
                module_name, class_name, size, basicsize) < 0) {
            goto bad;
        }
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* PxdImportShared (used by FunctionImport) */
#ifndef __PYX_HAVE_RT_ImportFromPxd_3_2_4
#define __PYX_HAVE_RT_ImportFromPxd_3_2_4
static int __Pyx_ImportFromPxd_3_2_4(PyObject *module, const char *name, void **p, const char *sig, const char *what) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, "__pyx_capi__");
    if (!d)
        goto bad;
#if (defined(Py_LIMITED_API) && Py_LIMITED_API >= 0x030d0000) || (!defined(Py_LIMITED_API) && PY_VERSION_HEX >= 0x030d0000)
    PyDict_GetItemStringRef(d, name, &cobj);
#else
    cobj = PyDict_GetItemString(d, name);
    Py_XINCREF(cobj);
#endif
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C %.8s %.200s",
                PyModule_GetName(module), what, name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C %.8s %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             what, PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    Py_DECREF(cobj);
    return 0;
bad:
    Py_XDECREF(d);
    Py_XDECREF(cobj);
    return -1;
}
#endif

/* FunctionImport */
#ifndef __PYX_HAVE_RT_ImportFunction_3_2_4
#define __PYX_HAVE_RT_ImportFunction_3_2_4
static int __Pyx_ImportFunction_3_2_4(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    int result = __Pyx_ImportFromPxd_3_2_4(module, funcname, &tmp.p, sig, "function");
    if (result == 0) {
        *f = tmp.fp;
    }
    return result;
}
#endif

/* ClassMethod */
static PyObject* __Pyx_Method_ClassMethod(PyObject *method) {
#if CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM <= 0x05080000
    if (PyObject_TypeCheck(method, &PyWrapperDescr_Type)) {
        return PyClassMethod_New(method);
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (PyMethodDescr_Check(method))
#else
    if (__Pyx_TypeCheck(method, &PyMethodDescr_Type))
#endif
    {
#if CYTHON_COMPILING_IN_LIMITED_API
        return PyErr_Format(
            PyExc_SystemError,
            "Cython cannot yet handle classmethod on a MethodDescriptorType (%S) in limited API mode. "
            "This is most likely a classmethod in a cdef class method with binding=False. "
            "Try setting 'binding' to True.",
            method);
#elif CYTHON_COMPILING_IN_GRAAL && defined(GRAALPY_VERSION_NUM) && GRAALPY_VERSION_NUM > 0x19000000
        PyTypeObject *d_type = GraalPyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, GraalPyMethodDescrObject_GetMethod(method));
#elif CYTHON_COMPILING_IN_GRAAL
        PyTypeObject *d_type = PyDescrObject_GetType(method);
        return PyDescr_NewClassMethod(d_type, PyMethodDescrObject_GetMethod(method));
#else
        PyMethodDescrObject *descr = (PyMethodDescrObject *)method;
        PyTypeObject *d_type = descr->d_common.d_type;
        return PyDescr_NewClassMethod(d_type, descr->d_method);
#endif
    }
#endif
#if !CYTHON_COMPILING_IN_LIMITED_API
    else if (PyMethod_Check(method)) {
        return PyClassMethod_New(PyMethod_GET_FUNCTION(method));
    }
    else {
        return PyClassMethod_New(method);
    }
#else
    {
        PyObject *func=NULL;
        PyObject *builtins, *classmethod, *classmethod_str, *result=NULL;
        if (__Pyx_TypeCheck(method, __pyx_mstate_global->__Pyx_CachedMethodType)) {
            func = PyObject_GetAttrString(method, "__func__");
            if (!func) goto bad;
        } else {
            func = method;
            Py_INCREF(func);
        }
        builtins = PyEval_GetBuiltins(); // borrowed
        if (unlikely(!builtins)) goto bad;
        classmethod_str = PyUnicode_FromString("classmethod");
        if (unlikely(!classmethod_str)) goto bad;
        classmethod = PyObject_GetItem(builtins, classmethod_str);
        Py_DECREF(classmethod_str);
        if (unlikely(!classmethod)) goto bad;
        result = PyObject_CallFunctionObjArgs(classmethod, func, NULL);
        Py_DECREF(classmethod);
        bad:
        Py_XDECREF(func);
        return result;
    }
#endif
}

/* GetNameInClass */
static PyObject *__Pyx__GetNameInClass(PyObject *nmspace, PyObject *name) {
    PyObject *result;
    PyObject *dict;
    assert(PyType_Check(nmspace));
#if CYTHON_USE_TYPE_SLOTS
    dict = ((PyTypeObject*)nmspace)->tp_dict;
    Py_XINCREF(dict);
#else
    dict = PyObject_GetAttr(nmspace, __pyx_mstate_global->__pyx_n_u_dict);
#endif
    if (likely(dict)) {
        result = PyObject_GetItem(dict, name);
        Py_DECREF(dict);
        if (result) {
            return result;
        }
    }
    PyErr_Clear();
    __Pyx_GetModuleGlobalNameUncached(result, name);
    return result;
}

/* PyLongBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_Fallback___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, int inplace) {
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#if CYTHON_USE_PYLONG_INTERNALS
static PyObject* __Pyx_Unpacked___Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(inplace);
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    long a;
    const PY_LONG_LONG llb = intval;
    PY_LONG_LONG lla;
    if (unlikely(__Pyx_PyLong_IsZero(op1))) {
        return __Pyx_NewRef(op2);
    }
    const int is_positive = __Pyx_PyLong_IsPos(op1);
    const digit* digits = __Pyx_PyLong_Digits(op1);
    const Py_ssize_t size = __Pyx_PyLong_DigitCount(op1);
    if (likely(size == 1)) {
        a = (long) digits[0];
        if (!is_positive) a *= -1;
    } else {
        switch (size) {
            case 2:
                if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                    a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 3:
                if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                    a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
            case 4:
                if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                    a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if (!is_positive) a *= -1;
                    goto calculate_long;
                } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                    lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                    if (!is_positive) lla *= -1;
                    goto calculate_long_long;
                }
                break;
        }
        return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    calculate_long:
        {
            long x;
            x = a + b;
            return PyLong_FromLong(x);
        }
    calculate_long_long:
        {
            PY_LONG_LONG llx;
            llx = lla + llb;
            return PyLong_FromLongLong(llx);
        }
    
}
#endif
static PyObject* __Pyx_Float___Pyx_PyLong_AddObjC(PyObject *float_val, long intval, int zerodivision_check) {
    CYTHON_UNUSED_VAR(zerodivision_check);
    const long b = intval;
    double a = __Pyx_PyFloat_AS_DOUBLE(float_val);
        double result;
        
        result = ((double)a) + (double)b;
        return PyFloat_FromDouble(result);
}
static CYTHON_INLINE PyObject* __Pyx_PyLong_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check) {
    CYTHON_MAYBE_UNUSED_VAR(intval);
    CYTHON_UNUSED_VAR(zerodivision_check);
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        return __Pyx_Unpacked___Pyx_PyLong_AddObjC(op1, op2, intval, inplace, zerodivision_check);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        return __Pyx_Float___Pyx_PyLong_AddObjC(op1, intval, zerodivision_check);
    }
    return __Pyx_Fallback___Pyx_PyLong_AddObjC(op1, op2, inplace);
}
#endif

/* CLineInTraceback (used by AddTraceback) */
#if CYTHON_CLINE_IN_TRACEBACK && CYTHON_CLINE_IN_TRACEBACK_RUNTIME
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
#define __Pyx_PyProbablyModule_GetDict(o) __Pyx_XNewRef(PyModule_GetDict(o))
#elif !CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
#define __Pyx_PyProbablyModule_GetDict(o) PyObject_GenericGetDict(o, NULL);
#else
PyObject* __Pyx_PyProbablyModule_GetDict(PyObject *o) {
    PyObject **dict_ptr = _PyObject_GetDictPtr(o);
    return dict_ptr ? __Pyx_XNewRef(*dict_ptr) : NULL;
}
#endif
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline = NULL;
    PyObject *ptype, *pvalue, *ptraceback;
    PyObject *cython_runtime_dict;
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_mstate_global->__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
    cython_runtime_dict = __Pyx_PyProbablyModule_GetDict(__pyx_mstate_global->__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, cython_runtime_dict,
            __Pyx_PyDict_SetDefault(cython_runtime_dict, __pyx_mstate_global->__pyx_n_u_cline_in_traceback, Py_False))
    }
    if (use_cline == NULL || use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    Py_XDECREF(use_cline);
    Py_XDECREF(cython_runtime_dict);
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache (used by AddTraceback) */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static __Pyx_CachedCodeObjectType *__pyx__find_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line) {
    __Pyx_CachedCodeObjectType* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!code_cache->entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if (unlikely(pos >= code_cache->count) || unlikely(code_cache->entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = code_cache->entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static __Pyx_CachedCodeObjectType *__pyx_find_code_object(int code_line) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__find_code_object;
    return NULL; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just miss.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type old_count = __pyx_atomic_incr_acq_rel(&code_cache->accessor_count);
    if (old_count < 0) {
        __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
        return NULL;
    }
#endif
    __Pyx_CachedCodeObjectType *result = __pyx__find_code_object(code_cache, code_line);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_decr_acq_rel(&code_cache->accessor_count);
#endif
    return result;
#endif
}
static void __pyx__insert_code_object(struct __Pyx_CodeObjectCache *code_cache, int code_line, __Pyx_CachedCodeObjectType* code_object)
{
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = code_cache->entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            code_cache->entries = entries;
            code_cache->max_count = 64;
            code_cache->count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(code_cache->entries, code_cache->count, code_line);
    if ((pos < code_cache->count) && unlikely(code_cache->entries[pos].code_line == code_line)) {
        __Pyx_CachedCodeObjectType* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_INCREF(code_object);
        Py_DECREF(tmp);
        return;
    }
    if (code_cache->count == code_cache->max_count) {
        int new_max = code_cache->max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            code_cache->entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        code_cache->entries = entries;
        code_cache->max_count = new_max;
    }
    for (i=code_cache->count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    code_cache->count++;
    Py_INCREF(code_object);
}
static void __pyx_insert_code_object(int code_line, __Pyx_CachedCodeObjectType* code_object) {
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING && !CYTHON_ATOMICS
    (void)__pyx__insert_code_object;
    return; // Most implementation should have atomics. But otherwise, don't make it thread-safe, just fail.
#else
    struct __Pyx_CodeObjectCache *code_cache = &__pyx_mstate_global->__pyx_code_cache;
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_nonatomic_int_type expected = 0;
    if (!__pyx_atomic_int_cmp_exchange(&code_cache->accessor_count, &expected, INT_MIN)) {
        return;
    }
#endif
    __pyx__insert_code_object(code_cache, code_line, code_object);
#if CYTHON_COMPILING_IN_CPYTHON_FREETHREADING
    __pyx_atomic_sub(&code_cache->accessor_count, INT_MIN);
#endif
#endif
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API && !defined(PYPY_VERSION)
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result = PyObject_Call(replace, __pyx_mstate_global->__pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!code_object) {
        code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
        if (unlikely(!code_object)) goto bad;
        py_py_line = PyLong_FromLong(py_line);
        if (unlikely(!py_py_line)) goto bad;
        if (c_line) {
            py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        } else {
            py_funcname = PyUnicode_FromString(funcname);
        }
        if (unlikely(!py_funcname)) goto bad;
        dict = PyDict_New();
        if (unlikely(!dict)) goto bad;
        {
            PyObject *old_code_object = code_object;
            code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
            Py_DECREF(old_code_object);
        }
        if (unlikely(!code_object)) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, code_object);
    } else {
        dict = PyDict_New();
    }
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    if (c_line) {
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
    }
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_mstate_global->__pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

/* CheckUnpickleChecksum */
static void __Pyx_RaiseUnpickleChecksumError(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    PyObject *pickle_module = PyImport_ImportModule("pickle");
    if (unlikely(!pickle_module)) return;
    PyObject *pickle_error = PyObject_GetAttrString(pickle_module, "PickleError");
    Py_DECREF(pickle_module);
    if (unlikely(!pickle_error)) return;
    if (checksum2 == checksum1) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x) = (%s))",
            checksum, checksum1, members);
    } else if (checksum3 == checksum2) {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, members);
    } else {
        PyErr_Format(pickle_error, "Incompatible checksums (0x%x vs (0x%x, 0x%x, 0x%x) = (%s))",
            checksum, checksum1, checksum2, checksum3, members);
    }
    Py_DECREF(pickle_error);
}
static int __Pyx_CheckUnpickleChecksum(long checksum, long checksum1, long checksum2, long checksum3, const char *members) {
    int found = 0;
    found |= checksum1 == checksum;
    found |= checksum2 == checksum;
    found |= checksum3 == checksum;
    if (likely(found))
        return 0;
    __Pyx_RaiseUnpickleChecksumError(checksum, checksum1, checksum2, checksum3, members);
    return -1;
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From___pyx_anon_enum(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE Oid __Pyx_PyLong_As_Oid(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Oid neg_one = (Oid) -1, const_zero = (Oid) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        Oid val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (Oid) -1;
        val = __Pyx_PyLong_As_Oid(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(Oid, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(Oid) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) >= 2 * PyLong_SHIFT)) {
                            return (Oid) (((((Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(Oid) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) >= 3 * PyLong_SHIFT)) {
                            return (Oid) (((((((Oid)digits[2]) << PyLong_SHIFT) | (Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(Oid) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) >= 4 * PyLong_SHIFT)) {
                            return (Oid) (((((((((Oid)digits[3]) << PyLong_SHIFT) | (Oid)digits[2]) << PyLong_SHIFT) | (Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (Oid) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(Oid) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(Oid, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(Oid) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(Oid, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(Oid, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(Oid) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) - 1 > 2 * PyLong_SHIFT)) {
                            return (Oid) (((Oid)-1)*(((((Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(Oid) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) - 1 > 2 * PyLong_SHIFT)) {
                            return (Oid) ((((((Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(Oid) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) - 1 > 3 * PyLong_SHIFT)) {
                            return (Oid) (((Oid)-1)*(((((((Oid)digits[2]) << PyLong_SHIFT) | (Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(Oid) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) - 1 > 3 * PyLong_SHIFT)) {
                            return (Oid) ((((((((Oid)digits[2]) << PyLong_SHIFT) | (Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(Oid) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) - 1 > 4 * PyLong_SHIFT)) {
                            return (Oid) (((Oid)-1)*(((((((((Oid)digits[3]) << PyLong_SHIFT) | (Oid)digits[2]) << PyLong_SHIFT) | (Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(Oid) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(Oid, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(Oid) - 1 > 4 * PyLong_SHIFT)) {
                            return (Oid) ((((((((((Oid)digits[3]) << PyLong_SHIFT) | (Oid)digits[2]) << PyLong_SHIFT) | (Oid)digits[1]) << PyLong_SHIFT) | (Oid)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(Oid) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(Oid, long, PyLong_AsLong(x))
        } else if ((sizeof(Oid) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(Oid, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        Oid val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (Oid) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (Oid) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (Oid) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (Oid) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(Oid) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((Oid) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(Oid) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((Oid) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((Oid) 1) << (sizeof(Oid) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (Oid) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to Oid");
    return (Oid) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to Oid");
    return (Oid) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyLong_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyLong_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
        } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyLong_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyLong_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (long) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(long) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(long) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
        } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        long val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (long) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (long) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (long) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (long) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((long) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((long) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (long) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_Oid(Oid value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Oid neg_one = (Oid) -1, const_zero = (Oid) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(Oid) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(Oid) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(Oid) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(Oid) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(Oid) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(Oid),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(Oid));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_ExecStatusType(ExecStatusType value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const ExecStatusType neg_one = (ExecStatusType) -1, const_zero = (ExecStatusType) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(ExecStatusType) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(ExecStatusType) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(ExecStatusType) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(ExecStatusType) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(ExecStatusType) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(ExecStatusType),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(ExecStatusType));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE char __Pyx_PyLong_As_char(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        char val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (char) -1;
        val = __Pyx_PyLong_As_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) >= 2 * PyLong_SHIFT)) {
                            return (char) (((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) >= 3 * PyLong_SHIFT)) {
                            return (char) (((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) >= 4 * PyLong_SHIFT)) {
                            return (char) (((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (char) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(char) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(char) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(char) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                            return (char) (((char)-1)*(((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                            return (char) ((((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                            return (char) (((char)-1)*(((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                            return (char) ((((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                            return (char) (((char)-1)*(((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                            return (char) ((((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(char) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, long, PyLong_AsLong(x))
        } else if ((sizeof(char) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(char, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        char val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (char) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (char) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (char) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (char) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(char) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((char) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(char) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((char) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((char) 1) << (sizeof(char) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (char) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to char");
    return (char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to char");
    return (char) -1;
}

/* CIntFromPy */
static CYTHON_INLINE int32_t __Pyx_PyLong_As_int32_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int32_t neg_one = (int32_t) -1, const_zero = (int32_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        int32_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (int32_t) -1;
        val = __Pyx_PyLong_As_int32_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int32_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(int32_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) >= 2 * PyLong_SHIFT)) {
                            return (int32_t) (((((int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int32_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) >= 3 * PyLong_SHIFT)) {
                            return (int32_t) (((((((int32_t)digits[2]) << PyLong_SHIFT) | (int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int32_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) >= 4 * PyLong_SHIFT)) {
                            return (int32_t) (((((((((int32_t)digits[3]) << PyLong_SHIFT) | (int32_t)digits[2]) << PyLong_SHIFT) | (int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (int32_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(int32_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int32_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(int32_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int32_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(int32_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(int32_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (int32_t) (((int32_t)-1)*(((((int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(int32_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (int32_t) ((((((int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(int32_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (int32_t) (((int32_t)-1)*(((((((int32_t)digits[2]) << PyLong_SHIFT) | (int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(int32_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (int32_t) ((((((((int32_t)digits[2]) << PyLong_SHIFT) | (int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(int32_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (int32_t) (((int32_t)-1)*(((((((((int32_t)digits[3]) << PyLong_SHIFT) | (int32_t)digits[2]) << PyLong_SHIFT) | (int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(int32_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(int32_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(int32_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (int32_t) ((((((((((int32_t)digits[3]) << PyLong_SHIFT) | (int32_t)digits[2]) << PyLong_SHIFT) | (int32_t)digits[1]) << PyLong_SHIFT) | (int32_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(int32_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(int32_t, long, PyLong_AsLong(x))
        } else if ((sizeof(int32_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(int32_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        int32_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (int32_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (int32_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (int32_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (int32_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(int32_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((int32_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(int32_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((int32_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((int32_t) 1) << (sizeof(int32_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (int32_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int32_t");
    return (int32_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int32_t");
    return (int32_t) -1;
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_int64_t(int64_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int64_t neg_one = (int64_t) -1, const_zero = (int64_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int64_t) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int64_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(int64_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int64_t) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(int64_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(int64_t),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int64_t));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_char(char value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(char) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(char) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(char) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(char) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(char) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(char),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(char));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyLong_From_uint16_t(uint16_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint16_t neg_one = (uint16_t) -1, const_zero = (uint16_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(uint16_t) < sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint16_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#if !CYTHON_COMPILING_IN_PYPY
        } else if (sizeof(uint16_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(uint16_t) <= sizeof(long)) {
            return PyLong_FromLong((long) value);
        } else if (sizeof(uint16_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d00A4
        if (is_unsigned) {
            return PyLong_FromUnsignedNativeBytes(bytes, sizeof(value), -1);
        } else {
            return PyLong_FromNativeBytes(bytes, sizeof(value), -1);
        }
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        int one = 1; int little = (int)*(unsigned char *)&one;
        return _PyLong_FromByteArray(bytes, sizeof(uint16_t),
                                     little, !is_unsigned);
#else
        int one = 1; int little = (int)*(unsigned char *)&one;
        PyObject *from_bytes, *result = NULL, *kwds = NULL;
        PyObject *py_bytes = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(uint16_t));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        {
            PyObject *args[3+(CYTHON_VECTORCALL ? 1 : 0)] = { NULL, py_bytes, order_str };
            if (!is_unsigned) {
                kwds = __Pyx_MakeVectorcallBuilderKwds(1);
                if (!kwds) goto limited_bad;
                if (__Pyx_VectorcallBuilder_AddArgStr("signed", __Pyx_NewRef(Py_True), kwds, args+3, 0) < 0) goto limited_bad;
            }
            result = __Pyx_Object_Vectorcall_CallFromBuilder(from_bytes, args+1, 2 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET, kwds);
        }
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
static CYTHON_INLINE uint16_t __Pyx_PyLong_As_uint16_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const uint16_t neg_one = (uint16_t) -1, const_zero = (uint16_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        uint16_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (uint16_t) -1;
        val = __Pyx_PyLong_As_uint16_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint16_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(uint16_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) >= 2 * PyLong_SHIFT)) {
                            return (uint16_t) (((((uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint16_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) >= 3 * PyLong_SHIFT)) {
                            return (uint16_t) (((((((uint16_t)digits[2]) << PyLong_SHIFT) | (uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint16_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) >= 4 * PyLong_SHIFT)) {
                            return (uint16_t) (((((((((uint16_t)digits[3]) << PyLong_SHIFT) | (uint16_t)digits[2]) << PyLong_SHIFT) | (uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (uint16_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(uint16_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint16_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(uint16_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint16_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(uint16_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(uint16_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint16_t) (((uint16_t)-1)*(((((uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(uint16_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (uint16_t) ((((((uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(uint16_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint16_t) (((uint16_t)-1)*(((((((uint16_t)digits[2]) << PyLong_SHIFT) | (uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(uint16_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (uint16_t) ((((((((uint16_t)digits[2]) << PyLong_SHIFT) | (uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(uint16_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint16_t) (((uint16_t)-1)*(((((((((uint16_t)digits[3]) << PyLong_SHIFT) | (uint16_t)digits[2]) << PyLong_SHIFT) | (uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(uint16_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(uint16_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(uint16_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (uint16_t) ((((((((((uint16_t)digits[3]) << PyLong_SHIFT) | (uint16_t)digits[2]) << PyLong_SHIFT) | (uint16_t)digits[1]) << PyLong_SHIFT) | (uint16_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(uint16_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint16_t, long, PyLong_AsLong(x))
        } else if ((sizeof(uint16_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(uint16_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        uint16_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (uint16_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (uint16_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (uint16_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (uint16_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(uint16_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((uint16_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(uint16_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((uint16_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((uint16_t) 1) << (sizeof(uint16_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (uint16_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to uint16_t");
    return (uint16_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to uint16_t");
    return (uint16_t) -1;
}

/* CIntFromPy */
static CYTHON_INLINE size_t __Pyx_PyLong_As_size_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const size_t neg_one = (size_t) -1, const_zero = (size_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (unlikely(!PyLong_Check(x))) {
        size_t val;
        PyObject *tmp = __Pyx_PyNumber_Long(x);
        if (!tmp) return (size_t) -1;
        val = __Pyx_PyLong_As_size_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
    if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
        if (unlikely(__Pyx_PyLong_IsNeg(x))) {
            goto raise_neg_overflow;
        } else if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_DigitCount(x)) {
                case 2:
                    if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 2 * PyLong_SHIFT)) {
                            return (size_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 3 * PyLong_SHIFT)) {
                            return (size_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) >= 4 * PyLong_SHIFT)) {
                            return (size_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
                        }
                    }
                    break;
            }
        }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
        if (unlikely(Py_SIZE(x) < 0)) {
            goto raise_neg_overflow;
        }
#else
        {
            int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
            if (unlikely(result < 0))
                return (size_t) -1;
            if (unlikely(result == 1))
                goto raise_neg_overflow;
        }
#endif
        if ((sizeof(size_t) <= sizeof(unsigned long))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned long, PyLong_AsUnsignedLong(x))
        } else if ((sizeof(size_t) <= sizeof(unsigned PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
        }
    } else {
#if CYTHON_USE_PYLONG_INTERNALS
        if (__Pyx_PyLong_IsCompact(x)) {
            __PYX_VERIFY_RETURN_INT(size_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
        } else {
            const digit* digits = __Pyx_PyLong_Digits(x);
            assert(__Pyx_PyLong_DigitCount(x) > 1);
            switch (__Pyx_PyLong_SignedDigitCount(x)) {
                case -2:
                    if ((8 * sizeof(size_t) - 1 > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if ((8 * sizeof(size_t) > 1 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                            return (size_t) ((((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if ((8 * sizeof(size_t) - 1 > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if ((8 * sizeof(size_t) > 2 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                            return (size_t) ((((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if ((8 * sizeof(size_t) - 1 > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (size_t) (((size_t)-1)*(((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if ((8 * sizeof(size_t) > 3 * PyLong_SHIFT)) {
                        if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                            __PYX_VERIFY_RETURN_INT(size_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if ((8 * sizeof(size_t) - 1 > 4 * PyLong_SHIFT)) {
                            return (size_t) ((((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0])));
                        }
                    }
                    break;
            }
        }
#endif
        if ((sizeof(size_t) <= sizeof(long))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, long, PyLong_AsLong(x))
        } else if ((sizeof(size_t) <= sizeof(PY_LONG_LONG))) {
            __PYX_VERIFY_RETURN_INT_EXC(size_t, PY_LONG_LONG, PyLong_AsLongLong(x))
        }
    }
    {
        size_t val;
        int ret = -1;
#if PY_VERSION_HEX >= 0x030d00A6 && !CYTHON_COMPILING_IN_LIMITED_API
        Py_ssize_t bytes_copied = PyLong_AsNativeBytes(
            x, &val, sizeof(val), Py_ASNATIVEBYTES_NATIVE_ENDIAN | (is_unsigned ? Py_ASNATIVEBYTES_UNSIGNED_BUFFER | Py_ASNATIVEBYTES_REJECT_NEGATIVE : 0));
        if (unlikely(bytes_copied == -1)) {
        } else if (unlikely(bytes_copied > (Py_ssize_t) sizeof(val))) {
            goto raise_overflow;
        } else {
            ret = 0;
        }
#elif PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
        int one = 1; int is_little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        ret = _PyLong_AsByteArray((PyLongObject *)x,
                                    bytes, sizeof(val),
                                    is_little, !is_unsigned);
#else
        PyObject *v;
        PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
        int bits, remaining_bits, is_negative = 0;
        int chunk_size = (sizeof(long) < 8) ? 30 : 62;
        if (likely(PyLong_CheckExact(x))) {
            v = __Pyx_NewRef(x);
        } else {
            v = PyNumber_Long(x);
            if (unlikely(!v)) return (size_t) -1;
            assert(PyLong_CheckExact(v));
        }
        {
            int result = PyObject_RichCompareBool(v, Py_False, Py_LT);
            if (unlikely(result < 0)) {
                Py_DECREF(v);
                return (size_t) -1;
            }
            is_negative = result == 1;
        }
        if (is_unsigned && unlikely(is_negative)) {
            Py_DECREF(v);
            goto raise_neg_overflow;
        } else if (is_negative) {
            stepval = PyNumber_Invert(v);
            Py_DECREF(v);
            if (unlikely(!stepval))
                return (size_t) -1;
        } else {
            stepval = v;
        }
        v = NULL;
        val = (size_t) 0;
        mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
        shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
        for (bits = 0; bits < (int) sizeof(size_t) * 8 - chunk_size; bits += chunk_size) {
            PyObject *tmp, *digit;
            long idigit;
            digit = PyNumber_And(stepval, mask);
            if (unlikely(!digit)) goto done;
            idigit = PyLong_AsLong(digit);
            Py_DECREF(digit);
            if (unlikely(idigit < 0)) goto done;
            val |= ((size_t) idigit) << bits;
            tmp = PyNumber_Rshift(stepval, shift);
            if (unlikely(!tmp)) goto done;
            Py_DECREF(stepval); stepval = tmp;
        }
        Py_DECREF(shift); shift = NULL;
        Py_DECREF(mask); mask = NULL;
        {
            long idigit = PyLong_AsLong(stepval);
            if (unlikely(idigit < 0)) goto done;
            remaining_bits = ((int) sizeof(size_t) * 8) - bits - (is_unsigned ? 0 : 1);
            if (unlikely(idigit >= (1L << remaining_bits)))
                goto raise_overflow;
            val |= ((size_t) idigit) << bits;
        }
        if (!is_unsigned) {
            if (unlikely(val & (((size_t) 1) << (sizeof(size_t) * 8 - 1))))
                goto raise_overflow;
            if (is_negative)
                val = ~val;
        }
        ret = 0;
    done:
        Py_XDECREF(shift);
        Py_XDECREF(mask);
        Py_XDECREF(stepval);
#endif
        if (unlikely(ret))
            return (size_t) -1;
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to size_t");
    return (size_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to size_t");
    return (size_t) -1;
}

/* UpdateUnpickledDict */
static int __Pyx__UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    PyObject *state_dict = __Pyx_PySequence_ITEM(state, index);
    if (unlikely(!state_dict)) {
        return -1;
    }
    int non_empty = PyObject_IsTrue(state_dict);
    if (non_empty == 0) {
        Py_DECREF(state_dict);
        return 0;
    } else if (unlikely(non_empty == -1)) {
        return -1;
    }
    PyObject *dict;
    #if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030A0000
    dict = PyObject_GetAttrString(obj, "__dict__");
    #else
    dict = PyObject_GenericGetDict(obj, NULL);
    #endif
    if (unlikely(!dict)) {
        Py_DECREF(state_dict);
        return -1;
    }
    int result;
    if (likely(PyDict_CheckExact(dict))) {
        result = PyDict_Update(dict, state_dict);
    } else {
        PyObject *obj_result = __Pyx_PyObject_CallMethod1(dict, __pyx_mstate_global->__pyx_n_u_update, state_dict);
        if (likely(obj_result)) {
            Py_DECREF(obj_result);
            result = 0;
        } else {
            result = -1;
        }
    }
    Py_DECREF(state_dict);
    Py_DECREF(dict);
    return result;
}
static int __Pyx_UpdateUnpickledDict(PyObject *obj, PyObject *state, Py_ssize_t index) {
    Py_ssize_t state_size = __Pyx_PyTuple_GET_SIZE(state);
    #if !CYTHON_ASSUME_SAFE_SIZE
    if (unlikely(state_size == -1)) return -1;
    #endif
    if (state_size <= index) {
        return 0;
    }
    return __Pyx__UpdateUnpickledDict(obj, state, index);
}

/* FormatTypeName */
#if CYTHON_COMPILING_IN_LIMITED_API && __PYX_LIMITED_VERSION_HEX < 0x030d0000
static __Pyx_TypeName
__Pyx_PyType_GetFullyQualifiedName(PyTypeObject* tp)
{
    PyObject *module = NULL, *name = NULL, *result = NULL;
    #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
    name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_qualname);
    #else
    name = PyType_GetQualName(tp);
    #endif
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) goto bad;
    module = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_mstate_global->__pyx_n_u_module);
    if (unlikely(module == NULL) || unlikely(!PyUnicode_Check(module))) goto bad;
    if (PyUnicode_CompareWithASCIIString(module, "builtins") == 0) {
        result = name;
        name = NULL;
        goto done;
    }
    result = PyUnicode_FromFormat("%U.%U", module, name);
    if (unlikely(result == NULL)) goto bad;
  done:
    Py_XDECREF(name);
    Py_XDECREF(module);
    return result;
  bad:
    PyErr_Clear();
    if (name) {
        result = name;
        name = NULL;
    } else {
        result = __Pyx_NewRef(__pyx_mstate_global->__pyx_kp_u__11);
    }
    goto done;
}
#endif

/* GetRuntimeVersion */
#if __PYX_LIMITED_VERSION_HEX < 0x030b0000
void __Pyx_init_runtime_version(void) {
    if (__Pyx_cached_runtime_version == 0) {
        const char* rt_version = Py_GetVersion();
        unsigned long version = 0;
        unsigned long factor = 0x01000000UL;
        unsigned int digit = 0;
        int i = 0;
        while (factor) {
            while ('0' <= rt_version[i] && rt_version[i] <= '9') {
                digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
                ++i;
            }
            version += factor * digit;
            if (rt_version[i] != '.')
                break;
            digit = 0;
            factor >>= 8;
            ++i;
        }
        __Pyx_cached_runtime_version = version;
    }
}
#endif
static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
    return Py_Version & ~0xFFUL;
#else
    return __Pyx_cached_runtime_version;
#endif
}

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* NewCodeObj */
#if CYTHON_COMPILING_IN_LIMITED_API
    static PyObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                       PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                       PyObject *fv, PyObject *cell, PyObject* fn,
                                       PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030b0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030b0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOOOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
#elif PY_VERSION_HEX >= 0x030B0000
  static PyCodeObject* __Pyx__PyCode_New(int a, int p, int k, int l, int s, int f,
                                         PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                         PyObject *fv, PyObject *cell, PyObject* fn,
                                         PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, __pyx_mstate_global->__pyx_empty_bytes);
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030c00A1
    if (likely(result))
        result->_co_firsttraceable = 0;
    #endif
    return result;
  }
#elif !CYTHON_COMPILING_IN_PYPY
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx__PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
static PyObject* __Pyx_PyCode_New(
        const __Pyx_PyCode_New_function_description descr,
        PyObject * const *varnames,
        PyObject *filename,
        PyObject *funcname,
        PyObject *line_table,
        PyObject *tuple_dedup_map
) {
    PyObject *code_obj = NULL, *varnames_tuple_dedup = NULL, *code_bytes = NULL;
    Py_ssize_t var_count = (Py_ssize_t) descr.nlocals;
    PyObject *varnames_tuple = PyTuple_New(var_count);
    if (unlikely(!varnames_tuple)) return NULL;
    for (Py_ssize_t i=0; i < var_count; i++) {
        Py_INCREF(varnames[i]);
        if (__Pyx_PyTuple_SET_ITEM(varnames_tuple, i, varnames[i]) != (0)) goto done;
    }
    #if CYTHON_COMPILING_IN_LIMITED_API
    varnames_tuple_dedup = PyDict_GetItem(tuple_dedup_map, varnames_tuple);
    if (!varnames_tuple_dedup) {
        if (unlikely(PyDict_SetItem(tuple_dedup_map, varnames_tuple, varnames_tuple) < 0)) goto done;
        varnames_tuple_dedup = varnames_tuple;
    }
    #else
    varnames_tuple_dedup = PyDict_SetDefault(tuple_dedup_map, varnames_tuple, varnames_tuple);
    if (unlikely(!varnames_tuple_dedup)) goto done;
    #endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(varnames_tuple_dedup);
    #endif
    if (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table != NULL && !CYTHON_COMPILING_IN_GRAAL) {
        Py_ssize_t line_table_length = __Pyx_PyBytes_GET_SIZE(line_table);
        #if !CYTHON_ASSUME_SAFE_SIZE
        if (unlikely(line_table_length == -1)) goto done;
        #endif
        Py_ssize_t code_len = (line_table_length * 2 + 4) & ~3LL;
        code_bytes = PyBytes_FromStringAndSize(NULL, code_len);
        if (unlikely(!code_bytes)) goto done;
        char* c_code_bytes = PyBytes_AsString(code_bytes);
        if (unlikely(!c_code_bytes)) goto done;
        memset(c_code_bytes, 0, (size_t) code_len);
    }
    code_obj = (PyObject*) __Pyx__PyCode_New(
        (int) descr.argcount,
        (int) descr.num_posonly_args,
        (int) descr.num_kwonly_args,
        (int) descr.nlocals,
        0,
        (int) descr.flags,
        code_bytes ? code_bytes : __pyx_mstate_global->__pyx_empty_bytes,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        varnames_tuple_dedup,
        __pyx_mstate_global->__pyx_empty_tuple,
        __pyx_mstate_global->__pyx_empty_tuple,
        filename,
        funcname,
        (int) descr.first_line,
        (__PYX_LIMITED_VERSION_HEX >= (0x030b0000) && line_table) ? line_table : __pyx_mstate_global->__pyx_empty_bytes
    );
done:
    Py_XDECREF(code_bytes);
    #if CYTHON_AVOID_BORROWED_REFS
    Py_XDECREF(varnames_tuple_dedup);
    #endif
    Py_DECREF(varnames_tuple);
    return code_obj;
}

/* DecompressString */
static PyObject *__Pyx_DecompressString(const char *s, Py_ssize_t length, int algo) {
    PyObject *module = NULL, *decompress, *compressed_bytes, *decompressed;
    const char* module_name = algo == 3 ? "compression.zstd" : algo == 2 ? "bz2" : "zlib";
    PyObject *methodname = PyUnicode_FromString("decompress");
    if (unlikely(!methodname)) return NULL;
    #if __PYX_LIMITED_VERSION_HEX >= 0x030e0000
    if (algo == 3) {
        PyObject *fromlist = Py_BuildValue("[O]", methodname);
        if (unlikely(!fromlist)) goto bad;
        module = PyImport_ImportModuleLevel("compression.zstd", NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
    } else
    #endif
        module = PyImport_ImportModule(module_name);
    if (unlikely(!module)) goto import_failed;
    decompress = PyObject_GetAttr(module, methodname);
    if (unlikely(!decompress)) goto import_failed;
    {
        #ifdef __cplusplus
            char *memview_bytes = const_cast<char*>(s);
        #else
            #if defined(__clang__)
              #pragma clang diagnostic push
              #pragma clang diagnostic ignored "-Wcast-qual"
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic push
              #pragma GCC diagnostic ignored "-Wcast-qual"
            #endif
            char *memview_bytes = (char*) s;
            #if defined(__clang__)
              #pragma clang diagnostic pop
            #elif !defined(__INTEL_COMPILER) && defined(__GNUC__)
              #pragma GCC diagnostic pop
            #endif
        #endif
        #if CYTHON_COMPILING_IN_LIMITED_API && !defined(PyBUF_READ)
        int memview_flags = 0x100;
        #else
        int memview_flags = PyBUF_READ;
        #endif
        compressed_bytes = PyMemoryView_FromMemory(memview_bytes, length, memview_flags);
    }
    if (unlikely(!compressed_bytes)) {
        Py_DECREF(decompress);
        goto bad;
    }
    decompressed = PyObject_CallFunctionObjArgs(decompress, compressed_bytes, NULL);
    Py_DECREF(compressed_bytes);
    Py_DECREF(decompress);
    Py_DECREF(module);
    Py_DECREF(methodname);
    return decompressed;
import_failed:
    PyErr_Format(PyExc_ImportError,
        "Failed to import '%.20s.decompress' - cannot initialise module strings. "
        "String compression was configured with the C macro 'CYTHON_COMPRESS_STRINGS=%d'.",
        module_name, algo);
bad:
    Py_XDECREF(module);
    Py_DECREF(methodname);
    return NULL;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    {
        const char* result;
        Py_ssize_t unicode_length;
        CYTHON_MAYBE_UNUSED_VAR(unicode_length); // only for __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        #if __PYX_LIMITED_VERSION_HEX < 0x030A0000
        if (unlikely(PyArg_Parse(o, "s#", &result, length) < 0)) return NULL;
        #else
        result = PyUnicode_AsUTF8AndSize(o, length);
        #endif
        #if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        unicode_length = PyUnicode_GetLength(o);
        if (unlikely(unicode_length < 0)) return NULL;
        if (unlikely(unicode_length != *length)) {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
        #endif
        return result;
    }
#else
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
}
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_UTF8
    if (PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
    if (PyByteArray_Check(o)) {
#if (CYTHON_ASSUME_SAFE_SIZE && CYTHON_ASSUME_SAFE_MACROS) || (CYTHON_COMPILING_IN_PYPY && (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE)))
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
#else
        *length = PyByteArray_Size(o);
        if (*length == -1) return NULL;
        return PyByteArray_AsString(o);
#endif
    } else
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_LongWrongResultType(PyObject* result) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetFullyQualifiedName(Py_TYPE(result));
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
    PyErr_Format(PyExc_TypeError,
                 "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ")",
                 result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Long(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  PyObject *res = NULL;
  if (likely(PyLong_Check(x)))
      return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  if (likely(m && m->nb_int)) {
      res = m->nb_int(x);
  }
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
      res = PyNumber_Long(x);
  }
#endif
  if (likely(res)) {
      if (unlikely(!PyLong_CheckExact(res))) {
          return __Pyx_PyNumber_LongWrongResultType(res);
      }
  }
  else if (!PyErr_Occurred()) {
      PyErr_SetString(PyExc_TypeError,
                      "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyLong_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyLong_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject *__Pyx_Owned_Py_None(int b) {
    CYTHON_UNUSED_VAR(b);
    return __Pyx_NewRef(Py_None);
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return __Pyx_NewRef(b ? Py_True: Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyLong_FromSize_t(size_t ival) {
    return PyLong_FromSize_t(ival);
}


/* MultiPhaseInitModuleState */
#if CYTHON_PEP489_MULTI_PHASE_INIT && CYTHON_USE_MODULE_STATE
#ifndef CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#if (CYTHON_COMPILING_IN_LIMITED_API || PY_VERSION_HEX >= 0x030C0000)
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 1
#else
  #define CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE 0
#endif
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE && !CYTHON_ATOMICS
#error "Module state with PEP489 requires atomics. Currently that's one of\
 C11, C++11, gcc atomic intrinsics or MSVC atomic intrinsics"
#endif
#if !CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
#define __Pyx_ModuleStateLookup_Lock()
#define __Pyx_ModuleStateLookup_Unlock()
#elif !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX >= 0x030d0000
static PyMutex __Pyx_ModuleStateLookup_mutex = {0};
#define __Pyx_ModuleStateLookup_Lock() PyMutex_Lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() PyMutex_Unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(__cplusplus) && __cplusplus >= 201103L
#include <mutex>
static std::mutex __Pyx_ModuleStateLookup_mutex;
#define __Pyx_ModuleStateLookup_Lock() __Pyx_ModuleStateLookup_mutex.lock()
#define __Pyx_ModuleStateLookup_Unlock() __Pyx_ModuleStateLookup_mutex.unlock()
#elif defined(__STDC_VERSION__) && (__STDC_VERSION__ > 201112L) && !defined(__STDC_NO_THREADS__)
#include <threads.h>
static mtx_t __Pyx_ModuleStateLookup_mutex;
static once_flag __Pyx_ModuleStateLookup_mutex_once_flag = ONCE_FLAG_INIT;
static void __Pyx_ModuleStateLookup_initialize_mutex(void) {
    mtx_init(&__Pyx_ModuleStateLookup_mutex, mtx_plain);
}
#define __Pyx_ModuleStateLookup_Lock()\
  call_once(&__Pyx_ModuleStateLookup_mutex_once_flag, __Pyx_ModuleStateLookup_initialize_mutex);\
  mtx_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() mtx_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(HAVE_PTHREAD_H)
#include <pthread.h>
static pthread_mutex_t __Pyx_ModuleStateLookup_mutex = PTHREAD_MUTEX_INITIALIZER;
#define __Pyx_ModuleStateLookup_Lock() pthread_mutex_lock(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() pthread_mutex_unlock(&__Pyx_ModuleStateLookup_mutex)
#elif defined(_WIN32)
#include <Windows.h>  // synchapi.h on its own doesn't work
static SRWLOCK __Pyx_ModuleStateLookup_mutex = SRWLOCK_INIT;
#define __Pyx_ModuleStateLookup_Lock() AcquireSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#define __Pyx_ModuleStateLookup_Unlock() ReleaseSRWLockExclusive(&__Pyx_ModuleStateLookup_mutex)
#else
#error "No suitable lock available for CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE.\
 Requires C standard >= C11, or C++ standard >= C++11,\
 or pthreads, or the Windows 32 API, or Python >= 3.13."
#endif
typedef struct {
    int64_t id;
    PyObject *module;
} __Pyx_InterpreterIdAndModule;
typedef struct {
    char interpreter_id_as_index;
    Py_ssize_t count;
    Py_ssize_t allocated;
    __Pyx_InterpreterIdAndModule table[1];
} __Pyx_ModuleStateLookupData;
#define __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE 32
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_int_type __Pyx_ModuleStateLookup_read_counter = 0;
#endif
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static __pyx_atomic_ptr_type __Pyx_ModuleStateLookup_data = 0;
#else
static __Pyx_ModuleStateLookupData* __Pyx_ModuleStateLookup_data = NULL;
#endif
static __Pyx_InterpreterIdAndModule* __Pyx_State_FindModuleStateLookupTableLowerBound(
        __Pyx_InterpreterIdAndModule* table,
        Py_ssize_t count,
        int64_t interpreterId) {
    __Pyx_InterpreterIdAndModule* begin = table;
    __Pyx_InterpreterIdAndModule* end = begin + count;
    if (begin->id == interpreterId) {
        return begin;
    }
    while ((end - begin) > __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
        __Pyx_InterpreterIdAndModule* halfway = begin + (end - begin)/2;
        if (halfway->id == interpreterId) {
            return halfway;
        }
        if (halfway->id < interpreterId) {
            begin = halfway;
        } else {
            end = halfway;
        }
    }
    for (; begin < end; ++begin) {
        if (begin->id >= interpreterId) return begin;
    }
    return begin;
}
static PyObject *__Pyx_State_FindModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return NULL;
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData* data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
    {
        __pyx_atomic_incr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        if (likely(data)) {
            __Pyx_ModuleStateLookupData* new_data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_acquire(&__Pyx_ModuleStateLookup_data);
            if (likely(data == new_data)) {
                goto read_finished;
            }
        }
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
        __Pyx_ModuleStateLookup_Lock();
        __pyx_atomic_incr_relaxed(&__Pyx_ModuleStateLookup_read_counter);
        data = (__Pyx_ModuleStateLookupData*)__pyx_atomic_pointer_load_relaxed(&__Pyx_ModuleStateLookup_data);
        __Pyx_ModuleStateLookup_Unlock();
    }
  read_finished:;
#else
    __Pyx_ModuleStateLookupData* data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_InterpreterIdAndModule* found = NULL;
    if (unlikely(!data)) goto end;
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            found = data->table+interpreter_id;
        }
    } else {
        found = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
    }
  end:
    {
        PyObject *result=NULL;
        if (found && found->id == interpreter_id) {
            result = found->module;
        }
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
        __pyx_atomic_decr_acq_rel(&__Pyx_ModuleStateLookup_read_counter);
#endif
        return result;
    }
}
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
static void __Pyx_ModuleStateLookup_wait_until_no_readers(void) {
    while (__pyx_atomic_load(&__Pyx_ModuleStateLookup_read_counter) != 0);
}
#else
#define __Pyx_ModuleStateLookup_wait_until_no_readers()
#endif
static int __Pyx_State_AddModuleInterpIdAsIndex(__Pyx_ModuleStateLookupData **old_data, PyObject* module, int64_t interpreter_id) {
    Py_ssize_t to_allocate = (*old_data)->allocated;
    while (to_allocate <= interpreter_id) {
        if (to_allocate == 0) to_allocate = 1;
        else to_allocate *= 2;
    }
    __Pyx_ModuleStateLookupData *new_data = *old_data;
    if (to_allocate != (*old_data)->allocated) {
         new_data = (__Pyx_ModuleStateLookupData *)realloc(
            *old_data,
            sizeof(__Pyx_ModuleStateLookupData)+(to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
        if (!new_data) {
            PyErr_NoMemory();
            return -1;
        }
        for (Py_ssize_t i = new_data->allocated; i < to_allocate; ++i) {
            new_data->table[i].id = i;
            new_data->table[i].module = NULL;
        }
        new_data->allocated = to_allocate;
    }
    new_data->table[interpreter_id].module = module;
    if (new_data->count < interpreter_id+1) {
        new_data->count = interpreter_id+1;
    }
    *old_data = new_data;
    return 0;
}
static void __Pyx_State_ConvertFromInterpIdAsIndex(__Pyx_ModuleStateLookupData *data) {
    __Pyx_InterpreterIdAndModule *read = data->table;
    __Pyx_InterpreterIdAndModule *write = data->table;
    __Pyx_InterpreterIdAndModule *end = read + data->count;
    for (; read<end; ++read) {
        if (read->module) {
            write->id = read->id;
            write->module = read->module;
            ++write;
        }
    }
    data->count = write - data->table;
    for (; write<end; ++write) {
        write->id = 0;
        write->module = NULL;
    }
    data->interpreter_id_as_index = 0;
}
static int __Pyx_State_AddModule(PyObject* module, CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    int result = 0;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *old_data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *old_data = __Pyx_ModuleStateLookup_data;
#endif
    __Pyx_ModuleStateLookupData *new_data = old_data;
    if (!new_data) {
        new_data = (__Pyx_ModuleStateLookupData *)calloc(1, sizeof(__Pyx_ModuleStateLookupData));
        if (!new_data) {
            result = -1;
            PyErr_NoMemory();
            goto end;
        }
        new_data->allocated = 1;
        new_data->interpreter_id_as_index = 1;
    }
    __Pyx_ModuleStateLookup_wait_until_no_readers();
    if (new_data->interpreter_id_as_index) {
        if (interpreter_id < __PYX_MODULE_STATE_LOOKUP_SMALL_SIZE) {
            result = __Pyx_State_AddModuleInterpIdAsIndex(&new_data, module, interpreter_id);
            goto end;
        }
        __Pyx_State_ConvertFromInterpIdAsIndex(new_data);
    }
    {
        Py_ssize_t insert_at = 0;
        {
            __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
                new_data->table, new_data->count, interpreter_id);
            assert(lower_bound);
            insert_at = lower_bound - new_data->table;
            if (unlikely(insert_at < new_data->count && lower_bound->id == interpreter_id)) {
                lower_bound->module = module;
                goto end;  // already in table, nothing more to do
            }
        }
        if (new_data->count+1 >= new_data->allocated) {
            Py_ssize_t to_allocate = (new_data->count+1)*2;
            new_data =
                (__Pyx_ModuleStateLookupData*)realloc(
                    new_data,
                    sizeof(__Pyx_ModuleStateLookupData) +
                    (to_allocate-1)*sizeof(__Pyx_InterpreterIdAndModule));
            if (!new_data) {
                result = -1;
                new_data = old_data;
                PyErr_NoMemory();
                goto end;
            }
            new_data->allocated = to_allocate;
        }
        ++new_data->count;
        int64_t last_id = interpreter_id;
        PyObject *last_module = module;
        for (Py_ssize_t i=insert_at; i<new_data->count; ++i) {
            int64_t current_id = new_data->table[i].id;
            new_data->table[i].id = last_id;
            last_id = current_id;
            PyObject *current_module = new_data->table[i].module;
            new_data->table[i].module = last_module;
            last_module = current_module;
        }
    }
  end:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, new_data);
#else
    __Pyx_ModuleStateLookup_data = new_data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return result;
}
static int __Pyx_State_RemoveModule(CYTHON_UNUSED void* dummy) {
    int64_t interpreter_id = PyInterpreterState_GetID(__Pyx_PyInterpreterState_Get());
    if (interpreter_id == -1) return -1;
    __Pyx_ModuleStateLookup_Lock();
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __Pyx_ModuleStateLookupData *data = (__Pyx_ModuleStateLookupData *)
            __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, 0);
#else
    __Pyx_ModuleStateLookupData *data = __Pyx_ModuleStateLookup_data;
#endif
    if (data->interpreter_id_as_index) {
        if (interpreter_id < data->count) {
            data->table[interpreter_id].module = NULL;
        }
        goto done;
    }
    {
        __Pyx_ModuleStateLookup_wait_until_no_readers();
        __Pyx_InterpreterIdAndModule* lower_bound = __Pyx_State_FindModuleStateLookupTableLowerBound(
            data->table, data->count, interpreter_id);
        if (!lower_bound) goto done;
        if (lower_bound->id != interpreter_id) goto done;
        __Pyx_InterpreterIdAndModule *end = data->table+data->count;
        for (;lower_bound<end-1; ++lower_bound) {
            lower_bound->id = (lower_bound+1)->id;
            lower_bound->module = (lower_bound+1)->module;
        }
    }
    --data->count;
    if (data->count == 0) {
        free(data);
        data = NULL;
    }
  done:
#if CYTHON_MODULE_STATE_LOOKUP_THREAD_SAFE
    __pyx_atomic_pointer_exchange(&__Pyx_ModuleStateLookup_data, data);
#else
    __Pyx_ModuleStateLookup_data = data;
#endif
    __Pyx_ModuleStateLookup_Unlock();
    return 0;
}
#endif

/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
